(function(){

if (!window.qx) window.qx = {};

qx.$$start = new Date();

if (!qx.$$environment) qx.$$environment = {};
var envinfo = {"clui.recordUrl":"/api/v1/record","clui.version":"0.3.1","qx.application":"clui.Application","qx.debug":false,"qx.debug.databinding":false,"qx.debug.dispose":false,"qx.debug.io":false,"qx.debug.ui.queue":false,"qx.dynlocale":true,"qx.optimization.basecalls":true,"qx.optimization.comments":true,"qx.optimization.privates":true,"qx.optimization.strings":true,"qx.optimization.variables":true,"qx.optimization.variants":true,"qx.optimization.whitespace":true,"qx.revision":"","qx.theme":"clui.theme.Theme","qx.version":"5.0.3"};
for (var k in envinfo) qx.$$environment[k] = envinfo[k];

if (!qx.$$libraries) qx.$$libraries = {};
var libinfo = {"__out__":{"sourceUri":"script"},"clui":{"resourceUri":"/resource","sourceUri":"script"},"kucken":{"resourceUri":"/resource","sourceUri":"script"},"qx":{"resourceUri":"/resource","sourceUri":"script","sourceViewUri":"https://github.com/qooxdoo/qooxdoo/blob/%{qxGitBranch}/framework/source/class/%{classFilePath}#L%{lineNumber}"}};
for (var k in libinfo) qx.$$libraries[k] = libinfo[k];

qx.$$resources = {};
qx.$$translations = {"C":null,"en":null,"en_GB":null};
qx.$$locales = {"C":null,"en":null,"en_GB":null};
qx.$$packageData = {};
qx.$$g = {}

qx.$$loader = {
  parts : {"boot":[0]},
  packages : {"0":{"uris":["__out__:clui.d30045181d3d.js"]}},
  urisBefore : [],
  cssBefore : ["resource/clui/style/timeline.css"],
  boot : "boot",
  closureParts : {},
  bootIsInline : true,
  addNoCacheParam : false,

  decodeUris : function(compressedUris)
  {
    var libs = qx.$$libraries;
    var uris = [];
    for (var i=0; i<compressedUris.length; i++)
    {
      var uri = compressedUris[i].split(":");
      var euri;
      if (uri.length==2 && uri[0] in libs) {
        var prefix = libs[uri[0]].sourceUri;
        euri = prefix + "/" + uri[1];
      } else {
        euri = compressedUris[i];
      }
      if (qx.$$loader.addNoCacheParam) {
        euri += "?nocache=" + Math.random();
      }
      
      uris.push(euri);
    }
    return uris;
  }
};

var readyStateValue = {"complete" : true};
if (document.documentMode && document.documentMode < 10 ||
    (typeof window.ActiveXObject !== "undefined" && !document.documentMode)) {
  readyStateValue["loaded"] = true;
}

function loadScript(uri, callback) {
  var elem = document.createElement("script");
  elem.charset = "utf-8";
  elem.src = uri;
  elem.onreadystatechange = elem.onload = function() {
    if (!this.readyState || readyStateValue[this.readyState]) {
      elem.onreadystatechange = elem.onload = null;
      if (typeof callback === "function") {
        callback();
      }
    }
  };

  if (isLoadParallel) {
    elem.async = null;
  }

  var head = document.getElementsByTagName("head")[0];
  head.appendChild(elem);
}

function loadCss(uri) {
  var elem = document.createElement("link");
  elem.rel = "stylesheet";
  elem.type= "text/css";
  elem.href= uri;
  var head = document.getElementsByTagName("head")[0];
  head.appendChild(elem);
}

var isWebkit = /AppleWebKit\/([^ ]+)/.test(navigator.userAgent);
var isLoadParallel = 'async' in document.createElement('script');

function loadScriptList(list, callback) {
  if (list.length == 0) {
    callback();
    return;
  }

  var item;

  if (isLoadParallel) {
    while (list.length) {
      item = list.shift();
      if (list.length) {
        loadScript(item);
      } else {
        loadScript(item, callback);
      }
    }
  } else {
    item = list.shift();
    loadScript(item,  function() {
      if (isWebkit) {
        // force async, else Safari fails with a "maximum recursion depth exceeded"
        window.setTimeout(function() {
          loadScriptList(list, callback);
        }, 0);
      } else {
        loadScriptList(list, callback);
      }
    });
  }
}

var fireContentLoadedEvent = function() {
  qx.$$domReady = true;
  document.removeEventListener('DOMContentLoaded', fireContentLoadedEvent, false);
};
if (document.addEventListener) {
  document.addEventListener('DOMContentLoaded', fireContentLoadedEvent, false);
}

qx.$$loader.importPackageData = function (dataMap, callback) {
  if (dataMap["resources"]){
    var resMap = dataMap["resources"];
    for (var k in resMap) qx.$$resources[k] = resMap[k];
  }
  if (dataMap["locales"]){
    var locMap = dataMap["locales"];
    var qxlocs = qx.$$locales;
    for (var lang in locMap){
      if (!qxlocs[lang]) qxlocs[lang] = locMap[lang];
      else
        for (var k in locMap[lang]) qxlocs[lang][k] = locMap[lang][k];
    }
  }
  if (dataMap["translations"]){
    var trMap   = dataMap["translations"];
    var qxtrans = qx.$$translations;
    for (var lang in trMap){
      if (!qxtrans[lang]) qxtrans[lang] = trMap[lang];
      else
        for (var k in trMap[lang]) qxtrans[lang][k] = trMap[lang][k];
    }
  }
  if (callback){
    callback(dataMap);
  }
}

qx.$$loader.signalStartup = function ()
{
  qx.$$loader.scriptLoaded = true;
  if (window.qx && qx.event && qx.event.handler && qx.event.handler.Application) {
    qx.event.handler.Application.onScriptLoaded();
    qx.$$loader.applicationHandlerReady = true;
  } else {
    qx.$$loader.applicationHandlerReady = false;
  }
}

// Load all stuff
qx.$$loader.init = function(){
  var l=qx.$$loader;
  if (l.cssBefore.length>0) {
    for (var i=0, m=l.cssBefore.length; i<m; i++) {
      loadCss(l.cssBefore[i]);
    }
  }
  if (l.urisBefore.length>0){
    loadScriptList(l.urisBefore, function(){
      l.initUris();
    });
  } else {
    l.initUris();
  }
}

// Load qooxdoo boot stuff
qx.$$loader.initUris = function(){
  var l=qx.$$loader;
  var bootPackageHash=l.parts[l.boot][0];
  if (l.bootIsInline){
    l.importPackageData(qx.$$packageData[bootPackageHash]);
    l.signalStartup();
  } else {
    loadScriptList(l.decodeUris(l.packages[l.parts[l.boot][0]].uris), function(){
      // Opera needs this extra time to parse the scripts
      window.setTimeout(function(){
        l.importPackageData(qx.$$packageData[bootPackageHash] || {});
        l.signalStartup();
      }, 0);
    });
  }
}
})();

qx.$$packageData['0']={"locales":{"C":{"alternateQuotationEnd":"’","alternateQuotationStart":"‘","cldr_am":"AM","cldr_date_format_full":"EEEE, MMMM d, y","cldr_date_format_long":"MMMM d, y","cldr_date_format_medium":"MMM d, y","cldr_date_format_short":"M/d/yy","cldr_date_time_format_EHm":"E HH:mm","cldr_date_time_format_EHms":"E HH:mm:ss","cldr_date_time_format_Ed":"d E","cldr_date_time_format_Ehm":"E h:mm a","cldr_date_time_format_Ehms":"E h:mm:ss a","cldr_date_time_format_Gy":"y G","cldr_date_time_format_GyMMM":"MMM y G","cldr_date_time_format_GyMMMEd":"E, MMM d, y G","cldr_date_time_format_GyMMMd":"MMM d, y G","cldr_date_time_format_H":"HH","cldr_date_time_format_Hm":"HH:mm","cldr_date_time_format_Hms":"HH:mm:ss","cldr_date_time_format_M":"L","cldr_date_time_format_MEd":"E, M/d","cldr_date_time_format_MMM":"LLL","cldr_date_time_format_MMMEd":"E, MMM d","cldr_date_time_format_MMMd":"MMM d","cldr_date_time_format_Md":"M/d","cldr_date_time_format_d":"d","cldr_date_time_format_h":"h a","cldr_date_time_format_hm":"h:mm a","cldr_date_time_format_hms":"h:mm:ss a","cldr_date_time_format_ms":"mm:ss","cldr_date_time_format_y":"y","cldr_date_time_format_yM":"M/y","cldr_date_time_format_yMEd":"E, M/d/y","cldr_date_time_format_yMMM":"MMM y","cldr_date_time_format_yMMMEd":"E, MMM d, y","cldr_date_time_format_yMMMd":"MMM d, y","cldr_date_time_format_yMd":"M/d/y","cldr_date_time_format_yQQQ":"QQQ y","cldr_date_time_format_yQQQQ":"QQQQ y","cldr_day_format_abbreviated_fri":"Fri","cldr_day_format_abbreviated_mon":"Mon","cldr_day_format_abbreviated_sat":"Sat","cldr_day_format_abbreviated_sun":"Sun","cldr_day_format_abbreviated_thu":"Thu","cldr_day_format_abbreviated_tue":"Tue","cldr_day_format_abbreviated_wed":"Wed","cldr_day_format_short_fri":"Fr","cldr_day_format_short_mon":"Mo","cldr_day_format_short_sat":"Sa","cldr_day_format_short_sun":"Su","cldr_day_format_short_thu":"Th","cldr_day_format_short_tue":"Tu","cldr_day_format_short_wed":"We","cldr_day_format_wide_fri":"Friday","cldr_day_format_wide_mon":"Monday","cldr_day_format_wide_sat":"Saturday","cldr_day_format_wide_sun":"Sunday","cldr_day_format_wide_thu":"Thursday","cldr_day_format_wide_tue":"Tuesday","cldr_day_format_wide_wed":"Wednesday","cldr_day_stand-alone_narrow_fri":"F","cldr_day_stand-alone_narrow_mon":"M","cldr_day_stand-alone_narrow_sat":"S","cldr_day_stand-alone_narrow_sun":"S","cldr_day_stand-alone_narrow_thu":"T","cldr_day_stand-alone_narrow_tue":"T","cldr_day_stand-alone_narrow_wed":"W","cldr_month_format_abbreviated_1":"Jan","cldr_month_format_abbreviated_10":"Oct","cldr_month_format_abbreviated_11":"Nov","cldr_month_format_abbreviated_12":"Dec","cldr_month_format_abbreviated_2":"Feb","cldr_month_format_abbreviated_3":"Mar","cldr_month_format_abbreviated_4":"Apr","cldr_month_format_abbreviated_5":"May","cldr_month_format_abbreviated_6":"Jun","cldr_month_format_abbreviated_7":"Jul","cldr_month_format_abbreviated_8":"Aug","cldr_month_format_abbreviated_9":"Sep","cldr_month_format_wide_1":"January","cldr_month_format_wide_10":"October","cldr_month_format_wide_11":"November","cldr_month_format_wide_12":"December","cldr_month_format_wide_2":"February","cldr_month_format_wide_3":"March","cldr_month_format_wide_4":"April","cldr_month_format_wide_5":"May","cldr_month_format_wide_6":"June","cldr_month_format_wide_7":"July","cldr_month_format_wide_8":"August","cldr_month_format_wide_9":"September","cldr_month_stand-alone_narrow_1":"J","cldr_month_stand-alone_narrow_10":"O","cldr_month_stand-alone_narrow_11":"N","cldr_month_stand-alone_narrow_12":"D","cldr_month_stand-alone_narrow_2":"F","cldr_month_stand-alone_narrow_3":"M","cldr_month_stand-alone_narrow_4":"A","cldr_month_stand-alone_narrow_5":"M","cldr_month_stand-alone_narrow_6":"J","cldr_month_stand-alone_narrow_7":"J","cldr_month_stand-alone_narrow_8":"A","cldr_month_stand-alone_narrow_9":"S","cldr_number_decimal_separator":".","cldr_number_group_separator":",","cldr_number_percent_format":"#,##0%","cldr_pm":"PM","cldr_time_format_full":"h:mm:ss a zzzz","cldr_time_format_long":"h:mm:ss a z","cldr_time_format_medium":"h:mm:ss a","cldr_time_format_short":"h:mm a","quotationEnd":"”","quotationStart":"“"},"en":{"alternateQuotationEnd":"’","alternateQuotationStart":"‘","cldr_am":"AM","cldr_date_format_full":"EEEE, MMMM d, y","cldr_date_format_long":"MMMM d, y","cldr_date_format_medium":"MMM d, y","cldr_date_format_short":"M/d/yy","cldr_date_time_format_EHm":"E HH:mm","cldr_date_time_format_EHms":"E HH:mm:ss","cldr_date_time_format_Ed":"d E","cldr_date_time_format_Ehm":"E h:mm a","cldr_date_time_format_Ehms":"E h:mm:ss a","cldr_date_time_format_Gy":"y G","cldr_date_time_format_GyMMM":"MMM y G","cldr_date_time_format_GyMMMEd":"E, MMM d, y G","cldr_date_time_format_GyMMMd":"MMM d, y G","cldr_date_time_format_H":"HH","cldr_date_time_format_Hm":"HH:mm","cldr_date_time_format_Hms":"HH:mm:ss","cldr_date_time_format_M":"L","cldr_date_time_format_MEd":"E, M/d","cldr_date_time_format_MMM":"LLL","cldr_date_time_format_MMMEd":"E, MMM d","cldr_date_time_format_MMMd":"MMM d","cldr_date_time_format_Md":"M/d","cldr_date_time_format_d":"d","cldr_date_time_format_h":"h a","cldr_date_time_format_hm":"h:mm a","cldr_date_time_format_hms":"h:mm:ss a","cldr_date_time_format_ms":"mm:ss","cldr_date_time_format_y":"y","cldr_date_time_format_yM":"M/y","cldr_date_time_format_yMEd":"E, M/d/y","cldr_date_time_format_yMMM":"MMM y","cldr_date_time_format_yMMMEd":"E, MMM d, y","cldr_date_time_format_yMMMd":"MMM d, y","cldr_date_time_format_yMd":"M/d/y","cldr_date_time_format_yQQQ":"QQQ y","cldr_date_time_format_yQQQQ":"QQQQ y","cldr_day_format_abbreviated_fri":"Fri","cldr_day_format_abbreviated_mon":"Mon","cldr_day_format_abbreviated_sat":"Sat","cldr_day_format_abbreviated_sun":"Sun","cldr_day_format_abbreviated_thu":"Thu","cldr_day_format_abbreviated_tue":"Tue","cldr_day_format_abbreviated_wed":"Wed","cldr_day_format_short_fri":"Fr","cldr_day_format_short_mon":"Mo","cldr_day_format_short_sat":"Sa","cldr_day_format_short_sun":"Su","cldr_day_format_short_thu":"Th","cldr_day_format_short_tue":"Tu","cldr_day_format_short_wed":"We","cldr_day_format_wide_fri":"Friday","cldr_day_format_wide_mon":"Monday","cldr_day_format_wide_sat":"Saturday","cldr_day_format_wide_sun":"Sunday","cldr_day_format_wide_thu":"Thursday","cldr_day_format_wide_tue":"Tuesday","cldr_day_format_wide_wed":"Wednesday","cldr_day_stand-alone_narrow_fri":"F","cldr_day_stand-alone_narrow_mon":"M","cldr_day_stand-alone_narrow_sat":"S","cldr_day_stand-alone_narrow_sun":"S","cldr_day_stand-alone_narrow_thu":"T","cldr_day_stand-alone_narrow_tue":"T","cldr_day_stand-alone_narrow_wed":"W","cldr_month_format_abbreviated_1":"Jan","cldr_month_format_abbreviated_10":"Oct","cldr_month_format_abbreviated_11":"Nov","cldr_month_format_abbreviated_12":"Dec","cldr_month_format_abbreviated_2":"Feb","cldr_month_format_abbreviated_3":"Mar","cldr_month_format_abbreviated_4":"Apr","cldr_month_format_abbreviated_5":"May","cldr_month_format_abbreviated_6":"Jun","cldr_month_format_abbreviated_7":"Jul","cldr_month_format_abbreviated_8":"Aug","cldr_month_format_abbreviated_9":"Sep","cldr_month_format_wide_1":"January","cldr_month_format_wide_10":"October","cldr_month_format_wide_11":"November","cldr_month_format_wide_12":"December","cldr_month_format_wide_2":"February","cldr_month_format_wide_3":"March","cldr_month_format_wide_4":"April","cldr_month_format_wide_5":"May","cldr_month_format_wide_6":"June","cldr_month_format_wide_7":"July","cldr_month_format_wide_8":"August","cldr_month_format_wide_9":"September","cldr_month_stand-alone_narrow_1":"J","cldr_month_stand-alone_narrow_10":"O","cldr_month_stand-alone_narrow_11":"N","cldr_month_stand-alone_narrow_12":"D","cldr_month_stand-alone_narrow_2":"F","cldr_month_stand-alone_narrow_3":"M","cldr_month_stand-alone_narrow_4":"A","cldr_month_stand-alone_narrow_5":"M","cldr_month_stand-alone_narrow_6":"J","cldr_month_stand-alone_narrow_7":"J","cldr_month_stand-alone_narrow_8":"A","cldr_month_stand-alone_narrow_9":"S","cldr_number_decimal_separator":".","cldr_number_group_separator":",","cldr_number_percent_format":"#,##0%","cldr_pm":"PM","cldr_time_format_full":"h:mm:ss a zzzz","cldr_time_format_long":"h:mm:ss a z","cldr_time_format_medium":"h:mm:ss a","cldr_time_format_short":"h:mm a","quotationEnd":"”","quotationStart":"“"},"en_GB":{"cldr_am":"am","cldr_date_format_full":"EEEE, d MMMM y","cldr_date_format_long":"d MMMM y","cldr_date_format_medium":"d MMM y","cldr_date_format_short":"dd/MM/y","cldr_date_time_format_Ed":"E d","cldr_date_time_format_GyMMMEd":"E, d MMM y G","cldr_date_time_format_GyMMMd":"d MMM y G","cldr_date_time_format_M":"LL","cldr_date_time_format_MEd":"E dd/MM","cldr_date_time_format_MMMEd":"E d MMM","cldr_date_time_format_MMMMd":"d MMMM","cldr_date_time_format_MMMd":"d MMM","cldr_date_time_format_MMdd":"dd/MM","cldr_date_time_format_Md":"dd/MM","cldr_date_time_format_yM":"MM/y","cldr_date_time_format_yMEd":"E, dd/MM/y","cldr_date_time_format_yMMMEd":"E, d MMM y","cldr_date_time_format_yMMMM":"MMMM y","cldr_date_time_format_yMMMd":"d MMM y","cldr_date_time_format_yMd":"dd/MM/y","cldr_pm":"pm","cldr_time_format_full":"HH:mm:ss zzzz","cldr_time_format_long":"HH:mm:ss z","cldr_time_format_medium":"HH:mm:ss","cldr_time_format_short":"HH:mm"}},"resources":{"ace/ace.js":"clui","ace/mode-yaml.js":"clui","ace/theme-textmate.js":"clui","clui/image/loading66.gif":[66,66,"gif","clui"],"clui/image/logo/logo64.png":[64,64,"png","clui"],"clui/style/timeline.css":"clui","kucken/image/loading16.gif":[16,16,"gif","kucken"],"qx/decoration/Simple/arrows/down-invert.gif":[7,4,"gif","qx"],"qx/decoration/Simple/arrows/down-small.gif":[5,3,"gif","qx"],"qx/decoration/Simple/arrows/down.gif":[7,4,"gif","qx"],"qx/decoration/Simple/arrows/forward.gif":[8,7,"gif","qx"],"qx/decoration/Simple/arrows/left-invert.gif":[4,7,"gif","qx"],"qx/decoration/Simple/arrows/left.gif":[4,7,"gif","qx"],"qx/decoration/Simple/arrows/rewind.gif":[8,7,"gif","qx"],"qx/decoration/Simple/arrows/right-invert.gif":[4,7,"gif","qx"],"qx/decoration/Simple/arrows/right.gif":[4,7,"gif","qx"],"qx/decoration/Simple/arrows/up-invert.gif":[7,4,"gif","qx"],"qx/decoration/Simple/arrows/up-small.gif":[5,3,"gif","qx"],"qx/decoration/Simple/arrows/up.gif":[7,4,"gif","qx"],"qx/decoration/Simple/checkbox/checked-disabled.png":[6,6,"png","qx"],"qx/decoration/Simple/checkbox/checked.png":[6,6,"png","qx"],"qx/decoration/Simple/checkbox/undetermined-disabled.png":[6,2,"png","qx"],"qx/decoration/Simple/checkbox/undetermined.png":[6,2,"png","qx"],"qx/decoration/Simple/colorselector/brightness-field.png":[19,256,"png","qx"],"qx/decoration/Simple/colorselector/brightness-handle.gif":[35,11,"gif","qx"],"qx/decoration/Simple/colorselector/huesaturation-field.jpg":[256,256,"jpeg","qx"],"qx/decoration/Simple/colorselector/huesaturation-handle.gif":[11,11,"gif","qx"],"qx/decoration/Simple/cursors/alias.gif":[19,15,"gif","qx"],"qx/decoration/Simple/cursors/copy.gif":[19,15,"gif","qx"],"qx/decoration/Simple/cursors/move.gif":[13,9,"gif","qx"],"qx/decoration/Simple/cursors/nodrop.gif":[20,20,"gif","qx"],"qx/decoration/Simple/menu/checkbox-invert.gif":[16,7,"gif","qx"],"qx/decoration/Simple/menu/checkbox.gif":[16,7,"gif","qx"],"qx/decoration/Simple/menu/radiobutton-invert.gif":[16,5,"gif","qx"],"qx/decoration/Simple/menu/radiobutton.gif":[16,5,"gif","qx"],"qx/decoration/Simple/splitpane/knob-horizontal.png":[1,8,"png","qx"],"qx/decoration/Simple/splitpane/knob-vertical.png":[8,1,"png","qx"],"qx/decoration/Simple/table/ascending-invert.png":[10,10,"png","qx"],"qx/decoration/Simple/table/ascending.png":[10,10,"png","qx"],"qx/decoration/Simple/table/boolean-false.png":[11,11,"png","qx"],"qx/decoration/Simple/table/boolean-true.png":[11,11,"png","qx"],"qx/decoration/Simple/table/descending-invert.png":[10,10,"png","qx"],"qx/decoration/Simple/table/descending.png":[10,10,"png","qx"],"qx/decoration/Simple/table/select-column-order.png":[10,9,"png","qx"],"qx/decoration/Simple/tabview/close.gif":[10,9,"gif","qx"],"qx/decoration/Simple/tree/minus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/tree/plus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/cross.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/cross_minus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/cross_plus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/end.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/end_minus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/end_plus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/line.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/only_minus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/only_plus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/start.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/start_minus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/treevirtual/start_plus.gif":[19,16,"gif","qx"],"qx/decoration/Simple/window/close-white.gif":[10,9,"gif","qx"],"qx/decoration/Simple/window/close.gif":[10,9,"gif","qx"],"qx/decoration/Simple/window/maximize-white.gif":[9,9,"gif","qx"],"qx/decoration/Simple/window/maximize.gif":[9,9,"gif","qx"],"qx/decoration/Simple/window/minimize-white.gif":[9,9,"gif","qx"],"qx/decoration/Simple/window/minimize.gif":[9,9,"gif","qx"],"qx/decoration/Simple/window/restore-white.gif":[8,9,"gif","qx"],"qx/decoration/Simple/window/restore.gif":[8,9,"gif","qx"],"qx/icon/Tango/16/actions/dialog-cancel.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/dialog-ok.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/document-open-recent.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/document-properties.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/help-faq.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/system-search.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/view-refresh.png":[16,16,"png","qx"],"qx/icon/Tango/16/actions/window-close.png":[16,16,"png","qx"],"qx/icon/Tango/16/apps/internet-mail.png":[16,16,"png","qx"],"qx/icon/Tango/16/apps/office-calendar.png":[16,16,"png","qx"],"qx/icon/Tango/16/apps/utilities-log-viewer.png":[16,16,"png","qx"],"qx/icon/Tango/16/mimetypes/text-plain.png":[16,16,"png","qx"],"qx/icon/Tango/16/places/folder-open.png":[16,16,"png","qx"],"qx/icon/Tango/16/places/folder.png":[16,16,"png","qx"],"qx/icon/Tango/16/status/dialog-information.png":[16,16,"png","qx"],"qx/icon/Tango/16/status/dialog-warning.png":[16,16,"png","qx"],"qx/icon/Tango/22/actions/address-book-new.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/dialog-close.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/document-new.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/go-first.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/go-last.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/mail-mark-read.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/system-run.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/system-search.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/view-refresh.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/view-restore.png":[22,22,"png","qx"],"qx/icon/Tango/22/actions/view-sort-ascending.png":[22,22,"png","qx"],"qx/icon/Tango/22/apps/office-calendar.png":[22,22,"png","qx"],"qx/icon/Tango/22/apps/office-chart.png":[22,22,"png","qx"],"qx/icon/Tango/22/apps/utilities-text-editor.png":[22,22,"png","qx"],"qx/icon/Tango/32/actions/help-faq.png":[32,32,"png","qx"],"qx/icon/Tango/32/status/dialog-information.png":[32,32,"png","qx"],"qx/icon/Tango/32/status/dialog-warning.png":[32,32,"png","qx"],"qx/static/blank.gif":[1,1,"gif","qx"],"qx/static/blank.png":[1,1,"png","qx"]},"translations":{"C":{},"en":{}}};
(function(){var b=".prototype",c="function",d="Boolean",e="Error",f="Object.keys requires an object as argument.",g="constructor",h="warn",j="default",k="Null",m="hasOwnProperty",n="Undefined",o="string",p="Object",q="toLocaleString",r="error",s="toString",t="qx.debug",u="()",v="RegExp",w="String",x="info",y="BROKEN_IE",z="isPrototypeOf",A="Date",B="",C="qx.Bootstrap",D="Function",E="]",F="Cannot call super class. Method is not derived: ",G="Array",H="[Class ",I="valueOf",J="Number",K="Class",L="debug",M="ES5",N=".",O="propertyIsEnumerable",P="object";if(!window.qx){window.qx={};};qx.Bootstrap={genericToString:function(){return H+this.classname+E;},createNamespace:function(name,Q){var T=name.split(N);var S=T[0];var parent=qx.$$namespaceRoot&&qx.$$namespaceRoot[S]?qx.$$namespaceRoot:window;for(var i=0,R=T.length-1;i<R;i++ ,S=T[i]){if(!parent[S]){parent=parent[S]={};}else {parent=parent[S];};};parent[S]=Q;return S;},setDisplayName:function(V,U,name){V.displayName=U+N+name+u;},setDisplayNames:function(X,W){for(var name in X){var Y=X[name];if(Y instanceof Function){Y.displayName=W+N+name+u;};};},base:function(ba,bb){if(qx.Bootstrap.DEBUG){if(!qx.Bootstrap.isFunction(ba.callee.base)){throw new Error(F+ba.callee.displayName);};};if(arguments.length===1){return ba.callee.base.call(this);}else {return ba.callee.base.apply(this,Array.prototype.slice.call(arguments,1));};},define:function(name,bm){if(!bm){bm={statics:{}};};var bi;var be=null;qx.Bootstrap.setDisplayNames(bm.statics,name);if(bm.members||bm.extend){qx.Bootstrap.setDisplayNames(bm.members,name+b);bi=bm.construct||new Function;if(bm.extend){this.extendClass(bi,bi,bm.extend,name,bg);};var bd=bm.statics||{};for(var i=0,bf=qx.Bootstrap.keys(bd),l=bf.length;i<l;i++ ){var bc=bf[i];bi[bc]=bd[bc];};be=bi.prototype;be.base=qx.Bootstrap.base;be.name=be.classname=name;var bk=bm.members||{};var bc,bj;for(var i=0,bf=qx.Bootstrap.keys(bk),l=bf.length;i<l;i++ ){bc=bf[i];bj=bk[bc];if(bj instanceof Function&&be[bc]){bj.base=be[bc];};be[bc]=bj;};}else {bi=bm.statics||{};if(qx.Bootstrap.$$registry&&qx.Bootstrap.$$registry[name]){var bl=qx.Bootstrap.$$registry[name];if(this.keys(bi).length!==0){if(bm.defer){bm.defer(bi,be);};for(var bh in bi){bl[bh]=bi[bh];};return bl;};};};bi.$$type=K;if(!bi.hasOwnProperty(s)){bi.toString=this.genericToString;};var bg=name?this.createNamespace(name,bi):B;bi.name=bi.classname=name;bi.basename=bg;bi.$$events=bm.events;if(bm.defer){bm.defer(bi,be);};if(name!=null){qx.Bootstrap.$$registry[name]=bi;};return bi;}};qx.Bootstrap.define(C,{statics:{LOADSTART:qx.$$start||new Date(),DEBUG:(function(){var bn=true;if(qx.$$environment&&qx.$$environment[t]===false){bn=false;};return bn;})(),getEnvironmentSetting:function(bo){if(qx.$$environment){return qx.$$environment[bo];};},setEnvironmentSetting:function(bp,bq){if(!qx.$$environment){qx.$$environment={};};if(qx.$$environment[bp]===undefined){qx.$$environment[bp]=bq;};},createNamespace:qx.Bootstrap.createNamespace,setRoot:function(br){qx.$$namespaceRoot=br;},base:qx.Bootstrap.base,define:qx.Bootstrap.define,setDisplayName:qx.Bootstrap.setDisplayName,setDisplayNames:qx.Bootstrap.setDisplayNames,genericToString:qx.Bootstrap.genericToString,extendClass:function(clazz,construct,superClass,name,basename){var superproto=superClass.prototype;var helper=new Function();helper.prototype=superproto;var proto=new helper();clazz.prototype=proto;proto.name=proto.classname=name;proto.basename=basename;construct.base=superClass;clazz.superclass=superClass;construct.self=clazz.constructor=proto.constructor=clazz;},getByName:function(name){return qx.Bootstrap.$$registry[name];},$$registry:{},objectGetLength:function(bs){return qx.Bootstrap.keys(bs).length;},objectMergeWith:function(bu,bt,bw){if(bw===undefined){bw=true;};for(var bv in bt){if(bw||bu[bv]===undefined){bu[bv]=bt[bv];};};return bu;},__a:[z,m,q,s,I,O,g],keys:({"ES5":Object.keys,"BROKEN_IE":function(bx){if(bx===null||(typeof bx!=P&&typeof bx!=c)){throw new TypeError(f);};var by=[];var bA=Object.prototype.hasOwnProperty;for(var bB in bx){if(bA.call(bx,bB)){by.push(bB);};};var bz=qx.Bootstrap.__a;for(var i=0,a=bz,l=a.length;i<l;i++ ){if(bA.call(bx,a[i])){by.push(a[i]);};};return by;},"default":function(bC){if(bC===null||(typeof bC!=P&&typeof bC!=c)){throw new TypeError(f);};var bD=[];var bE=Object.prototype.hasOwnProperty;for(var bF in bC){if(bE.call(bC,bF)){bD.push(bF);};};return bD;}})[typeof (Object.keys)==c?M:(function(){for(var bG in {toString:1}){return bG;};})()!==s?y:j],__b:{"[object String]":w,"[object Array]":G,"[object Object]":p,"[object RegExp]":v,"[object Number]":J,"[object Boolean]":d,"[object Date]":A,"[object Function]":D,"[object Error]":e},bind:function(bI,self,bJ){var bH=Array.prototype.slice.call(arguments,2,arguments.length);return function(){var bK=Array.prototype.slice.call(arguments,0,arguments.length);return bI.apply(self,bH.concat(bK));};},firstUp:function(bL){return bL.charAt(0).toUpperCase()+bL.substr(1);},firstLow:function(bM){return bM.charAt(0).toLowerCase()+bM.substr(1);},getClass:function(bO){if(bO===undefined){return n;}else if(bO===null){return k;};var bN=Object.prototype.toString.call(bO);return (qx.Bootstrap.__b[bN]||bN.slice(8,-1));},isString:function(bP){return (bP!==null&&(typeof bP===o||qx.Bootstrap.getClass(bP)==w||bP instanceof String||(!!bP&&!!bP.$$isString)));},isArray:function(bQ){return (bQ!==null&&(bQ instanceof Array||(bQ&&qx.data&&qx.data.IListData&&qx.util.OOUtil.hasInterface(bQ.constructor,qx.data.IListData))||qx.Bootstrap.getClass(bQ)==G||(!!bQ&&!!bQ.$$isArray)));},isObject:function(bR){return (bR!==undefined&&bR!==null&&qx.Bootstrap.getClass(bR)==p);},isFunction:function(bS){return qx.Bootstrap.getClass(bS)==D;},$$logs:[],debug:function(bU,bT){qx.Bootstrap.$$logs.push([L,arguments]);},info:function(bW,bV){qx.Bootstrap.$$logs.push([x,arguments]);},warn:function(bY,bX){qx.Bootstrap.$$logs.push([h,arguments]);},error:function(cb,ca){qx.Bootstrap.$$logs.push([r,arguments]);},trace:function(cc){}}});})();(function(){var a="qx.util.OOUtil";qx.Bootstrap.define(a,{statics:{classIsDefined:function(name){return qx.Bootstrap.getByName(name)!==undefined;},getPropertyDefinition:function(b,name){while(b){if(b.$$properties&&b.$$properties[name]){return b.$$properties[name];};b=b.superclass;};return null;},hasProperty:function(c,name){return !!qx.util.OOUtil.getPropertyDefinition(c,name);},getEventType:function(d,name){var d=d.constructor;while(d.superclass){if(d.$$events&&d.$$events[name]!==undefined){return d.$$events[name];};d=d.superclass;};return null;},supportsEvent:function(e,name){return !!qx.util.OOUtil.getEventType(e,name);},getByInterface:function(h,f){var g,i,l;while(h){if(h.$$implements){g=h.$$flatImplements;for(i=0,l=g.length;i<l;i++ ){if(g[i]===f){return h;};};};h=h.superclass;};return null;},hasInterface:function(k,j){return !!qx.util.OOUtil.getByInterface(k,j);},getMixins:function(n){var m=[];while(n){if(n.$$includes){m.push.apply(m,n.$$flatIncludes);};n=n.superclass;};return m;}}});})();(function(){var a="qx.core.Environment",b="default",c=' type)',d="&",e="qx/static/blank.html",f="true",g="|",h="qx.core.Environment for a list of predefined keys.",j="false",k='] found, and no default ("default") given',l=":",m='" (',n=' in variants [',o=".",p="qx.allowUrlSettings",q='No match for variant "',r=" is not a valid key. Please see the API-doc of ",s="qxenv";qx.Bootstrap.define(a,{statics:{_checks:{},_asyncChecks:{},__c:{},_checksMap:{},_defaults:{"true":true,"qx.allowUrlSettings":false,"qx.allowUrlVariants":false,"qx.debug.property.level":0,"qx.debug":true,"qx.debug.ui.queue":true,"qx.aspects":false,"qx.dynlocale":true,"qx.dyntheme":true,"qx.blankpage":e,"qx.debug.databinding":false,"qx.debug.dispose":false,"qx.optimization.basecalls":false,"qx.optimization.comments":false,"qx.optimization.privates":false,"qx.optimization.strings":false,"qx.optimization.variables":false,"qx.optimization.variants":false,"module.databinding":true,"module.logger":true,"module.property":true,"module.events":true,"qx.nativeScrollBars":false},get:function(w){if(this.__c[w]!=undefined){return this.__c[w];};var y=this._checks[w];if(y){var u=y();this.__c[w]=u;return u;};var t=this._getClassNameFromEnvKey(w);if(t[0]!=undefined){var x=t[0];var v=t[1];var u=x[v]();this.__c[w]=u;return u;};if(qx.Bootstrap.DEBUG){qx.Bootstrap.warn(w+r+h);qx.Bootstrap.trace(this);};},_getClassNameFromEnvKey:function(D){var F=this._checksMap;if(F[D]!=undefined){var A=F[D];var E=A.lastIndexOf(o);if(E>-1){var C=A.slice(0,E);var z=A.slice(E+1);var B=qx.Bootstrap.getByName(C);if(B!=undefined){return [B,z];};};};return [undefined,undefined];},getAsync:function(H,K,self){var L=this;if(this.__c[H]!=undefined){window.setTimeout(function(){K.call(self,L.__c[H]);},0);return;};var I=this._asyncChecks[H];if(I){I(function(N){L.__c[H]=N;K.call(self,N);});return;};var G=this._getClassNameFromEnvKey(H);if(G[0]!=undefined){var J=G[0];var M=G[1];J[M](function(O){L.__c[H]=O;K.call(self,O);});return;};if(qx.Bootstrap.DEBUG){qx.Bootstrap.warn(H+r+h);qx.Bootstrap.trace(this);};},select:function(Q,P){return this.__d(this.get(Q),P);},selectAsync:function(S,R,self){this.getAsync(S,function(T){var U=this.__d(S,R);U.call(self,T);},this);},__d:function(Y,X){var W=X[Y];if(X.hasOwnProperty(Y)){return W;};for(var ba in X){if(ba.indexOf(g)!=-1){var V=ba.split(g);for(var i=0;i<V.length;i++ ){if(V[i]==Y){return X[ba];};};};};if(X[b]!==undefined){return X[b];};if(qx.Bootstrap.DEBUG){throw new Error(q+Y+m+(typeof Y)+c+n+qx.Bootstrap.keys(X)+k);};},filter:function(bb){var bd=[];for(var bc in bb){if(this.get(bc)){bd.push(bb[bc]);};};return bd;},invalidateCacheKey:function(be){delete this.__c[be];},add:function(bg,bf){if(this._checks[bg]==undefined){if(bf instanceof Function){if(!this._checksMap[bg]&&bf.displayName){this._checksMap[bg]=bf.displayName.substr(0,bf.displayName.length-2);};this._checks[bg]=bf;}else {this._checks[bg]=this.__g(bf);};};},addAsync:function(bi,bh){if(this._checks[bi]==undefined){this._asyncChecks[bi]=bh;};},getChecks:function(){return this._checks;},getAsyncChecks:function(){return this._asyncChecks;},_initDefaultQxValues:function(){var bj=function(bl){return function(){return bl;};};for(var bk in this._defaults){this.add(bk,bj(this._defaults[bk]));};},__e:function(){if(qx&&qx.$$environment){for(var bm in qx.$$environment){var bn=qx.$$environment[bm];this._checks[bm]=this.__g(bn);};};},__f:function(){if(window.document&&window.document.location){var bo=window.document.location.search.slice(1).split(d);for(var i=0;i<bo.length;i++ ){var br=bo[i].split(l);if(br.length!=3||br[0]!=s){continue;};var bp=br[1];var bq=decodeURIComponent(br[2]);if(bq==f){bq=true;}else if(bq==j){bq=false;}else if(/^(\d|\.)+$/.test(bq)){bq=parseFloat(bq);};this._checks[bp]=this.__g(bq);};};},__g:function(bs){return qx.Bootstrap.bind(function(bt){return bt;},null,bs);}},defer:function(bu){bu._initDefaultQxValues();bu.__e();if(bu.get(p)===true){bu.__f();};}});})();(function(){var a="ecmascript.string.startsWith",b="function",c="ecmascript.array.indexof",d="qx.bom.client.EcmaScript",f="ecmascript.array.foreach",g="ecmascript.array.reduceright",h="stack",i="ecmascript.array.map",j="2001-02-03T04:05:06.007Z",k="[object Error]",l="ecmascript.object.keys",m="ecmascript.string.trim",n="ecmascript.array.reduce",o="ecmascript.array.every",p="ecmascript.array.filter",q="ecmascript.date.parse",r="ecmascript.string.endsWith",s="ecmascript.object.is",t="2001-02-03T04:05:06.007",u="ecmascript.array.some",v="stacktrace",w="ecmascript.error.toString",x="ecmascript.function.bind",y="ecmascript.array.lastindexof",z="e",A="ecmascript.error.stacktrace",B="ecmascript.object.values",C="ecmascript.date.now";qx.Bootstrap.define(d,{statics:{getStackTrace:function(){var D;var e=new Error(z);D=e.stack?h:e.stacktrace?v:null;if(!D){try{throw e;}catch(E){e=E;};};return e.stacktrace?v:e.stack?h:null;},getArrayIndexOf:function(){return !!Array.prototype.indexOf;},getArrayLastIndexOf:function(){return !!Array.prototype.lastIndexOf;},getArrayForEach:function(){return !!Array.prototype.forEach;},getArrayFilter:function(){return !!Array.prototype.filter;},getArrayMap:function(){return !!Array.prototype.map;},getArraySome:function(){return !!Array.prototype.some;},getArrayEvery:function(){return !!Array.prototype.every;},getArrayReduce:function(){return !!Array.prototype.reduce;},getArrayReduceRight:function(){return !!Array.prototype.reduceRight;},getErrorToString:function(){return typeof Error.prototype.toString==b&&Error.prototype.toString()!==k;},getFunctionBind:function(){return typeof Function.prototype.bind===b;},getObjectKeys:function(){return !!Object.keys;},getObjectValues:function(){return !!Object.values;},getObjectIs:function(){return !!Object.is;},getDateNow:function(){return !!Date.now;},getDateParse:function(){return typeof Date.parse===b&&(Date.parse(t)!=Date.parse(j));},getStringStartsWith:function(){return typeof String.prototype.startsWith===b;},getStringEndsWith:function(){return typeof String.prototype.endsWith===b;},getStringTrim:function(){return typeof String.prototype.trim===b;}},defer:function(F){qx.core.Environment.add(c,F.getArrayIndexOf);qx.core.Environment.add(y,F.getArrayLastIndexOf);qx.core.Environment.add(f,F.getArrayForEach);qx.core.Environment.add(p,F.getArrayFilter);qx.core.Environment.add(i,F.getArrayMap);qx.core.Environment.add(u,F.getArraySome);qx.core.Environment.add(o,F.getArrayEvery);qx.core.Environment.add(n,F.getArrayReduce);qx.core.Environment.add(g,F.getArrayReduceRight);qx.core.Environment.add(C,F.getDateNow);qx.core.Environment.add(q,F.getDateParse);qx.core.Environment.add(w,F.getErrorToString);qx.core.Environment.add(A,F.getStackTrace);qx.core.Environment.add(x,F.getFunctionBind);qx.core.Environment.add(l,F.getObjectKeys);qx.core.Environment.add(B,F.getObjectValues);qx.core.Environment.add(s,F.getObjectIs);qx.core.Environment.add(a,F.getStringStartsWith);qx.core.Environment.add(r,F.getStringEndsWith);qx.core.Environment.add(m,F.getStringTrim);}});})();(function(){var a="qx.lang.normalize.Function",b="ecmascript.function.bind",c="function",d="Function.prototype.bind called on incompatible ";qx.Bootstrap.define(a,{statics:{bind:function(i){var e=Array.prototype.slice;var h=this;if(typeof h!=c){throw new TypeError(d+h);};var f=e.call(arguments,1);var g=function(){if(this instanceof g){var F=function(){};F.prototype=h.prototype;var self=new F;var j=h.apply(self,f.concat(e.call(arguments)));if(Object(j)===j){return j;};return self;}else {return h.apply(i,f.concat(e.call(arguments)));};};return g;}},defer:function(k){if(!qx.core.Environment.get(b)){Function.prototype.bind=k.bind;};}});})();(function(){var a="function",b="ecmascript.array.lastindexof",c="ecmascript.array.map",d="ecmascript.array.filter",e="Length is 0 and no second argument given",f="qx.lang.normalize.Array",g="ecmascript.array.indexof",h="First argument is not callable",j="ecmascript.array.reduce",k="ecmascript.array.foreach",m="ecmascript.array.reduceright",n="ecmascript.array.some",o="ecmascript.array.every";qx.Bootstrap.define(f,{statics:{indexOf:function(p,q){if(q==null){q=0;}else if(q<0){q=Math.max(0,this.length+q);};for(var i=q;i<this.length;i++ ){if(this[i]===p){return i;};};return -1;},lastIndexOf:function(r,s){if(s==null){s=this.length-1;}else if(s<0){s=Math.max(0,this.length+s);};for(var i=s;i>=0;i-- ){if(this[i]===r){return i;};};return -1;},forEach:function(t,u){var l=this.length;for(var i=0;i<l;i++ ){var v=this[i];if(v!==undefined){t.call(u||window,v,i,this);};};},filter:function(z,w){var x=[];var l=this.length;for(var i=0;i<l;i++ ){var y=this[i];if(y!==undefined){if(z.call(w||window,y,i,this)){x.push(this[i]);};};};return x;},map:function(D,A){var B=[];var l=this.length;for(var i=0;i<l;i++ ){var C=this[i];if(C!==undefined){B[i]=D.call(A||window,C,i,this);};};return B;},some:function(E,F){var l=this.length;for(var i=0;i<l;i++ ){var G=this[i];if(G!==undefined){if(E.call(F||window,G,i,this)){return true;};};};return false;},every:function(H,I){var l=this.length;for(var i=0;i<l;i++ ){var J=this[i];if(J!==undefined){if(!H.call(I||window,J,i,this)){return false;};};};return true;},reduce:function(K,L){if(typeof K!==a){throw new TypeError(h);};if(L===undefined&&this.length===0){throw new TypeError(e);};var M=L===undefined?this[0]:L;for(var i=L===undefined?1:0;i<this.length;i++ ){if(i in this){M=K.call(undefined,M,this[i],i,this);};};return M;},reduceRight:function(N,O){if(typeof N!==a){throw new TypeError(h);};if(O===undefined&&this.length===0){throw new TypeError(e);};var P=O===undefined?this[this.length-1]:O;for(var i=O===undefined?this.length-2:this.length-1;i>=0;i-- ){if(i in this){P=N.call(undefined,P,this[i],i,this);};};return P;}},defer:function(Q){if(!qx.core.Environment.get(g)){Array.prototype.indexOf=Q.indexOf;};if(!qx.core.Environment.get(b)){Array.prototype.lastIndexOf=Q.lastIndexOf;};if(!qx.core.Environment.get(k)){Array.prototype.forEach=Q.forEach;};if(!qx.core.Environment.get(d)){Array.prototype.filter=Q.filter;};if(!qx.core.Environment.get(c)){Array.prototype.map=Q.map;};if(!qx.core.Environment.get(n)){Array.prototype.some=Q.some;};if(!qx.core.Environment.get(o)){Array.prototype.every=Q.every;};if(!qx.core.Environment.get(j)){Array.prototype.reduce=Q.reduce;};if(!qx.core.Environment.get(m)){Array.prototype.reduceRight=Q.reduceRight;};}});})();(function(){var a="qx.Mixin",b=".prototype",c="]",d='Conflict between mixin "',e="constructor",f="Array",g='"!',h='" and "',j="destruct",k='" in property "',m="Mixin",n='" in member "',o="[Mixin ";qx.Bootstrap.define(a,{statics:{define:function(name,q){if(q){if(q.include&&!(qx.Bootstrap.getClass(q.include)===f)){q.include=[q.include];};{};var r=q.statics?q.statics:{};qx.Bootstrap.setDisplayNames(r,name);for(var p in r){if(r[p] instanceof Function){r[p].$$mixin=r;};};if(q.construct){r.$$constructor=q.construct;qx.Bootstrap.setDisplayName(q.construct,name,e);};if(q.include){r.$$includes=q.include;};if(q.properties){r.$$properties=q.properties;};if(q.members){r.$$members=q.members;qx.Bootstrap.setDisplayNames(q.members,name+b);};for(var p in r.$$members){if(r.$$members[p] instanceof Function){r.$$members[p].$$mixin=r;};};if(q.events){r.$$events=q.events;};if(q.destruct){r.$$destructor=q.destruct;qx.Bootstrap.setDisplayName(q.destruct,name,j);};}else {var r={};};r.$$type=m;r.name=name;r.toString=this.genericToString;r.basename=qx.Bootstrap.createNamespace(name,r);this.$$registry[name]=r;return r;},checkCompatibility:function(t){var u=this.flatten(t);var v=u.length;if(v<2){return true;};var w={};var x={};var z={};var y;for(var i=0;i<v;i++ ){y=u[i];for(var s in y.events){if(z[s]){throw new Error(d+y.name+h+z[s]+n+s+g);};z[s]=y.name;};for(var s in y.properties){if(w[s]){throw new Error(d+y.name+h+w[s]+k+s+g);};w[s]=y.name;};for(var s in y.members){if(x[s]){throw new Error(d+y.name+h+x[s]+n+s+g);};x[s]=y.name;};};return true;},isCompatible:function(B,C){var A=qx.util.OOUtil.getMixins(C);A.push(B);return qx.Mixin.checkCompatibility(A);},getByName:function(name){return this.$$registry[name];},isDefined:function(name){return this.getByName(name)!==undefined;},getTotalNumber:function(){return qx.Bootstrap.objectGetLength(this.$$registry);},flatten:function(D){if(!D){return [];};var E=D.concat();for(var i=0,l=D.length;i<l;i++ ){if(D[i].$$includes){E.push.apply(E,this.flatten(D[i].$$includes));};};return E;},genericToString:function(){return o+this.name+c;},$$registry:{},__h:null,__i:function(name,F){}}});})();(function(){var a="qx.core.Aspect",b="before",c="*",d="static";qx.Bootstrap.define(a,{statics:{__j:[],wrap:function(h,l,j){var m=[];var e=[];var k=this.__j;var g;for(var i=0;i<k.length;i++ ){g=k[i];if((g.type==null||j==g.type||g.type==c)&&(g.name==null||h.match(g.name))){g.pos==-1?m.push(g.fcn):e.push(g.fcn);};};if(m.length===0&&e.length===0){return l;};var f=function(){for(var i=0;i<m.length;i++ ){m[i].call(this,h,l,j,arguments);};var n=l.apply(this,arguments);for(var i=0;i<e.length;i++ ){e[i].call(this,h,l,j,arguments,n);};return n;};if(j!==d){f.self=l.self;f.base=l.base;};l.wrapper=f;f.original=l;return f;},addAdvice:function(q,o,p,name){this.__j.push({fcn:q,pos:o===b?-1:1,type:p,name:name});}}});})();(function(){var a="ecmascript.string.startsWith",b="ecmascript.string.endsWith",c="qx.lang.normalize.String",d='number',e='',f="ecmascript.string.trim";qx.Bootstrap.define(c,{statics:{trim:function(){return this.replace(/^\s+|\s+$/g,e);},startsWith:function(h,g){g=g||0;return this.substr(g,h.length)===h;},endsWith:function(j,i){var l=this.toString();if(typeof i!==d||!isFinite(i)||Math.floor(i)!==i||i>l.length){i=l.length;};i-=j.length;var k=l.indexOf(j,i);return k!==-1&&k===i;}},defer:function(m){if(!qx.core.Environment.get(f)){String.prototype.trim=m.trim;};if(!qx.core.Environment.get(a)){String.prototype.startsWith=m.startsWith;};if(!qx.core.Environment.get(b)){String.prototype.endsWith=m.endsWith;};}});})();(function(){var a="ecmascript.object.keys",b="qx.lang.normalize.Object",c="ecmascript.object.values",d="ecmascript.object.is";qx.Bootstrap.define(b,{statics:{keys:qx.Bootstrap.keys,values:function(f){{};var g=[];var e=Object.keys(f);for(var i=0,l=e.length;i<l;i++ ){g.push(f[e[i]]);};return g;},is:function(x,y){if(x===y){return x!==0||1/x===1/y;}else {return x!==x&&y!==y;};}},defer:function(h){if(!qx.core.Environment.get(a)){Object.keys=h.keys;};if(!qx.core.Environment.get(c)){Object.values=h.values;};if(!qx.core.Environment.get(d)){Object.is=h.is;};}});})();(function(){var a='Implementation of method "',b='"',c="function",d='" is not supported by Class "',e="Boolean",f="qx.Interface",g='The event "',h='" required by interface "',j='" is missing in class "',k='"!',m='The property "',n="Interface",o="toggle",p="]",q="[Interface ",r="is",s="Array",t='Implementation of member "';qx.Bootstrap.define(f,{statics:{define:function(name,v){if(v){if(v.extend&&!(qx.Bootstrap.getClass(v.extend)===s)){v.extend=[v.extend];};{};var u=v.statics?v.statics:{};if(v.extend){u.$$extends=v.extend;};if(v.properties){u.$$properties=v.properties;};if(v.members){u.$$members=v.members;};if(v.events){u.$$events=v.events;};}else {var u={};};u.$$type=n;u.name=name;u.toString=this.genericToString;u.basename=qx.Bootstrap.createNamespace(name,u);qx.Interface.$$registry[name]=u;return u;},getByName:function(name){return this.$$registry[name];},isDefined:function(name){return this.getByName(name)!==undefined;},getTotalNumber:function(){return qx.Bootstrap.objectGetLength(this.$$registry);},flatten:function(x){if(!x){return [];};var w=x.concat();for(var i=0,l=x.length;i<l;i++ ){if(x[i].$$extends){w.push.apply(w,this.flatten(x[i].$$extends));};};return w;},__S:function(B,C,y,F,D){var z=y.$$members;if(z){for(var E in z){if(qx.Bootstrap.isFunction(z[E])){var H=this.__T(C,E);var A=H||qx.Bootstrap.isFunction(B[E]);if(!A){if(D){throw new Error(a+E+j+C.classname+h+y.name+b);}else {return false;};};var G=F===true&&!H&&!qx.util.OOUtil.hasInterface(C,y);if(G){B[E]=this.__W(y,B[E],E,z[E]);};}else {if(typeof B[E]===undefined){if(typeof B[E]!==c){if(D){throw new Error(t+E+j+C.classname+h+y.name+b);}else {return false;};};};};};};if(!D){return true;};},__T:function(L,I){var N=I.match(/^(is|toggle|get|set|reset)(.*)$/);if(!N){return false;};var K=qx.Bootstrap.firstLow(N[2]);var M=qx.util.OOUtil.getPropertyDefinition(L,K);if(!M){return false;};var J=N[0]==r||N[0]==o;if(J){return qx.util.OOUtil.getPropertyDefinition(L,K).check==e;};return true;},__U:function(R,O,P){if(O.$$properties){for(var Q in O.$$properties){if(!qx.util.OOUtil.getPropertyDefinition(R,Q)){if(P){throw new Error(m+Q+d+R.classname+k);}else {return false;};};};};if(!P){return true;};},__V:function(V,S,T){if(S.$$events){for(var U in S.$$events){if(!qx.util.OOUtil.supportsEvent(V,U)){if(T){throw new Error(g+U+d+V.classname+k);}else {return false;};};};};if(!T){return true;};},assertObject:function(Y,W){var ba=Y.constructor;this.__S(Y,ba,W,false,true);this.__U(ba,W,true);this.__V(ba,W,true);var X=W.$$extends;if(X){for(var i=0,l=X.length;i<l;i++ ){this.assertObject(Y,X[i]);};};},assert:function(bd,bb,be){this.__S(bd.prototype,bd,bb,be,true);this.__U(bd,bb,true);this.__V(bd,bb,true);var bc=bb.$$extends;if(bc){for(var i=0,l=bc.length;i<l;i++ ){this.assert(bd,bc[i],be);};};},objectImplements:function(bh,bf){var bi=bh.constructor;if(!this.__S(bh,bi,bf)||!this.__U(bi,bf)||!this.__V(bi,bf)){return false;};var bg=bf.$$extends;if(bg){for(var i=0,l=bg.length;i<l;i++ ){if(!this.objectImplements(bh,bg[i])){return false;};};};return true;},classImplements:function(bl,bj){if(!this.__S(bl.prototype,bl,bj)||!this.__U(bl,bj)||!this.__V(bl,bj)){return false;};var bk=bj.$$extends;if(bk){for(var i=0,l=bk.length;i<l;i++ ){if(!this.has(bl,bk[i])){return false;};};};return true;},genericToString:function(){return q+this.name+p;},$$registry:{},__W:function(bo,bn,bp,bm){},__h:null,__i:function(name,bq){}}});})();(function(){var a="ecmascript.error.toString",b="qx.lang.normalize.Error",c=": ",d="Error",e="";qx.Bootstrap.define(b,{statics:{toString:function(){var name=this.name||d;var f=this.message||e;if(name===e&&f===e){return d;};if(name===e){return f;};if(f===e){return name;};return name+c+f;}},defer:function(g){if(!qx.core.Environment.get(a)){Error.prototype.toString=g.toString;};}});})();(function(){var a="qx.lang.normalize.Date",b="ecmascript.date.now",c="Z",d="+",e="ecmascript.date.parse";qx.Bootstrap.define(a,{statics:{now:function(){return +new Date();},parse:function(j){var f=/^(\d{4}|[+\-]\d{6})(?:-(\d{2})(?:-(\d{2}))?)?(?:T(\d{2}):(\d{2})(?::(\d{2})(?:\.(\d{3}))?)?(?:(Z)|([+\-])(\d{2})(?::(\d{2}))?)?)?$/.exec(j);if(!f){var g=Date.originalParse(j);if(isNaN(g)||isNaN((new Date()).setTime(g))){return NaN;};return g;};var h=[4,5,6,7].every(function(i){return f[i]===undefined;});[1,4,5,6,7,10,11].forEach(function(i){f[i]=+f[i]||0;});f[2]=(+f[2]||1)-1;f[3]=+f[3]||1;if(f[8]!==c&&f[9]===undefined&&!h){return new Date(f[1],f[2],f[3],f[4],f[5],f[6],f[7]).getTime();};var k=0;if(f[8]!==c){k=f[10]*60+f[11];if(f[9]===d){k=-k;};};return Date.UTC(f[1],f[2],f[3],f[4],f[5]+k,f[6],f[7]);}},defer:function(l){if(!qx.core.Environment.get(b)){Date.now=l.now;};if(!qx.core.Environment.get(e)){Date.originalParse=Date.parse||function(m){return NaN;};Date.parse=l.parse;};}});})();(function(){var b='!==inherit){',c='qx.lang.Type.isString(value) && qx.util.ColorUtil.isValidPropertyValue(value)',d='value !== null && qx.theme.manager.Font.getInstance().isDynamic(value)',e="set",f=';',g="resetThemed",h='value !== null && value.nodeType === 9 && value.documentElement',j='===value)return value;',k='value !== null && value.$$type === "Mixin"',m='return init;',n='var init=this.',o='value !== null && value.nodeType === 1 && value.attributes',p="var parent = this.getLayoutParent();",q="Error in property ",r='var a=this._getChildren();if(a)for(var i=0,l=a.length;i<l;i++){',s="property",t="();",u='.validate.call(this, value);',v='qx.core.Assert.assertInstance(value, Date, msg) || true',w='else{',x="if (!parent) return;",y=" in method ",z='qx.core.Assert.assertInstance(value, Error, msg) || true',A='=computed;',B='Undefined value is not allowed!',C='(backup);',D='else ',E='=true;',F='if(old===undefined)old=this.',G='if(computed===inherit){',H='old=computed=this.',I="inherit",J='if(this.',K='return this.',L='else if(this.',M='Is invalid!',N='if(value===undefined)prop.error(this,2,"',O='", "',P='var computed, old=this.',Q='else if(computed===undefined)',R='delete this.',S="resetRuntime",T="': ",U=" of class ",V='value !== null && value.nodeType !== undefined',W='===undefined)return;',X='value !== null && qx.theme.manager.Decoration.getInstance().isValidPropertyValue(value)',Y="reset",ba="string",bb="')){",bc="module.events",bd="return this.",be='qx.core.Assert.assertPositiveInteger(value, msg) || true',bf='else this.',bg='value=this.',bh='","',bi='if(init==qx.core.Property.$$inherit)init=null;',bj="get",bk='value !== null && value.$$type === "Interface"',bl='var inherit=prop.$$inherit;',bm="', qx.event.type.Data, [computed, old]",bn="var value = parent.",bo="$$useinit_",bp='computed=undefined;delete this.',bq="(value);",br='this.',bs='Requires exactly one argument!',bt='",value);',bu='computed=value;',bv='}else{',bw="$$runtime_",bx="setThemed",by=';}',bz='(value);',bA="$$user_",bB='!==undefined)',bC='){',bD='qx.core.Assert.assertArray(value, msg) || true',bE='if(computed===undefined||computed===inherit){',bF=";",bG='qx.core.Assert.assertPositiveNumber(value, msg) || true',bH=".prototype",bI="Boolean",bJ=")}",bK="(a[",bL='(computed, old, "',bM="setRuntime",bN='return value;',bO="this.",bP="if(reg.hasListener(this, '",bQ='Does not allow any arguments!',bR=')a[i].',bS="()",bT="var a=arguments[0] instanceof Array?arguments[0]:arguments;",bU='.$$properties.',bV='value !== null && value.$$type === "Theme"',bW='old=this.',bX="var reg=qx.event.Registration;",bY="())",ca='=value;',cb='return null;',cc='qx.core.Assert.assertObject(value, msg) || true',cd='");',ce='if(old===computed)return value;',cf='qx.core.Assert.assertString(value, msg) || true',cg='if(old===undefined)old=null;',ch='var pa=this.getLayoutParent();if(pa)computed=pa.',ci="if (value===undefined) value = parent.",cj='value !== null && value.$$type === "Class"',ck='qx.core.Assert.assertFunction(value, msg) || true',cl='!==undefined&&',cm='var computed, old;',cn='var backup=computed;',co=".",cp='}',cq="object",cr="$$init_",cs="$$theme_",ct='!==undefined){',cu='if(computed===undefined)computed=null;',cv="Unknown reason: ",cw="init",cx='qx.core.Assert.assertMap(value, msg) || true',cy="qx.aspects",cz='qx.core.Assert.assertNumber(value, msg) || true',cA='if((computed===undefined||computed===inherit)&&',cB="reg.fireEvent(this, '",cC='Null value is not allowed!',cD='qx.core.Assert.assertInteger(value, msg) || true',cE="value",cF="shorthand",cG='computed=this.',cH='qx.core.Assert.assertInstance(value, RegExp, msg) || true',cI='value !== null && value.type !== undefined',cJ='value !== null && value.document',cK="",cL='throw new Error("Property ',cM="(!this.",cN='qx.core.Assert.assertBoolean(value, msg) || true',cO='if(a[i].',cP=' of an instance of ',cQ="toggle",cR="refresh",cS="$$inherit_",cT='var prop=qx.core.Property;',cU="boolean",cV=" with incoming value '",cW="a=qx.lang.Array.fromShortHand(qx.lang.Array.fromArguments(a));",cX='if(computed===undefined||computed==inherit)computed=null;',cY="qx.core.Property",da="is",db=' is not (yet) ready!");',dc="]);",dd='Could not change or apply init value after constructing phase!';qx.Bootstrap.define(cY,{statics:{__X:function(){if(qx.core.Environment.get(bc)){qx.event.type.Data;qx.event.dispatch.Direct;};},__Y:{"Boolean":cN,"String":cf,"Number":cz,"Integer":cD,"PositiveNumber":bG,"PositiveInteger":be,"Error":z,"RegExp":cH,"Object":cc,"Array":bD,"Map":cx,"Function":ck,"Date":v,"Node":V,"Element":o,"Document":h,"Window":cJ,"Event":cI,"Class":cj,"Mixin":k,"Interface":bk,"Theme":bV,"Color":c,"Decorator":X,"Font":d},__ba:{"Node":true,"Element":true,"Document":true,"Window":true,"Event":true},$$inherit:I,$$store:{runtime:{},user:{},theme:{},inherit:{},init:{},useinit:{}},$$method:{get:{},set:{},reset:{},init:{},refresh:{},setRuntime:{},resetRuntime:{},setThemed:{},resetThemed:{}},$$allowedKeys:{name:ba,dereference:cU,inheritable:cU,nullable:cU,themeable:cU,refine:cU,init:null,apply:ba,event:ba,check:null,transform:ba,deferredInit:cU,validate:null},$$allowedGroupKeys:{name:ba,group:cq,mode:ba,themeable:cU},$$inheritable:{},__bb:function(dg){var de=this.__bc(dg);if(!de.length){var df=function(){};}else {df=this.__bd(de);};dg.prototype.$$refreshInheritables=df;},__bc:function(dh){var di=[];while(dh){var dj=dh.$$properties;if(dj){for(var name in this.$$inheritable){if(dj[name]&&dj[name].inheritable){di.push(name);};};};dh=dh.superclass;};return di;},__bd:function(inheritables){var inherit=this.$$store.inherit;var init=this.$$store.init;var refresh=this.$$method.refresh;var code=[p,x];for(var i=0,l=inheritables.length;i<l;i++ ){var name=inheritables[i];code.push(bn,inherit[name],bF,ci,init[name],bF,bO,refresh[name],bq);};return new Function(code.join(cK));},attachRefreshInheritables:function(dk){dk.prototype.$$refreshInheritables=function(){qx.core.Property.__bb(dk);return this.$$refreshInheritables();};},attachMethods:function(dm,name,dl){dl.group?this.__be(dm,dl,name):this.__bf(dm,dl,name);},__be:function(clazz,config,name){var upname=qx.Bootstrap.firstUp(name);var members=clazz.prototype;var themeable=config.themeable===true;{};var setter=[];var resetter=[];if(themeable){var styler=[];var unstyler=[];};var argHandler=bT;setter.push(argHandler);if(themeable){styler.push(argHandler);};if(config.mode==cF){var shorthand=cW;setter.push(shorthand);if(themeable){styler.push(shorthand);};};for(var i=0,a=config.group,l=a.length;i<l;i++ ){{};setter.push(bO,this.$$method.set[a[i]],bK,i,dc);resetter.push(bO,this.$$method.reset[a[i]],t);if(themeable){{};styler.push(bO,this.$$method.setThemed[a[i]],bK,i,dc);unstyler.push(bO,this.$$method.resetThemed[a[i]],t);};};this.$$method.set[name]=e+upname;members[this.$$method.set[name]]=new Function(setter.join(cK));this.$$method.reset[name]=Y+upname;members[this.$$method.reset[name]]=new Function(resetter.join(cK));if(themeable){this.$$method.setThemed[name]=bx+upname;members[this.$$method.setThemed[name]]=new Function(styler.join(cK));this.$$method.resetThemed[name]=g+upname;members[this.$$method.resetThemed[name]]=new Function(unstyler.join(cK));};},__bf:function(clazz,config,name){var upname=qx.Bootstrap.firstUp(name);var members=clazz.prototype;{};if(config.dereference===undefined&&typeof config.check===ba){config.dereference=this.__bg(config.check);};var method=this.$$method;var store=this.$$store;store.runtime[name]=bw+name;store.user[name]=bA+name;store.theme[name]=cs+name;store.init[name]=cr+name;store.inherit[name]=cS+name;store.useinit[name]=bo+name;method.get[name]=bj+upname;members[method.get[name]]=function(){return qx.core.Property.executeOptimizedGetter(this,clazz,name,bj);};method.set[name]=e+upname;members[method.set[name]]=function(dn){return qx.core.Property.executeOptimizedSetter(this,clazz,name,e,arguments);};method.reset[name]=Y+upname;members[method.reset[name]]=function(){return qx.core.Property.executeOptimizedSetter(this,clazz,name,Y);};if(config.inheritable||config.apply||config.event||config.deferredInit){method.init[name]=cw+upname;members[method.init[name]]=function(dp){return qx.core.Property.executeOptimizedSetter(this,clazz,name,cw,arguments);};{};};if(config.inheritable){method.refresh[name]=cR+upname;members[method.refresh[name]]=function(dq){return qx.core.Property.executeOptimizedSetter(this,clazz,name,cR,arguments);};{};};method.setRuntime[name]=bM+upname;members[method.setRuntime[name]]=function(dr){return qx.core.Property.executeOptimizedSetter(this,clazz,name,bM,arguments);};method.resetRuntime[name]=S+upname;members[method.resetRuntime[name]]=function(){return qx.core.Property.executeOptimizedSetter(this,clazz,name,S);};if(config.themeable){method.setThemed[name]=bx+upname;members[method.setThemed[name]]=function(ds){return qx.core.Property.executeOptimizedSetter(this,clazz,name,bx,arguments);};method.resetThemed[name]=g+upname;members[method.resetThemed[name]]=function(){return qx.core.Property.executeOptimizedSetter(this,clazz,name,g);};{};};if(config.check===bI){members[cQ+upname]=new Function(bd+method.set[name]+cM+method.get[name]+bY);members[da+upname]=new Function(bd+method.get[name]+bS);{};};{};},__bg:function(dt){return !!this.__ba[dt];},__bh:{'0':dd,'1':bs,'2':B,'3':bQ,'4':cC,'5':M},error:function(du,dA,dz,dv,dw){var dx=du.constructor.classname;var dy=q+dz+U+dx+y+this.$$method[dv][dz]+cV+dw+T;throw new Error(dy+(this.__bh[dA]||cv+dA));},__bi:function(instance,members,name,variant,code,args){var store=this.$$method[variant][name];{members[store]=new Function(cE,code.join(cK));};if(qx.core.Environment.get(cy)){members[store]=qx.core.Aspect.wrap(instance.classname+co+store,members[store],s);};qx.Bootstrap.setDisplayName(members[store],instance.classname+bH,store);if(args===undefined){return instance[store]();}else {return instance[store](args[0]);};},executeOptimizedGetter:function(dE,dD,name,dC){var dG=dD.$$properties[name];var dF=dD.prototype;var dB=[];var dH=this.$$store;dB.push(J,dH.runtime[name],bB);dB.push(K,dH.runtime[name],f);if(dG.inheritable){dB.push(L,dH.inherit[name],bB);dB.push(K,dH.inherit[name],f);dB.push(D);};dB.push(J,dH.user[name],bB);dB.push(K,dH.user[name],f);if(dG.themeable){dB.push(L,dH.theme[name],bB);dB.push(K,dH.theme[name],f);};if(dG.deferredInit&&dG.init===undefined){dB.push(L,dH.init[name],bB);dB.push(K,dH.init[name],f);};dB.push(D);if(dG.init!==undefined){if(dG.inheritable){dB.push(n,dH.init[name],f);if(dG.nullable){dB.push(bi);};dB.push(m);}else {dB.push(K,dH.init[name],f);};}else if(dG.inheritable||dG.nullable){dB.push(cb);}else {dB.push(cL,name,cP,dD.classname,db);};return this.__bi(dE,dF,name,dC,dB);},executeOptimizedSetter:function(dO,dN,name,dM,dL){var dQ=dN.$$properties[name];var dP=dN.prototype;var dJ=[];var dI=dM===e||dM===bx||dM===bM||(dM===cw&&dQ.init===undefined);var dK=dQ.apply||dQ.event||dQ.inheritable;var dR=this.__bj(dM,name);this.__bk(dJ,dQ,name,dM,dI);if(dI){this.__bl(dJ,dN,dQ,name);};if(dK){this.__bm(dJ,dI,dR,dM);};if(dQ.inheritable){dJ.push(bl);};{};if(!dK){this.__bo(dJ,name,dM,dI);}else {this.__bp(dJ,dQ,name,dM,dI);};if(dQ.inheritable){this.__bq(dJ,dQ,name,dM);}else if(dK){this.__br(dJ,dQ,name,dM);};if(dK){this.__bs(dJ,dQ,name,dM);if(dQ.inheritable&&dP._getChildren){this.__bt(dJ,name);};};if(dI){dJ.push(bN);};return this.__bi(dO,dP,name,dM,dJ,dL);},__bj:function(dS,name){if(dS===bM||dS===S){var dT=this.$$store.runtime[name];}else if(dS===bx||dS===g){dT=this.$$store.theme[name];}else if(dS===cw){dT=this.$$store.init[name];}else {dT=this.$$store.user[name];};return dT;},__bk:function(dW,dU,name,dX,dV){{if(!dU.nullable||dU.check||dU.inheritable){dW.push(cT);};if(dX===e){dW.push(N,name,bh,dX,bt);};};},__bl:function(dY,eb,ea,name){if(ea.transform){dY.push(bg,ea.transform,bz);};if(ea.validate){if(typeof ea.validate===ba){dY.push(br,ea.validate,bz);}else if(ea.validate instanceof Function){dY.push(eb.classname,bU,name);dY.push(u);};};},__bm:function(ed,ec,ef,ee){var eg=(ee===Y||ee===g||ee===S);if(ec){ed.push(J,ef,j);}else if(eg){ed.push(J,ef,W);};},__bn:undefined,__bo:function(ei,name,ej,eh){if(ej===bM){ei.push(br,this.$$store.runtime[name],ca);}else if(ej===S){ei.push(J,this.$$store.runtime[name],bB);ei.push(R,this.$$store.runtime[name],f);}else if(ej===e){ei.push(br,this.$$store.user[name],ca);}else if(ej===Y){ei.push(J,this.$$store.user[name],bB);ei.push(R,this.$$store.user[name],f);}else if(ej===bx){ei.push(br,this.$$store.theme[name],ca);}else if(ej===g){ei.push(J,this.$$store.theme[name],bB);ei.push(R,this.$$store.theme[name],f);}else if(ej===cw&&eh){ei.push(br,this.$$store.init[name],ca);};},__bp:function(em,ek,name,en,el){if(ek.inheritable){em.push(P,this.$$store.inherit[name],f);}else {em.push(cm);};em.push(J,this.$$store.runtime[name],ct);if(en===bM){em.push(cG,this.$$store.runtime[name],ca);}else if(en===S){em.push(R,this.$$store.runtime[name],f);em.push(J,this.$$store.user[name],bB);em.push(cG,this.$$store.user[name],f);em.push(L,this.$$store.theme[name],bB);em.push(cG,this.$$store.theme[name],f);em.push(L,this.$$store.init[name],ct);em.push(cG,this.$$store.init[name],f);em.push(br,this.$$store.useinit[name],E);em.push(cp);}else {em.push(H,this.$$store.runtime[name],f);if(en===e){em.push(br,this.$$store.user[name],ca);}else if(en===Y){em.push(R,this.$$store.user[name],f);}else if(en===bx){em.push(br,this.$$store.theme[name],ca);}else if(en===g){em.push(R,this.$$store.theme[name],f);}else if(en===cw&&el){em.push(br,this.$$store.init[name],ca);};};em.push(cp);em.push(L,this.$$store.user[name],ct);if(en===e){if(!ek.inheritable){em.push(bW,this.$$store.user[name],f);};em.push(cG,this.$$store.user[name],ca);}else if(en===Y){if(!ek.inheritable){em.push(bW,this.$$store.user[name],f);};em.push(R,this.$$store.user[name],f);em.push(J,this.$$store.runtime[name],bB);em.push(cG,this.$$store.runtime[name],f);em.push(J,this.$$store.theme[name],bB);em.push(cG,this.$$store.theme[name],f);em.push(L,this.$$store.init[name],ct);em.push(cG,this.$$store.init[name],f);em.push(br,this.$$store.useinit[name],E);em.push(cp);}else {if(en===bM){em.push(cG,this.$$store.runtime[name],ca);}else if(ek.inheritable){em.push(cG,this.$$store.user[name],f);}else {em.push(H,this.$$store.user[name],f);};if(en===bx){em.push(br,this.$$store.theme[name],ca);}else if(en===g){em.push(R,this.$$store.theme[name],f);}else if(en===cw&&el){em.push(br,this.$$store.init[name],ca);};};em.push(cp);if(ek.themeable){em.push(L,this.$$store.theme[name],ct);if(!ek.inheritable){em.push(bW,this.$$store.theme[name],f);};if(en===bM){em.push(cG,this.$$store.runtime[name],ca);}else if(en===e){em.push(cG,this.$$store.user[name],ca);}else if(en===bx){em.push(cG,this.$$store.theme[name],ca);}else if(en===g){em.push(R,this.$$store.theme[name],f);em.push(J,this.$$store.init[name],ct);em.push(cG,this.$$store.init[name],f);em.push(br,this.$$store.useinit[name],E);em.push(cp);}else if(en===cw){if(el){em.push(br,this.$$store.init[name],ca);};em.push(cG,this.$$store.theme[name],f);}else if(en===cR){em.push(cG,this.$$store.theme[name],f);};em.push(cp);};em.push(L,this.$$store.useinit[name],bC);if(!ek.inheritable){em.push(bW,this.$$store.init[name],f);};if(en===cw){if(el){em.push(cG,this.$$store.init[name],ca);}else {em.push(cG,this.$$store.init[name],f);};}else if(en===e||en===bM||en===bx||en===cR){em.push(R,this.$$store.useinit[name],f);if(en===bM){em.push(cG,this.$$store.runtime[name],ca);}else if(en===e){em.push(cG,this.$$store.user[name],ca);}else if(en===bx){em.push(cG,this.$$store.theme[name],ca);}else if(en===cR){em.push(cG,this.$$store.init[name],f);};};em.push(cp);if(en===e||en===bM||en===bx||en===cw){em.push(w);if(en===bM){em.push(cG,this.$$store.runtime[name],ca);}else if(en===e){em.push(cG,this.$$store.user[name],ca);}else if(en===bx){em.push(cG,this.$$store.theme[name],ca);}else if(en===cw){if(el){em.push(cG,this.$$store.init[name],ca);}else {em.push(cG,this.$$store.init[name],f);};em.push(br,this.$$store.useinit[name],E);};em.push(cp);};},__bq:function(ep,eo,name,eq){ep.push(bE);if(eq===cR){ep.push(bu);}else {ep.push(ch,this.$$store.inherit[name],f);};ep.push(cA);ep.push(br,this.$$store.init[name],cl);ep.push(br,this.$$store.init[name],b);ep.push(cG,this.$$store.init[name],f);ep.push(br,this.$$store.useinit[name],E);ep.push(bv);ep.push(R,this.$$store.useinit[name],by);ep.push(cp);ep.push(ce);ep.push(G);ep.push(bp,this.$$store.inherit[name],f);ep.push(cp);ep.push(Q);ep.push(R,this.$$store.inherit[name],f);ep.push(bf,this.$$store.inherit[name],A);ep.push(cn);if(eo.init!==undefined&&eq!==cw){ep.push(F,this.$$store.init[name],bF);}else {ep.push(cg);};ep.push(cX);},__br:function(es,er,name,et){if(et!==e&&et!==bM&&et!==bx){es.push(cu);};es.push(ce);if(er.init!==undefined&&et!==cw){es.push(F,this.$$store.init[name],bF);}else {es.push(cg);};},__bs:function(ev,eu,name,ew){if(eu.apply){ev.push(br,eu.apply,bL,name,O,ew,cd);};if(eu.event){ev.push(bX,bP,eu.event,bb,cB,eu.event,bm,bJ);};},__bt:function(ex,name){ex.push(r);ex.push(cO,this.$$method.refresh[name],bR,this.$$method.refresh[name],C);ex.push(cp);}}});})();(function(){var b=".prototype",c="$$init_",d="constructor",e="Property module disabled.",f="extend",g="module.property",h="singleton",j="qx.event.type.Data",k="module.events",m="qx.aspects",n="toString",o='extend',p="Array",q="static",r="",s="Events module not enabled.",t="]",u="Class",v="qx.Class",w='"extend" parameter is null or undefined',x="[Class ",y="destructor",z="destruct",A=".",B="member";qx.Bootstrap.define(v,{statics:{__bu:qx.core.Environment.get(g)?qx.core.Property:null,define:function(name,F){if(!F){F={};};if(F.include&&!(qx.Bootstrap.getClass(F.include)===p)){F.include=[F.include];};if(F.implement&&!(qx.Bootstrap.getClass(F.implement)===p)){F.implement=[F.implement];};var C=false;if(!F.hasOwnProperty(f)&&!F.type){F.type=q;C=true;};{};var D=this.__bx(name,F.type,F.extend,F.statics,F.construct,F.destruct,F.include);if(F.extend){if(F.properties){this.__bz(D,F.properties,true);};if(F.members){this.__bB(D,F.members,true,true,false);};if(F.events){this.__by(D,F.events,true);};if(F.include){for(var i=0,l=F.include.length;i<l;i++ ){this.__bF(D,F.include[i],false);};};}else if(F.hasOwnProperty(o)&&false){throw new Error(w);};if(F.environment){for(var E in F.environment){qx.core.Environment.add(E,F.environment[E]);};};if(F.implement){for(var i=0,l=F.implement.length;i<l;i++ ){this.__bD(D,F.implement[i]);};};{};if(F.defer){F.defer.self=D;F.defer(D,D.prototype,{add:function(name,G){var H={};H[name]=G;qx.Class.__bz(D,H,true);}});};return D;},undefine:function(name){delete this.$$registry[name];var K=name.split(A);var J=[window];for(var i=0;i<K.length;i++ ){J.push(J[i][K[i]]);};for(var i=J.length-1;i>=1;i-- ){var I=J[i];var parent=J[i-1];if(qx.Bootstrap.isFunction(I)||qx.Bootstrap.objectGetLength(I)===0){delete parent[K[i-1]];}else {break;};};},isDefined:qx.util.OOUtil.classIsDefined,getTotalNumber:function(){return qx.Bootstrap.objectGetLength(this.$$registry);},getByName:qx.Bootstrap.getByName,include:function(M,L){{};qx.Class.__bF(M,L,false);},patch:function(O,N){{};qx.Class.__bF(O,N,true);},isSubClassOf:function(Q,P){if(!Q){return false;};if(Q==P){return true;};if(Q.prototype instanceof P){return true;};return false;},getPropertyDefinition:qx.util.OOUtil.getPropertyDefinition,getProperties:function(S){var R=[];while(S){if(S.$$properties){R.push.apply(R,Object.keys(S.$$properties));};S=S.superclass;};return R;},getByProperty:function(T,name){while(T){if(T.$$properties&&T.$$properties[name]){return T;};T=T.superclass;};return null;},hasProperty:qx.util.OOUtil.hasProperty,getEventType:qx.util.OOUtil.getEventType,supportsEvent:qx.util.OOUtil.supportsEvent,hasOwnMixin:function(V,U){return V.$$includes&&V.$$includes.indexOf(U)!==-1;},getByMixin:function(Y,X){var W,i,l;while(Y){if(Y.$$includes){W=Y.$$flatIncludes;for(i=0,l=W.length;i<l;i++ ){if(W[i]===X){return Y;};};};Y=Y.superclass;};return null;},getMixins:qx.util.OOUtil.getMixins,hasMixin:function(bb,ba){return !!this.getByMixin(bb,ba);},hasOwnInterface:function(bd,bc){return bd.$$implements&&bd.$$implements.indexOf(bc)!==-1;},getByInterface:qx.util.OOUtil.getByInterface,getInterfaces:function(bf){var be=[];while(bf){if(bf.$$implements){be.push.apply(be,bf.$$flatImplements);};bf=bf.superclass;};return be;},hasInterface:qx.util.OOUtil.hasInterface,implementsInterface:function(bh,bg){var bi=bh.constructor;if(this.hasInterface(bi,bg)){return true;};if(qx.Interface.objectImplements(bh,bg)){return true;};if(qx.Interface.classImplements(bi,bg)){return true;};return false;},getInstance:function(){if(!this.$$instance){this.$$allowconstruct=true;this.$$instance=new this();delete this.$$allowconstruct;};return this.$$instance;},genericToString:function(){return x+this.classname+t;},$$registry:qx.Bootstrap.$$registry,__h:null,__bv:null,__i:function(name,bj){},__bw:function(bk){},__bx:function(name,bu,bt,bl,br,bp,bo){var bq;if(!bt&&qx.core.Environment.get(m)==false){bq=bl||{};qx.Bootstrap.setDisplayNames(bq,name);}else {bq={};if(bt){if(!br){br=this.__bG();};if(this.__bH(bt,bo)){bq=this.__bI(br,name,bu);}else {bq=br;};if(bu===h){bq.getInstance=this.getInstance;};qx.Bootstrap.setDisplayName(br,name,d);};if(bl){qx.Bootstrap.setDisplayNames(bl,name);var bs;for(var i=0,a=Object.keys(bl),l=a.length;i<l;i++ ){bs=a[i];var bm=bl[bs];if(qx.core.Environment.get(m)){if(bm instanceof Function){bm=qx.core.Aspect.wrap(name+A+bs,bm,q);};bq[bs]=bm;}else {bq[bs]=bm;};};};};var bn=name?qx.Bootstrap.createNamespace(name,bq):r;bq.name=bq.classname=name;bq.basename=bn;bq.$$type=u;if(bu){bq.$$classtype=bu;};if(!bq.hasOwnProperty(n)){bq.toString=this.genericToString;};if(bt){qx.Bootstrap.extendClass(bq,br,bt,name,bn);if(bp){if(qx.core.Environment.get(m)){bp=qx.core.Aspect.wrap(name,bp,y);};bq.$$destructor=bp;qx.Bootstrap.setDisplayName(bp,name,z);};};this.$$registry[name]=bq;return bq;},__by:function(bv,bw,by){{var bx,bx;};if(bv.$$events){for(var bx in bw){bv.$$events[bx]=bw[bx];};}else {bv.$$events=bw;};},__bz:function(bA,bD,bB){if(!qx.core.Environment.get(g)){throw new Error(e);};var bC;if(bB===undefined){bB=false;};var bz=bA.prototype;for(var name in bD){bC=bD[name];{};bC.name=name;if(!bC.refine){if(bA.$$properties===undefined){bA.$$properties={};};bA.$$properties[name]=bC;};if(bC.init!==undefined){bA.prototype[c+name]=bC.init;};if(bC.event!==undefined){if(!qx.core.Environment.get(k)){throw new Error(s);};var event={};event[bC.event]=j;this.__by(bA,event,bB);};if(bC.inheritable){this.__bu.$$inheritable[name]=true;if(!bz.$$refreshInheritables){this.__bu.attachRefreshInheritables(bA);};};if(!bC.refine){this.__bu.attachMethods(bA,name,bC);};};},__bA:null,__bB:function(bL,bE,bG,bI,bK){var bF=bL.prototype;var bJ,bH;qx.Bootstrap.setDisplayNames(bE,bL.classname+b);for(var i=0,a=Object.keys(bE),l=a.length;i<l;i++ ){bJ=a[i];bH=bE[bJ];{};if(bI!==false&&bH instanceof Function&&bH.$$type==null){if(bK==true){bH=this.__bC(bH,bF[bJ]);}else {if(bF[bJ]){bH.base=bF[bJ];};bH.self=bL;};if(qx.core.Environment.get(m)){bH=qx.core.Aspect.wrap(bL.classname+A+bJ,bH,B);};};bF[bJ]=bH;};},__bC:function(bM,bN){if(bN){return function(){var bP=bM.base;bM.base=bN;var bO=bM.apply(this,arguments);bM.base=bP;return bO;};}else {return bM;};},__bD:function(bS,bQ){{};var bR=qx.Interface.flatten([bQ]);if(bS.$$implements){bS.$$implements.push(bQ);bS.$$flatImplements.push.apply(bS.$$flatImplements,bR);}else {bS.$$implements=[bQ];bS.$$flatImplements=bR;};},__bE:function(bU){var name=bU.classname;var bT=this.__bI(bU,name,bU.$$classtype);for(var i=0,a=Object.keys(bU),l=a.length;i<l;i++ ){bV=a[i];bT[bV]=bU[bV];};bT.prototype=bU.prototype;var bX=bU.prototype;for(var i=0,a=Object.keys(bX),l=a.length;i<l;i++ ){bV=a[i];var bY=bX[bV];if(bY&&bY.self==bU){bY.self=bT;};};for(var bV in this.$$registry){var bW=this.$$registry[bV];if(!bW){continue;};if(bW.base==bU){bW.base=bT;};if(bW.superclass==bU){bW.superclass=bT;};if(bW.$$original){if(bW.$$original.base==bU){bW.$$original.base=bT;};if(bW.$$original.superclass==bU){bW.$$original.superclass=bT;};};};qx.Bootstrap.createNamespace(name,bT);this.$$registry[name]=bT;return bT;},__bF:function(cf,cd,cc){{};if(this.hasMixin(cf,cd)){return;};var ca=cf.$$original;if(cd.$$constructor&&!ca){cf=this.__bE(cf);};var cb=qx.Mixin.flatten([cd]);var ce;for(var i=0,l=cb.length;i<l;i++ ){ce=cb[i];if(ce.$$events){this.__by(cf,ce.$$events,cc);};if(ce.$$properties){this.__bz(cf,ce.$$properties,cc);};if(ce.$$members){this.__bB(cf,ce.$$members,cc,cc,cc);};};if(cf.$$includes){cf.$$includes.push(cd);cf.$$flatIncludes.push.apply(cf.$$flatIncludes,cb);}else {cf.$$includes=[cd];cf.$$flatIncludes=cb;};},__bG:function(){function cg(){cg.base.apply(this,arguments);};return cg;},__bH:function(ci,ch){{};if(ci&&ci.$$includes){var cj=ci.$$flatIncludes;for(var i=0,l=cj.length;i<l;i++ ){if(cj[i].$$constructor){return true;};};};if(ch){var ck=qx.Mixin.flatten(ch);for(var i=0,l=ck.length;i<l;i++ ){if(ck[i].$$constructor){return true;};};};return false;},__bI:function(cm,name,cl){var co=function(){var cr=co;{};var cp=cr.$$original.apply(this,arguments);if(cr.$$includes){var cq=cr.$$flatIncludes;for(var i=0,l=cq.length;i<l;i++ ){if(cq[i].$$constructor){cq[i].$$constructor.apply(this,arguments);};};};{};return cp;};if(qx.core.Environment.get(m)){var cn=qx.core.Aspect.wrap(name,co,d);co.$$original=cm;co.constructor=cn;co=cn;};co.$$original=cm;cm.wrapper=co;return co;}},defer:function(){if(qx.core.Environment.get(m)){for(var cs in qx.Bootstrap.$$registry){var ct=qx.Bootstrap.$$registry[cs];for(var cu in ct){if(ct[cu] instanceof Function){ct[cu]=qx.core.Aspect.wrap(cs+A+cu,ct[cu],q);};};};};}});})();(function(){var a="qx.data.MBinding";qx.Mixin.define(a,{construct:function(){this.__bJ=this.toHashCode();},members:{__bJ:null,bind:function(b,e,c,d){return qx.data.SingleValueBinding.bind(this,b,e,c,d);},removeBinding:function(f){qx.data.SingleValueBinding.removeBindingFromObject(this,f);},removeRelatedBindings:function(g){qx.data.SingleValueBinding.removeRelatedBindings(this,g);},removeAllBindings:function(){qx.data.SingleValueBinding.removeAllBindingsForObject(this);},getBindings:function(){return qx.data.SingleValueBinding.getAllBindingsForObject(this);}},destruct:function(){this.$$hash=this.__bJ;this.removeAllBindings();delete this.$$hash;}});})();(function(){var a=". Error message: ",b="Boolean",c=").",d="set",f="deepBinding",g=") to the object '",h="item",k="Please use only one array at a time: ",l="Integer",m="reset",n=" of object ",p="qx.data.SingleValueBinding",q="Binding property ",r="Failed so set value ",s="change",t="Binding could not be found!",u="get",v="^",w=" does not work.",x="String",y="Binding from '",z="",A="PositiveNumber",B="]",C="[",D=".",E="PositiveInteger",F='No number or \'last\' value hast been given in an array binding: ',G="' (",H=" on ",I="Binding does not exist!",J="Number",K=".[",L="Date",M=" not possible: No event available. ",N="last";qx.Class.define(p,{statics:{__bK:{},__bL:{},bind:function(bb,U,bg,bd,bj){{};var bf=this.__bN(bb,U,bg,bd,bj);var Q=U.split(D);var P=this.__bV(Q);var S=[];var bh=[];var R=[];var T=[];var Y=bb;try{for(var i=0;i<Q.length;i++ ){if(P[i]!==z){T.push(s);}else {var X=this.__bO(Y,Q[i]);if(!X){if(i==0){throw new qx.core.AssertionError(q+Q[i]+n+Y+M);};this.__bU(undefined,bg,bd,bj,bb);break;};T.push(X);};S[i]=Y;if(i==Q.length-1){if(P[i]!==z){var ba=P[i]===N?Y.length-1:P[i];var O=Y.getItem(ba);this.__bU(O,bg,bd,bj,bb);R[i]=this.__bW(Y,T[i],bg,bd,bj,P[i]);}else {if(Q[i]!=null&&Y[u+qx.lang.String.firstUp(Q[i])]!=null){var O=Y[u+qx.lang.String.firstUp(Q[i])]();this.__bU(O,bg,bd,bj,bb);};R[i]=this.__bW(Y,T[i],bg,bd,bj);};}else {var bi={index:i,propertyNames:Q,sources:S,listenerIds:R,arrayIndexValues:P,targetObject:bg,targetPropertyChain:bd,options:bj,listeners:bh};var be=qx.lang.Function.bind(this.__bM,this,bi);bh.push(be);R[i]=Y.addListener(T[i],be);};if(Y[u+qx.lang.String.firstUp(Q[i])]==null){Y=undefined;}else if(P[i]!==z){var ba=P[i]===N?Y.length-1:P[i];Y=Y[u+qx.lang.String.firstUp(Q[i])](ba);}else {Y=Y[u+qx.lang.String.firstUp(Q[i])]();if(Y===null&&(Q.length-1)!=i){Y=undefined;};};if(!Y){this.__bU(Y,bg,bd,bj,bb);break;};};}catch(bk){for(var i=0;i<S.length;i++ ){if(S[i]&&R[i]){S[i].removeListenerById(R[i]);};};var V=bf.targets;var bc=bf.listenerIds;for(var i=0;i<V.length;i++ ){if(V[i]&&bc[i]){V[i].removeListenerById(bc[i]);};};throw bk;};var W={type:f,listenerIds:R,sources:S,targetListenerIds:bf.listenerIds,targets:bf.targets};this.__bX(W,bb,U,bg,bd);return W;},__bM:function(br){if(br.options&&br.options.onUpdate){br.options.onUpdate(br.sources[br.index],br.targetObject);};for(var j=br.index+1;j<br.propertyNames.length;j++ ){var bp=br.sources[j];br.sources[j]=null;if(!bp){continue;};bp.removeListenerById(br.listenerIds[j]);};var bp=br.sources[br.index];for(var j=br.index+1;j<br.propertyNames.length;j++ ){if(br.arrayIndexValues[j-1]!==z){bp=bp[u+qx.lang.String.firstUp(br.propertyNames[j-1])](br.arrayIndexValues[j-1]);}else {bp=bp[u+qx.lang.String.firstUp(br.propertyNames[j-1])]();};br.sources[j]=bp;if(!bp){if(br.options&&br.options.converter){var bl=false;if(br.options.ignoreConverter){var bs=br.propertyNames.slice(0,j).join(D);var bq=bs.match(new RegExp(v+br.options.ignoreConverter));bl=bq?bq.length>0:false;};if(!bl){this.__bQ(br.targetObject,br.targetPropertyChain,br.options.converter());}else {this.__bP(br.targetObject,br.targetPropertyChain);};}else {this.__bP(br.targetObject,br.targetPropertyChain);};break;};if(j==br.propertyNames.length-1){if(qx.Class.implementsInterface(bp,qx.data.IListData)){var bt=br.arrayIndexValues[j]===N?bp.length-1:br.arrayIndexValues[j];var bm=bp.getItem(bt);this.__bU(bm,br.targetObject,br.targetPropertyChain,br.options,br.sources[br.index]);br.listenerIds[j]=this.__bW(bp,s,br.targetObject,br.targetPropertyChain,br.options,br.arrayIndexValues[j]);}else {if(br.propertyNames[j]!=null&&bp[u+qx.lang.String.firstUp(br.propertyNames[j])]!=null){var bm=bp[u+qx.lang.String.firstUp(br.propertyNames[j])]();this.__bU(bm,br.targetObject,br.targetPropertyChain,br.options,br.sources[br.index]);};var bn=this.__bO(bp,br.propertyNames[j]);if(!bn){this.__bP(br.targetObject,br.targetPropertyChain);break;};br.listenerIds[j]=this.__bW(bp,bn,br.targetObject,br.targetPropertyChain,br.options);};}else {if(br.listeners[j]==null){var bo=qx.lang.Function.bind(this.__bM,this,br);br.listeners.push(bo);};if(qx.Class.implementsInterface(bp,qx.data.IListData)){var bn=s;}else {var bn=this.__bO(bp,br.propertyNames[j]);};if(!bn){this.__bP(br.targetObject,br.targetPropertyChain);return;};br.listenerIds[j]=bp.addListener(bn,br.listeners[j]);};};},__bN:function(bw,bE,bI,bA,bC){var bz=bA.split(D);var bx=this.__bV(bz);var bH=[];var bG=[];var bB=[];var bF=[];var by=bI;for(var i=0;i<bz.length-1;i++ ){if(bx[i]!==z){bF.push(s);}else {var bv=this.__bO(by,bz[i]);if(!bv){break;};bF.push(bv);};bH[i]=by;var bD=function(){for(var j=i+1;j<bz.length-1;j++ ){var bL=bH[j];bH[j]=null;if(!bL){continue;};bL.removeListenerById(bB[j]);};var bL=bH[i];for(var j=i+1;j<bz.length-1;j++ ){var bJ=qx.lang.String.firstUp(bz[j-1]);if(bx[j-1]!==z){var bM=bx[j-1]===N?bL.getLength()-1:bx[j-1];bL=bL[u+bJ](bM);}else {bL=bL[u+bJ]();};bH[j]=bL;if(bG[j]==null){bG.push(bD);};if(qx.Class.implementsInterface(bL,qx.data.IListData)){var bK=s;}else {var bK=qx.data.SingleValueBinding.__bO(bL,bz[j]);if(!bK){break;};};bB[j]=bL.addListener(bK,bG[j]);};qx.data.SingleValueBinding.updateTarget(bw,bE,bI,bA,bC);};bG.push(bD);bB[i]=by.addListener(bF[i],bD);var bu=qx.lang.String.firstUp(bz[i]);if(by[u+bu]==null){by=null;}else if(bx[i]!==z){by=by[u+bu](bx[i]);}else {by=by[u+bu]();};if(!by){break;};};return {listenerIds:bB,targets:bH};},updateTarget:function(bN,bQ,bS,bO,bR){var bP=this.resolvePropertyChain(bN,bQ);bP=qx.data.SingleValueBinding.__bY(bP,bS,bO,bR,bN);this.__bQ(bS,bO,bP);},resolvePropertyChain:function(o,bT){var bU=this.__bS(bT);return this.__bT(o,bU,bU.length);},__bO:function(bW,bX){var bV=this.__ca(bW,bX);if(bV==null){if(qx.Class.supportsEvent(bW.constructor,bX)){bV=bX;}else if(qx.Class.supportsEvent(bW.constructor,s+qx.lang.String.firstUp(bX))){bV=s+qx.lang.String.firstUp(bX);}else {return null;};};return bV;},__bP:function(cd,cb){var cc=this.__bS(cb);var ca=this.__bT(cd,cc);if(ca!=null){var ce=cc[cc.length-1];var bY=this.__bR(ce);if(bY){this.__bQ(cd,cb,null);return;};if(ca[m+qx.lang.String.firstUp(ce)]!=undefined){ca[m+qx.lang.String.firstUp(ce)]();}else {ca[d+qx.lang.String.firstUp(ce)](null);};};},__bQ:function(ck,ch,ci){var cj=this.__bS(ch);var cg=this.__bT(ck,cj);if(cg){var cl=cj[cj.length-1];var cf=this.__bR(cl);if(cf){if(cf===N){cf=cg.length-1;};cg.setItem(cf,ci);}else {cg[d+qx.lang.String.firstUp(cl)](ci);};};},__bR:function(co){var cm=/^\[(\d+|last)\]$/;var cn=co.match(cm);if(cn){return cn[1];};return null;},__bS:function(cp){return cp.replace(/\[/g,K).split(D).filter(function(cq){return cq!==z;});},__bT:function(cw,cr,cs){cs=cs||cr.length-1;var cu=cw;for(var i=0;i<cs;i++ ){try{var cv=cr[i];var ct=this.__bR(cv);if(ct){if(ct===N){ct=cu.length-1;};cu=cu.getItem(ct);}else {cu=cu[u+qx.lang.String.firstUp(cv)]();};}catch(cx){return null;};};return cu;},__bU:function(cC,cy,cA,cB,cz){cC=this.__bY(cC,cy,cA,cB,cz);if(cC===undefined){this.__bP(cy,cA);};if(cC!==undefined){try{this.__bQ(cy,cA,cC);if(cB&&cB.onUpdate){cB.onUpdate(cz,cy,cC);};}catch(e){if(!(e instanceof qx.core.ValidationError)){throw e;};if(cB&&cB.onSetFail){cB.onSetFail(e);}else {qx.log.Logger.warn(r+cC+H+cy+a+e);};};};},__bV:function(cD){var cE=[];for(var i=0;i<cD.length;i++ ){var name=cD[i];if(qx.lang.String.endsWith(name,B)){var cF=name.substring(name.indexOf(C)+1,name.indexOf(B));if(name.indexOf(B)!=name.length-1){throw new Error(k+name+w);};if(cF!==N){if(cF==z||isNaN(parseInt(cF,10))){throw new Error(F+name+w);};};if(name.indexOf(C)!=0){cD[i]=name.substring(0,name.indexOf(C));cE[i]=z;cE[i+1]=cF;cD.splice(i+1,0,h);i++ ;}else {cE[i]=cF;cD.splice(i,1,h);};}else {cE[i]=z;};};return cE;},__bW:function(cG,cJ,cO,cM,cK,cI){{var cH;};var cL=function(cR,e){if(cR!==z){if(cR===N){cR=cG.length-1;};var cS=cG.getItem(cR);if(cS===undefined){qx.data.SingleValueBinding.__bP(cO,cM);};var cQ=e.getData().start;var cP=e.getData().end;if(cR<cQ||cR>cP){return;};}else {var cS=e.getData();};{};cS=qx.data.SingleValueBinding.__bY(cS,cO,cM,cK,cG);{};try{if(cS!==undefined){qx.data.SingleValueBinding.__bQ(cO,cM,cS);}else {qx.data.SingleValueBinding.__bP(cO,cM);};if(cK&&cK.onUpdate){cK.onUpdate(cG,cO,cS);};}catch(cT){if(!(cT instanceof qx.core.ValidationError)){throw cT;};if(cK&&cK.onSetFail){cK.onSetFail(cT);}else {qx.log.Logger.warn(r+cS+H+cO+a+cT);};};};if(!cI){cI=z;};cL=qx.lang.Function.bind(cL,cG,cI);var cN=cG.addListener(cJ,cL);return cN;},__bX:function(da,cU,cX,db,cY){var cV;cV=cU.toHashCode();if(this.__bK[cV]===undefined){this.__bK[cV]=[];};var cW=[da,cU,cX,db,cY];this.__bK[cV].push(cW);cV=db.toHashCode();if(this.__bL[cV]===undefined){this.__bL[cV]=[];};this.__bL[cV].push(cW);},__bY:function(df,dl,de,dh,dc){if(dh&&dh.converter){var di;if(dl.getModel){di=dl.getModel();};return dh.converter(df,di,dc,dl);}else {var dg=this.__bS(de);var dd=this.__bT(dl,dg);var dm=de.substring(de.lastIndexOf(D)+1,de.length);if(dd==null){return df;};var dj=qx.Class.getPropertyDefinition(dd.constructor,dm);var dk=dj==null?z:dj.check;return this.__cb(df,dk);};},__ca:function(dn,dq){var dp=qx.Class.getPropertyDefinition(dn.constructor,dq);if(dp==null){return null;};return dp.event;},__cb:function(dt,ds){var dr=qx.lang.Type.getClass(dt);if((dr==J||dr==x)&&(ds==l||ds==E)){dt=parseInt(dt,10);};if((dr==b||dr==J||dr==L)&&ds==x){dt=dt+z;};if((dr==J||dr==x)&&(ds==J||ds==A)){dt=parseFloat(dt);};return dt;},removeBindingFromObject:function(du,dy){if(dy.type==f){for(var i=0;i<dy.sources.length;i++ ){if(dy.sources[i]){dy.sources[i].removeListenerById(dy.listenerIds[i]);};};for(var i=0;i<dy.targets.length;i++ ){if(dy.targets[i]){dy.targets[i].removeListenerById(dy.targetListenerIds[i]);};};}else {du.removeListenerById(dy);};var dx=this.getAllBindingsForObject(du);if(dx!=undefined){for(var i=0;i<dx.length;i++ ){if(dx[i][0]==dy){var dv=dx[i][3];if(this.__bL[dv.toHashCode()]){qx.lang.Array.remove(this.__bL[dv.toHashCode()],dx[i]);};var dw=dx[i][1];if(this.__bK[dw.toHashCode()]){qx.lang.Array.remove(this.__bK[dw.toHashCode()],dx[i]);};return;};};};throw new Error(t);},removeAllBindingsForObject:function(dA){{};var dz=this.getAllBindingsForObject(dA);if(dz!=undefined){for(var i=dz.length-1;i>=0;i-- ){this.removeBindingFromObject(dA,dz[i][0]);};};},removeRelatedBindings:function(dC,dD){{};var dF=this.getAllBindingsForObject(dC);if(dF!=undefined){for(var i=dF.length-1;i>=0;i-- ){var dE=dF[i][1];var dB=dF[i][3];if(dE===dD||dB===dD){this.removeBindingFromObject(dC,dF[i][0]);};};};},getAllBindingsForObject:function(dH){var dI=dH.toHashCode();if(this.__bK[dI]===undefined){this.__bK[dI]=[];};var dJ=this.__bK[dI];var dG=this.__bL[dI]?this.__bL[dI]:[];return qx.lang.Array.unique(dJ.concat(dG));},removeAllBindings:function(){for(var dL in this.__bK){var dK=qx.core.ObjectRegistry.fromHashCode(dL);if(dK==null){delete this.__bK[dL];continue;};this.removeAllBindingsForObject(dK);};this.__bK={};},getAllBindings:function(){return this.__bK;},showBindingInLog:function(dN,dP){var dO;for(var i=0;i<this.__bK[dN.toHashCode()].length;i++ ){if(this.__bK[dN.toHashCode()][i][0]==dP){dO=this.__bK[dN.toHashCode()][i];break;};};if(dO===undefined){var dM=I;}else {var dM=y+dO[1]+G+dO[2]+g+dO[3]+G+dO[4]+c;};qx.log.Logger.debug(dM);},showAllBindingsInLog:function(){for(var dR in this.__bK){var dQ=qx.core.ObjectRegistry.fromHashCode(dR);for(var i=0;i<this.__bK[dR].length;i++ ){this.showBindingInLog(dQ,this.__bK[dR][i][0]);};};}}});})();(function(){var a=": ",b="qx.type.BaseError",c="",d="error";qx.Bootstrap.define(b,{extend:Error,construct:function(e,f){var g=Error.call(this,f);if(g.stack){this.stack=g.stack;};if(g.stacktrace){this.stacktrace=g.stacktrace;};this.__o=e||c;this.message=f||qx.type.BaseError.DEFAULTMESSAGE;},statics:{DEFAULTMESSAGE:d},members:{__p:null,__o:null,message:null,getComment:function(){return this.__o;},toString:function(){return this.__o+(this.message?a+this.message:c);}}});})();(function(){var a="qx.core.AssertionError";qx.Bootstrap.define(a,{extend:qx.type.BaseError,construct:function(b,c){qx.type.BaseError.call(this,b,c);this.__q=qx.dev.StackTrace.getStackTrace();},members:{__q:null,getStackTrace:function(){return this.__q;}}});})();(function(){var a="anonymous",b="...",c="qx.dev.StackTrace",d="",e="\n",f="?",g="/source/class/",h="Error created at",j="ecmascript.error.stacktrace",k="Backtrace:",l="stack",m=":",n=".",o="function",p="prototype",q="stacktrace";qx.Bootstrap.define(c,{statics:{FILENAME_TO_CLASSNAME:null,FORMAT_STACKTRACE:null,getStackTrace:function(){var t=[];try{throw new Error();}catch(G){if(qx.dev.StackTrace.hasEnvironmentCheck&&qx.core.Environment.get(j)){var y=qx.dev.StackTrace.getStackTraceFromError(G);var B=qx.dev.StackTrace.getStackTraceFromCaller(arguments);qx.lang.Array.removeAt(y,0);t=B.length>y.length?B:y;for(var i=0;i<Math.min(B.length,y.length);i++ ){var w=B[i];if(w.indexOf(a)>=0){continue;};var s=null;var C=w.split(n);var v=/(.*?)\(/.exec(C[C.length-1]);if(v&&v.length==2){s=v[1];C.pop();};if(C[C.length-1]==p){C.pop();};var E=C.join(n);var u=y[i];var F=u.split(m);var A=F[0];var z=F[1];var r;if(F[2]){r=F[2];};var x=null;if(qx.Class&&qx.Class.getByName(A)){x=A;}else {x=E;};var D=x;if(s){D+=n+s;};D+=m+z;if(r){D+=m+r;};t[i]=D;};}else {t=this.getStackTraceFromCaller(arguments);};};return t;},getStackTraceFromCaller:function(K){var J=[];var M=qx.lang.Function.getCaller(K);var H={};while(M){var L=qx.lang.Function.getName(M);J.push(L);try{M=M.caller;}catch(N){break;};if(!M){break;};var I=qx.core.ObjectRegistry.toHashCode(M);if(H[I]){J.push(b);break;};H[I]=M;};return J;},getStackTraceFromError:function(be){var U=[];var R,S,bc,Q,P,bg,T,W;var bd=qx.dev.StackTrace.hasEnvironmentCheck?qx.core.Environment.get(j):null;if(bd===l){if(!be.stack){return U;};R=/\s*([^@]+)@(.+):(\d+):(\d+)$/gm;while((S=R.exec(be.stack))!=null){W=S[2];Q=S[3];P=S[4];T=S[1];bc=this.__r(W);U.push(bc+m+T+m+Q+m+P);};if(U.length>0){return this.__t(U);};R=/at (.*)/gm;var bf=/\((.*?)(:[^\/].*)\)/;var bb=/(.*?)(:[^\/].*)/;while((S=R.exec(be.stack))!=null){var ba=bf.exec(S[1]);if(!ba){ba=bb.exec(S[1]);};if(ba){bc=this.__r(ba[1]);U.push(bc+ba[2]);}else {U.push(S[1]);};};}else if(bd===q){var V=be.stacktrace;if(!V){return U;};if(V.indexOf(h)>=0){V=V.split(h)[0];};R=/line\ (\d+?),\ column\ (\d+?)\ in\ (?:.*?)\ in\ (.*?):[^\/]/gm;while((S=R.exec(V))!=null){Q=S[1];P=S[2];W=S[3];bc=this.__r(W);U.push(bc+m+Q+m+P);};if(U.length>0){return this.__t(U);};R=/Line\ (\d+?)\ of\ linked\ script\ (.*?)$/gm;while((S=R.exec(V))!=null){Q=S[1];W=S[2];bc=this.__r(W);U.push(bc+m+Q);};}else if(be.message&&be.message.indexOf(k)>=0){var Y=be.message.split(k)[1].trim();var X=Y.split(e);for(var i=0;i<X.length;i++ ){var O=X[i].match(/\s*Line ([0-9]+) of.* (\S.*)/);if(O&&O.length>=2){Q=O[1];bg=this.__r(O[2]);U.push(bg+m+Q);};};}else if(be.sourceURL&&be.line){U.push(this.__r(be.sourceURL)+m+be.line);};return this.__t(U);},__r:function(bi){if(typeof qx.dev.StackTrace.FILENAME_TO_CLASSNAME==o){var bh=qx.dev.StackTrace.FILENAME_TO_CLASSNAME(bi);{};return bh;};return qx.dev.StackTrace.__s(bi);},__s:function(bl){var bm=g;var bj=bl.indexOf(bm);var bn=bl.indexOf(f);if(bn>=0){bl=bl.substring(0,bn);};var bk=(bj==-1)?bl:bl.substring(bj+bm.length).replace(/\//g,n).replace(/\.js$/,d);return bk;},__t:function(bo){if(typeof qx.dev.StackTrace.FORMAT_STACKTRACE==o){bo=qx.dev.StackTrace.FORMAT_STACKTRACE(bo);{};};return bo;}},defer:function(bp){bp.hasEnvironmentCheck=qx.bom&&qx.bom.client&&qx.bom.client.EcmaScript&&qx.bom.client.EcmaScript.getStackTrace;}});})();(function(){var a="mshtml",b="engine.name",c="[object Array]",d="qx.lang.Array",e="Cannot clean-up map entry doneObjects[",f="]",g="qx",h="number",j="][",k="string";qx.Bootstrap.define(d,{statics:{cast:function(m,o,p){if(m.constructor===o){return m;};if(qx.data&&qx.data.IListData){if(qx.Class&&qx.Class.hasInterface(m,qx.data.IListData)){var m=m.toArray();};};var n=new o;if((qx.core.Environment.get(b)==a)){if(m.item){for(var i=p||0,l=m.length;i<l;i++ ){n.push(m[i]);};return n;};};if(Object.prototype.toString.call(m)===c&&p==null){n.push.apply(n,m);}else {n.push.apply(n,Array.prototype.slice.call(m,p||0));};return n;},fromArguments:function(q,r){return Array.prototype.slice.call(q,r||0);},fromCollection:function(t){if((qx.core.Environment.get(b)==a)){if(t.item){var s=[];for(var i=0,l=t.length;i<l;i++ ){s[i]=t[i];};return s;};};return Array.prototype.slice.call(t,0);},fromShortHand:function(u){var w=u.length;var v=qx.lang.Array.clone(u);switch(w){case 1:v[1]=v[2]=v[3]=v[0];break;case 2:v[2]=v[0];case 3:v[3]=v[1];};return v;},clone:function(x){return x.concat();},insertAt:function(y,z,i){y.splice(i,0,z);return y;},insertBefore:function(A,C,B){var i=A.indexOf(B);if(i==-1){A.push(C);}else {A.splice(i,0,C);};return A;},insertAfter:function(D,F,E){var i=D.indexOf(E);if(i==-1||i==(D.length-1)){D.push(F);}else {D.splice(i+1,0,F);};return D;},removeAt:function(G,i){return G.splice(i,1)[0];},removeAll:function(H){H.length=0;return this;},append:function(J,I){{};Array.prototype.push.apply(J,I);return J;},exclude:function(M,L){{};for(var i=0,N=L.length,K;i<N;i++ ){K=M.indexOf(L[i]);if(K!=-1){M.splice(K,1);};};return M;},remove:function(O,P){var i=O.indexOf(P);if(i!=-1){O.splice(i,1);return P;};},contains:function(Q,R){return Q.indexOf(R)!==-1;},equals:function(T,S){var length=T.length;if(length!==S.length){return false;};for(var i=0;i<length;i++ ){if(T[i]!==S[i]){return false;};};return true;},sum:function(U){var V=0;for(var i=0,l=U.length;i<l;i++ ){if(U[i]!=undefined){V+=U[i];};};return V;},max:function(W){{};var i,Y=W.length,X=W[0];for(i=1;i<Y;i++ ){if(W[i]>X){X=W[i];};};return X===undefined?null:X;},min:function(ba){{};var i,bc=ba.length,bb=ba[0];for(i=1;i<bc;i++ ){if(ba[i]<bb){bb=ba[i];};};return bb===undefined?null:bb;},unique:function(bf){var bp=[],be={},bi={},bk={};var bj,bd=0;var bn=g+Date.now();var bg=false,bl=false,bo=false;for(var i=0,bm=bf.length;i<bm;i++ ){bj=bf[i];if(bj===null){if(!bg){bg=true;bp.push(bj);};}else if(bj===undefined){}else if(bj===false){if(!bl){bl=true;bp.push(bj);};}else if(bj===true){if(!bo){bo=true;bp.push(bj);};}else if(typeof bj===k){if(!be[bj]){be[bj]=1;bp.push(bj);};}else if(typeof bj===h){if(!bi[bj]){bi[bj]=1;bp.push(bj);};}else {var bh=bj[bn];if(bh==null){bh=bj[bn]=bd++ ;};if(!bk[bh]){bk[bh]=bj;bp.push(bj);};};};for(var bh in bk){try{delete bk[bh][bn];}catch(bq){try{bk[bh][bn]=null;}catch(br){throw new Error(e+bh+j+bn+f);};};};return bp;},range:function(bu,stop,bv){if(arguments.length<=1){stop=bu||0;bu=0;};bv=arguments[2]||1;var length=Math.max(Math.ceil((stop-bu)/bv),0);var bs=0;var bt=Array(length);while(bs<length){bt[bs++ ]=bu;bu+=bv;};return bt;}}});})();(function(){var a="[object Opera]",b="function",c="[^\\.0-9]",d="4.0",e="gecko",f="1.9.0.0",g="Version/",h="9.0",i="8.0",j="engine.version",k="Gecko",l="Maple",m="AppleWebKit/",n="Trident",o="Unsupported client: ",p="",q="opera",r="Windows Phone",s="! Assumed gecko version 1.9.0.0 (Firefox 3.0).",t="mshtml",u="engine.name",v="webkit",w="5.0",x=".",y="qx.bom.client.Engine";qx.Bootstrap.define(y,{statics:{getVersion:function(){var B=window.navigator.userAgent;var C=p;if(qx.bom.client.Engine.__y()){var A=/Trident\/([^\);]+)(\)|;)/.test(B);if(/MSIE\s+([^\);]+)(\)|;)/.test(B)){C=RegExp.$1;if(C<8&&A){if(RegExp.$1==d){C=i;}else if(RegExp.$1==w){C=h;};};}else if(A){var E=/\brv\:(\d+?\.\d+?)\b/.exec(B);if(E){C=E[1];};};}else if(qx.bom.client.Engine.__u()){if(/Opera[\s\/]([0-9]+)\.([0-9])([0-9]*)/.test(B)){if(B.indexOf(g)!=-1){var E=B.match(/Version\/(\d+)\.(\d+)/);C=E[1]+x+E[2].charAt(0)+x+E[2].substring(1,E[2].length);}else {C=RegExp.$1+x+RegExp.$2;if(RegExp.$3!=p){C+=x+RegExp.$3;};};};}else if(qx.bom.client.Engine.__v()){if(/AppleWebKit\/([^ ]+)/.test(B)){C=RegExp.$1;var D=RegExp(c).exec(C);if(D){C=C.slice(0,D.index);};};}else if(qx.bom.client.Engine.__x()||qx.bom.client.Engine.__w()){if(/rv\:([^\);]+)(\)|;)/.test(B)){C=RegExp.$1;};}else {var z=window.qxFail;if(z&&typeof z===b){C=z().FULLVERSION;}else {C=f;qx.Bootstrap.warn(o+B+s);};};return C;},getName:function(){var name;if(qx.bom.client.Engine.__y()){name=t;}else if(qx.bom.client.Engine.__u()){name=q;}else if(qx.bom.client.Engine.__v()){name=v;}else if(qx.bom.client.Engine.__x()||qx.bom.client.Engine.__w()){name=e;}else {var F=window.qxFail;if(F&&typeof F===b){name=F().NAME;}else {name=e;qx.Bootstrap.warn(o+window.navigator.userAgent+s);};};return name;},__u:function(){return window.opera&&Object.prototype.toString.call(window.opera)==a;},__v:function(){return window.navigator.userAgent.indexOf(m)!=-1;},__w:function(){return window.navigator.userAgent.indexOf(l)!=-1;},__x:function(){return (window.navigator.mozApps||window.navigator.buildID)&&window.navigator.product===k&&window.navigator.userAgent.indexOf(l)==-1&&window.navigator.userAgent.indexOf(n)==-1;},__y:function(){if(window.navigator.cpuClass&&(/MSIE\s+([^\);]+)(\)|;)/.test(window.navigator.userAgent)||/Trident\/\d+?\.\d+?/.test(window.navigator.userAgent))){return true;};if(qx.bom.client.Engine.__z()){return true;};return false;},__z:function(){return window.navigator.userAgent.indexOf(r)>-1;}},defer:function(G){qx.core.Environment.add(j,G.getVersion);qx.core.Environment.add(u,G.getName);}});})();(function(){var a='anonymous()',b="()",c="qx.globalErrorHandling",d="qx.lang.Function",e=".",f=".prototype.",g=".constructor()";qx.Bootstrap.define(d,{statics:{getCaller:function(h){return h.caller?h.caller.callee:h.callee.caller;},getName:function(i){if(i.displayName){return i.displayName;};if(i.$$original||i.wrapper||i.classname){return i.classname+g;};if(i.$$mixin){for(var j in i.$$mixin.$$members){if(i.$$mixin.$$members[j]==i){return i.$$mixin.name+f+j+b;};};for(var j in i.$$mixin){if(i.$$mixin[j]==i){return i.$$mixin.name+e+j+b;};};};if(i.self){var l=i.self.constructor;if(l){for(var j in l.prototype){if(l.prototype[j]==i){return l.classname+f+j+b;};};for(var j in l){if(l[j]==i){return l.classname+e+j+b;};};};};var k=i.toString().match(/function\s*(\w*)\s*\(.*/);if(k&&k.length>=1&&k[1]){return k[1]+b;};return a;},globalEval:function(data){if(window.execScript){return window.execScript(data);}else {return eval.call(window,data);};},create:function(n,m){{};if(!m){return n;};if(!(m.self||m.args||m.delay!=null||m.periodical!=null||m.attempt)){return n;};return function(event){{};var p=qx.lang.Array.fromArguments(arguments);if(m.args){p=m.args.concat(p);};if(m.delay||m.periodical){var o=function(){return n.apply(m.self||this,p);};if(qx.core.Environment.get(c)){o=qx.event.GlobalError.observeMethod(o);};if(m.delay){return window.setTimeout(o,m.delay);};if(m.periodical){return window.setInterval(o,m.periodical);};}else if(m.attempt){var q=false;try{q=n.apply(m.self||this,p);}catch(r){};return q;}else {return n.apply(m.self||this,p);};};},bind:function(s,self,t){return this.create(s,{self:self,args:arguments.length>2?qx.lang.Array.fromArguments(arguments,2):null});},curry:function(u,v){return this.create(u,{args:arguments.length>1?qx.lang.Array.fromArguments(arguments,1):null});},listener:function(x,self,y){if(arguments.length<3){return function(event){return x.call(self||this,event||window.event);};}else {var w=qx.lang.Array.fromArguments(arguments,2);return function(event){var z=[event||window.event];z.push.apply(z,w);x.apply(self||this,z);};};},attempt:function(A,self,B){return this.create(A,{self:self,attempt:true,args:arguments.length>2?qx.lang.Array.fromArguments(arguments,2):null})();},delay:function(D,C,self,E){return this.create(D,{delay:C,self:self,args:arguments.length>3?qx.lang.Array.fromArguments(arguments,3):null})();},periodical:function(G,F,self,H){return this.create(G,{periodical:F,self:self,args:arguments.length>3?qx.lang.Array.fromArguments(arguments,3):null})();}}});})();(function(){var a="qx.globalErrorHandling",b="qx.event.GlobalError";qx.Bootstrap.define(b,{statics:{__A:null,__B:null,__C:null,__D:function(){if(qx.core&&qx.core.Environment){return qx.core.Environment.get(a);}else {return !!qx.Bootstrap.getEnvironmentSetting(a);};},setErrorHandler:function(c,d){this.__A=c||null;this.__C=d||window;if(this.__D()){if(c&&window.onerror){var e=qx.Bootstrap.bind(this.__E,this);if(this.__B==null){this.__B=window.onerror;};var self=this;window.onerror=function(f,g,h){self.__B(f,g,h);e(f,g,h);};};if(c&&!window.onerror){window.onerror=qx.Bootstrap.bind(this.__E,this);};if(this.__A==null){if(this.__B!=null){window.onerror=this.__B;this.__B=null;}else {window.onerror=null;};};};},__E:function(i,j,k){if(this.__A){this.handleError(new qx.core.WindowError(i,j,k));};},observeMethod:function(l){if(this.__D()){var self=this;return function(){if(!self.__A){return l.apply(this,arguments);};try{return l.apply(this,arguments);}catch(m){self.handleError(new qx.core.GlobalError(m,arguments));};};}else {return l;};},handleError:function(n){if(this.__A){this.__A.call(this.__C,n);};}},defer:function(o){if(qx.core&&qx.core.Environment){qx.core.Environment.add(a,true);}else {qx.Bootstrap.setEnvironmentSetting(a,true);};o.setErrorHandler(null,null);}});})();(function(){var a="",b="qx.core.WindowError";qx.Bootstrap.define(b,{extend:Error,construct:function(c,e,f){var d=Error.call(this,c);if(d.stack){this.stack=d.stack;};if(d.stacktrace){this.stacktrace=d.stacktrace;};this.__F=c;this.__G=e||a;this.__H=f===undefined?-1:f;},members:{__F:null,__G:null,__H:null,toString:function(){return this.__F;},getUri:function(){return this.__G;},getLineNumber:function(){return this.__H;}}});})();(function(){var a="GlobalError: ",b="qx.core.GlobalError";qx.Bootstrap.define(b,{extend:Error,construct:function(e,c){if(qx.Bootstrap.DEBUG){qx.core.Assert.assertNotUndefined(e);};this.__F=a+(e&&e.message?e.message:e);var d=Error.call(this,this.__F);if(d.stack){this.stack=d.stack;};if(d.stacktrace){this.stacktrace=d.stacktrace;};this.__I=c;this.__J=e;},members:{__J:null,__I:null,__F:null,toString:function(){return this.__F;},getArguments:function(){return this.__I;},getSourceException:function(){return this.__J;}},destruct:function(){this.__J=null;this.__I=null;this.__F=null;}});})();(function(){var a="qx.lang.Type",b="Error",c="RegExp",d="Date",e="Number",f="Boolean";qx.Bootstrap.define(a,{statics:{getClass:qx.Bootstrap.getClass,isString:qx.Bootstrap.isString,isArray:qx.Bootstrap.isArray,isObject:qx.Bootstrap.isObject,isFunction:qx.Bootstrap.isFunction,isRegExp:function(g){return this.getClass(g)==c;},isNumber:function(h){return (h!==null&&(this.getClass(h)==e||h instanceof Number));},isBoolean:function(i){return (i!==null&&(this.getClass(i)==f||i instanceof Boolean));},isDate:function(j){return (j!==null&&(this.getClass(j)==d||j instanceof Date));},isError:function(k){return (k!==null&&(this.getClass(k)==b||k instanceof Error));}}});})();(function(){var a=" != ",b="qx.core.Object",c="Expected value to be an array but found ",d="' (rgb(",f=") was fired.",g="Expected value to be an integer >= 0 but found ",h="' to be not equal with '",j="' to '",k="Expected object '",m="Called assertTrue with '",n="Expected value to be a map but found ",o="The function did not raise an exception!",p="Expected value to be undefined but found ",q="Expected value to be a DOM element but found  '",r="Expected value to be a regular expression but found ",s="' to implement the interface '",t="Expected value to be null but found ",u="Invalid argument 'type'",v="Called assert with 'false'",w="Assertion error! ",x="'",y="null",z="' but found '",A="'undefined'",B=",",C="' must must be a key of the map '",D="Expected '",E="The String '",F="Expected value to be a string but found ",G="Event (",H="Expected value to be the CSS color '",I="!",J="Expected value not to be undefined but found undefined!",K="qx.util.ColorUtil",L=": ",M="The raised exception does not have the expected type! ",N=") not fired.",O="'!",P="qx.core.Assert",Q="",R="Expected value to be typeof object but found ",S="' but found ",T="' (identical) but found '",U="' must have any of the values defined in the array '",V="Expected value to be a number but found ",W="Called assertFalse with '",X="qx.ui.core.Widget",Y="]",bJ="Expected value to be a qooxdoo object but found ",bK="' arguments.",bL="Expected value '%1' to be in the range '%2'..'%3'!",bF="Array[",bG="' does not match the regular expression '",bH="' to be not identical with '",bI="Expected [",bP="' arguments but found '",bQ="', which cannot be converted to a CSS color!",bR=", ",cg="qx.core.AssertionError",bM="Expected value to be a boolean but found ",bN="Expected value not to be null but found null!",bO="))!",bD="Expected value to be a qooxdoo widget but found ",bU="The value '",bE="Expected value to be typeof '",bV="\n Stack trace: \n",bW="Expected value to be typeof function but found ",cb="Expected value to be an integer but found ",bS="Called fail().",cf="The parameter 're' must be a string or a regular expression.",bT=")), but found value '",bX="qx.util.ColorUtil not available! Your code must have a dependency on 'qx.util.ColorUtil'",bY="Expected value to be a number >= 0 but found ",ca="Expected value to be instanceof '",cc="], but found [",cd="Wrong number of arguments given. Expected '",ce="object";qx.Bootstrap.define(P,{statics:{__k:true,__l:function(ch,ci){var cm=Q;for(var i=1,l=arguments.length;i<l;i++ ){cm=cm+this.__m(arguments[i]===undefined?A:arguments[i]);};var cl=Q;if(cm){cl=ch+L+cm;}else {cl=ch;};var ck=w+cl;if(qx.Class&&qx.Class.isDefined(cg)){var cj=new qx.core.AssertionError(ch,cm);if(this.__k){qx.Bootstrap.error(ck+bV+cj.getStackTrace());};throw cj;}else {if(this.__k){qx.Bootstrap.error(ck);};throw new Error(ck);};},__m:function(co){var cn;if(co===null){cn=y;}else if(qx.lang.Type.isArray(co)&&co.length>10){cn=bF+co.length+Y;}else if((co instanceof Object)&&(co.toString==null)){cn=qx.lang.Json.stringify(co,null,2);}else {try{cn=co.toString();}catch(e){cn=Q;};};return cn;},assert:function(cq,cp){cq==true||this.__l(cp||Q,v);},fail:function(cr,cs){var ct=cs?Q:bS;this.__l(cr||Q,ct);},assertTrue:function(cv,cu){(cv===true)||this.__l(cu||Q,m,cv,x);},assertFalse:function(cx,cw){(cx===false)||this.__l(cw||Q,W,cx,x);},assertEquals:function(cy,cz,cA){cy==cz||this.__l(cA||Q,D,cy,z,cz,O);},assertNotEquals:function(cB,cC,cD){cB!=cC||this.__l(cD||Q,D,cB,h,cC,O);},assertIdentical:function(cE,cF,cG){cE===cF||this.__l(cG||Q,D,cE,T,cF,O);},assertNotIdentical:function(cH,cI,cJ){cH!==cI||this.__l(cJ||Q,D,cH,bH,cI,O);},assertNotUndefined:function(cL,cK){cL!==undefined||this.__l(cK||Q,J);},assertUndefined:function(cN,cM){cN===undefined||this.__l(cM||Q,p,cN,I);},assertNotNull:function(cP,cO){cP!==null||this.__l(cO||Q,bN);},assertNull:function(cR,cQ){cR===null||this.__l(cQ||Q,t,cR,I);},assertJsonEquals:function(cS,cT,cU){this.assertEquals(qx.lang.Json.stringify(cS),qx.lang.Json.stringify(cT),cU);},assertMatch:function(cX,cW,cV){this.assertString(cX);this.assert(qx.lang.Type.isRegExp(cW)||qx.lang.Type.isString(cW),cf);cX.search(cW)>=0||this.__l(cV||Q,E,cX,bG,cW.toString(),O);},assertArgumentsCount:function(db,dc,dd,cY){var da=db.length;(da>=dc&&da<=dd)||this.__l(cY||Q,cd,dc,j,dd,bP,da,bK);},assertEventFired:function(de,event,dh,di,dj){var df=false;var dg=function(e){if(di){di.call(de,e);};df=true;};var dk;try{dk=de.addListener(event,dg,de);dh.call(de);}catch(dl){throw dl;}finally{try{de.removeListenerById(dk);}catch(dm){};};df===true||this.__l(dj||Q,G,event,N);},assertEventNotFired:function(dn,event,dr,ds){var dp=false;var dq=function(e){dp=true;};var dt=dn.addListener(event,dq,dn);dr.call();dp===false||this.__l(ds||Q,G,event,f);dn.removeListenerById(dt);},assertException:function(dx,dw,dv,du){var dw=dw||Error;var dy;try{this.__k=false;dx();}catch(dz){dy=dz;}finally{this.__k=true;};if(dy==null){this.__l(du||Q,o);};dy instanceof dw||this.__l(du||Q,M,dw,a,dy);if(dv){this.assertMatch(dy.toString(),dv,du);};},assertInArray:function(dC,dB,dA){dB.indexOf(dC)!==-1||this.__l(dA||Q,bU,dC,U,dB,x);},assertArrayEquals:function(dD,dE,dF){this.assertArray(dD,dF);this.assertArray(dE,dF);dF=dF||bI+dD.join(bR)+cc+dE.join(bR)+Y;if(dD.length!==dE.length){this.fail(dF,true);};for(var i=0;i<dD.length;i++ ){if(dD[i]!==dE[i]){this.fail(dF,true);};};},assertKeyInMap:function(dI,dH,dG){dH[dI]!==undefined||this.__l(dG||Q,bU,dI,C,dH,x);},assertFunction:function(dK,dJ){qx.lang.Type.isFunction(dK)||this.__l(dJ||Q,bW,dK,I);},assertString:function(dM,dL){qx.lang.Type.isString(dM)||this.__l(dL||Q,F,dM,I);},assertBoolean:function(dO,dN){qx.lang.Type.isBoolean(dO)||this.__l(dN||Q,bM,dO,I);},assertNumber:function(dQ,dP){(qx.lang.Type.isNumber(dQ)&&isFinite(dQ))||this.__l(dP||Q,V,dQ,I);},assertPositiveNumber:function(dS,dR){(qx.lang.Type.isNumber(dS)&&isFinite(dS)&&dS>=0)||this.__l(dR||Q,bY,dS,I);},assertInteger:function(dU,dT){(qx.lang.Type.isNumber(dU)&&isFinite(dU)&&dU%1===0)||this.__l(dT||Q,cb,dU,I);},assertPositiveInteger:function(dX,dV){var dW=(qx.lang.Type.isNumber(dX)&&isFinite(dX)&&dX%1===0&&dX>=0);dW||this.__l(dV||Q,g,dX,I);},assertInRange:function(eb,ec,ea,dY){(eb>=ec&&eb<=ea)||this.__l(dY||Q,qx.lang.String.format(bL,[eb,ec,ea]));},assertObject:function(ee,ed){var ef=ee!==null&&(qx.lang.Type.isObject(ee)||typeof ee===ce);ef||this.__l(ed||Q,R,(ee),I);},assertArray:function(eh,eg){qx.lang.Type.isArray(eh)||this.__l(eg||Q,c,eh,I);},assertMap:function(ej,ei){qx.lang.Type.isObject(ej)||this.__l(ei||Q,n,ej,I);},assertRegExp:function(el,ek){qx.lang.Type.isRegExp(el)||this.__l(ek||Q,r,el,I);},assertType:function(eo,en,em){this.assertString(en,u);typeof (eo)===en||this.__l(em||Q,bE,en,S,eo,I);},assertInstance:function(er,es,ep){var eq=es.classname||es+Q;er instanceof es||this.__l(ep||Q,ca,eq,S,er,I);},assertInterface:function(ev,eu,et){qx.Class&&qx.Class.implementsInterface(ev,eu)||this.__l(et||Q,k,ev,s,eu,O);},assertCssColor:function(eC,ez,eB){var ew=qx.Class?qx.Class.getByName(K):null;if(!ew){throw new Error(bX);};var ey=ew.stringToRgb(eC);try{var eA=ew.stringToRgb(ez);}catch(eE){this.__l(eB||Q,H,eC,d,ey.join(B),bT,ez,bQ);};var eD=ey[0]==eA[0]&&ey[1]==eA[1]&&ey[2]==eA[2];eD||this.__l(eB||Q,H,ey,d,ey.join(B),bT,ez,d,eA.join(B),bO);},assertElement:function(eG,eF){!!(eG&&eG.nodeType===1)||this.__l(eF||Q,q,eG,O);},assertQxObject:function(eI,eH){this.__n(eI,b)||this.__l(eH||Q,bJ,eI,I);},assertQxWidget:function(eK,eJ){this.__n(eK,X)||this.__l(eJ||Q,bD,eK,I);},__n:function(eM,eL){if(!eM){return false;};var eN=eM.constructor;while(eN){if(eN.classname===eL){return true;};eN=eN.superclass;};return false;}}});})();(function(){var a="\x00\b\n\f\r\t",b="-",c="function",d="[null,null,null]",e="T",f="+",g=",\n",h="constructor",i="{\n",j='"+275760-09-13T00:00:00.000Z"',k="true",l="\\n",m="false",n='"-271821-04-20T00:00:00.000Z"',o="json",p='object',q='""',r="qx.lang.Json",s="{}",t="hasOwnProperty",u="@",v="prototype",w='hasOwnProperty',x='"',y="toLocaleString",z="0",A='function',B="",C='\\"',D="\t",E="string",F="}",G="\r",H="toJSON",I=":",J="[\n 1,\n 2\n]",K="\\f",L='"1969-12-31T23:59:59.999Z"',M="/",N="\\b",O="Z",P="\\t",Q="\b",R="[object Number]",S="isPrototypeOf",T="{",U="toString",V="0x",W="[1]",X="\\r",Y="]",bO=",",bP="null",bQ="\\u00",bK="\n",bL="json-stringify",bM="[]",bN="1",bU="000000",bV="[object Boolean]",bW="valueOf",cm="\\\\",bR="[object String]",bS="json-parse",bT="bug-string-char-index",bG="[object Array]",ca="$",bJ="[\n",cb='"-000001-01-01T00:00:00.000Z"',cc="[",bI="[null]",bX="\\",cl="[object Date]",bY='{"a":[1,true,false,null,"\\u0000\\b\\n\\f\\r\\t"]}',cd="a",ce=" ",cf=".",ci="[object Function]",cj="01",ck='"\t"',bH="propertyIsEnumerable",cg="\f",ch="object";qx.Bootstrap.define(r,{statics:{stringify:null,parse:null}});(function(){var co;var cn;var cp;(function(window){var cr={}.toString,cG,cQ,cC;var cy=typeof cp===c&&cp.amd,cx=typeof cn==ch&&cn;if(cx||cy){if(typeof JSON==ch&&JSON){if(cx){cx.stringify=JSON.stringify;cx.parse=JSON.parse;}else {cx=JSON;};}else if(cy){cx=window.JSON={};};}else {cx=window.JSON||(window.JSON={});};var cU=new Date(-3509827334573292);try{cU=cU.getUTCFullYear()==-109252&&cU.getUTCMonth()===0&&cU.getUTCDate()===1&&cU.getUTCHours()==10&&cU.getUTCMinutes()==37&&cU.getUTCSeconds()==6&&cU.getUTCMilliseconds()==708;}catch(da){};function cJ(name){if(name==bT){return cd[0]!=cd;};var de,dd=bY,dh=name==o;if(dh||name==bL||name==bS){if(name==bL||dh){var db=cx.stringify,dg=typeof db==c&&cU;if(dg){(de=function(){return 1;}).toJSON=de;try{dg=db(0)===z&&db(new Number())===z&&db(new String())==q&&db(cr)===cC&&db(cC)===cC&&db()===cC&&db(de)===bN&&db([de])==W&&db([cC])==bI&&db(null)==bP&&db([cC,cr,null])==d&&db({"a":[de,true,false,null,a]})==dd&&db(null,de)===bN&&db([1,2],null,1)==J&&db(new Date(-8.64e15))==n&&db(new Date(8.64e15))==j&&db(new Date(-621987552e5))==cb&&db(new Date(-1))==L;}catch(di){dg=false;};};if(!dh){return dg;};};if(name==bS||dh){var df=cx.parse;if(typeof df==c){try{if(df(z)===0&&!df(false)){de=df(dd);var dc=de[cd].length==5&&de[cd][0]===1;if(dc){try{dc=!df(ck);}catch(dj){};if(dc){try{dc=df(cj)!==1;}catch(dk){};};};};}catch(dl){dc=false;};};if(!dh){return dc;};};return dg&&dc;};};if(!cJ(o)){var cV=ci;var cN=cl;var cv=R;var cY=bR;var cR=bG;var cF=bV;var cE=cJ(bT);if(!cU){var cD=Math.floor;var cM=[0,31,59,90,120,151,181,212,243,273,304,334];var cX=function(dm,dn){return cM[dn]+365*(dm-1970)+cD((dm-1969+(dn=+(dn>1)))/4)-cD((dm-1901+dn)/100)+cD((dm-1601+dn)/400);};};if(!(cG={}.hasOwnProperty)){cG=function(dp){var dq={},dr;if((dq.__O=null,dq.__O={"toString":1},dq).toString!=cr){cG=function(ds){var dt=this.__O,du=ds in (this.__O=null,this);this.__O=dt;return du;};}else {dr=dq.constructor;cG=function(dv){var parent=(this.constructor||dr).prototype;return dv in this&&!(dv in parent&&this[dv]===parent[dv]);};};dq=null;return cG.call(this,dp);};};var cH={'boolean':1,'number':1,'string':1,'undefined':1};var cP=function(dy,dw){var dx=typeof dy[dw];return dx==p?!!dy[dw]:!cH[dx];};cQ=function(dz,dA){var dF=0,dE,dC,dD,dB;(dE=function(){this.valueOf=0;}).prototype.valueOf=0;dC=new dE();for(dD in dC){if(cG.call(dC,dD)){dF++ ;};};dE=dC=null;if(!dF){dC=[bW,U,y,bH,S,t,h];dB=function(dH,dI){var dJ=cr.call(dH)==cV,dK,length;var dG=!dJ&&typeof dH.constructor!=A&&cP(dH,w)?dH.hasOwnProperty:cG;for(dK in dH){if(!(dJ&&dK==v)&&dG.call(dH,dK)){dI(dK);};};for(length=dC.length;dK=dC[ --length];dG.call(dH,dK)&&dI(dK));};}else if(dF==2){dB=function(dP,dL){var dO={},dM=cr.call(dP)==cV,dN;for(dN in dP){if(!(dM&&dN==v)&&!cG.call(dO,dN)&&(dO[dN]=1)&&cG.call(dP,dN)){dL(dN);};};};}else {dB=function(dT,dQ){var dR=cr.call(dT)==cV,dS,dU;for(dS in dT){if(!(dR&&dS==v)&&cG.call(dT,dS)&&!(dU=dS===h)){dQ(dS);};};if(dU||cG.call(dT,(dS=h))){dQ(dS);};};};return dB(dz,dA);};if(!cJ(bL)){var cT={'92':cm,'34':C,'8':N,'12':K,'10':l,'13':X,'9':P};var cI=bU;var cW=function(dV,dW){return (cI+(dW||0)).slice(-dV);};var cB=bQ;var cL=function(dY){var eb=x,dX=0,length=dY.length,ec=length>10&&cE,ea;if(ec){ea=dY.split(B);};for(;dX<length;dX++ ){var ed=dY.charCodeAt(dX);switch(ed){case 8:case 9:case 10:case 12:case 13:case 34:case 92:eb+=cT[ed];break;default:if(ed<32){eb+=cB+cW(2,ed.toString(16));break;};eb+=ec?ea[dX]:cE?dY.charAt(dX):dY[dX];};};return eb+x;};var cs=function(ez,eo,ew,el,ek,ex,es){var et=eo[ez],ev,ei,ef,er,ey,ep,eA,en,em,ee,eu,ej,length,eg,eq,eh;try{et=eo[ez];}catch(eB){};if(typeof et==ch&&et){ev=cr.call(et);if(ev==cN&&!cG.call(et,H)){if(et>-1/0&&et<1/0){if(cX){er=cD(et/864e5);for(ei=cD(er/365.2425)+1970-1;cX(ei+1,0)<=er;ei++ );for(ef=cD((er-cX(ei,0))/30.42);cX(ei,ef+1)<=er;ef++ );er=1+er-cX(ei,ef);ey=(et%864e5+864e5)%864e5;ep=cD(ey/36e5)%24;eA=cD(ey/6e4)%60;en=cD(ey/1e3)%60;em=ey%1e3;}else {ei=et.getUTCFullYear();ef=et.getUTCMonth();er=et.getUTCDate();ep=et.getUTCHours();eA=et.getUTCMinutes();en=et.getUTCSeconds();em=et.getUTCMilliseconds();};et=(ei<=0||ei>=1e4?(ei<0?b:f)+cW(6,ei<0?-ei:ei):cW(4,ei))+b+cW(2,ef+1)+b+cW(2,er)+e+cW(2,ep)+I+cW(2,eA)+I+cW(2,en)+cf+cW(3,em)+O;}else {et=null;};}else if(typeof et.toJSON==c&&((ev!=cv&&ev!=cY&&ev!=cR)||cG.call(et,H))){et=et.toJSON(ez);};};if(ew){et=ew.call(eo,ez,et);};if(et===null){return bP;};ev=cr.call(et);if(ev==cF){return B+et;}else if(ev==cv){return et>-1/0&&et<1/0?B+et:bP;}else if(ev==cY){return cL(B+et);};if(typeof et==ch){for(length=es.length;length-- ;){if(es[length]===et){throw TypeError();};};es.push(et);ee=[];eg=ex;ex+=ek;if(ev==cR){for(ej=0,length=et.length;ej<length;eq||(eq=true),ej++ ){eu=cs(ej,et,ew,el,ek,ex,es);ee.push(eu===cC?bP:eu);};eh=eq?(ek?bJ+ex+ee.join(g+ex)+bK+eg+Y:(cc+ee.join(bO)+Y)):bM;}else {cQ(el||et,function(eC){var eD=cs(eC,et,ew,el,ek,ex,es);if(eD!==cC){ee.push(cL(eC)+I+(ek?ce:B)+eD);};eq||(eq=true);});eh=eq?(ek?i+ex+ee.join(g+ex)+bK+eg+F:(T+ee.join(bO)+F)):s;};es.pop();return eh;};};cx.stringify=function(eK,eJ,eL){var eF,eG,eI;if(typeof eJ==c||typeof eJ==ch&&eJ){if(cr.call(eJ)==cV){eG=eJ;}else if(cr.call(eJ)==cR){eI={};for(var eE=0,length=eJ.length,eH;eE<length;eH=eJ[eE++ ],((cr.call(eH)==cY||cr.call(eH)==cv)&&(eI[eH]=1)));};};if(eL){if(cr.call(eL)==cv){if((eL-=eL%1)>0){for(eF=B,eL>10&&(eL=10);eF.length<eL;eF+=ce);};}else if(cr.call(eL)==cY){eF=eL.length<=10?eL:eL.slice(0,10);};};return cs(B,(eH={},eH[B]=eK,eH),eG,eI,eF,B,[]);};};if(!cJ(bS)){var cA=String.fromCharCode;var cz={'92':bX,'34':x,'47':M,'98':Q,'116':D,'110':bK,'102':cg,'114':G};var cq,cu;var cw=function(){cq=cu=null;throw SyntaxError();};var cS=function(){var eO=cu,length=eO.length,eN,eM,eQ,eP,eR;while(cq<length){eR=eO.charCodeAt(cq);switch(eR){case 9:case 10:case 13:case 32:cq++ ;break;case 123:case 125:case 91:case 93:case 58:case 44:eN=cE?eO.charAt(cq):eO[cq];cq++ ;return eN;case 34:for(eN=u,cq++ ;cq<length;){eR=eO.charCodeAt(cq);if(eR<32){cw();}else if(eR==92){eR=eO.charCodeAt( ++cq);switch(eR){case 92:case 34:case 47:case 98:case 116:case 110:case 102:case 114:eN+=cz[eR];cq++ ;break;case 117:eM= ++cq;for(eQ=cq+4;cq<eQ;cq++ ){eR=eO.charCodeAt(cq);if(!(eR>=48&&eR<=57||eR>=97&&eR<=102||eR>=65&&eR<=70)){cw();};};eN+=cA(V+eO.slice(eM,cq));break;default:cw();};}else {if(eR==34){break;};eR=eO.charCodeAt(cq);eM=cq;while(eR>=32&&eR!=92&&eR!=34){eR=eO.charCodeAt( ++cq);};eN+=eO.slice(eM,cq);};};if(eO.charCodeAt(cq)==34){cq++ ;return eN;};cw();default:eM=cq;if(eR==45){eP=true;eR=eO.charCodeAt( ++cq);};if(eR>=48&&eR<=57){if(eR==48&&((eR=eO.charCodeAt(cq+1)),eR>=48&&eR<=57)){cw();};eP=false;for(;cq<length&&((eR=eO.charCodeAt(cq)),eR>=48&&eR<=57);cq++ );if(eO.charCodeAt(cq)==46){eQ= ++cq;for(;eQ<length&&((eR=eO.charCodeAt(eQ)),eR>=48&&eR<=57);eQ++ );if(eQ==cq){cw();};cq=eQ;};eR=eO.charCodeAt(cq);if(eR==101||eR==69){eR=eO.charCodeAt( ++cq);if(eR==43||eR==45){cq++ ;};for(eQ=cq;eQ<length&&((eR=eO.charCodeAt(eQ)),eR>=48&&eR<=57);eQ++ );if(eQ==cq){cw();};cq=eQ;};return +eO.slice(eM,cq);};if(eP){cw();};if(eO.slice(cq,cq+4)==k){cq+=4;return true;}else if(eO.slice(cq,cq+5)==m){cq+=5;return false;}else if(eO.slice(cq,cq+4)==bP){cq+=4;return null;};cw();};};return ca;};var cK=function(eU){var eT,eS;if(eU==ca){cw();};if(typeof eU==E){if((cE?eU.charAt(0):eU[0])==u){return eU.slice(1);};if(eU==cc){eT=[];for(;;eS||(eS=true)){eU=cS();if(eU==Y){break;};if(eS){if(eU==bO){eU=cS();if(eU==Y){cw();};}else {cw();};};if(eU==bO){cw();};eT.push(cK(eU));};return eT;}else if(eU==T){eT={};for(;;eS||(eS=true)){eU=cS();if(eU==F){break;};if(eS){if(eU==bO){eU=cS();if(eU==F){cw();};}else {cw();};};if(eU==bO||typeof eU!=E||(cE?eU.charAt(0):eU[0])!=u||cS()!=I){cw();};eT[eU.slice(1)]=cK(cS());};return eT;};cw();};return eU;};var cO=function(eV,eW,eX){var eY=ct(eV,eW,eX);if(eY===cC){delete eV[eW];}else {eV[eW]=eY;};};var ct=function(fa,fb,fd){var fc=fa[fb],length;if(typeof fc==ch&&fc){if(cr.call(fc)==cR){for(length=fc.length;length-- ;){cO(fc,length,fd);};}else {cQ(fc,function(fe){cO(fc,fe,fd);});};};return fd.call(fa,fb,fc);};cx.parse=function(ff,fi){var fg,fh;cq=0;cu=B+ff;fg=cK(cS());if(cS()!=ca){cw();};cq=cu=null;return fi&&cr.call(fi)==cV?ct((fh={},fh[B]=fg,fh),B,fi):fg;};};};if(cy){cp(function(){return cx;});};}(this));}());qx.lang.Json.stringify=window.JSON.stringify;qx.lang.Json.parse=window.JSON.parse;})();(function(){var a="-",b="]",c='\\u',d="undefined",e="",f='\\$1',g="0041-005A0061-007A00AA00B500BA00C0-00D600D8-00F600F8-02C102C6-02D102E0-02E402EC02EE0370-037403760377037A-037D03860388-038A038C038E-03A103A3-03F503F7-0481048A-05250531-055605590561-058705D0-05EA05F0-05F20621-064A066E066F0671-06D306D506E506E606EE06EF06FA-06FC06FF07100712-072F074D-07A507B107CA-07EA07F407F507FA0800-0815081A082408280904-0939093D09500958-0961097109720979-097F0985-098C098F09900993-09A809AA-09B009B209B6-09B909BD09CE09DC09DD09DF-09E109F009F10A05-0A0A0A0F0A100A13-0A280A2A-0A300A320A330A350A360A380A390A59-0A5C0A5E0A72-0A740A85-0A8D0A8F-0A910A93-0AA80AAA-0AB00AB20AB30AB5-0AB90ABD0AD00AE00AE10B05-0B0C0B0F0B100B13-0B280B2A-0B300B320B330B35-0B390B3D0B5C0B5D0B5F-0B610B710B830B85-0B8A0B8E-0B900B92-0B950B990B9A0B9C0B9E0B9F0BA30BA40BA8-0BAA0BAE-0BB90BD00C05-0C0C0C0E-0C100C12-0C280C2A-0C330C35-0C390C3D0C580C590C600C610C85-0C8C0C8E-0C900C92-0CA80CAA-0CB30CB5-0CB90CBD0CDE0CE00CE10D05-0D0C0D0E-0D100D12-0D280D2A-0D390D3D0D600D610D7A-0D7F0D85-0D960D9A-0DB10DB3-0DBB0DBD0DC0-0DC60E01-0E300E320E330E40-0E460E810E820E840E870E880E8A0E8D0E94-0E970E99-0E9F0EA1-0EA30EA50EA70EAA0EAB0EAD-0EB00EB20EB30EBD0EC0-0EC40EC60EDC0EDD0F000F40-0F470F49-0F6C0F88-0F8B1000-102A103F1050-1055105A-105D106110651066106E-10701075-1081108E10A0-10C510D0-10FA10FC1100-1248124A-124D1250-12561258125A-125D1260-1288128A-128D1290-12B012B2-12B512B8-12BE12C012C2-12C512C8-12D612D8-13101312-13151318-135A1380-138F13A0-13F41401-166C166F-167F1681-169A16A0-16EA1700-170C170E-17111720-17311740-17511760-176C176E-17701780-17B317D717DC1820-18771880-18A818AA18B0-18F51900-191C1950-196D1970-19741980-19AB19C1-19C71A00-1A161A20-1A541AA71B05-1B331B45-1B4B1B83-1BA01BAE1BAF1C00-1C231C4D-1C4F1C5A-1C7D1CE9-1CEC1CEE-1CF11D00-1DBF1E00-1F151F18-1F1D1F20-1F451F48-1F4D1F50-1F571F591F5B1F5D1F5F-1F7D1F80-1FB41FB6-1FBC1FBE1FC2-1FC41FC6-1FCC1FD0-1FD31FD6-1FDB1FE0-1FEC1FF2-1FF41FF6-1FFC2071207F2090-209421022107210A-211321152119-211D212421262128212A-212D212F-2139213C-213F2145-2149214E218321842C00-2C2E2C30-2C5E2C60-2CE42CEB-2CEE2D00-2D252D30-2D652D6F2D80-2D962DA0-2DA62DA8-2DAE2DB0-2DB62DB8-2DBE2DC0-2DC62DC8-2DCE2DD0-2DD62DD8-2DDE2E2F300530063031-3035303B303C3041-3096309D-309F30A1-30FA30FC-30FF3105-312D3131-318E31A0-31B731F0-31FF3400-4DB54E00-9FCBA000-A48CA4D0-A4FDA500-A60CA610-A61FA62AA62BA640-A65FA662-A66EA67F-A697A6A0-A6E5A717-A71FA722-A788A78BA78CA7FB-A801A803-A805A807-A80AA80C-A822A840-A873A882-A8B3A8F2-A8F7A8FBA90A-A925A930-A946A960-A97CA984-A9B2A9CFAA00-AA28AA40-AA42AA44-AA4BAA60-AA76AA7AAA80-AAAFAAB1AAB5AAB6AAB9-AABDAAC0AAC2AADB-AADDABC0-ABE2AC00-D7A3D7B0-D7C6D7CB-D7FBF900-FA2DFA30-FA6DFA70-FAD9FB00-FB06FB13-FB17FB1DFB1F-FB28FB2A-FB36FB38-FB3CFB3EFB40FB41FB43FB44FB46-FBB1FBD3-FD3DFD50-FD8FFD92-FDC7FDF0-FDFBFE70-FE74FE76-FEFCFF21-FF3AFF41-FF5AFF66-FFBEFFC2-FFC7FFCA-FFCFFFD2-FFD7FFDA-FFDC",h="\\\\",j='-',k="g",l="\\\"",m="qx.lang.String",n="(^|[^",o="0",p="%",q='"',r=' ',s='\n',t="])[";qx.Bootstrap.define(m,{statics:{__P:g,__Q:null,__R:{},camelCase:function(v){var u=this.__R[v];if(!u){u=v.replace(/\-([a-z])/g,function(x,w){return w.toUpperCase();});if(v.indexOf(a)>=0){this.__R[v]=u;};};return u;},hyphenate:function(z){var y=this.__R[z];if(!y){y=z.replace(/[A-Z]/g,function(A){return (j+A.charAt(0).toLowerCase());});if(z.indexOf(a)==-1){this.__R[z]=y;};};return y;},capitalize:function(C){if(this.__Q===null){var B=c;this.__Q=new RegExp(n+this.__P.replace(/[0-9A-F]{4}/g,function(D){return B+D;})+t+this.__P.replace(/[0-9A-F]{4}/g,function(E){return B+E;})+b,k);};return C.replace(this.__Q,function(F){return F.toUpperCase();});},clean:function(G){return G.replace(/\s+/g,r).trim();},trimLeft:function(H){return H.replace(/^\s+/,e);},trimRight:function(I){return I.replace(/\s+$/,e);},startsWith:function(K,J){return K.startsWith(J);},endsWith:function(M,L){return M.endsWith(L);},repeat:function(N,O){return N.length>0?new Array(O+1).join(N):e;},pad:function(Q,length,P){var R=length-Q.length;if(R>0){if(typeof P===d){P=o;};return this.repeat(P,R)+Q;}else {return Q;};},firstUp:qx.Bootstrap.firstUp,firstLow:qx.Bootstrap.firstLow,contains:function(T,S){return T.indexOf(S)!=-1;},format:function(U,V){var W=U;var i=V.length;while(i-- ){W=W.replace(new RegExp(p+(i+1),k),function(){return V[i]+e;});};return W;},escapeRegexpChars:function(X){return X.replace(/([.*+?^${}()|[\]\/\\])/g,f);},toArray:function(Y){return Y.split(/\B|\b/g);},stripTags:function(ba){return ba.replace(/<\/?[^>]+>/gi,e);},stripScripts:function(bd,bc){var be=e;var bb=bd.replace(/<script[^>]*>([\s\S]*?)<\/script>/gi,function(){be+=arguments[1]+s;return e;});if(bc===true){qx.lang.Function.globalEval(be);};return bb;},quote:function(bf){return q+bf.replace(/\\/g,h).replace(/\"/g,l)+q;}}});})();(function(){var c="-",d="",e="qx.core.ObjectRegistry",f="Disposed ",g="$$hash",h="-0",j=" objects",k="Could not dispose object ",m=": ";qx.Bootstrap.define(e,{statics:{inShutDown:false,__j:{},__K:0,__L:[],__M:d,__N:{},register:function(n){var q=this.__j;if(!q){return;};var p=n.$$hash;if(p==null){var o=this.__L;if(o.length>0&&true){p=o.pop();}else {p=(this.__K++ )+this.__M;};n.$$hash=p;{};};{};q[p]=n;},unregister:function(r){var s=r.$$hash;if(s==null){return;};var t=this.__j;if(t&&t[s]){delete t[s];this.__L.push(s);};try{delete r.$$hash;}catch(u){if(r.removeAttribute){r.removeAttribute(g);};};},toHashCode:function(v){{};var x=v.$$hash;if(x!=null){return x;};var w=this.__L;if(w.length>0){x=w.pop();}else {x=(this.__K++ )+this.__M;};return v.$$hash=x;},clearHashCode:function(y){{};var z=y.$$hash;if(z!=null){this.__L.push(z);try{delete y.$$hash;}catch(A){if(y.removeAttribute){y.removeAttribute(g);};};};},fromHashCode:function(B){return this.__j[B]||null;},shutdown:function(){this.inShutDown=true;var D=this.__j;var F=[];for(var C in D){F.push(C);};F.sort(function(a,b){return parseInt(b,10)-parseInt(a,10);});var E,i=0,l=F.length;while(true){try{for(;i<l;i++ ){C=F[i];E=D[C];if(E&&E.dispose){E.dispose();};};}catch(G){qx.Bootstrap.error(this,k+E.toString()+m+G,G);if(i!==l){i++ ;continue;};};break;};qx.Bootstrap.debug(this,f+l+j);delete this.__j;},getRegistry:function(){return this.__j;},getNextHash:function(){return this.__K;},getPostId:function(){return this.__M;},getStackTraces:function(){return this.__N;}},defer:function(H){if(window&&window.top){var frames=window.top.frames;for(var i=0;i<frames.length;i++ ){if(frames[i]===window){H.__M=c+(i+1);return;};};};H.__M=h;}});})();(function(){var a="qx.event.type.Data",b="qx.event.type.Event",c="qx.data.IListData";qx.Interface.define(c,{events:{"change":a,"changeLength":b},members:{getItem:function(d){},setItem:function(e,f){},splice:function(g,h,i){},contains:function(j){},getLength:function(){},toArray:function(){}}});})();(function(){var a="qx.core.ValidationError";qx.Class.define(a,{extend:qx.type.BaseError});})();(function(){var a="qx.util.RingBuffer";qx.Bootstrap.define(a,{extend:Object,construct:function(b){this.setMaxEntries(b||50);},members:{__cc:0,__cd:0,__ce:false,__cf:0,__cg:null,__ch:null,setMaxEntries:function(c){this.__ch=c;this.clear();},getMaxEntries:function(){return this.__ch;},addEntry:function(d){this.__cg[this.__cc]=d;this.__cc=this.__ci(this.__cc,1);var e=this.getMaxEntries();if(this.__cd<e){this.__cd++ ;};if(this.__ce&&(this.__cf<e)){this.__cf++ ;};},mark:function(){this.__ce=true;this.__cf=0;},clearMark:function(){this.__ce=false;},getAllEntries:function(){return this.getEntries(this.getMaxEntries(),false);},getEntries:function(f,j){if(f>this.__cd){f=this.__cd;};if(j&&this.__ce&&(f>this.__cf)){f=this.__cf;};if(f>0){var h=this.__ci(this.__cc,-1);var g=this.__ci(h,-f+1);var i;if(g<=h){i=this.__cg.slice(g,h+1);}else {i=this.__cg.slice(g,this.__cd).concat(this.__cg.slice(0,h+1));};}else {i=[];};return i;},clear:function(){this.__cg=new Array(this.getMaxEntries());this.__cd=0;this.__cf=0;this.__cc=0;},__ci:function(n,l){var k=this.getMaxEntries();var m=(n+l)%k;if(m<0){m+=k;};return m;}}});})();(function(){var a="qx.log.appender.RingBuffer";qx.Bootstrap.define(a,{extend:qx.util.RingBuffer,construct:function(b){this.setMaxMessages(b||50);},members:{setMaxMessages:function(c){this.setMaxEntries(c);},getMaxMessages:function(){return this.getMaxEntries();},process:function(d){this.addEntry(d);},getAllLogEvents:function(){return this.getAllEntries();},retrieveLogEvents:function(e,f){return this.getEntries(e,f);},clearHistory:function(){this.clear();}}});})();(function(){var a="qx.log.Logger",b="[",c="...(+",d="array",e=")",f="info",g="node",h="instance",j="string",k="null",m="error",n="#",o="class",p=": ",q="warn",r="document",s="{...(",t="",u="number",v="stringify",w="]",x="date",y="unknown",z="function",A="text[",B="[...(",C="boolean",D="\n",E=")}",F="debug",G=")]",H="map",I="undefined",J="object";qx.Bootstrap.define(a,{statics:{__cj:F,setLevel:function(K){this.__cj=K;},getLevel:function(){return this.__cj;},setTreshold:function(L){this.__cm.setMaxMessages(L);},getTreshold:function(){return this.__cm.getMaxMessages();},__ck:{},__cl:0,register:function(P){if(P.$$id){return;};var M=this.__cl++ ;this.__ck[M]=P;P.$$id=M;var N=this.__cn;var O=this.__cm.getAllLogEvents();for(var i=0,l=O.length;i<l;i++ ){if(N[O[i].level]>=N[this.__cj]){P.process(O[i]);};};},unregister:function(Q){var R=Q.$$id;if(R==null){return;};delete this.__ck[R];delete Q.$$id;},debug:function(T,S){qx.log.Logger.__co(F,arguments);},info:function(V,U){qx.log.Logger.__co(f,arguments);},warn:function(X,W){qx.log.Logger.__co(q,arguments);},error:function(ba,Y){qx.log.Logger.__co(m,arguments);},trace:function(bb){var bc=qx.dev.StackTrace.getStackTrace();qx.log.Logger.__co(f,[(typeof bb!==I?[bb].concat(bc):bc).join(D)]);},deprecatedMethodWarning:function(bf,bd){{var be;};},deprecatedClassWarning:function(bi,bg){{var bh;};},deprecatedEventWarning:function(bl,event,bj){{var bk;};},deprecatedMixinWarning:function(bn,bm){{var bo;};},deprecatedConstantWarning:function(bs,bq,bp){{var self,br;};},deprecateMethodOverriding:function(bv,bu,bw,bt){{var bx;};},clear:function(){this.__cm.clearHistory();},__cm:new qx.log.appender.RingBuffer(50),__cn:{debug:0,info:1,warn:2,error:3},__co:function(bz,bB){var bE=this.__cn;if(bE[bz]<bE[this.__cj]){return;};var by=bB.length<2?null:bB[0];var bD=by?1:0;var bA=[];for(var i=bD,l=bB.length;i<l;i++ ){bA.push(this.__cq(bB[i],true));};var bF=new Date;var bG={time:bF,offset:bF-qx.Bootstrap.LOADSTART,level:bz,items:bA,win:window};if(by){if(by.$$hash!==undefined){bG.object=by.$$hash;}else if(by.$$type){bG.clazz=by;}else if(by.constructor){bG.clazz=by.constructor;};};this.__cm.process(bG);var bC=this.__ck;for(var bH in bC){bC[bH].process(bG);};},__cp:function(bJ){if(bJ===undefined){return I;}else if(bJ===null){return k;};if(bJ.$$type){return o;};var bI=typeof bJ;if(bI===z||bI==j||bI===u||bI===C){return bI;}else if(bI===J){if(bJ.nodeType){return g;}else if(bJ instanceof Error||(bJ.name&&bJ.message)){return m;}else if(bJ.classname){return h;}else if(bJ instanceof Array){return d;}else if(bJ instanceof Date){return x;}else {return H;};};if(bJ.toString){return v;};return y;},__cq:function(bP,bO){var bS=this.__cp(bP);var bM=y;var bL=[];switch(bS){case k:case I:bM=bS;break;case j:case u:case C:case x:bM=bP;break;case g:if(bP.nodeType===9){bM=r;}else if(bP.nodeType===3){bM=A+bP.nodeValue+w;}else if(bP.nodeType===1){bM=bP.nodeName.toLowerCase();if(bP.id){bM+=n+bP.id;};}else {bM=g;};break;case z:bM=qx.lang.Function.getName(bP)||bS;break;case h:bM=bP.basename+b+bP.$$hash+w;break;case o:case v:bM=bP.toString();break;case m:bL=qx.dev.StackTrace.getStackTraceFromError(bP);bM=(bP.basename?bP.basename+p:t)+bP.toString();break;case d:if(bO){bM=[];for(var i=0,l=bP.length;i<l;i++ ){if(bM.length>20){bM.push(c+(l-i)+e);break;};bM.push(this.__cq(bP[i],false));};}else {bM=B+bP.length+G;};break;case H:if(bO){var bK;var bR=[];for(var bQ in bP){bR.push(bQ);};bR.sort();bM=[];for(var i=0,l=bR.length;i<l;i++ ){if(bM.length>20){bM.push(c+(l-i)+e);break;};bQ=bR[i];bK=this.__cq(bP[bQ],false);bK.key=bQ;bM.push(bK);};}else {var bN=0;for(var bQ in bP){bN++ ;};bM=s+bN+E;};break;};return {type:bS,text:bM,trace:bL};}},defer:function(bT){var bU=qx.Bootstrap.$$logs;for(var i=0;i<bU.length;i++ ){bT.__co(bU[i][0],bU[i][1]);};qx.Bootstrap.debug=bT.debug;qx.Bootstrap.info=bT.info;qx.Bootstrap.warn=bT.warn;qx.Bootstrap.error=bT.error;qx.Bootstrap.trace=bT.trace;}});})();(function(){var a="qx.core.MProperty",b="get",c="reset",d="No such property: ",e="set";qx.Mixin.define(a,{members:{set:function(g,h){var f=qx.core.Property.$$method.set;if(qx.Bootstrap.isString(g)){if(!this[f[g]]){if(this[e+qx.Bootstrap.firstUp(g)]!=undefined){this[e+qx.Bootstrap.firstUp(g)](h);return this;};throw new Error(d+g);};return this[f[g]](h);}else {for(var i in g){if(!this[f[i]]){if(this[e+qx.Bootstrap.firstUp(i)]!=undefined){this[e+qx.Bootstrap.firstUp(i)](g[i]);continue;};throw new Error(d+i);};this[f[i]](g[i]);};return this;};},get:function(k){var j=qx.core.Property.$$method.get;if(!this[j[k]]){if(this[b+qx.Bootstrap.firstUp(k)]!=undefined){return this[b+qx.Bootstrap.firstUp(k)]();};throw new Error(d+k);};return this[j[k]]();},reset:function(m){var l=qx.core.Property.$$method.reset;if(!this[l[m]]){if(this[c+qx.Bootstrap.firstUp(m)]!=undefined){this[c+qx.Bootstrap.firstUp(m)]();return;};throw new Error(d+m);};this[l[m]]();}}});})();(function(){var a="info",b="debug",c="warn",d="qx.core.MLogging",e="error";qx.Mixin.define(d,{members:{__cr:qx.log.Logger,debug:function(f){this.__cs(b,arguments);},info:function(g){this.__cs(a,arguments);},warn:function(h){this.__cs(c,arguments);},error:function(i){this.__cs(e,arguments);},trace:function(){this.__cr.trace(this);},__cs:function(j,l){var k=qx.lang.Array.fromArguments(l);k.unshift(this);this.__cr[j].apply(this.__cr,k);}}});})();(function(){var b="qx.dom.Node",c="";qx.Bootstrap.define(b,{statics:{ELEMENT:1,ATTRIBUTE:2,TEXT:3,CDATA_SECTION:4,ENTITY_REFERENCE:5,ENTITY:6,PROCESSING_INSTRUCTION:7,COMMENT:8,DOCUMENT:9,DOCUMENT_TYPE:10,DOCUMENT_FRAGMENT:11,NOTATION:12,getDocument:function(d){return d.nodeType===this.DOCUMENT?d:d.ownerDocument||d.document;},getWindow:function(e){if(e.nodeType==null){return e;};if(e.nodeType!==this.DOCUMENT){e=e.ownerDocument;};return e.defaultView||e.parentWindow;},getDocumentElement:function(f){return this.getDocument(f).documentElement;},getBodyElement:function(g){return this.getDocument(g).body;},isNode:function(h){return !!(h&&h.nodeType!=null);},isElement:function(j){return !!(j&&j.nodeType===this.ELEMENT);},isDocument:function(k){return !!(k&&k.nodeType===this.DOCUMENT);},isDocumentFragment:function(l){return !!(l&&l.nodeType===this.DOCUMENT_FRAGMENT);},isText:function(m){return !!(m&&m.nodeType===this.TEXT);},isWindow:function(n){return !!(n&&n.history&&n.location&&n.document);},isNodeName:function(o,p){if(!p||!o||!o.nodeName){return false;};return p.toLowerCase()==qx.dom.Node.getName(o);},getName:function(q){if(!q||!q.nodeName){return null;};return q.nodeName.toLowerCase();},getText:function(r){if(!r||!r.nodeType){return null;};switch(r.nodeType){case 1:var i,a=[],s=r.childNodes,length=s.length;for(i=0;i<length;i++ ){a[i]=this.getText(s[i]);};return a.join(c);case 2:case 3:case 4:return r.nodeValue;};return null;},isBlockNode:function(t){if(!qx.dom.Node.isElement(t)){return false;};t=qx.dom.Node.getName(t);return /^(body|form|textarea|fieldset|ul|ol|dl|dt|dd|li|div|hr|p|h[1-6]|quote|pre|table|thead|tbody|tfoot|tr|td|th|iframe|address|blockquote)$/.test(t);}}});})();(function(){var a="function",b='loadeddata',c="pointerover",d='pause',f="transitionend",g="gecko",h="browser.name",j='timeupdate',k='canplay',m="HTMLEvents",n='loadedmetadata',o="css.transition",p="mobile safari",q="return;",r="browser.documentmode",s="safari",t='play',u='ended',v="",w="qx.bom.Event",x='playing',y="mouseover",z="end-event",A="mshtml",B="engine.name",C='progress',D="webkit",E='volumechange',F='seeked',G="on",H="undefined";qx.Bootstrap.define(w,{statics:{addNativeListener:function(L,K,I,J){if(L.addEventListener){L.addEventListener(K,I,!!J);}else if(L.attachEvent){L.attachEvent(G+K,I);}else if(typeof L[G+K]!=H){L[G+K]=I;}else {{};};},removeNativeListener:function(P,O,M,N){if(P.removeEventListener){P.removeEventListener(O,M,!!N);}else if(P.detachEvent){try{P.detachEvent(G+O,M);}catch(e){if(e.number!==-2146828218){throw e;};};}else if(typeof P[G+O]!=H){P[G+O]=null;}else {{};};},getTarget:function(e){return e.target||e.srcElement;},getRelatedTarget:function(e){if(e.relatedTarget!==undefined){if((qx.core.Environment.get(B)==g)){try{e.relatedTarget&&e.relatedTarget.nodeType;}catch(Q){return null;};};return e.relatedTarget;}else if(e.fromElement!==undefined&&(e.type===y||e.type===c)){return e.fromElement;}else if(e.toElement!==undefined){return e.toElement;}else {return null;};},preventDefault:function(e){if(e.preventDefault){e.preventDefault();}else {try{e.keyCode=0;}catch(R){};e.returnValue=false;};},stopPropagation:function(e){if(e.stopPropagation){e.stopPropagation();}else {e.cancelBubble=true;};},fire:function(U,S){if(document.createEvent){var T=document.createEvent(m);T.initEvent(S,true,true);return !U.dispatchEvent(T);}else {var T=document.createEventObject();return U.fireEvent(G+S,T);};},supportsEvent:function(V,be){var ba=qx.core.Environment.get(h);var bb=qx.core.Environment.get(B);if(be.toLowerCase().indexOf(f)!=-1&&bb===A&&qx.core.Environment.get(r)>9){return true;};var bc=[p,s];if(bb===D&&bc.indexOf(ba)>-1){var W=[b,C,j,F,k,t,x,d,n,u,E];if(W.indexOf(be.toLowerCase())>-1){return true;};};if(V!=window&&be.toLowerCase().indexOf(f)!=-1){var bd=qx.core.Environment.get(o);return (bd&&bd[z]==be);};var X=G+be.toLowerCase();var Y=(X in V);if(!Y){Y=typeof V[X]==a;if(!Y&&V.setAttribute){V.setAttribute(X,q);Y=typeof V[X]==a;V.removeAttribute(X);};};return Y;},getEventName:function(bf,bi){var bg=[v].concat(qx.bom.Style.VENDOR_PREFIXES);for(var i=0,l=bg.length;i<l;i++ ){var bh=bg[i].toLowerCase();if(qx.bom.Event.supportsEvent(bf,bh+bi)){return bh?bh+qx.lang.String.firstUp(bi):bi;};};return null;}}});})();(function(){var a="-",b="qx.bom.Style",c="",d='-',e="Webkit",f="ms",g=":",h=";",j="Moz",k="O",m="string",n="Khtml";qx.Bootstrap.define(b,{statics:{VENDOR_PREFIXES:[e,j,k,f,n],__ct:{},__cu:null,getPropertyName:function(q){var o=document.documentElement.style;if(o[q]!==undefined){return q;};for(var i=0,l=this.VENDOR_PREFIXES.length;i<l;i++ ){var p=this.VENDOR_PREFIXES[i]+qx.lang.String.firstUp(q);if(o[p]!==undefined){return p;};};return null;},getCssName:function(r){var s=this.__ct[r];if(!s){s=r.replace(/[A-Z]/g,function(t){return (d+t.charAt(0).toLowerCase());});if((/^ms/.test(s))){s=a+s;};this.__ct[r]=s;};return s;},getAppliedStyle:function(A,x,z,v){var C=qx.bom.Style.getCssName(x);var w=qx.dom.Node.getWindow(A);var u=(v!==false)?[null].concat(this.VENDOR_PREFIXES):[null];for(var i=0,l=u.length;i<l;i++ ){var y=false;var B=u[i]?a+u[i].toLowerCase()+a+z:z;if(qx.bom.Style.__cu){y=qx.bom.Style.__cu.call(w,C,B);}else {A.style.cssText+=C+g+B+h;y=(typeof A.style[x]==m&&A.style[x]!==c);};if(y){return B;};};return null;}},defer:function(D){if(window.CSS&&window.CSS.supports){qx.bom.Style.__cu=window.CSS.supports.bind(window.CSS);}else if(window.supportsCSS){qx.bom.Style.__cu=window.supportsCSS.bind(window);};}});})();(function(){var a="rim_tabletos",b="10.1",c="Darwin",d="10.3",e="Windows Phone",f="os.version",g="10.7",h="2003",i=")",j="iPhone",k="android",l="unix",m="ce",n="7",o="10.11",p="SymbianOS",q="10.5",r="os.name",s="10.12",t="10.9",u="|",v="MacPPC",w="95",x="iPod",y="10.8",z="\.",A="Win64",B="linux",C="me",D="10.2",E="Macintosh",F="Android",G="Windows",H="98",I="ios",J="10",K="vista",L="8",M="blackberry",N="2000",O="8.1",P="(",Q="",R="win",S="Linux",T="10.6",U="BSD",V="10.0",W="10.4",X="Mac OS X",Y="iPad",bv="X11",bw="xp",bx="10.13",br="symbian",bs="qx.bom.client.OperatingSystem",bt="g",bu="Win32",bB="10.10",bC="osx",bD="webOS",bF="RIM Tablet OS",by="BlackBerry",bz="nt4",bA=".",bq="MacIntel",bE="webos";qx.Bootstrap.define(bs,{statics:{getName:function(){if(!navigator){return Q;};var bG=navigator.platform||Q;var bH=navigator.userAgent||Q;if(bG.indexOf(G)!=-1||bG.indexOf(bu)!=-1||bG.indexOf(A)!=-1||bH.indexOf(e)!=-1){return R;}else if(bG.indexOf(E)!=-1||bG.indexOf(v)!=-1||bG.indexOf(bq)!=-1||bG.indexOf(X)!=-1){return bC;}else if(bH.indexOf(bF)!=-1){return a;}else if(bH.indexOf(bD)!=-1){return bE;}else if(bG.indexOf(x)!=-1||bG.indexOf(j)!=-1||bG.indexOf(Y)!=-1){return I;}else if(bH.indexOf(F)!=-1){return k;}else if(bG.indexOf(S)!=-1){return B;}else if(bG.indexOf(bv)!=-1||bG.indexOf(U)!=-1||bG.indexOf(c)!=-1){return l;}else if(bG.indexOf(p)!=-1){return br;}else if(bG.indexOf(by)!=-1){return M;};return Q;},__cv:{"Windows NT 10.0":J,"Windows NT 6.3":O,"Windows NT 6.2":L,"Windows NT 6.1":n,"Windows NT 6.0":K,"Windows NT 5.2":h,"Windows NT 5.1":bw,"Windows NT 5.0":N,"Windows 2000":N,"Windows NT 4.0":bz,"Win 9x 4.90":C,"Windows CE":m,"Windows 98":H,"Win98":H,"Windows 95":w,"Win95":w,"Mac OS X 10_13":bx,"Mac OS X 10.13":bx,"Mac OS X 10_12":s,"Mac OS X 10.12":s,"Mac OS X 10_11":o,"Mac OS X 10.11":o,"Mac OS X 10_10":bB,"Mac OS X 10.10":bB,"Mac OS X 10_9":t,"Mac OS X 10.9":t,"Mac OS X 10_8":y,"Mac OS X 10.8":y,"Mac OS X 10_7":g,"Mac OS X 10.7":g,"Mac OS X 10_6":T,"Mac OS X 10.6":T,"Mac OS X 10_5":q,"Mac OS X 10.5":q,"Mac OS X 10_4":W,"Mac OS X 10.4":W,"Mac OS X 10_3":d,"Mac OS X 10.3":d,"Mac OS X 10_2":D,"Mac OS X 10.2":D,"Mac OS X 10_1":b,"Mac OS X 10.1":b,"Mac OS X 10_0":V,"Mac OS X 10.0":V},getVersion:function(){var bI=qx.bom.client.OperatingSystem.__cw(navigator.userAgent);if(bI==null){bI=qx.bom.client.OperatingSystem.__cx(navigator.userAgent);};if(bI!=null){return bI;}else {return Q;};},__cw:function(bJ){var bM=[];for(var bL in qx.bom.client.OperatingSystem.__cv){bM.push(bL);};var bN=new RegExp(P+bM.join(u).replace(/\./g,z)+i,bt);var bK=bN.exec(bJ);if(bK&&bK[1]){return qx.bom.client.OperatingSystem.__cv[bK[1]];};return null;},__cx:function(bT){var bO=bT.indexOf(e)!=-1;var bU=bT.indexOf(F)!=-1;var bP=bT.match(/(iPad|iPhone|iPod)/i)?true:false;if(bO){var bW=new RegExp(/Windows Phone (\d+(?:\.\d+)+)/i);var bR=bW.exec(bT);if(bR&&bR[1]){return bR[1];};}else if(bU){var bS=new RegExp(/ Android (\d+(?:\.\d+)+)/i);var bV=bS.exec(bT);if(bV&&bV[1]){return bV[1];};}else if(bP){var bX=new RegExp(/(CPU|iPhone|iPod) OS (\d+)_(\d+)(?:_(\d+))*\s+/);var bQ=bX.exec(bT);if(bQ&&bQ[2]&&bQ[3]){if(bQ[4]){return bQ[2]+bA+bQ[3]+bA+bQ[4];}else {return bQ[2]+bA+bQ[3];};};};return null;}},defer:function(bY){qx.core.Environment.add(r,bY.getName);qx.core.Environment.add(f,bY.getVersion);}});})();(function(){var a="CSS1Compat",b="IEMobile",c=" OPR/",d="msie",e="android",f="operamini",g="gecko",h="maple",i="AdobeAIR|Titanium|Fluid|Chrome|Android|Epiphany|Konqueror|iCab|iPad|iPhone|OmniWeb|Maxthon|Pre|PhantomJS|Mobile Safari|Safari",j="browser.quirksmode",k="browser.name",l="trident",m="mobile chrome",n=")(/| )([0-9]+\.[0-9])",o="iemobile",p="prism|Fennec|Camino|Kmeleon|Galeon|Netscape|SeaMonkey|Namoroka|Firefox",q="IEMobile|Maxthon|MSIE|Trident",r="opera mobi",s="Mobile Safari",t="Maple",u="operamobile",v="ie",w="mobile safari",x="qx.bom.client.Browser",y="(Maple )([0-9]+\.[0-9]+\.[0-9]*)",z="",A="opera mini",B="(",C="browser.version",D="opera",E="ce",F=")(/|)?([0-9]+\.[0-9])?",G="mshtml",H="Opera Mini|Opera Mobi|Opera",I="edge",J="webkit",K="browser.documentmode",L="5.0",M="Mobile/";qx.Bootstrap.define(x,{statics:{getName:function(){var P=navigator.userAgent;var Q=new RegExp(B+qx.bom.client.Browser.__cy+F);var O=P.match(Q);if(!O){return z;};var name=O[1].toLowerCase();var N=qx.bom.client.Engine.getName();if(N===J){if(P.match(/Edge\/\d+\.\d+/)){name=I;}else if(name===e){name=m;}else if(P.indexOf(s)!==-1||P.indexOf(M)!==-1){name=w;}else if(P.indexOf(c)!=-1){name=D;};}else if(N===G){if(name===d||name===l){name=v;if(qx.bom.client.OperatingSystem.getVersion()===E){name=o;};var Q=new RegExp(b);if(P.match(Q)){name=o;};};}else if(N===D){if(name===r){name=u;}else if(name===A){name=f;};}else if(N===g){if(P.indexOf(t)!==-1){name=h;};};return name;},getVersion:function(){var T=navigator.userAgent;var U=new RegExp(B+qx.bom.client.Browser.__cy+n);var R=T.match(U);if(!R){return z;};var name=R[1].toLowerCase();var S=R[3];if(T.match(/Version(\/| )([0-9]+\.[0-9])/)){S=RegExp.$2;};if(qx.bom.client.Engine.getName()==G){S=qx.bom.client.Engine.getVersion();if(name===d&&qx.bom.client.OperatingSystem.getVersion()==E){S=L;};};if(qx.bom.client.Browser.getName()==h){U=new RegExp(y);R=T.match(U);if(!R){return z;};S=R[2];};if(qx.bom.client.Engine.getName()==J||qx.bom.client.Browser.getName()==D){if(T.match(/OPR(\/| )([0-9]+\.[0-9])/)){S=RegExp.$2;};if(T.match(/Edge\/([\d+\.*]+)/)){S=RegExp.$1;};};return S;},getDocumentMode:function(){if(document.documentMode){return document.documentMode;};return 0;},getQuirksMode:function(){if(qx.bom.client.Engine.getName()==G&&parseFloat(qx.bom.client.Engine.getVersion())>=8){return qx.bom.client.Engine.DOCUMENT_MODE===5;}else {return document.compatMode!==a;};},__cy:{"webkit":i,"gecko":p,"mshtml":q,"opera":H}[qx.bom.client.Engine.getName()]},defer:function(V){qx.core.Environment.add(k,V.getName);qx.core.Environment.add(C,V.getVersion);qx.core.Environment.add(K,V.getDocumentMode);qx.core.Environment.add(j,V.getQuirksMode);}});})();(function(){var a="qx.bom.client.CssTransition",b="E",c="transitionEnd",d="e",e="nd",f="transition",g="css.transition",h="Trans";qx.Bootstrap.define(a,{statics:{getTransitionName:function(){return qx.bom.Style.getPropertyName(f);},getSupport:function(){var name=qx.bom.client.CssTransition.getTransitionName();if(!name){return null;};var i=qx.bom.Event.getEventName(window,c);i=i==c?i.toLowerCase():i;if(!i){i=name+(name.indexOf(h)>0?b:d)+e;};return {name:name,"end-event":i};}},defer:function(j){qx.core.Environment.add(g,j.getSupport);}});})();(function(){var a="__cD",b="UNKNOWN_",c="|bubble",d="",e="_",f="__cE",g="c",h="|",j="qx.globalErrorHandling",k="unload",m="|capture",n="DOM_",o="WIN_",p="QX_",q="qx.event.Manager",r="capture",s="DOCUMENT_";qx.Class.define(q,{extend:Object,construct:function(t,v){this.__cz=t;this.__cA=qx.core.ObjectRegistry.toHashCode(t);this.__cB=v;if(t.qx!==qx){var self=this;var u=function(){qx.bom.Event.removeNativeListener(t,k,u);self.dispose();};if(qx.core.Environment.get(j)){qx.bom.Event.addNativeListener(t,k,qx.event.GlobalError.observeMethod(u));}else {qx.bom.Event.addNativeListener(t,k,u);};};this.__cC={};this.__cD={};this.__cE={};this.__cF={};},statics:{__cG:0,getNextUniqueId:function(){return (this.__cG++ )+d;}},members:{__cB:null,__cC:null,__cE:null,__cH:null,__cD:null,__cF:null,__cz:null,__cA:null,getWindow:function(){return this.__cz;},getWindowId:function(){return this.__cA;},getHandler:function(x){var w=this.__cD[x.classname];if(w){return w;};return this.__cD[x.classname]=new x(this);},getDispatcher:function(z){var y=this.__cE[z.classname];if(y){return y;};return this.__cE[z.classname]=new z(this,this.__cB);},getListeners:function(B,F,A){var D=B.$$hash||qx.core.ObjectRegistry.toHashCode(B);var G=this.__cC[D];if(!G){return null;};var E=F+(A?m:c);var C=G[E];return C?C.concat():null;},getAllListeners:function(){return this.__cC;},serializeListeners:function(I){var M=I.$$hash||qx.core.ObjectRegistry.toHashCode(I);var Q=this.__cC[M];var L=[];if(Q){var J,P,H,K,N;for(var O in Q){J=O.indexOf(h);P=O.substring(0,J);H=O.charAt(J+1)==g;K=Q[O];for(var i=0,l=K.length;i<l;i++ ){N=K[i];L.push({self:N.context,handler:N.handler,type:P,capture:H});};};};return L;},toggleAttachedEvents:function(T,S){var W=T.$$hash||qx.core.ObjectRegistry.toHashCode(T);var ba=this.__cC[W];if(ba){var U,Y,R,V;for(var X in ba){U=X.indexOf(h);Y=X.substring(0,U);R=X.charCodeAt(U+1)===99;V=ba[X];if(S){this.__cI(T,Y,R);}else {this.__cJ(T,Y,R);};};};},hasListener:function(bc,bg,bb){{};var be=bc.$$hash||qx.core.ObjectRegistry.toHashCode(bc);var bh=this.__cC[be];if(!bh){return false;};var bf=bg+(bb?m:c);var bd=bh[bf];return !!(bd&&bd.length>0);},importListeners:function(bi,bk){{};var bo=bi.$$hash||qx.core.ObjectRegistry.toHashCode(bi);var bq=this.__cC[bo]={};var bm=qx.event.Manager;for(var bj in bk){var bn=bk[bj];var bp=bn.type+(bn.capture?m:c);var bl=bq[bp];if(!bl){bl=bq[bp]=[];this.__cI(bi,bn.type,bn.capture);};bl.push({handler:bn.listener,context:bn.self,unique:bn.unique||(bm.__cG++ )+d});};},addListener:function(bt,bA,bv,self,br){{var bx;};var bs=bt.$$hash||qx.core.ObjectRegistry.toHashCode(bt);var bB=this.__cC[bs];if(!bB){bB=this.__cC[bs]={};};var bw=bA+(br?m:c);var bu=bB[bw];if(!bu){bu=bB[bw]=[];};if(bu.length===0){this.__cI(bt,bA,br);};var bz=(qx.event.Manager.__cG++ )+d;var by={handler:bv,context:self,unique:bz};bu.push(by);return bw+h+bz;},findHandler:function(bG,bP){var bN=false,bF=false,bQ=false,bC=false;var bM;if(bG.nodeType===1){bN=true;bM=n+bG.tagName.toLowerCase()+e+bP;}else if(bG.nodeType===9){bC=true;bM=s+bP;}else if(bG==this.__cz){bF=true;bM=o+bP;}else if(bG.classname){bQ=true;bM=p+bG.classname+e+bP;}else {bM=b+bG+e+bP;};var bE=this.__cF;if(bE[bM]){return bE[bM];};var bL=this.__cB.getHandlers();var bH=qx.event.IEventHandler;var bJ,bK,bI,bD;for(var i=0,l=bL.length;i<l;i++ ){bJ=bL[i];bI=bJ.SUPPORTED_TYPES;if(bI&&!bI[bP]){continue;};bD=bJ.TARGET_CHECK;if(bD){var bO=false;if(bN&&((bD&bH.TARGET_DOMNODE)!=0)){bO=true;}else if(bF&&((bD&bH.TARGET_WINDOW)!=0)){bO=true;}else if(bQ&&((bD&bH.TARGET_OBJECT)!=0)){bO=true;}else if(bC&&((bD&bH.TARGET_DOCUMENT)!=0)){bO=true;};if(!bO){continue;};};bK=this.getHandler(bL[i]);if(bJ.IGNORE_CAN_HANDLE||bK.canHandleEvent(bG,bP)){bE[bM]=bK;return bK;};};return null;},__cI:function(bU,bT,bR){var bS=this.findHandler(bU,bT);if(bS){bS.registerEvent(bU,bT,bR);return;};{};},removeListener:function(bX,ce,ca,self,bV){{var cc;};var bW=bX.$$hash||qx.core.ObjectRegistry.toHashCode(bX);var cf=this.__cC[bW];if(!cf){return false;};var cb=ce+(bV?m:c);var bY=cf[cb];if(!bY){return false;};var cd;for(var i=0,l=bY.length;i<l;i++ ){cd=bY[i];if(cd.handler===ca&&cd.context===self){qx.lang.Array.removeAt(bY,i);if(bY.length==0){this.__cJ(bX,ce,bV);};return true;};};return false;},removeListenerById:function(ci,cq){{var cm;};var ck=cq.split(h);var cp=ck[0];var cg=ck[1].charCodeAt(0)==99;var co=ck[2];var ch=ci.$$hash||qx.core.ObjectRegistry.toHashCode(ci);var cr=this.__cC[ch];if(!cr){return false;};var cl=cp+(cg?m:c);var cj=cr[cl];if(!cj){return false;};var cn;for(var i=0,l=cj.length;i<l;i++ ){cn=cj[i];if(cn.unique===co){qx.lang.Array.removeAt(cj,i);if(cj.length==0){this.__cJ(ci,cp,cg);};return true;};};return false;},removeAllListeners:function(ct){var cv=ct.$$hash||qx.core.ObjectRegistry.toHashCode(ct);var cy=this.__cC[cv];if(!cy){return false;};var cu,cx,cs;for(var cw in cy){if(cy[cw].length>0){cu=cw.split(h);cx=cu[0];cs=cu[1]===r;this.__cJ(ct,cx,cs);};};delete this.__cC[cv];return true;},deleteAllListeners:function(cz){delete this.__cC[cz];},__cJ:function(cD,cC,cA){var cB=this.findHandler(cD,cC);if(cB){cB.unregisterEvent(cD,cC,cA);return;};{};},dispatchEvent:function(cF,event){{var cJ;};var cK=event.getType();if(!event.getBubbles()&&!this.hasListener(cF,cK)){qx.event.Pool.getInstance().poolObject(event);return true;};if(!event.getTarget()){event.setTarget(cF);};var cI=this.__cB.getDispatchers();var cH;var cE=false;for(var i=0,l=cI.length;i<l;i++ ){cH=this.getDispatcher(cI[i]);if(cH.canDispatchEvent(cF,event,cK)){cH.dispatchEvent(cF,event,cK);cE=true;break;};};if(!cE){{};return true;};var cG=event.getDefaultPrevented();qx.event.Pool.getInstance().poolObject(event);return !cG;},dispose:function(){this.__cB.removeManager(this);qx.util.DisposeUtil.disposeMap(this,a);qx.util.DisposeUtil.disposeMap(this,f);this.__cC=this.__cz=this.__cH=null;this.__cB=this.__cF=null;}}});})();(function(){var a="qx.event.IEventHandler";qx.Interface.define(a,{statics:{TARGET_DOMNODE:1,TARGET_WINDOW:2,TARGET_OBJECT:4,TARGET_DOCUMENT:8},members:{canHandleEvent:function(c,b){},registerEvent:function(f,e,d){},unregisterEvent:function(i,h,g){}}});})();(function(){var c="qx.event.Registration";qx.Class.define(c,{statics:{__cK:{},getManager:function(f){if(f==null){{};f=window;}else if(f.nodeType){f=qx.dom.Node.getWindow(f);}else if(!qx.dom.Node.isWindow(f)){f=window;};var e=f.$$hash||qx.core.ObjectRegistry.toHashCode(f);var d=this.__cK[e];if(!d){d=new qx.event.Manager(f,this);this.__cK[e]=d;};return d;},removeManager:function(g){var h=g.getWindowId();delete this.__cK[h];},addListener:function(l,k,i,self,j){return this.getManager(l).addListener(l,k,i,self,j);},removeListener:function(p,o,m,self,n){return this.getManager(p).removeListener(p,o,m,self,n);},removeListenerById:function(q,r){return this.getManager(q).removeListenerById(q,r);},removeAllListeners:function(s){return this.getManager(s).removeAllListeners(s);},deleteAllListeners:function(u){var t=u.$$hash;if(t){this.getManager(u).deleteAllListeners(t);};},hasListener:function(x,w,v){return this.getManager(x).hasListener(x,w,v);},serializeListeners:function(y){return this.getManager(y).serializeListeners(y);},createEvent:function(B,C,A){{};if(C==null){C=qx.event.type.Event;};var z=qx.event.Pool.getInstance().getObject(C);A?z.init.apply(z,A):z.init();if(B){z.setType(B);};return z;},dispatchEvent:function(D,event){return this.getManager(D).dispatchEvent(D,event);},fireEvent:function(E,F,H,G){{var I;};var J=this.createEvent(F,H||null,G);return this.getManager(E).dispatchEvent(E,J);},fireNonBubblingEvent:function(K,P,N,M){{};var O=this.getManager(K);if(!O.hasListener(K,P,false)){return true;};var L=this.createEvent(P,N||null,M);return O.dispatchEvent(K,L);},PRIORITY_FIRST:-32000,PRIORITY_NORMAL:0,PRIORITY_LAST:32000,__cD:[],addHandler:function(Q){{};this.__cD.push(Q);this.__cD.sort(function(a,b){return a.PRIORITY-b.PRIORITY;});},getHandlers:function(){return this.__cD;},__cE:[],addDispatcher:function(S,R){{};this.__cE.push(S);this.__cE.sort(function(a,b){return a.PRIORITY-b.PRIORITY;});},getDispatchers:function(){return this.__cE;}}});})();(function(){var a="qx.core.MEvent";qx.Mixin.define(a,{members:{__cL:qx.event.Registration,addListener:function(d,b,self,c){if(!this.$$disposed){return this.__cL.addListener(this,d,b,self,c);};return null;},addListenerOnce:function(h,f,self,g){var i=function(e){this.removeListener(h,f,this,g);f.call(self||this,e);};if(!f.$$wrapped_callback){f.$$wrapped_callback={};};f.$$wrapped_callback[h+this.$$hash]=i;return this.addListener(h,i,this,g);},removeListener:function(l,j,self,k){if(!this.$$disposed){if(j.$$wrapped_callback&&j.$$wrapped_callback[l+this.$$hash]){var m=j.$$wrapped_callback[l+this.$$hash];delete j.$$wrapped_callback[l+this.$$hash];j=m;};return this.__cL.removeListener(this,l,j,self,k);};return false;},removeListenerById:function(n){if(!this.$$disposed){return this.__cL.removeListenerById(this,n);};return false;},hasListener:function(p,o){return this.__cL.hasListener(this,p,o);},dispatchEvent:function(q){if(!this.$$disposed){return this.__cL.dispatchEvent(this,q);};return true;},fireEvent:function(s,t,r){if(!this.$$disposed){return this.__cL.fireEvent(this,s,t,r);};return true;},fireNonBubblingEvent:function(v,w,u){if(!this.$$disposed){return this.__cL.fireNonBubblingEvent(this,v,w,u);};return true;},fireDataEvent:function(z,A,x,y){if(!this.$$disposed){if(x===undefined){x=null;};return this.__cL.fireNonBubblingEvent(this,z,qx.event.type.Data,[A,x,!!y]);};return true;}}});})();(function(){var a="qx.event.IEventDispatcher";qx.Interface.define(a,{members:{canDispatchEvent:function(c,event,b){this.assertInstance(event,qx.event.type.Event);this.assertString(b);},dispatchEvent:function(e,event,d){this.assertInstance(event,qx.event.type.Event);this.assertString(d);}}});})();(function(){var a="module.events",b="Cloning only possible with properties.",c="qx.core.Object",d="module.property",e="]",f="[",g="Object";qx.Class.define(c,{extend:Object,include:qx.core.Environment.filter({"module.databinding":qx.data.MBinding,"module.logger":qx.core.MLogging,"module.events":qx.core.MEvent,"module.property":qx.core.MProperty}),construct:function(){qx.core.ObjectRegistry.register(this);},statics:{$$type:g},members:{__bu:qx.core.Environment.get(d)?qx.core.Property:null,toHashCode:function(){return this.$$hash;},toString:function(){return this.classname+f+this.$$hash+e;},base:function(h,j){{};if(arguments.length===1){return h.callee.base.call(this);}else {return h.callee.base.apply(this,Array.prototype.slice.call(arguments,1));};},self:function(k){return k.callee.self;},clone:function(){if(!qx.core.Environment.get(d)){throw new Error(b);};var n=this.constructor;var m=new n;var p=qx.Class.getProperties(n);var o=this.__bu.$$store.user;var q=this.__bu.$$method.set;var name;for(var i=0,l=p.length;i<l;i++ ){name=p[i];if(this.hasOwnProperty(o[name])){m[q[name]](this[o[name]]);};};return m;},__cM:null,setUserData:function(r,s){if(!this.__cM){this.__cM={};};this.__cM[r]=s;},getUserData:function(u){if(!this.__cM){return null;};var t=this.__cM[u];return t===undefined?null:t;},isDisposed:function(){return this.$$disposed||false;},dispose:function(){if(this.$$disposed){return;};this.$$disposed=true;this.$$instance=null;this.$$allowconstruct=null;{};var x=this.constructor;var v;while(x.superclass){if(x.$$destructor){x.$$destructor.call(this);};if(x.$$includes){v=x.$$flatIncludes;for(var i=0,l=v.length;i<l;i++ ){if(v[i].$$destructor){v[i].$$destructor.call(this);};};};x=x.superclass;};{var y,w;};},_disposeObjects:function(z){qx.util.DisposeUtil.disposeObjects(this,arguments);},_disposeSingletonObjects:function(A){qx.util.DisposeUtil.disposeObjects(this,arguments,true);},_disposeArray:function(B){qx.util.DisposeUtil.disposeArray(this,B);},_disposeMap:function(C){qx.util.DisposeUtil.disposeMap(this,C);}},environment:{"qx.debug.dispose.level":0},destruct:function(){if(qx.core.Environment.get(a)){if(!qx.core.ObjectRegistry.inShutDown){qx.event.Registration.removeAllListeners(this);}else {qx.event.Registration.deleteAllListeners(this);};};qx.core.ObjectRegistry.unregister(this);this.__cM=null;if(qx.core.Environment.get(d)){var F=this.constructor;var J;var K=this.__bu.$$store;var H=K.user;var I=K.theme;var D=K.inherit;var G=K.useinit;var E=K.init;while(F){J=F.$$properties;if(J){for(var name in J){if(J[name].dereference){this[H[name]]=this[I[name]]=this[D[name]]=this[G[name]]=this[E[name]]=undefined;};};};F=F.superclass;};};}});})();(function(){var a=" is a singleton! Please use disposeSingleton instead.",b="undefined",c="qx.util.DisposeUtil",d=" of object: ",e="!",f=" has non disposable entries: ",g="The map field: ",h="The array field: ",j="The object stored in key ",k="Has no disposable object under key: ";qx.Class.define(c,{statics:{disposeObjects:function(n,m,o){var name;for(var i=0,l=m.length;i<l;i++ ){name=m[i];if(n[name]==null||!n.hasOwnProperty(name)){continue;};if(!qx.core.ObjectRegistry.inShutDown){if(n[name].dispose){if(!o&&n[name].constructor.$$instance){throw new Error(j+name+a);}else {n[name].dispose();};}else {throw new Error(k+name+e);};};n[name]=null;};},disposeArray:function(q,p){var r=q[p];if(!r){return;};if(qx.core.ObjectRegistry.inShutDown){q[p]=null;return;};try{var s;for(var i=r.length-1;i>=0;i-- ){s=r[i];if(s){s.dispose();};};}catch(t){throw new Error(h+p+d+q+f+t);};r.length=0;q[p]=null;},disposeMap:function(v,u){var w=v[u];if(!w){return;};if(qx.core.ObjectRegistry.inShutDown){v[u]=null;return;};try{var y;for(var x in w){y=w[x];if(w.hasOwnProperty(x)&&y){y.dispose();};};}catch(z){throw new Error(g+u+d+v+f+z);};v[u]=null;},disposeTriggeredBy:function(A,C){var B=C.dispose;C.dispose=function(){B.call(C);A.dispose();};},destroyContainer:function(E){{};var D=[];this._collectContainerChildren(E,D);var F=D.length;for(var i=F-1;i>=0;i-- ){D[i].destroy();};E.destroy();},_collectContainerChildren:function(I,H){var J=I.getChildren();for(var i=0;i<J.length;i++ ){var G=J[i];H.push(G);if(this.__cN(G)){this._collectContainerChildren(G,H);};};},__cN:function(L){var K=[];if(qx.ui.mobile&&L instanceof qx.ui.mobile.core.Widget){K=[qx.ui.mobile.container.Composite];}else {K=[qx.ui.container.Composite,qx.ui.container.Scroll,qx.ui.container.SlideBar,qx.ui.container.Stack];};for(var i=0,l=K.length;i<l;i++ ){if(typeof K[i]!==b&&qx.Class.isSubClassOf(L.constructor,K[i])){return true;};};return false;}}});})();(function(){var a="qx.event.type.Event";qx.Class.define(a,{extend:qx.core.Object,statics:{CAPTURING_PHASE:1,AT_TARGET:2,BUBBLING_PHASE:3},members:{init:function(c,b){{};this._type=null;this._target=null;this._currentTarget=null;this._relatedTarget=null;this._originalTarget=null;this._stopPropagation=false;this._preventDefault=false;this._bubbles=!!c;this._cancelable=!!b;this._timeStamp=(new Date()).getTime();this._eventPhase=null;return this;},clone:function(d){if(d){var e=d;}else {var e=qx.event.Pool.getInstance().getObject(this.constructor);};e._type=this._type;e._target=this._target;e._currentTarget=this._currentTarget;e._relatedTarget=this._relatedTarget;e._originalTarget=this._originalTarget;e._stopPropagation=this._stopPropagation;e._bubbles=this._bubbles;e._preventDefault=this._preventDefault;e._cancelable=this._cancelable;return e;},stop:function(){if(this._bubbles){this.stopPropagation();};if(this._cancelable){this.preventDefault();};},stopPropagation:function(){{};this._stopPropagation=true;},getPropagationStopped:function(){return !!this._stopPropagation;},preventDefault:function(){{};this._preventDefault=true;},getDefaultPrevented:function(){return !!this._preventDefault;},getType:function(){return this._type;},setType:function(f){this._type=f;},getEventPhase:function(){return this._eventPhase;},setEventPhase:function(g){this._eventPhase=g;},getTimeStamp:function(){return this._timeStamp;},getTarget:function(){return this._target;},setTarget:function(h){this._target=h;},getCurrentTarget:function(){return this._currentTarget||this._target;},setCurrentTarget:function(i){this._currentTarget=i;},getRelatedTarget:function(){return this._relatedTarget;},setRelatedTarget:function(j){this._relatedTarget=j;},getOriginalTarget:function(){return this._originalTarget;},setOriginalTarget:function(k){this._originalTarget=k;},getBubbles:function(){return this._bubbles;},setBubbles:function(l){this._bubbles=l;},isCancelable:function(){return this._cancelable;},setCancelable:function(m){this._cancelable=m;}},destruct:function(){this._target=this._currentTarget=this._relatedTarget=this._originalTarget=null;}});})();(function(){var a="qx.util.ObjectPool",b="Class needs to be defined!",c="Object is already pooled: ",d="Integer";qx.Class.define(a,{extend:qx.core.Object,construct:function(e){qx.core.Object.call(this);this.__cO={};if(e!=null){this.setSize(e);};},properties:{size:{check:d,init:Infinity}},members:{__cO:null,getObject:function(h){if(this.$$disposed){return new h;};if(!h){throw new Error(b);};var f=null;var g=this.__cO[h.classname];if(g){f=g.pop();};if(f){f.$$pooled=false;}else {f=new h;};return f;},poolObject:function(k){if(!this.__cO){return;};var j=k.classname;var m=this.__cO[j];if(k.$$pooled){throw new Error(c+k);};if(!m){this.__cO[j]=m=[];};if(m.length>this.getSize()){if(k.destroy){k.destroy();}else {k.dispose();};return;};k.$$pooled=true;m.push(k);}},destruct:function(){var p=this.__cO;var n,o,i,l;for(n in p){o=p[n];for(i=0,l=o.length;i<l;i++ ){o[i].dispose();};};delete this.__cO;}});})();(function(){var a="singleton",b="qx.event.Pool";qx.Class.define(b,{extend:qx.util.ObjectPool,type:a,construct:function(){qx.util.ObjectPool.call(this,30);}});})();(function(){var a="qx.event.dispatch.Direct";qx.Class.define(a,{extend:qx.core.Object,implement:qx.event.IEventDispatcher,construct:function(b){this._manager=b;},statics:{PRIORITY:qx.event.Registration.PRIORITY_LAST},members:{canDispatchEvent:function(d,event,c){return !event.getBubbles();},dispatchEvent:function(e,event,k){{var j,f;};event.setEventPhase(qx.event.type.Event.AT_TARGET);var g=this._manager.getListeners(e,k,false);if(g){for(var i=0,l=g.length;i<l;i++ ){var h=g[i].context||e;{};g[i].handler.call(h,event);};};}},defer:function(m){qx.event.Registration.addDispatcher(m);}});})();(function(){var a="qx.event.handler.Object";qx.Class.define(a,{extend:qx.core.Object,implement:qx.event.IEventHandler,statics:{PRIORITY:qx.event.Registration.PRIORITY_LAST,SUPPORTED_TYPES:null,TARGET_CHECK:qx.event.IEventHandler.TARGET_OBJECT,IGNORE_CAN_HANDLE:false},members:{canHandleEvent:function(c,b){return qx.Class.supportsEvent(c.constructor,b);},registerEvent:function(f,e,d){},unregisterEvent:function(i,h,g){}},defer:function(j){qx.event.Registration.addHandler(j);}});})();(function(){var a="qx.event.type.Data";qx.Class.define(a,{extend:qx.event.type.Event,members:{__cP:null,__cQ:null,init:function(c,d,b){qx.event.type.Event.prototype.init.call(this,false,b);this.__cP=c;this.__cQ=d;return this;},clone:function(e){var f=qx.event.type.Event.prototype.clone.call(this,e);f.__cP=this.__cP;f.__cQ=this.__cQ;return f;},getData:function(){return this.__cP;},getOldData:function(){return this.__cQ;}},destruct:function(){this.__cP=this.__cQ=null;}});})();(function(){var a="To enable localization please include qx.locale.Manager into your build!",b="qx.locale.MTranslation";qx.Mixin.define(b,{members:{tr:function(c,e){var d=qx.locale.Manager;if(d){return d.tr.apply(d,arguments);};throw new Error(a);},trn:function(g,j,f,h){var i=qx.locale.Manager;if(i){return i.trn.apply(i,arguments);};throw new Error(a);},trc:function(n,m,l){var k=qx.locale.Manager;if(k){return k.trc.apply(k,arguments);};throw new Error(a);},trnc:function(p,q,r,o,s){var t=qx.locale.Manager;if(t){return t.trnc.apply(t,arguments);};throw new Error(a);},marktr:function(v){var u=qx.locale.Manager;if(u){return u.marktr.apply(u,arguments);};throw new Error(a);}}});})();(function(){var a="qx.application.IApplication";qx.Interface.define(a,{members:{main:function(){},finalize:function(){},close:function(){},terminate:function(){}}});})();(function(){var a="qx.core.BaseInit",b="engine.name",c="Main runtime: ",d="",f="os.name",g="engine.version",h="Missing application class: ",i="Load runtime: ",j="ms",k="Could not detect engine!",l="Finalize runtime: ",m='clui.Application',n="Could not detect operating system!",o="Could not detect the version of the engine!";qx.Class.define(a,{statics:{__cR:null,getApplication:function(){return this.__cR||null;},ready:function(){if(this.__cR){return;};if(qx.core.Environment.get(b)==d){qx.log.Logger.warn(k);};if(qx.core.Environment.get(g)==d){qx.log.Logger.warn(o);};if(qx.core.Environment.get(f)==d){qx.log.Logger.warn(n);};qx.log.Logger.debug(this,i+(new Date-qx.Bootstrap.LOADSTART)+j);var q=m;var r=qx.Class.getByName(q);if(r){this.__cR=new r;var p=new Date;this.__cR.main();qx.log.Logger.debug(this,c+(new Date-p)+j);var p=new Date;this.__cR.finalize();qx.log.Logger.debug(this,l+(new Date-p)+j);}else {qx.log.Logger.warn(h+q);};},__cS:function(e){var s=this.__cR;if(s){s.close();};},__cT:function(){var t=this.__cR;if(t){t.terminate();};qx.core.ObjectRegistry.shutdown();}}});})();(function(){var a="qx.event.type.Native";qx.Class.define(a,{extend:qx.event.type.Event,members:{init:function(b,e,f,d,c){qx.event.type.Event.prototype.init.call(this,d,c);this._target=e||qx.bom.Event.getTarget(b);this._relatedTarget=f||qx.bom.Event.getRelatedTarget(b);if(b.timeStamp){this._timeStamp=b.timeStamp;};this._native=b;this._returnValue=null;return this;},clone:function(g){var h=qx.event.type.Event.prototype.clone.call(this,g);var i={};h._native=this._cloneNativeEvent(this._native,i);h._returnValue=this._returnValue;return h;},_cloneNativeEvent:function(j,k){k.preventDefault=(function(){});return k;},preventDefault:function(){qx.event.type.Event.prototype.preventDefault.call(this);qx.bom.Event.preventDefault(this._native);},getNativeEvent:function(){return this._native;},setReturnValue:function(l){this._returnValue=l;},getReturnValue:function(){return this._returnValue;}},destruct:function(){this._native=this._returnValue=null;}});})();(function(){var a="qx.globalErrorHandling",b="qx.event.handler.Window";qx.Class.define(b,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(c){qx.core.Object.call(this);this._manager=c;this._window=c.getWindow();this._initWindowObserver();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{error:1,load:1,beforeunload:1,unload:1,resize:1,scroll:1,beforeshutdown:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true},members:{canHandleEvent:function(f,d){},registerEvent:function(i,h,g){},unregisterEvent:function(l,k,j){},_initWindowObserver:function(){this._onNativeWrapper=qx.lang.Function.listener(this._onNative,this);var m=qx.event.handler.Window.SUPPORTED_TYPES;for(var n in m){qx.bom.Event.addNativeListener(this._window,n,this._onNativeWrapper);};},_stopWindowObserver:function(){var o=qx.event.handler.Window.SUPPORTED_TYPES;for(var p in o){qx.bom.Event.removeNativeListener(this._window,p,this._onNativeWrapper);};},_onNative:function(){var q=qx.core.Environment.select(a,{"true":qx.event.GlobalError.observeMethod(this.__cU),"false":this.__cU});q.apply(this,arguments);},__cU:function(e){if(this.isDisposed()){return;};var v=this._window;var s;try{s=v.document;}catch(w){return;};var t=s.documentElement;var r=qx.bom.Event.getTarget(e);if(r==null||r===v||r===s||r===t){var event=qx.event.Registration.createEvent(e.type,qx.event.type.Native,[e,v]);qx.event.Registration.dispatchEvent(v,event);var u=event.getReturnValue();if(u!=null){e.returnValue=u;return u;};};}},destruct:function(){this._stopWindowObserver();this._manager=this._window=null;},defer:function(x){qx.event.Registration.addHandler(x);}});})();(function(){var a="ready",b="mshtml",c="engine.name",d="qx.event.handler.Application",f="complete",g="webkit",h="gecko",i="qx.globalErrorHandling",j="load",k="unload",l="opera",m="left",n="DOMContentLoaded",o="shutdown",p="browser.documentmode";qx.Class.define(d,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(q){qx.core.Object.call(this);this._window=q.getWindow();this.__cV=false;this.__cW=false;this.__cX=false;this.__cY=false;this._initObserver();qx.event.handler.Application.$$instance=this;},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{ready:1,shutdown:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true,onScriptLoaded:function(){var r=qx.event.handler.Application.$$instance;if(r){r.__da();};}},members:{canHandleEvent:function(t,s){},registerEvent:function(w,v,u){},unregisterEvent:function(z,y,x){},__cX:null,__cV:null,__cW:null,__cY:null,__da:function(){if(!this.__cX&&this.__cV&&qx.$$loader.scriptLoaded){if((qx.core.Environment.get(c)==b)){if(qx.event.Registration.hasListener(this._window,a)){this.__cX=true;qx.event.Registration.fireEvent(this._window,a);};}else {this.__cX=true;qx.event.Registration.fireEvent(this._window,a);};};},isApplicationReady:function(){return this.__cX;},_initObserver:function(){if(qx.$$domReady||document.readyState==f||document.readyState==a){this.__cV=true;this.__da();}else {this._onNativeLoadWrapped=qx.lang.Function.bind(this._onNativeLoad,this);if(qx.core.Environment.get(c)==h||qx.core.Environment.get(c)==l||qx.core.Environment.get(c)==g||(qx.core.Environment.get(c)==b&&qx.core.Environment.get(p)>8)){qx.bom.Event.addNativeListener(this._window,n,this._onNativeLoadWrapped);}else {var self=this;var A=function(){try{document.documentElement.doScroll(m);if(document.body){self._onNativeLoadWrapped();};}catch(B){window.setTimeout(A,100);};};A();};qx.bom.Event.addNativeListener(this._window,j,this._onNativeLoadWrapped);};this._onNativeUnloadWrapped=qx.lang.Function.bind(this._onNativeUnload,this);qx.bom.Event.addNativeListener(this._window,k,this._onNativeUnloadWrapped);},_stopObserver:function(){if(this._onNativeLoadWrapped){qx.bom.Event.removeNativeListener(this._window,j,this._onNativeLoadWrapped);};qx.bom.Event.removeNativeListener(this._window,k,this._onNativeUnloadWrapped);this._onNativeLoadWrapped=null;this._onNativeUnloadWrapped=null;},_onNativeLoad:function(){var C=qx.core.Environment.select(i,{"true":qx.event.GlobalError.observeMethod(this.__db),"false":this.__db});C.apply(this,arguments);},__db:function(){this.__cV=true;this.__da();},_onNativeUnload:function(){var D=qx.core.Environment.select(i,{"true":qx.event.GlobalError.observeMethod(this.__dc),"false":this.__dc});D.apply(this,arguments);},__dc:function(){if(!this.__cY){this.__cY=true;try{qx.event.Registration.fireEvent(this._window,o);}catch(e){throw e;}finally{qx.core.ObjectRegistry.shutdown();};};}},destruct:function(){this._stopObserver();this._window=null;},defer:function(E){qx.event.Registration.addHandler(E);}});})();(function(){var a="ready",b="shutdown",c="beforeunload",d="qx.core.Init";qx.Class.define(d,{statics:{getApplication:qx.core.BaseInit.getApplication,ready:qx.core.BaseInit.ready,__cS:function(e){var f=this.getApplication();if(f){e.setReturnValue(f.close());};},__cT:function(){var g=this.getApplication();if(g){g.terminate();};}},defer:function(h){qx.event.Registration.addListener(window,a,h.ready,h);qx.event.Registration.addListener(window,b,h.__cT,h);qx.event.Registration.addListener(window,c,h.__cS,h);}});})();(function(){var a="Abstract method call",b="abstract",c="*",d="",e="-webkit-tap-highlight-color: transparent;",f="-ms-touch-select: none;",g="qx.application.AbstractGui",h="-webkit-touch-callout: none;",i="-webkit-tap-highlight-color: rgba(0,0,0,0);";qx.Class.define(g,{type:b,extend:qx.core.Object,implement:[qx.application.IApplication],include:qx.locale.MTranslation,members:{__dd:null,_createRootWidget:function(){throw new Error(a);},getRoot:function(){return this.__dd;},main:function(){qx.theme.manager.Meta.getInstance().initialize();qx.ui.tooltip.Manager.getInstance();var j=[h,f,i,e].join(d);qx.ui.style.Stylesheet.getInstance().addRule(c,j);this.__dd=this._createRootWidget();window.scrollTo(0,0);},finalize:function(){this.render();},render:function(){qx.ui.core.queue.Manager.flush();},close:function(k){},terminate:function(){}},destruct:function(){this.__dd=null;}});})();(function(){var a="The theme to use is not available: ",b="_applyTheme",c="qx.theme",d="qx.theme.manager.Meta",f="qx.theme.Modern",g="qx.event.type.Event",h="Theme",i="changeTheme",j="singleton";qx.Class.define(d,{type:j,extend:qx.core.Object,events:{"changeTheme":g},properties:{theme:{check:h,nullable:false,apply:b}},members:{_applyTheme:function(k,m){var u=true;var w=true;var o=true;var q=true;var l=true;if(m){u=k.meta.color!==m.meta.color;w=k.meta.decoration!==m.meta.decoration;o=k.meta.font!==m.meta.font;q=k.meta.icon!==m.meta.icon;l=k.meta.appearance!==m.meta.appearance;};var n=qx.theme.manager.Color.getInstance();var t=qx.theme.manager.Decoration.getInstance();var r=qx.theme.manager.Font.getInstance();var p=qx.theme.manager.Icon.getInstance();var s=qx.theme.manager.Appearance.getInstance();this._suspendEvents();if(u){if(!w){var v=t.getTheme();t._applyTheme(v);};n.setTheme(k.meta.color);};t.setTheme(k.meta.decoration);r.setTheme(k.meta.font);p.setTheme(k.meta.icon);s.setTheme(k.meta.appearance);if(u||w||o||q||l){this.fireEvent(i);};this._activateEvents();},__de:null,_fireEvent:function(e){if(e.getTarget()===qx.theme.manager.Color.getInstance()){qx.theme.manager.Decoration.getInstance().refresh();};this.fireEvent(i);},_suspendEvents:function(){var B=qx.theme.manager.Color.getInstance();var A=qx.theme.manager.Decoration.getInstance();var x=qx.theme.manager.Font.getInstance();var z=qx.theme.manager.Icon.getInstance();var y=qx.theme.manager.Appearance.getInstance();if(B.hasListener(i)){B.removeListener(i,this._fireEvent,this);};if(A.hasListener(i)){A.removeListener(i,this._fireEvent,this);};if(x.hasListener(i)){x.removeListener(i,this._fireEvent,this);};if(z.hasListener(i)){z.removeListener(i,this._fireEvent,this);};if(y.hasListener(i)){y.removeListener(i,this._fireEvent,this);};},_activateEvents:function(){var G=qx.theme.manager.Color.getInstance();var F=qx.theme.manager.Decoration.getInstance();var C=qx.theme.manager.Font.getInstance();var E=qx.theme.manager.Icon.getInstance();var D=qx.theme.manager.Appearance.getInstance();if(!G.hasListener(i)){G.addListener(i,this._fireEvent,this);};if(!F.hasListener(i)){F.addListener(i,this._fireEvent,this);};if(!C.hasListener(i)){C.addListener(i,this._fireEvent,this);};if(!E.hasListener(i)){E.addListener(i,this._fireEvent,this);};if(!D.hasListener(i)){D.addListener(i,this._fireEvent,this);};},initialize:function(){var J=qx.core.Environment;var H,I;H=J.get(c);if(H){I=qx.Theme.getByName(H);if(!I){throw new Error(a+H);};this.setTheme(I);};}},environment:{"qx.theme":f}});})();(function(){var a="qx.util.ValueManager",b="abstract";qx.Class.define(a,{type:b,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this._dynamic={};},members:{_dynamic:null,resolveDynamic:function(c){return this._dynamic[c];},isDynamic:function(d){return !!this._dynamic[d];},resolve:function(e){if(e&&this._dynamic[e]){return this._dynamic[e];};return e;},_setDynamic:function(f){this._dynamic=f;},_getDynamic:function(){return this._dynamic;}},destruct:function(){this._dynamic=null;}});})();(function(){var a="Could not parse color: ",b="_applyTheme",c="qx.theme.manager.Color",d="Theme",e="changeTheme",f="string",g="singleton";qx.Class.define(c,{type:g,extend:qx.util.ValueManager,properties:{theme:{check:d,nullable:true,apply:b,event:e}},members:{_applyTheme:function(j){var h={};if(j){var i=j.colors;for(var name in i){h[name]=this.__df(i,name);};};this._setDynamic(h);},__df:function(l,name){var k=l[name];if(typeof k===f){if(!qx.util.ColorUtil.isCssString(k)){if(l[k]!=undefined){return this.__df(l,k);};throw new Error(a+k);};return k;}else if(k instanceof Array){return qx.util.ColorUtil.rgbToRgbString(k);};throw new Error(a+k);},resolve:function(p){var o=this._dynamic;var m=o[p];if(m){return m;};var n=this.getTheme();if(n!==null&&n.colors[p]){return o[p]=n.colors[p];};return p;},isDynamic:function(s){var r=this._dynamic;if(s&&(r[s]!==undefined)){return true;};var q=this.getTheme();if(q!==null&&s&&(q.colors[s]!==undefined)){r[s]=q.colors[s];return true;};return false;}}});})();(function(){var a="Could not parse color: ",c="",d="Invalid hex value: ",e="Could not convert system colors to RGB: ",h="(",j=")",k="#",l="a",m="Invalid hex3 value: ",n="qx.theme.manager.Color",o="qx.util.ColorUtil",q="Invalid hex6 value: ",s="rgb",u=",";qx.Bootstrap.define(o,{statics:{REGEXP:{hex3:/^#([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,rgb:/^rgb\(\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*,\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*,\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*\)$/,rgba:/^rgba\(\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*,\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*,\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*,\s*([0-9]{1,3}\.{0,1}[0-9]*)\s*\)$/},SYSTEM:{activeborder:true,activecaption:true,appworkspace:true,background:true,buttonface:true,buttonhighlight:true,buttonshadow:true,buttontext:true,captiontext:true,graytext:true,highlight:true,highlighttext:true,inactiveborder:true,inactivecaption:true,inactivecaptiontext:true,infobackground:true,infotext:true,menu:true,menutext:true,scrollbar:true,threeddarkshadow:true,threedface:true,threedhighlight:true,threedlightshadow:true,threedshadow:true,window:true,windowframe:true,windowtext:true},NAMED:{black:[0,0,0],silver:[192,192,192],gray:[128,128,128],white:[255,255,255],maroon:[128,0,0],red:[255,0,0],purple:[128,0,128],fuchsia:[255,0,255],green:[0,128,0],lime:[0,255,0],olive:[128,128,0],yellow:[255,255,0],navy:[0,0,128],blue:[0,0,255],teal:[0,128,128],aqua:[0,255,255],transparent:[-1,-1,-1],magenta:[255,0,255],orange:[255,165,0],brown:[165,42,42]},isNamedColor:function(v){return this.NAMED[v]!==undefined;},isSystemColor:function(w){return this.SYSTEM[w]!==undefined;},supportsThemes:function(){if(qx.Class){return qx.Class.isDefined(n);};return false;},isThemedColor:function(x){if(!this.supportsThemes()){return false;};if(qx.theme&&qx.theme.manager&&qx.theme.manager.Color){return qx.theme.manager.Color.getInstance().isDynamic(x);};return false;},stringToRgb:function(y){if(this.supportsThemes()&&this.isThemedColor(y)){y=qx.theme.manager.Color.getInstance().resolveDynamic(y);};if(this.isNamedColor(y)){return this.NAMED[y].concat();}else if(this.isSystemColor(y)){throw new Error(e+y);}else if(this.isRgbaString(y)){return this.__dh(y);}else if(this.isRgbString(y)){return this.__dg();}else if(this.isHex3String(y)){return this.__di();}else if(this.isHex6String(y)){return this.__dj();};throw new Error(a+y);},cssStringToRgb:function(z){if(this.isNamedColor(z)){return this.NAMED[z];}else if(this.isSystemColor(z)){throw new Error(e+z);}else if(this.isRgbString(z)){return this.__dg();}else if(this.isRgbaString(z)){return this.__dh();}else if(this.isHex3String(z)){return this.__di();}else if(this.isHex6String(z)){return this.__dj();};throw new Error(a+z);},stringToRgbString:function(A){return this.rgbToRgbString(this.stringToRgb(A));},rgbToRgbString:function(B){return s+(B[3]!==undefined?l:c)+h+B.join(u)+j;},rgbToHexString:function(C){return (k+qx.lang.String.pad(C[0].toString(16).toUpperCase(),2)+qx.lang.String.pad(C[1].toString(16).toUpperCase(),2)+qx.lang.String.pad(C[2].toString(16).toUpperCase(),2));},isValidPropertyValue:function(D){return (this.isThemedColor(D)||this.isNamedColor(D)||this.isHex3String(D)||this.isHex6String(D)||this.isRgbString(D)||this.isRgbaString(D));},isCssString:function(E){return (this.isSystemColor(E)||this.isNamedColor(E)||this.isHex3String(E)||this.isHex6String(E)||this.isRgbString(E)||this.isRgbaString(E));},isHex3String:function(F){return this.REGEXP.hex3.test(F);},isHex6String:function(G){return this.REGEXP.hex6.test(G);},isRgbString:function(H){return this.REGEXP.rgb.test(H);},isRgbaString:function(I){return this.REGEXP.rgba.test(I);},__dg:function(){var L=parseInt(RegExp.$1,10);var K=parseInt(RegExp.$2,10);var J=parseInt(RegExp.$3,10);return [L,K,J];},__dh:function(){var P=parseInt(RegExp.$1,10);var O=parseInt(RegExp.$2,10);var M=parseInt(RegExp.$3,10);var N=parseFloat(RegExp.$4,10);if(P===0&&O===0&M===0&&N===0){return [-1,-1,-1];};return [P,O,M];},__di:function(){var S=parseInt(RegExp.$1,16)*17;var R=parseInt(RegExp.$2,16)*17;var Q=parseInt(RegExp.$3,16)*17;return [S,R,Q];},__dj:function(){var V=(parseInt(RegExp.$1,16)*16)+parseInt(RegExp.$2,16);var U=(parseInt(RegExp.$3,16)*16)+parseInt(RegExp.$4,16);var T=(parseInt(RegExp.$5,16)*16)+parseInt(RegExp.$6,16);return [V,U,T];},hex3StringToRgb:function(W){if(this.isHex3String(W)){return this.__di(W);};throw new Error(m+W);},hex3StringToHex6String:function(X){if(this.isHex3String(X)){return this.rgbToHexString(this.hex3StringToRgb(X));};return X;},hex6StringToRgb:function(Y){if(this.isHex6String(Y)){return this.__dj(Y);};throw new Error(q+Y);},hexStringToRgb:function(ba){if(this.isHex3String(ba)){return this.__di(ba);};if(this.isHex6String(ba)){return this.__dj(ba);};throw new Error(d+ba);},rgbToHsb:function(bi){var bc,bd,bf;var bm=bi[0];var bj=bi[1];var bb=bi[2];var bl=(bm>bj)?bm:bj;if(bb>bl){bl=bb;};var be=(bm<bj)?bm:bj;if(bb<be){be=bb;};bf=bl/255.0;if(bl!=0){bd=(bl-be)/bl;}else {bd=0;};if(bd==0){bc=0;}else {var bh=(bl-bm)/(bl-be);var bk=(bl-bj)/(bl-be);var bg=(bl-bb)/(bl-be);if(bm==bl){bc=bg-bk;}else if(bj==bl){bc=2.0+bh-bg;}else {bc=4.0+bk-bh;};bc=bc/6.0;if(bc<0){bc=bc+1.0;};};return [Math.round(bc*360),Math.round(bd*100),Math.round(bf*100)];},hsbToRgb:function(bn){var i,f,p,r,t;var bo=bn[0]/360;var bp=bn[1]/100;var bq=bn[2]/100;if(bo>=1.0){bo%=1.0;};if(bp>1.0){bp=1.0;};if(bq>1.0){bq=1.0;};var br=Math.floor(255*bq);var bs={};if(bp==0.0){bs.red=bs.green=bs.blue=br;}else {bo*=6.0;i=Math.floor(bo);f=bo-i;p=Math.floor(br*(1.0-bp));r=Math.floor(br*(1.0-(bp*f)));t=Math.floor(br*(1.0-(bp*(1.0-f))));switch(i){case 0:bs.red=br;bs.green=t;bs.blue=p;break;case 1:bs.red=r;bs.green=br;bs.blue=p;break;case 2:bs.red=p;bs.green=br;bs.blue=t;break;case 3:bs.red=p;bs.green=r;bs.blue=br;break;case 4:bs.red=t;bs.green=p;bs.blue=br;break;case 5:bs.red=br;bs.green=p;bs.blue=r;break;};};return [bs.red,bs.green,bs.blue];},randomColor:function(){var r=Math.round(Math.random()*255);var g=Math.round(Math.random()*255);var b=Math.round(Math.random()*255);return this.rgbToRgbString([r,g,b]);}}});})();(function(){var a="mshtml",b="engine.name",c="_applyTheme",d="",e="'.",f="qx-",g="__dm",h="Unable to resolve decorator '",j="singleton",k=";",l="qx.theme.manager.Decoration",m=".",n="Theme",o="object",p="changeTheme",q="string",r="browser.documentmode",s=":";qx.Class.define(l,{type:j,extend:qx.core.Object,statics:{CSS_CLASSNAME_PREFIX:f},construct:function(){qx.core.Object.call(this);this.__dk=[];this.__dl=(qx.core.Environment.get(b)==a&&qx.core.Environment.get(r)<9);},properties:{theme:{check:n,nullable:true,apply:c,event:p}},members:{__dm:null,__dk:null,__dl:false,getCssClassName:function(u){var t=qx.theme.manager.Decoration.CSS_CLASSNAME_PREFIX;if(qx.lang.Type.isString(u)){return t+u;}else {return t+u.toHashCode();};},addCssClass:function(z){var w=qx.ui.style.Stylesheet.getInstance();var B=z;z=this.getCssClassName(z);var A=m+z;if(w.hasRule(A)){return z;};if(qx.lang.Type.isString(B)){B=this.resolve(B);};if(!B){throw new Error(h+z+e);};var G=d;var v=B.getStyles(true);for(var D in v){if(qx.Bootstrap.isObject(v[D])){var x=d;var F=v[D];var C=false;for(var y in F){C=true;x+=y+s+F[y]+k;};var E=this.__dl?A:A+(C?s:d);this.__dk.push(E+D);w.addRule(E+D,x);continue;};G+=D+s+v[D]+k;};if(G){w.addRule(A,G);this.__dk.push(A);};return z;},removeAllCssClasses:function(){for(var i=0;i<this.__dk.length;i++ ){var H=this.__dk[i];qx.ui.style.Stylesheet.getInstance().removeRule(H);};this.__dk=[];},resolve:function(L){if(!L){return null;};if(typeof L===o){return L;};var M=this.getTheme();if(!M){return null;};var J=this.__dm;if(!J){J=this.__dm={};};var I=J[L];if(I){return I;};var O=qx.lang.Object.clone(M.decorations[L],true);if(!O){return null;};if(!O.style){O.style={};};var K=O;while(K.include){K=M.decorations[K.include];if(!O.decorator&&K.decorator){O.decorator=qx.lang.Object.clone(K.decorator);};if(K.style){for(var N in K.style){if(O.style[N]===undefined){O.style[N]=qx.lang.Object.clone(K.style[N],true);};};};};return J[L]=(new qx.ui.decoration.Decorator()).set(O.style);},isValidPropertyValue:function(P){if(typeof P===q){return this.isDynamic(P);}else if(typeof P===o){var Q=P.constructor;return qx.Class.hasInterface(Q,qx.ui.decoration.IDecorator);};return false;},isDynamic:function(S){if(!S){return false;};var R=this.getTheme();if(!R){return false;};return !!R.decorations[S];},isCached:function(T){return !this.__dm?false:qx.lang.Object.contains(this.__dm,T);},_applyTheme:function(X,V){var W=qx.util.AliasManager.getInstance();this.removeAllCssClasses();if(V){for(var U in V.aliases){W.remove(U);};};if(X){for(var U in X.aliases){W.add(U,X.aliases[U]);};};this._disposeMap(g);this.__dm={};},clear:function(){var bb=qx.util.AliasManager.getInstance();var ba=this.getTheme();if(!bb.isDisposed()&&ba&&ba.alias){for(var Y in ba.aliases){bb.remove(Y,ba.aliases[Y]);};};this.removeAllCssClasses();this._disposeMap(g);this.__dm={};},refresh:function(){this.clear();var be=qx.util.AliasManager.getInstance();var bd=this.getTheme();if(bd&&bd.alias){for(var bc in bd.aliases){be.add(bc,bd.aliases[bc]);};};}},destruct:function(){this.clear();}});})();(function(){var a="qx.ui.style.Stylesheet",b="singleton";qx.Class.define(a,{type:b,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__dn=qx.bom.Stylesheet.createElement();this.__dk=[];},members:{__dk:null,__dn:null,addRule:function(d,c){if(this.hasRule(d)){return;};qx.bom.Stylesheet.addRule(this.__dn,d,c);this.__dk.push(d);},hasRule:function(e){return this.__dk.indexOf(e)!=-1;},removeRule:function(f){delete this.__dk[this.__dk.indexOf(f)];qx.bom.Stylesheet.removeRule(this.__dn,f);}}});})();(function(){var a="stylesheet",b="head",c="html.stylesheet.addimport",d="html.stylesheet.insertrule",e="}",f="html.stylesheet.createstylesheet",g='@import "',h="text/css",j="{",k='";',l="html.stylesheet.removeimport",m="html.stylesheet.deleterule",n="qx.bom.Stylesheet",o="link",p="style";qx.Bootstrap.define(n,{statics:{includeFile:function(s,q){if(!q){q=document;};var t=q.createElement(o);t.type=h;t.rel=a;t.href=s;var r=q.getElementsByTagName(b)[0];r.appendChild(t);},createElement:function(u){if(qx.core.Environment.get(f)){var v=document.createStyleSheet();if(u){v.cssText=u;};return v;}else {var w=document.createElement(p);w.type=h;if(u){w.appendChild(document.createTextNode(u));};document.getElementsByTagName(b)[0].appendChild(w);return w.sheet;};},addRule:function(z,A,y){{var x;};if(qx.core.Environment.get(d)){z.insertRule(A+j+y+e,z.cssRules.length);}else {z.addRule(A,y);};},removeRule:function(C,E){if(qx.core.Environment.get(m)){var B=C.cssRules;var D=B.length;for(var i=D-1;i>=0; --i){if(B[i].selectorText==E){C.deleteRule(i);};};}else {var B=C.rules;var D=B.length;for(var i=D-1;i>=0; --i){if(B[i].selectorText==E){C.removeRule(i);};};};},removeSheet:function(G){var F=G.ownerNode?G.ownerNode:G.owningElement;qx.dom.Element.removeChild(F,F.parentNode);},removeAllRules:function(I){if(qx.core.Environment.get(m)){var H=I.cssRules;var J=H.length;for(var i=J-1;i>=0;i-- ){I.deleteRule(i);};}else {var H=I.rules;var J=H.length;for(var i=J-1;i>=0;i-- ){I.removeRule(i);};};},addImport:function(L,K){if(qx.core.Environment.get(c)){L.addImport(K);}else {L.insertRule(g+K+k,L.cssRules.length);};},removeImport:function(M,N){if(qx.core.Environment.get(l)){var O=M.imports;var P=O.length;for(var i=P-1;i>=0;i-- ){if(O[i].href==N||O[i].href==qx.util.Uri.getAbsolute(N)){M.removeImport(i);};};}else {var Q=M.cssRules;var P=Q.length;for(var i=P-1;i>=0;i-- ){if(Q[i].href==N){M.deleteRule(i);};};};},removeAllImports:function(S){if(qx.core.Environment.get(l)){var U=S.imports;var T=U.length;for(var i=T-1;i>=0;i-- ){S.removeImport(i);};}else {var R=S.cssRules;var T=R.length;for(var i=T-1;i>=0;i-- ){if(R[i].type==R[i].IMPORT_RULE){S.deleteRule(i);};};};}}});})();(function(){var a="engine.name",b="",c="none",d="qx.dom.Element",e="webkit",f="The tag name is missing!",g="div";qx.Bootstrap.define(d,{statics:{hasChild:function(parent,h){return h.parentNode===parent;},hasChildren:function(j){return !!j.firstChild;},hasChildElements:function(k){k=k.firstChild;while(k){if(k.nodeType===1){return true;};k=k.nextSibling;};return false;},getParentElement:function(m){return m.parentNode;},isInDom:function(p,n){if(!n){n=window;};var o=n.document.getElementsByTagName(p.nodeName);for(var i=0,l=o.length;i<l;i++ ){if(o[i]===p){return true;};};return false;},insertAt:function(q,parent,r){var s=parent.childNodes[r];if(s){parent.insertBefore(q,s);}else {parent.appendChild(q);};return true;},insertBegin:function(t,parent){if(parent.firstChild){this.insertBefore(t,parent.firstChild);}else {parent.appendChild(t);};return true;},insertEnd:function(u,parent){parent.appendChild(u);return true;},insertBefore:function(v,w){w.parentNode.insertBefore(v,w);return true;},insertAfter:function(x,y){var parent=y.parentNode;if(y==parent.lastChild){parent.appendChild(x);}else {return this.insertBefore(x,y.nextSibling);};return true;},remove:function(z){if(!z.parentNode){return false;};z.parentNode.removeChild(z);return true;},removeChild:function(A,parent){if(A.parentNode!==parent){return false;};parent.removeChild(A);return true;},removeChildAt:function(B,parent){var C=parent.childNodes[B];if(!C){return false;};parent.removeChild(C);return true;},replaceChild:function(E,D){if(!D.parentNode){return false;};D.parentNode.replaceChild(E,D);return true;},replaceAt:function(G,H,parent){var F=parent.childNodes[H];if(!F){return false;};parent.replaceChild(G,F);return true;},__do:{},getHelperElement:function(I){if(!I){I=window;};var J=I.location.href;if(!qx.dom.Element.__do[J]){var K=qx.dom.Element.__do[J]=I.document.createElement(g);if(qx.core.Environment.get(a)==e){K.style.display=c;I.document.body.appendChild(K);};};return qx.dom.Element.__do[J];},create:function(name,M,L){if(!L){L=window;};if(!name){throw new Error(f);};var O=L.document.createElement(name);for(var N in M){qx.bom.element.Attribute.set(O,N,M[N]);};return O;},empty:function(P){return P.innerHTML=b;}}});})();(function(){var b="function",c="html.video.h264",d="html.element.contains",f='video/ogg; codecs="theora, vorbis"',g="qxtest",h="html.console",i="html.xul",j="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",k="html.video.ogg",l="http://www.w3.org/TR/SVG11/feature#BasicStructure",m="html.storage.local",n="div",o="qx.bom.client.Html",p="getSelection",q='audio',r='video/mp4; codecs="avc1.42E01E, mp4a.40.2"',s="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==",t="html.audio",u="video",w="url(#default#VML)",x="head",y="audio",z="audio/mpeg",A="org.w3c.dom.svg",B="html.classlist",C="html.svg",D="html.video",E="html.geolocation",F="DOMTokenList",G="html.storage.session",H="1.1",I="html.history.state",J="object",K="html.image.naturaldimensions",L="html.audio.aif",M="audio/x-wav",N='<v:shape id="vml_flag1" adj="1" />',O="html.node.isequalnode",P="html.canvas",Q="audio/ogg",R="",S="html.storage.userdata",T="html.fullscreen",U="number",V="html.element.compareDocumentPosition",W="audio/x-aiff",X="html.audio.au",Y="img",bF="html.selection",bG="selection",bH="html.xpath",bB="$qx_check",bC="test",bD='video',bE="span",bM="html.element.textcontent",bN="geolocation",bW="html.audio.mp3",bA="html.vml",bI="undefined",bJ="html.audio.ogg",bK="none",bL="label",bQ='video/webm; codecs="vp8, vorbis"',ca="html.dataurl",bR="html.webworker",bS="html.dataset",bX="1.0",bO="html.audio.wav",bY="html.filereader",bP="audio/basic",bT="display",bU="html.video.webm",bV="#default#userdata";qx.Bootstrap.define(o,{statics:{getWebWorker:function(){return window.Worker!=null;},getFileReader:function(){return window.FileReader!=null;},getGeoLocation:function(){return bN in navigator;},getAudio:function(){return !!document.createElement(q).canPlayType;},getAudioOgg:function(){if(!qx.bom.client.Html.getAudio()){return R;};var a=document.createElement(y);return a.canPlayType(Q);},getAudioMp3:function(){if(!qx.bom.client.Html.getAudio()){return R;};var a=document.createElement(y);return a.canPlayType(z);},getAudioWav:function(){if(!qx.bom.client.Html.getAudio()){return R;};var a=document.createElement(y);return a.canPlayType(M);},getAudioAu:function(){if(!qx.bom.client.Html.getAudio()){return R;};var a=document.createElement(y);return a.canPlayType(bP);},getAudioAif:function(){if(!qx.bom.client.Html.getAudio()){return R;};var a=document.createElement(y);return a.canPlayType(W);},getVideo:function(){return !!document.createElement(bD).canPlayType;},getVideoOgg:function(){if(!qx.bom.client.Html.getVideo()){return R;};var v=document.createElement(u);return v.canPlayType(f);},getVideoH264:function(){if(!qx.bom.client.Html.getVideo()){return R;};var v=document.createElement(u);return v.canPlayType(r);},getVideoWebm:function(){if(!qx.bom.client.Html.getVideo()){return R;};var v=document.createElement(u);return v.canPlayType(bQ);},getLocalStorage:function(){try{window.localStorage.setItem(bB,bC);window.localStorage.removeItem(bB);return true;}catch(cb){return false;};},getSessionStorage:function(){try{window.sessionStorage.setItem(bB,bC);window.sessionStorage.removeItem(bB);return true;}catch(cc){return false;};},getUserDataStorage:function(){var cd=document.createElement(n);cd.style[bT]=bK;document.getElementsByTagName(x)[0].appendChild(cd);var ce=false;try{cd.addBehavior(bV);cd.load(g);ce=true;}catch(e){};document.getElementsByTagName(x)[0].removeChild(cd);return ce;},getClassList:function(){return !!(document.documentElement.classList&&qx.Bootstrap.getClass(document.documentElement.classList)===F);},getXPath:function(){return !!document.evaluate;},getXul:function(){try{document.createElementNS(j,bL);return true;}catch(e){return false;};},getSvg:function(){return document.implementation&&document.implementation.hasFeature&&(document.implementation.hasFeature(A,bX)||document.implementation.hasFeature(l,H));},getVml:function(){var cf=document.createElement(n);document.body.appendChild(cf);cf.innerHTML=N;cf.firstChild.style.behavior=w;var cg=typeof cf.firstChild.adj==J;document.body.removeChild(cf);return cg;},getCanvas:function(){return !!window.CanvasRenderingContext2D;},getDataUrl:function(ch){var ci=new Image();ci.onload=ci.onerror=function(){window.setTimeout(function(){ch.call(null,(ci.width==1&&ci.height==1));},0);};ci.src=s;},getDataset:function(){return !!document.documentElement.dataset;},getContains:function(){return (typeof document.documentElement.contains!==bI);},getCompareDocumentPosition:function(){return (typeof document.documentElement.compareDocumentPosition===b);},getTextContent:function(){var cj=document.createElement(bE);return (typeof cj.textContent!==bI);},getFullScreen:function(){return document.fullscreenEnabled||document.webkitFullscreenEnabled||document.mozFullScreenEnabled||document.msFullscreenEnabled||false;},getConsole:function(){return typeof window.console!==bI;},getNaturalDimensions:function(){var ck=document.createElement(Y);return typeof ck.naturalHeight===U&&typeof ck.naturalWidth===U;},getHistoryState:function(){return (typeof window.onpopstate!==bI&&typeof window.history.replaceState!==bI&&typeof window.history.pushState!==bI);},getSelection:function(){if(typeof window.getSelection===b){return p;};if(typeof document.selection===J){return bG;};return null;},getIsEqualNode:function(){return typeof document.documentElement.isEqualNode===b;}},defer:function(cl){qx.core.Environment.add(bR,cl.getWebWorker);qx.core.Environment.add(bY,cl.getFileReader);qx.core.Environment.add(E,cl.getGeoLocation);qx.core.Environment.add(t,cl.getAudio);qx.core.Environment.add(bJ,cl.getAudioOgg);qx.core.Environment.add(bW,cl.getAudioMp3);qx.core.Environment.add(bO,cl.getAudioWav);qx.core.Environment.add(X,cl.getAudioAu);qx.core.Environment.add(L,cl.getAudioAif);qx.core.Environment.add(D,cl.getVideo);qx.core.Environment.add(k,cl.getVideoOgg);qx.core.Environment.add(c,cl.getVideoH264);qx.core.Environment.add(bU,cl.getVideoWebm);qx.core.Environment.add(m,cl.getLocalStorage);qx.core.Environment.add(G,cl.getSessionStorage);qx.core.Environment.add(S,cl.getUserDataStorage);qx.core.Environment.add(B,cl.getClassList);qx.core.Environment.add(bH,cl.getXPath);qx.core.Environment.add(i,cl.getXul);qx.core.Environment.add(P,cl.getCanvas);qx.core.Environment.add(C,cl.getSvg);qx.core.Environment.add(bA,cl.getVml);qx.core.Environment.add(bS,cl.getDataset);qx.core.Environment.addAsync(ca,cl.getDataUrl);qx.core.Environment.add(d,cl.getContains);qx.core.Environment.add(V,cl.getCompareDocumentPosition);qx.core.Environment.add(bM,cl.getTextContent);qx.core.Environment.add(h,cl.getConsole);qx.core.Environment.add(K,cl.getNaturalDimensions);qx.core.Environment.add(I,cl.getHistoryState);qx.core.Environment.add(bF,cl.getSelection);qx.core.Environment.add(O,cl.getIsEqualNode);qx.core.Environment.add(T,cl.getFullScreen);}});})();(function(){var a="readOnly",b="data-",c="accessKey",d="qx.bom.element.Attribute",e="rowSpan",f="vAlign",g="className",h="textContent",i="'",j="htmlFor",k="longDesc",l="cellSpacing",m="frameBorder",n="='",o="",p="useMap",q="innerText",r="innerHTML",s="tabIndex",t="dateTime",u="maxLength",v="html.element.textcontent",w="mshtml",x="engine.name",y="cellPadding",z="browser.documentmode",A="colSpan",B="undefined";qx.Bootstrap.define(d,{statics:{__dp:{names:{"class":g,"for":j,html:r,text:qx.core.Environment.get(v)?h:q,colspan:A,rowspan:e,valign:f,datetime:t,accesskey:c,tabindex:s,maxlength:u,readonly:a,longdesc:k,cellpadding:y,cellspacing:l,frameborder:m,usemap:p},runtime:{"html":1,"text":1},bools:{compact:1,nowrap:1,ismap:1,declare:1,noshade:1,checked:1,disabled:1,readOnly:1,multiple:1,selected:1,noresize:1,defer:1,allowTransparency:1},property:{$$html:1,$$widget:1,checked:1,readOnly:1,multiple:1,selected:1,value:1,maxLength:1,className:1,innerHTML:1,innerText:1,textContent:1,htmlFor:1,tabIndex:1},qxProperties:{$$widget:1,$$html:1},propertyDefault:{disabled:false,checked:false,readOnly:false,multiple:false,selected:false,value:o,className:o,innerHTML:o,innerText:o,textContent:o,htmlFor:o,tabIndex:0,maxLength:qx.core.Environment.select(x,{"mshtml":2147483647,"webkit":524288,"default":-1})},removeableProperties:{disabled:1,multiple:1,maxLength:1}},compile:function(C){var D=[];var F=this.__dp.runtime;for(var E in C){if(!F[E]){D.push(E,n,C[E],i);};};return D.join(o);},get:function(I,name){var G=this.__dp;var H;name=G.names[name]||name;if(G.property[name]){H=I[name];if(typeof G.propertyDefault[name]!==B&&H==G.propertyDefault[name]){if(typeof G.bools[name]===B){return null;}else {return H;};};}else {H=I.getAttribute(name);if(G.bools[name]&&!(qx.core.Environment.get(x)==w&&parseInt(qx.core.Environment.get(z),10)<=8)){return qx.Bootstrap.isString(H);};};if(G.bools[name]){return !!H;};return H;},set:function(L,name,K){if(typeof K===B){return;};var J=this.__dp;name=J.names[name]||name;if(J.bools[name]&&!qx.lang.Type.isBoolean(K)){K=qx.lang.Type.isString(K);};if(J.property[name]&&(!(L[name]===undefined)||J.qxProperties[name])){if(K==null){if(J.removeableProperties[name]){L.removeAttribute(name);return;}else if(typeof J.propertyDefault[name]!==B){K=J.propertyDefault[name];};};L[name]=K;}else {if((J.bools[name]||K===null)&&name.indexOf(b)!==0){if(K===true){L.setAttribute(name,name);}else if(K===false||K===null){L.removeAttribute(name);};}else {L.setAttribute(name,K);};};},reset:function(M,name){if(name.indexOf(b)===0){M.removeAttribute(name);}else {this.set(M,name,null);};}}});})();(function(){var a="file",b="+",c="strict",d="anchor",e="div",f="query",g="source",h="password",j="host",k="protocol",l="user",n="directory",p="loose",q="relative",r="queryKey",s="qx.util.Uri",t="",u="path",v="authority",w='">0</a>',x="&",y="port",z='<a href="',A="userInfo",B="?",C="=";qx.Bootstrap.define(s,{statics:{parseUri:function(F,E){var G={key:[g,k,v,A,l,h,j,y,q,u,n,a,f,d],q:{name:r,parser:/(?:^|&)([^&=]*)=?([^&]*)/g},parser:{strict:/^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,loose:/^(?:(?![^:@]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/}};var o=G,m=G.parser[E?c:p].exec(F),D={},i=14;while(i-- ){D[o.key[i]]=m[i]||t;};D[o.q.name]={};D[o.key[12]].replace(o.q.parser,function(I,J,H){if(J){D[o.q.name][J]=H;};});return D;},appendParamsToUrl:function(K,L){if(L===undefined){return K;};{};if(qx.lang.Type.isObject(L)){L=qx.util.Uri.toParameter(L);};if(!L){return K;};return K+=/\?/.test(K)?x+L:B+L;},toParameter:function(M,Q){var P,O=[];for(P in M){if(M.hasOwnProperty(P)){var N=M[P];if(N instanceof Array){for(var i=0;i<N.length;i++ ){this.__dq(P,N[i],O,Q);};}else {this.__dq(P,N,O,Q);};};};return O.join(x);},__dq:function(U,V,T,S){var R=window.encodeURIComponent;if(S){T.push(R(U).replace(/%20/g,b)+C+R(V).replace(/%20/g,b));}else {T.push(R(U)+C+R(V));};},getAbsolute:function(X){var W=document.createElement(e);W.innerHTML=z+X+w;return W.firstChild.href;}}});})();(function(){var a="qx.bom.client.Stylesheet",b="html.stylesheet.deleterule",c="html.stylesheet.insertrule",d="function",e="html.stylesheet.createstylesheet",f="html.stylesheet.addimport",g="html.stylesheet.removeimport",h="object";qx.Bootstrap.define(a,{statics:{__dr:function(){if(!qx.bom.client.Stylesheet.__ds){qx.bom.client.Stylesheet.__ds=qx.bom.Stylesheet.createElement();};return qx.bom.client.Stylesheet.__ds;},getCreateStyleSheet:function(){return typeof document.createStyleSheet===h;},getInsertRule:function(){return typeof qx.bom.client.Stylesheet.__dr().insertRule===d;},getDeleteRule:function(){return typeof qx.bom.client.Stylesheet.__dr().deleteRule===d;},getAddImport:function(){return (typeof qx.bom.client.Stylesheet.__dr().addImport===h);},getRemoveImport:function(){return (typeof qx.bom.client.Stylesheet.__dr().removeImport===h);}},defer:function(i){qx.core.Environment.add(e,i.getCreateStyleSheet);qx.core.Environment.add(c,i.getInsertRule);qx.core.Environment.add(b,i.getDeleteRule);qx.core.Environment.add(f,i.getAddImport);qx.core.Environment.add(g,i.getRemoveImport);}});})();(function(){var a='[object Boolean]',b='[object String]',c='constructor',d='[object Date]',e='[object Number]',f='object',g="qx.lang.Object",h='[object RegExp]',j='[object Array]';qx.Bootstrap.define(g,{statics:{empty:function(k){{};for(var m in k){if(k.hasOwnProperty(m)){delete k[m];};};},isEmpty:function(n){{};for(var o in n){return false;};return true;},getLength:qx.Bootstrap.objectGetLength,getValues:function(p){return Object.values(p);},mergeWith:qx.Bootstrap.objectMergeWith,clone:function(q,t){if(qx.lang.Type.isObject(q)){var r={};for(var s in q){if(t){r[s]=qx.lang.Object.clone(q[s],t);}else {r[s]=q[s];};};return r;}else if(qx.lang.Type.isArray(q)){var r=[];for(var i=0;i<q.length;i++ ){if(t){r[i]=qx.lang.Object.clone(q[i],t);}else {r[i]=q[i];};};return r;};return q;},equals:function(u,v){return qx.lang.Object.__dt(u,v,[],[]);},__dt:function(C,y,w,x){if(C===y){return C!==0||1/C==1/y;};if(C==null||y==null){return C===y;};var B=Object.prototype.toString.call(C);if(B!=Object.prototype.toString.call(y)){return false;};switch(B){case b:return C==String(y);case e:return C!=+C?y!=+y:(C==0?1/C==1/y:C==+y);case d:case a:return +C==+y;case h:return C.source==y.source&&C.global==y.global&&C.multiline==y.multiline&&C.ignoreCase==y.ignoreCase;};if(typeof C!=f||typeof y!=f){return false;};var length=w.length;while(length-- ){if(w[length]==C){return x[length]==y;};};var A=C.constructor,z=y.constructor;if(A!==z&&!(qx.Bootstrap.isFunction(A)&&(A instanceof A)&&qx.Bootstrap.isFunction(z)&&(z instanceof z))&&(c in C&&c in y)){return false;};w.push(C);x.push(y);var F=0,D=true;if(B==j){F=C.length;D=F==y.length;if(D){while(F-- ){if(!(D=qx.lang.Object.__dt(C[F],y[F],w,x))){break;};};};}else {for(var E in C){if(Object.prototype.hasOwnProperty.call(C,E)){F++ ;if(!(D=Object.prototype.hasOwnProperty.call(y,E)&&qx.lang.Object.__dt(C[E],y[E],w,x))){break;};};};if(D){for(E in y){if(Object.prototype.hasOwnProperty.call(y,E)&&!(F-- )){break;};};D=!F;};};w.pop();x.pop();return D;},invert:function(G){{};var H={};for(var I in G){H[G[I].toString()]=I;};return H;},getKeyFromValue:function(J,K){{};for(var L in J){if(J.hasOwnProperty(L)&&J[L]===K){return L;};};return null;},contains:function(M,N){{};return this.getKeyFromValue(M,N)!==null;},fromArray:function(O){{};var P={};for(var i=0,l=O.length;i<l;i++ ){{};P[O[i].toString()]=true;};return P;}}});})();(function(){var a="qx.ui.decoration.MBackgroundColor",b='clui.theme.Theme',c="background-color",d="Color",e="_applyBackgroundColor";qx.Mixin.define(a,{properties:{backgroundColor:{check:d,nullable:true,apply:e}},members:{_styleBackgroundColor:function(f){var g=this.getBackgroundColor();if(g&&b){g=qx.theme.manager.Color.getInstance().resolve(g);};if(g){f[c]=g;};},_applyBackgroundColor:function(){{};}}});})();(function(){var a="qx.ui.decoration.IDecorator";qx.Interface.define(a,{members:{getStyles:function(){},getPadding:function(){},getInsets:function(){}}});})();(function(){var a="abstract",b="Abstract method called.",c="qx.ui.decoration.Abstract";qx.Class.define(c,{extend:qx.core.Object,implement:[qx.ui.decoration.IDecorator],type:a,members:{__du:null,_getDefaultInsets:function(){throw new Error(b);},_isInitialized:function(){throw new Error(b);},_resetInsets:function(){this.__du=null;},getInsets:function(){if(this.__du){return this.__du;};return this._getDefaultInsets();}},destruct:function(){this.__du=null;}});})();(function(){var a="double",b="px ",c="widthTop",d="inset",e="solid",f="dotted",g="styleRight",h="styleBottom",i="_applyWidth",j="border-top",k="border-left",l="ridge",m="border-right",n="qx.ui.decoration.MSingleBorder",o="shorthand",p="Color",q="widthBottom",r="outset",s="widthLeft",t="",u="border-bottom",v="styleTop",w="colorBottom",x="groove",y="styleLeft",z="widthRight",A="dashed",B="Number",C="colorLeft",D="colorRight",E="colorTop",F="_applyStyle",G=" ",H="absolute";qx.Mixin.define(n,{properties:{widthTop:{check:B,init:0,apply:i},widthRight:{check:B,init:0,apply:i},widthBottom:{check:B,init:0,apply:i},widthLeft:{check:B,init:0,apply:i},styleTop:{nullable:true,check:[e,f,A,a,d,r,l,x],init:e,apply:F},styleRight:{nullable:true,check:[e,f,A,a,d,r,l,x],init:e,apply:F},styleBottom:{nullable:true,check:[e,f,A,a,d,r,l,x],init:e,apply:F},styleLeft:{nullable:true,check:[e,f,A,a,d,r,l,x],init:e,apply:F},colorTop:{nullable:true,check:p,apply:F},colorRight:{nullable:true,check:p,apply:F},colorBottom:{nullable:true,check:p,apply:F},colorLeft:{nullable:true,check:p,apply:F},left:{group:[s,y,C]},right:{group:[z,g,D]},top:{group:[c,v,E]},bottom:{group:[q,h,w]},width:{group:[c,z,q,s],mode:o},style:{group:[v,g,h,y],mode:o},color:{group:[E,D,w,C],mode:o}},members:{_styleBorder:function(I){{var K=qx.theme.manager.Color.getInstance();var O=K.resolve(this.getColorTop());var L=K.resolve(this.getColorRight());var J=K.resolve(this.getColorBottom());var N=K.resolve(this.getColorLeft());};var M=this.getWidthTop();if(M>0){I[j]=M+b+this.getStyleTop()+G+(O||t);};var M=this.getWidthRight();if(M>0){I[m]=M+b+this.getStyleRight()+G+(L||t);};var M=this.getWidthBottom();if(M>0){I[u]=M+b+this.getStyleBottom()+G+(J||t);};var M=this.getWidthLeft();if(M>0){I[k]=M+b+this.getStyleLeft()+G+(N||t);};{};I.position=H;},_getDefaultInsetsForBorder:function(){return {top:this.getWidthTop(),right:this.getWidthRight(),bottom:this.getWidthBottom(),left:this.getWidthLeft()};},_applyWidth:function(){this._applyStyle();this._resetInsets();},_applyStyle:function(){{};}}});})();(function(){var a=', url(',b="repeat",c="backgroundPositionX",d="backgroundPositionY",e="px",f="background-position",g=" ",h="background-repeat",i="no-repeat",j=')',k="scale",l="_applyBackgroundPosition",m='url(',n="repeat-x",o="background-image",p="100% 100%",q="repeat-y",r="qx.ui.decoration.MBackgroundImage",s="background-size",t="String",u="_applyBackgroundImage";qx.Mixin.define(r,{properties:{backgroundImage:{check:t,nullable:true,apply:u},backgroundRepeat:{check:[b,n,q,i,k],init:b,apply:u},backgroundPositionX:{nullable:true,apply:l},backgroundPositionY:{nullable:true,apply:l},backgroundPosition:{group:[d,c]}},members:{_styleBackgroundImage:function(v){var x=this.getBackgroundImage();if(!x){return;};var y=qx.util.AliasManager.getInstance().resolve(x);var z=qx.util.ResourceManager.getInstance().toUri(y);if(v[o]){v[o]+=a+z+j;}else {v[o]=m+z+j;};var w=this.getBackgroundRepeat();if(w===k){v[s]=p;}else {v[h]=w;};var top=this.getBackgroundPositionY()||0;var A=this.getBackgroundPositionX()||0;if(!isNaN(top)){top+=e;};if(!isNaN(A)){A+=e;};v[f]=A+g+top;{};},_applyBackgroundImage:function(){{};},_applyBackgroundPosition:function(){{};}}});})();(function(){var a="0",b="qx/static",c="http://",d="https://",e="file://",f="qx.util.AliasManager",g="singleton",h=".",i="/",j="static";qx.Class.define(f,{type:g,extend:qx.util.ValueManager,construct:function(){qx.util.ValueManager.call(this);this.__dv={};this.add(j,b);},members:{__dv:null,_preprocess:function(n){var m=this._getDynamic();if(m[n]===false){return n;}else if(m[n]===undefined){if(n.charAt(0)===i||n.charAt(0)===h||n.indexOf(c)===0||n.indexOf(d)===a||n.indexOf(e)===0){m[n]=false;return n;};if(this.__dv[n]){return this.__dv[n];};var l=n.substring(0,n.indexOf(i));var k=this.__dv[l];if(k!==undefined){m[n]=k+n.substring(l.length);};};return n;},add:function(o,q){this.__dv[o]=q;var p=this._getDynamic();for(var r in p){if(r.substring(0,r.indexOf(i))===o){p[r]=q+r.substring(o.length);};};},remove:function(s){delete this.__dv[s];},resolve:function(t){var u=this._getDynamic();if(t!=null){t=this._preprocess(t);};return u[t]||t;},getAliases:function(){var v={};for(var w in this.__dv){v[w]=this.__dv[w];};return v;}},destruct:function(){this.__dv=null;}});})();(function(){var c="-",d="(^|",f="'] ",g="CLASS",h=":disabled",k="div",l="input",n="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",o="nth",p="*(?:(['\"])((?:\\\\.|[^\\\\])*?)\\3|(",q="type|href|height|width",r=")*)|.*)\\)|)",s="disabled",t="*(?:value|",u="~=",v="previousSibling",w="*(even|odd|(([+-]|)(\\d*)n|)",x="xml:lang",y="only",z="*",A="unsupported lang: ",B="+|((?:^|[^\\\\])(?:\\\\.)*)",C="i",D="\\\\([\\da-f]{1,6}",E="='$1']",F="w#",G="^=",H="*([>+~]|",I="[t^='']",J="*\\)|)",K="+$",L="=",M="unload",N="id",O="text",P="needsContext",Q="nextSibling",R="$=",S="[s!='']:x",T="string",U=")|.)",V="[\\x20\\t\\r\\n\\f]",W="[name=d]",X="*(?:([+-]|)",Y="*((?:-\\d)?\\d*)",cL="#",cM="[selected]",cN="type",cH="ig",cI="parentNode",cJ="href",cK="0x",cS="(",cT="w",cY="even",cU="<div class='a'></div><div class='a i'></div>",cO="g",cP="*\\]",cQ="*\\)|)(?=[^-]|$)",cR="unsupported pseudo: ",dC="w*",eo="*[*^$|!~]?=",da="<select t=''><option selected=''></option></select>",cV=" ",cW="hidden",el="*(?:([*^$|!~]?=)",cX="*,",db="function",dc="^",dd=")",di=")|)|)",dj=":(",dk="onunload",de="button",df="0",dg="^(",dh="option",dq="odd",dr="class",ds="*(\\d+)|))",dt="lang",dl="|=",dm="\\[",dn="name",dp="D",dx="!=",dy="<input/>",en="*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(",dz="sizzle",du="*=",dv="|",em="Syntax error, unrecognized expression: ",dw=")$",dA="object",dB="?|(",dN="$1",dM=")(?:\\(((['\"])((?:\\\\.|[^\\\\])*?)\\3|((?:\\\\.|[^\\\\()[\\]]|",dL="*([^\\]'\"]*?)",dR="*(?:''|\"\")",dQ="eq",dP="className",dO=":enabled",dG="of-type",dF="TAG",dE="|$)",dD="<a href='#'></a>",dK="empty",dJ="qx.bom.Selector",dI="^(?:",dH="value",dY="[id='",dX="^#(",dW="[*^$]=",dV="*,:x",ed="*(",ec="^\\.(",eb="",ea="CHILD",dU=",.*:",dT="^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(",dS="(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",eg="$",ef="\\$&",ee=":checked",ek=",",ej="ID",ei="last",eh="HTML";qx.Bootstrap.define(dJ,{statics:{query:null,matches:null}});(function(window){var i,eM,fM,ew,eB,fC,eG,ep,eE,eF,eD,document,fK,fq,fe,eq,ff,eN,fa=dz+-(new Date()),eH=window.document,eW=0,eA=0,es=ey(),fr=ey(),fI=ey(),eT=function(a,b){if(a===b){eF=true;};return 0;},eR=typeof undefined,ft=1<<31,fA=({}).hasOwnProperty,ev=[],ez=ev.pop,fD=ev.push,fG=ev.push,eI=ev.slice,eS=ev.indexOf||function(fN){var i=0,fO=this.length;for(;i<fO;i++ ){if(this[i]===fN){return i;};};return -1;},fd=n,eK=V,fh=dS,fv=fh.replace(cT,F),fH=dm+eK+ed+fh+dd+eK+el+eK+p+fv+di+eK+cP,fg=dj+fh+dM+fH.replace(3,8)+r,fp=new RegExp(dc+eK+B+eK+K,cO),fx=new RegExp(dc+eK+cX+eK+z),eL=new RegExp(dc+eK+H+eK+dd+eK+z),fj=new RegExp(L+eK+dL+eK+cP,cO),fu=new RegExp(fg),eX=new RegExp(dc+fv+eg),fB={"ID":new RegExp(dX+fh+dd),"CLASS":new RegExp(ec+fh+dd),"TAG":new RegExp(dg+fh.replace(cT,dC)+dd),"ATTR":new RegExp(dc+fH),"PSEUDO":new RegExp(dc+fg),"CHILD":new RegExp(dT+eK+w+eK+X+eK+ds+eK+J,C),"bool":new RegExp(dI+fd+dw,C),"needsContext":new RegExp(dc+eK+en+eK+Y+eK+cQ,C)},fl=/^(?:input|select|textarea|button)$/i,et=/^h\d$/i,fz=/^[^{]+\{\s*\[native \w/,fF=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,fc=/[+~]/,fm=/'|\\/g,eu=new RegExp(D+eK+dB+eK+U,cH),fs=function(_,fP,fQ){var fR=cK+fP-0x10000;return fR!==fR||fQ?fP:fR<0?String.fromCharCode(fR+0x10000):String.fromCharCode(fR>>10|0xD800,fR&0x3FF|0xDC00);};try{fG.apply((ev=eI.call(eH.childNodes)),eH.childNodes);ev[eH.childNodes.length].nodeType;}catch(e){fG={apply:ev.length?function(fT,fS){fD.apply(fT,eI.call(fS));}:function(fV,fU){var j=fV.length,i=0;while((fV[j++ ]=fU[i++ ])){};fV.length=j-1;}};};function fL(gg,fX,gb,gd){var gi,fY,m,fW,i,ge,gh,ga,gf,gc;if((fX?fX.ownerDocument||fX:eH)!==document){eD(fX);};fX=fX||document;gb=gb||[];if(!gg||typeof gg!==T){return gb;};if((fW=fX.nodeType)!==1&&fW!==9){return [];};if(fq&&!gd){if((gi=fF.exec(gg))){if((m=gi[1])){if(fW===9){fY=fX.getElementById(m);if(fY&&fY.parentNode){if(fY.id===m){gb.push(fY);return gb;};}else {return gb;};}else {if(fX.ownerDocument&&(fY=fX.ownerDocument.getElementById(m))&&eN(fX,fY)&&fY.id===m){gb.push(fY);return gb;};};}else if(gi[2]){fG.apply(gb,fX.getElementsByTagName(gg));return gb;}else if((m=gi[3])&&eM.getElementsByClassName&&fX.getElementsByClassName){fG.apply(gb,fX.getElementsByClassName(m));return gb;};};if(eM.qsa&&(!fe||!fe.test(gg))){ga=gh=fa;gf=fX;gc=fW===9&&gg;if(fW===1&&fX.nodeName.toLowerCase()!==dA){ge=eV(gg);if((gh=fX.getAttribute(N))){ga=gh.replace(fm,ef);}else {fX.setAttribute(N,ga);};ga=dY+ga+f;i=ge.length;while(i-- ){ge[i]=ga+eQ(ge[i]);};gf=fc.test(gg)&&eC(fX.parentNode)||fX;gc=ge.join(ek);};if(gc){try{fG.apply(gb,gf.querySelectorAll(gc));return gb;}catch(gj){}finally{if(!gh){fX.removeAttribute(N);};};};};};return eG(gg.replace(fp,dN),fX,gb,gd);};function ey(){var gk=[];function gl(gm,gn){if(gk.push(gm+cV)>fM.cacheLength){delete gl[gk.shift()];};return (gl[gm+cV]=gn);};return gl;};function fy(go){go[fa]=true;return go;};function fk(gq){var gp=document.createElement(k);try{return !!gq(gp);}catch(e){return false;}finally{if(gp.parentNode){gp.parentNode.removeChild(gp);};gp=null;};};function fo(gt,gs){var gr=gt.split(dv),i=gt.length;while(i-- ){fM.attrHandle[gr[i]]=gs;};};function eY(a,b){var gv=b&&a,gu=gv&&a.nodeType===1&&b.nodeType===1&&(~b.sourceIndex||ft)-(~a.sourceIndex||ft);if(gu){return gu;};if(gv){while((gv=gv.nextSibling)){if(gv===b){return -1;};};};return a?1:-1;};function fE(gw){return function(gx){var name=gx.nodeName.toLowerCase();return name===l&&gx.type===gw;};};function er(gy){return function(gz){var name=gz.nodeName.toLowerCase();return (name===l||name===de)&&gz.type===gy;};};function fi(gA){return fy(function(gB){gB=+gB;return fy(function(gE,gC){var j,gD=gA([],gE.length,gB),i=gD.length;while(i-- ){if(gE[(j=gD[i])]){gE[j]=!(gC[j]=gE[j]);};};});});};function eC(gF){return gF&&typeof gF.getElementsByTagName!==eR&&gF;};eM=fL.support={};eB=fL.isXML=function(gG){var gH=gG&&(gG.ownerDocument||gG).documentElement;return gH?gH.nodeName!==eh:false;};eD=fL.setDocument=function(gI){var gK,gJ=gI?gI.ownerDocument||gI:eH,parent=gJ.defaultView;if(gJ===document||gJ.nodeType!==9||!gJ.documentElement){return document;};document=gJ;fK=gJ.documentElement;fq=!eB(gJ);if(parent&&parent!==parent.top){if(parent.addEventListener){parent.addEventListener(M,function(){eD();},false);}else if(parent.attachEvent){parent.attachEvent(dk,function(){eD();});};};eM.attributes=fk(function(gL){gL.className=C;return !gL.getAttribute(dP);});eM.getElementsByTagName=fk(function(gM){gM.appendChild(gJ.createComment(eb));return !gM.getElementsByTagName(z).length;});eM.getElementsByClassName=fz.test(gJ.getElementsByClassName)&&fk(function(gN){gN.innerHTML=cU;gN.firstChild.className=C;return gN.getElementsByClassName(C).length===2;});eM.getById=fk(function(gO){fK.appendChild(gO).id=fa;return !gJ.getElementsByName||!gJ.getElementsByName(fa).length;});if(eM.getById){fM.find[ej]=function(gP,gQ){if(typeof gQ.getElementById!==eR&&fq){var m=gQ.getElementById(gP);return m&&m.parentNode?[m]:[];};};fM.filter[ej]=function(gS){var gR=gS.replace(eu,fs);return function(gT){return gT.getAttribute(N)===gR;};};}else {delete fM.find[ej];fM.filter[ej]=function(gV){var gU=gV.replace(eu,fs);return function(gX){var gW=typeof gX.getAttributeNode!==eR&&gX.getAttributeNode(N);return gW&&gW.value===gU;};};};fM.find[dF]=eM.getElementsByTagName?function(gY,ha){if(typeof ha.getElementsByTagName!==eR){return ha.getElementsByTagName(gY);};}:function(he,hf){var hc,hb=[],i=0,hd=hf.getElementsByTagName(he);if(he===z){while((hc=hd[i++ ])){if(hc.nodeType===1){hb.push(hc);};};return hb;};return hd;};fM.find[g]=eM.getElementsByClassName&&function(hg,hh){if(typeof hh.getElementsByClassName!==eR&&fq){return hh.getElementsByClassName(hg);};};eq=[];fe=[];if((eM.qsa=fz.test(gJ.querySelectorAll))){fk(function(hi){hi.innerHTML=da;if(hi.querySelectorAll(I).length){fe.push(dW+eK+dR);};if(!hi.querySelectorAll(cM).length){fe.push(dm+eK+t+fd+dd);};if(!hi.querySelectorAll(ee).length){fe.push(ee);};});fk(function(hk){var hj=gJ.createElement(l);hj.setAttribute(cN,cW);hk.appendChild(hj).setAttribute(dn,dp);if(hk.querySelectorAll(W).length){fe.push(dn+eK+eo);};if(!hk.querySelectorAll(dO).length){fe.push(dO,h);};hk.querySelectorAll(dV);fe.push(dU);});};if((eM.matchesSelector=fz.test((ff=fK.webkitMatchesSelector||fK.mozMatchesSelector||fK.oMatchesSelector||fK.msMatchesSelector)))){fk(function(hl){eM.disconnectedMatch=ff.call(hl,k);ff.call(hl,S);eq.push(dx,fg);});};fe=fe.length&&new RegExp(fe.join(dv));eq=eq.length&&new RegExp(eq.join(dv));gK=fz.test(fK.compareDocumentPosition);eN=gK||fz.test(fK.contains)?function(a,b){var hm=a.nodeType===9?a.documentElement:a,hn=b&&b.parentNode;return a===hn||!!(hn&&hn.nodeType===1&&(hm.contains?hm.contains(hn):a.compareDocumentPosition&&a.compareDocumentPosition(hn)&16));}:function(a,b){if(b){while((b=b.parentNode)){if(b===a){return true;};};};return false;};eT=gK?function(a,b){if(a===b){eF=true;return 0;};var ho=!a.compareDocumentPosition-!b.compareDocumentPosition;if(ho){return ho;};ho=(a.ownerDocument||a)===(b.ownerDocument||b)?a.compareDocumentPosition(b):1;if(ho&1||(!eM.sortDetached&&b.compareDocumentPosition(a)===ho)){if(a===gJ||a.ownerDocument===eH&&eN(eH,a)){return -1;};if(b===gJ||b.ownerDocument===eH&&eN(eH,b)){return 1;};return eE?(eS.call(eE,a)-eS.call(eE,b)):0;};return ho&4?-1:1;}:function(a,b){if(a===b){eF=true;return 0;};var hp,i=0,hq=a.parentNode,hr=b.parentNode,hs=[a],ht=[b];if(!hq||!hr){return a===gJ?-1:b===gJ?1:hq?-1:hr?1:eE?(eS.call(eE,a)-eS.call(eE,b)):0;}else if(hq===hr){return eY(a,b);};hp=a;while((hp=hp.parentNode)){hs.unshift(hp);};hp=b;while((hp=hp.parentNode)){ht.unshift(hp);};while(hs[i]===ht[i]){i++ ;};return i?eY(hs[i],ht[i]):hs[i]===eH?-1:ht[i]===eH?1:0;};return gJ;};fL.matches=function(hu,hv){return fL(hu,null,null,hv);};fL.matchesSelector=function(hx,hw){if((hx.ownerDocument||hx)!==document){eD(hx);};hw=hw.replace(fj,E);if(eM.matchesSelector&&fq&&(!eq||!eq.test(hw))&&(!fe||!fe.test(hw))){try{var hy=ff.call(hx,hw);if(hy||eM.disconnectedMatch||hx.document&&hx.document.nodeType!==11){return hy;};}catch(e){};};return fL(hw,document,null,[hx]).length>0;};fL.contains=function(hA,hz){if((hA.ownerDocument||hA)!==document){eD(hA);};return eN(hA,hz);};fL.attr=function(hC,name){if((hC.ownerDocument||hC)!==document){eD(hC);};var hB=fM.attrHandle[name.toLowerCase()],hD=hB&&fA.call(fM.attrHandle,name.toLowerCase())?hB(hC,name,!fq):undefined;return hD!==undefined?hD:eM.attributes||!fq?hC.getAttribute(name):(hD=hC.getAttributeNode(name))&&hD.specified?hD.value:null;};fL.error=function(hE){throw new Error(em+hE);};fL.uniqueSort=function(hG){var hH,hF=[],j=0,i=0;eF=!eM.detectDuplicates;eE=!eM.sortStable&&hG.slice(0);hG.sort(eT);if(eF){while((hH=hG[i++ ])){if(hH===hG[i]){j=hF.push(i);};};while(j-- ){hG.splice(hF[j],1);};};eE=null;return hG;};ew=fL.getText=function(hK){var hI,hL=eb,i=0,hJ=hK.nodeType;if(!hJ){while((hI=hK[i++ ])){hL+=ew(hI);};}else if(hJ===1||hJ===9||hJ===11){if(typeof hK.textContent===T){return hK.textContent;}else {for(hK=hK.firstChild;hK;hK=hK.nextSibling){hL+=ew(hK);};};}else if(hJ===3||hJ===4){return hK.nodeValue;};return hL;};fM=fL.selectors={cacheLength:50,createPseudo:fy,match:fB,attrHandle:{},find:{},relative:{">":{dir:cI,first:true}," ":{dir:cI},"+":{dir:v,first:true},"~":{dir:v}},preFilter:{"ATTR":function(hM){hM[1]=hM[1].replace(eu,fs);hM[3]=(hM[4]||hM[5]||eb).replace(eu,fs);if(hM[2]===u){hM[3]=cV+hM[3]+cV;};return hM.slice(0,4);},"CHILD":function(hN){hN[1]=hN[1].toLowerCase();if(hN[1].slice(0,3)===o){if(!hN[3]){fL.error(hN[0]);};hN[4]=+(hN[4]?hN[5]+(hN[6]||1):2*(hN[3]===cY||hN[3]===dq));hN[5]=+((hN[7]+hN[8])||hN[3]===dq);}else if(hN[3]){fL.error(hN[0]);};return hN;},"PSEUDO":function(hP){var hQ,hO=!hP[5]&&hP[2];if(fB[ea].test(hP[0])){return null;};if(hP[3]&&hP[4]!==undefined){hP[2]=hP[4];}else if(hO&&fu.test(hO)&&(hQ=eV(hO,true))&&(hQ=hO.indexOf(dd,hO.length-hQ)-hO.length)){hP[0]=hP[0].slice(0,hQ);hP[2]=hO.slice(0,hQ);};return hP.slice(0,3);}},filter:{"TAG":function(hR){var hS=hR.replace(eu,fs).toLowerCase();return hR===z?function(){return true;}:function(hT){return hT.nodeName&&hT.nodeName.toLowerCase()===hS;};},"CLASS":function(hU){var hV=es[hU+cV];return hV||(hV=new RegExp(d+eK+dd+hU+cS+eK+dE))&&es(hU,function(hW){return hV.test(typeof hW.className===T&&hW.className||typeof hW.getAttribute!==eR&&hW.getAttribute(dr)||eb);});},"ATTR":function(name,hX,hY){return function(ia){var ib=fL.attr(ia,name);if(ib==null){return hX===dx;};if(!hX){return true;};ib+=eb;return hX===L?ib===hY:hX===dx?ib!==hY:hX===G?hY&&ib.indexOf(hY)===0:hX===du?hY&&ib.indexOf(hY)>-1:hX===R?hY&&ib.slice(-hY.length)===hY:hX===u?(cV+ib+cV).indexOf(hY)>-1:hX===dl?ib===hY||ib.slice(0,hY.length+1)===hY+c:false;};},"CHILD":function(ij,ic,ii,ik,ie){var ih=ij.slice(0,3)!==o,forward=ij.slice(-4)!==ei,ig=ic===dG;return ik===1&&ie===0?function(il){return !!il.parentNode;}:function(ir,iu,im){var iq,iv,io,iw,ip,is,ix=ih!==forward?Q:v,parent=ir.parentNode,name=ig&&ir.nodeName.toLowerCase(),it=!im&&!ig;if(parent){if(ih){while(ix){io=ir;while((io=io[ix])){if(ig?io.nodeName.toLowerCase()===name:io.nodeType===1){return false;};};is=ix=ij===y&&!is&&Q;};return true;};is=[forward?parent.firstChild:parent.lastChild];if(forward&&it){iv=parent[fa]||(parent[fa]={});iq=iv[ij]||[];ip=iq[0]===eW&&iq[1];iw=iq[0]===eW&&iq[2];io=ip&&parent.childNodes[ip];while((io= ++ip&&io&&io[ix]||(iw=ip=0)||is.pop())){if(io.nodeType===1&& ++iw&&io===ir){iv[ij]=[eW,ip,iw];break;};};}else if(it&&(iq=(ir[fa]||(ir[fa]={}))[ij])&&iq[0]===eW){iw=iq[1];}else {while((io= ++ip&&io&&io[ix]||(iw=ip=0)||is.pop())){if((ig?io.nodeName.toLowerCase()===name:io.nodeType===1)&& ++iw){if(it){(io[fa]||(io[fa]={}))[ij]=[eW,iw];};if(io===ir){break;};};};};iw-=ie;return iw===ik||(iw%ik===0&&iw/ik>=0);};};},"PSEUDO":function(iz,iA){var iy,iB=fM.pseudos[iz]||fM.setFilters[iz.toLowerCase()]||fL.error(cR+iz);if(iB[fa]){return iB(iA);};if(iB.length>1){iy=[iz,iz,eb,iA];return fM.setFilters.hasOwnProperty(iz.toLowerCase())?fy(function(iD,iC){var iE,iF=iB(iD,iA),i=iF.length;while(i-- ){iE=eS.call(iD,iF[i]);iD[iE]=!(iC[iE]=iF[i]);};}):function(iG){return iB(iG,0,iy);};};return iB;}},pseudos:{"not":fy(function(iI){var iH=[],iJ=[],iK=fC(iI.replace(fp,dN));return iK[fa]?fy(function(iP,iM,iQ,iL){var iN,iO=iK(iP,null,iL,[]),i=iP.length;while(i-- ){if((iN=iO[i])){iP[i]=!(iM[i]=iN);};};}):function(iS,iT,iR){iH[0]=iS;iK(iH,null,iR,iJ);return !iJ.pop();};}),"has":fy(function(iU){return function(iV){return fL(iU,iV).length>0;};}),"contains":fy(function(iW){return function(iX){return (iX.textContent||iX.innerText||ew(iX)).indexOf(iW)>-1;};}),"lang":fy(function(iY){if(!eX.test(iY||eb)){fL.error(A+iY);};iY=iY.replace(eu,fs).toLowerCase();return function(jb){var ja;do {if((ja=fq?jb.lang:jb.getAttribute(x)||jb.getAttribute(dt))){ja=ja.toLowerCase();return ja===iY||ja.indexOf(iY+c)===0;};}while((jb=jb.parentNode)&&jb.nodeType===1);return false;};}),"target":function(jd){var jc=window.location&&window.location.hash;return jc&&jc.slice(1)===jd.id;},"root":function(je){return je===fK;},"focus":function(jf){return jf===document.activeElement&&(!document.hasFocus||document.hasFocus())&&!!(jf.type||jf.href||~jf.tabIndex);},"enabled":function(jg){return jg.disabled===false;},"disabled":function(jh){return jh.disabled===true;},"checked":function(ji){var jj=ji.nodeName.toLowerCase();return (jj===l&&!!ji.checked)||(jj===dh&&!!ji.selected);},"selected":function(jk){if(jk.parentNode){jk.parentNode.selectedIndex;};return jk.selected===true;},"empty":function(jl){for(jl=jl.firstChild;jl;jl=jl.nextSibling){if(jl.nodeType<6){return false;};};return true;},"parent":function(jm){return !fM.pseudos[dK](jm);},"header":function(jn){return et.test(jn.nodeName);},"input":function(jo){return fl.test(jo.nodeName);},"button":function(jp){var name=jp.nodeName.toLowerCase();return name===l&&jp.type===de||name===de;},"text":function(jq){var jr;return jq.nodeName.toLowerCase()===l&&jq.type===O&&((jr=jq.getAttribute(cN))==null||jr.toLowerCase()===O);},"first":fi(function(){return [0];}),"last":fi(function(js,length){return [length-1];}),"eq":fi(function(jt,length,ju){return [ju<0?ju+length:ju];}),"even":fi(function(jv,length){var i=0;for(;i<length;i+=2){jv.push(i);};return jv;}),"odd":fi(function(jw,length){var i=1;for(;i<length;i+=2){jw.push(i);};return jw;}),"lt":fi(function(jx,length,jy){var i=jy<0?jy+length:jy;for(; --i>=0;){jx.push(i);};return jx;}),"gt":fi(function(jz,length,jA){var i=jA<0?jA+length:jA;for(; ++i<length;){jz.push(i);};return jz;})}};fM.pseudos[o]=fM.pseudos[dQ];for(i in {radio:true,checkbox:true,file:true,password:true,image:true}){fM.pseudos[i]=fE(i);};for(i in {submit:true,reset:true}){fM.pseudos[i]=er(i);};function fJ(){};fJ.prototype=fM.filters=fM.pseudos;fM.setFilters=new fJ();function eV(jE,jD){var jK,jJ,jB,jI,jF,jH,jG,jC=fr[jE+cV];if(jC){return jD?0:jC.slice(0);};jF=jE;jH=[];jG=fM.preFilter;while(jF){if(!jK||(jJ=fx.exec(jF))){if(jJ){jF=jF.slice(jJ[0].length)||jF;};jH.push((jB=[]));};jK=false;if((jJ=eL.exec(jF))){jK=jJ.shift();jB.push({value:jK,type:jJ[0].replace(fp,cV)});jF=jF.slice(jK.length);};for(jI in fM.filter){if((jJ=fB[jI].exec(jF))&&(!jG[jI]||(jJ=jG[jI](jJ)))){jK=jJ.shift();jB.push({value:jK,type:jI,matches:jJ});jF=jF.slice(jK.length);};};if(!jK){break;};};return jD?jF.length:jF?fL.error(jE):fr(jE,jH).slice(0);};function eQ(jL){var i=0,jM=jL.length,jN=eb;for(;i<jM;i++ ){jN+=jL[i].value;};return jN;};function eO(jO,jP,jQ){var jR=jP.dir,jT=jQ&&jR===cI,jS=eA++ ;return jP.first?function(jV,jW,jU){while((jV=jV[jR])){if(jV.nodeType===1||jT){return jO(jV,jW,jU);};};}:function(jY,kb,jX){var ka,kc,kd=[eW,jS];if(jX){while((jY=jY[jR])){if(jY.nodeType===1||jT){if(jO(jY,kb,jX)){return true;};};};}else {while((jY=jY[jR])){if(jY.nodeType===1||jT){kc=jY[fa]||(jY[fa]={});if((ka=kc[jR])&&ka[0]===eW&&ka[1]===jS){return (kd[2]=ka[2]);}else {kc[jR]=kd;if((kd[2]=jO(jY,kb,jX))){return true;};};};};};};};function eP(ke){return ke.length>1?function(kg,kh,kf){var i=ke.length;while(i-- ){if(!ke[i](kg,kh,kf)){return false;};};return true;}:ke[0];};function fw(kl,ki,kj){var i=0,kk=ki.length;for(;i<kk;i++ ){fL(kl,ki[i],kj);};return kj;};function ex(kp,kn,kq,ks,km){var ko,ku=[],i=0,kr=kp.length,kt=kn!=null;for(;i<kr;i++ ){if((ko=kp[i])){if(!kq||kq(ko,ks,km)){ku.push(ko);if(kt){kn.push(i);};};};};return ku;};function eJ(kz,ky,kx,kw,kv,kA){if(kw&&!kw[fa]){kw=eJ(kw);};if(kv&&!kv[fa]){kv=eJ(kv,kA);};return fy(function(kJ,kE,kK,kB){var kC,i,kG,kI=[],kM=[],kD=kE.length,kL=kJ||fw(ky||z,kK.nodeType?[kK]:kK,[]),kF=kz&&(kJ||!ky)?ex(kL,kI,kz,kK,kB):kL,kH=kx?kv||(kJ?kz:kD||kw)?[]:kE:kF;if(kx){kx(kF,kH,kK,kB);};if(kw){kC=ex(kH,kM);kw(kC,[],kK,kB);i=kC.length;while(i-- ){if((kG=kC[i])){kH[kM[i]]=!(kF[kM[i]]=kG);};};};if(kJ){if(kv||kz){if(kv){kC=[];i=kH.length;while(i-- ){if((kG=kH[i])){kC.push((kF[i]=kG));};};kv(null,(kH=[]),kC,kB);};i=kH.length;while(i-- ){if((kG=kH[i])&&(kC=kv?eS.call(kJ,kG):kI[i])>-1){kJ[kC]=!(kE[kC]=kG);};};};}else {kH=ex(kH===kE?kH.splice(kD,kH.length):kH);if(kv){kv(null,kE,kH,kB);}else {fG.apply(kE,kH);};};});};function fb(kS){var kN,kP,j,kQ=kS.length,kO=fM.relative[kS[0].type],kV=kO||fM.relative[cV],i=kO?1:0,kU=eO(function(kW){return kW===kN;},kV,true),kR=eO(function(kX){return eS.call(kN,kX)>-1;},kV,true),kT=[function(la,lb,kY){return (!kO&&(kY||lb!==ep))||((kN=lb).nodeType?kU(la,lb,kY):kR(la,lb,kY));}];for(;i<kQ;i++ ){if((kP=fM.relative[kS[i].type])){kT=[eO(eP(kT),kP)];}else {kP=fM.filter[kS[i].type].apply(null,kS[i].matches);if(kP[fa]){j= ++i;for(;j<kQ;j++ ){if(fM.relative[kS[j].type]){break;};};return eJ(i>1&&eP(kT),i>1&&eQ(kS.slice(0,i-1).concat({value:kS[i-2].type===cV?z:eb})).replace(fp,dN),kP,i<j&&fb(kS.slice(i,j)),j<kQ&&fb((kS=kS.slice(j))),j<kQ&&eQ(kS));};kT.push(kP);};};return eP(kT);};function eU(lg,ld){var lc=ld.length>0,le=lg.length>0,lf=function(lp,ls,lh,ll,lk){var ln,j,lt,li=0,i=df,lm=lp&&[],lo=[],lj=ep,lu=lp||le&&fM.find[dF](z,lk),lq=(eW+=lj==null?1:Math.random()||0.1),lr=lu.length;if(lk){ep=ls!==document&&ls;};for(;i!==lr&&(ln=lu[i])!=null;i++ ){if(le&&ln){j=0;while((lt=lg[j++ ])){if(lt(ln,ls,lh)){ll.push(ln);break;};};if(lk){eW=lq;};};if(lc){if((ln=!lt&&ln)){li-- ;};if(lp){lm.push(ln);};};};li+=i;if(lc&&i!==li){j=0;while((lt=ld[j++ ])){lt(lm,lo,ls,lh);};if(lp){if(li>0){while(i-- ){if(!(lm[i]||lo[i])){lo[i]=ez.call(ll);};};};lo=ex(lo);};fG.apply(ll,lo);if(lk&&!lp&&lo.length>0&&(li+ld.length)>1){fL.uniqueSort(ll);};};if(lk){eW=lq;ep=lj;};return lm;};return lc?fy(lf):lf;};fC=fL.compile=function(lw,lz){var i,ly=[],lv=[],lx=fI[lw+cV];if(!lx){if(!lz){lz=eV(lw);};i=lz.length;while(i-- ){lx=fb(lz[i]);if(lx[fa]){ly.push(lx);}else {lv.push(lx);};};lx=fI(lw,eU(lv,ly));lx.selector=lw;};return lx;};eG=fL.select=function(lC,lG,lB,lF){var i,lD,lE,lH,find,lA=typeof lC===db&&lC,lI=!lF&&eV((lC=lA.selector||lC));lB=lB||[];if(lI.length===1){lD=lI[0]=lI[0].slice(0);if(lD.length>2&&(lE=lD[0]).type===ej&&eM.getById&&lG.nodeType===9&&fq&&fM.relative[lD[1].type]){lG=(fM.find[ej](lE.matches[0].replace(eu,fs),lG)||[])[0];if(!lG){return lB;}else if(lA){lG=lG.parentNode;};lC=lC.slice(lD.shift().value.length);};i=fB[P].test(lC)?0:lD.length;while(i-- ){lE=lD[i];if(fM.relative[(lH=lE.type)]){break;};if((find=fM.find[lH])){if((lF=find(lE.matches[0].replace(eu,fs),fc.test(lD[0].type)&&eC(lG.parentNode)||lG))){lD.splice(i,1);lC=lF.length&&eQ(lD);if(!lC){fG.apply(lB,lF);return lB;};break;};};};};(lA||fC(lC,lI))(lF,lG,!fq,lB,fc.test(lC)&&eC(lG.parentNode)||lG);return lB;};eM.sortStable=fa.split(eb).sort(eT).join(eb)===fa;eM.detectDuplicates=!!eF;eD();eM.sortDetached=fk(function(lJ){return lJ.compareDocumentPosition(document.createElement(k))&1;});if(!fk(function(lK){lK.innerHTML=dD;return lK.firstChild.getAttribute(cJ)===cL;})){fo(q,function(lL,name,lM){if(!lM){return lL.getAttribute(name,name.toLowerCase()===cN?1:2);};});};if(!eM.attributes||!fk(function(lN){lN.innerHTML=dy;lN.firstChild.setAttribute(dH,eb);return lN.firstChild.getAttribute(dH)===eb;})){fo(dH,function(lO,name,lP){if(!lP&&lO.nodeName.toLowerCase()===l){return lO.defaultValue;};});};if(!fk(function(lQ){return lQ.getAttribute(s)==null;})){fo(fd,function(lS,name,lR){var lT;if(!lR){return lS[name]===true?name.toLowerCase():(lT=lS.getAttributeNode(name))&&lT.specified?lT.value:null;};});};qx.bom.Selector.query=function(lV,lU){return fL(lV,lU);};qx.bom.Selector.matches=function(lX,lW){return fL(lX,null,null,lW);};})(window);})();(function(){var a="Microsoft.XMLHTTP",b="xhr",c="io.ssl",d="io.xhr",e="",f="file:",g="https:",h="webkit",i="gecko",j="activex",k="opera",l=".",m="io.maxrequests",n="qx.bom.client.Transport";qx.Bootstrap.define(n,{statics:{getMaxConcurrentRequestCount:function(){var p;var r=qx.bom.client.Engine.getVersion().split(l);var o=0;var s=0;var q=0;if(r[0]){o=r[0];};if(r[1]){s=r[1];};if(r[2]){q=r[2];};if(window.maxConnectionsPerServer){p=window.maxConnectionsPerServer;}else if(qx.bom.client.Engine.getName()==k){p=8;}else if(qx.bom.client.Engine.getName()==h){p=4;}else if(qx.bom.client.Engine.getName()==i&&((o>1)||((o==1)&&(s>9))||((o==1)&&(s==9)&&(q>=1)))){p=6;}else {p=2;};return p;},getSsl:function(){return window.location.protocol===g;},getXmlHttpRequest:function(){var t=window.ActiveXObject?(function(){if(window.location.protocol!==f){try{new window.XMLHttpRequest();return b;}catch(u){};};try{new window.ActiveXObject(a);return j;}catch(v){};})():(function(){try{new window.XMLHttpRequest();return b;}catch(w){};})();return t||e;}},defer:function(x){qx.core.Environment.add(m,x.getMaxConcurrentRequestCount);qx.core.Environment.add(c,x.getSsl);qx.core.Environment.add(d,x.getXmlHttpRequest);}});})();(function(){var a="singleton",b="qx.util.LibraryManager";qx.Class.define(b,{extend:qx.core.Object,type:a,statics:{__dw:qx.$$libraries||{}},members:{has:function(c){return !!this.self(arguments).__dw[c];},get:function(d,e){return this.self(arguments).__dw[d][e]?this.self(arguments).__dw[d][e]:null;},set:function(f,g,h){this.self(arguments).__dw[f][g]=h;}}});})();(function(){var a="mshtml",b="engine.name",c="//",d="io.ssl",e="",f="encoding",g="?",h="data",i="base",j="string",k="type",l="data:image/",m=";",n="/",o="resourceUri",p="qx.util.ResourceManager",q="singleton",r=",";qx.Class.define(p,{extend:qx.core.Object,type:q,construct:function(){qx.core.Object.call(this);},statics:{__j:qx.$$resources||{},__dx:{}},members:{has:function(s){return !!this.self(arguments).__j[s];},getData:function(t){return this.self(arguments).__j[t]||null;},getImageWidth:function(v){var u=this.self(arguments).__j[v];return u?u[0]:null;},getImageHeight:function(x){var w=this.self(arguments).__j[x];return w?w[1]:null;},getImageFormat:function(z){var y=this.self(arguments).__j[z];return y?y[2]:null;},getCombinedFormat:function(E){var B=e;var D=this.self(arguments).__j[E];var A=D&&D.length>4&&typeof (D[4])==j&&this.constructor.__j[D[4]];if(A){var F=D[4];var C=this.constructor.__j[F];B=C[2];};return B;},toUri:function(J){if(J==null){return J;};var G=this.self(arguments).__j[J];if(!G){return J;};if(typeof G===j){var I=G;}else {var I=G[3];if(!I){return J;};};var H=e;if((qx.core.Environment.get(b)==a)&&qx.core.Environment.get(d)){H=this.self(arguments).__dx[I];};return H+qx.util.LibraryManager.getInstance().get(I,o)+n+J;},toDataUri:function(M){var L=this.constructor.__j[M];var O=this.constructor.__j[L[4]];var N;if(O){var K=O[4][M];N=l+K[k]+m+K[f]+r+K[h];}else {N=this.toUri(M);};return N;}},defer:function(Q){if((qx.core.Environment.get(b)==a)){if(qx.core.Environment.get(d)){for(var R in qx.$$libraries){var P;if(qx.util.LibraryManager.getInstance().get(R,o)){P=qx.util.LibraryManager.getInstance().get(R,o);}else {Q.__dx[R]=e;continue;};var V;var T=qx.bom.Selector.query(i,document);if(T.length>0){V=T[0].href;};if(P.match(/^\/\//)!=null){Q.__dx[R]=window.location.protocol;}else if(P.match(/^\//)!=null){if(V){Q.__dx[R]=V;}else {Q.__dx[R]=window.location.protocol+c+window.location.host;};}else if(P.match(/^\.\//)!=null){var U=document.URL;Q.__dx[R]=U.substring(0,U.lastIndexOf(n)+1);}else if(P.match(/^http/)!=null){Q.__dx[R]=e;}else {if(!V){var S=window.location.href.indexOf(g);if(S==-1){V=window.location.href;}else {V=window.location.href.substring(0,S);};};Q.__dx[R]=V.substring(0,V.lastIndexOf(n)+1);};};};};}});})();(function(){var a="innerWidthRight",b="innerColorBottom",c="css.borderradius",d="px ",e='""',f="_applyDoubleBorder",g="border-top",h="inset 0 -",i="css.boxsizing",j="innerWidthTop",k="100%",l="border-left",m="innerColorRight",n="css.boxshadow",o="innerColorTop",p="innerColorLeft",q="inset ",r="shorthand",s="inset -",t="Color",u="border-box",v="qx.ui.decoration.MDoubleBorder",w="border-bottom",x=":before",y="inset 0 ",z="px solid ",A="innerWidthBottom",B="css.rgba",C="inherit",D="Number",E="innerWidthLeft",F="px 0 ",G="inset 0 0 0 ",H="border-right",I=" ",J=",",K="absolute";qx.Mixin.define(v,{include:[qx.ui.decoration.MSingleBorder,qx.ui.decoration.MBackgroundImage],construct:function(){this._getDefaultInsetsForBorder=this.__dA;this._styleBorder=this.__dy;},properties:{innerWidthTop:{check:D,init:0,apply:f},innerWidthRight:{check:D,init:0,apply:f},innerWidthBottom:{check:D,init:0,apply:f},innerWidthLeft:{check:D,init:0,apply:f},innerWidth:{group:[j,a,A,E],mode:r},innerColorTop:{nullable:true,check:t,apply:f},innerColorRight:{nullable:true,check:t,apply:f},innerColorBottom:{nullable:true,check:t,apply:f},innerColorLeft:{nullable:true,check:t,apply:f},innerColor:{group:[o,m,b,p],mode:r},innerOpacity:{check:D,init:1,apply:f}},members:{__dy:function(L){var U=qx.core.Environment.get(n);var O,Y,innerWidth;{var T=qx.theme.manager.Color.getInstance();O={top:T.resolve(this.getColorTop()),right:T.resolve(this.getColorRight()),bottom:T.resolve(this.getColorBottom()),left:T.resolve(this.getColorLeft())};Y={top:T.resolve(this.getInnerColorTop()),right:T.resolve(this.getInnerColorRight()),bottom:T.resolve(this.getInnerColorBottom()),left:T.resolve(this.getInnerColorLeft())};};innerWidth={top:this.getInnerWidthTop(),right:this.getInnerWidthRight(),bottom:this.getInnerWidthBottom(),left:this.getInnerWidthLeft()};var R=this.getWidthTop();if(R>0){L[g]=R+d+this.getStyleTop()+I+O.top;};R=this.getWidthRight();if(R>0){L[H]=R+d+this.getStyleRight()+I+O.right;};R=this.getWidthBottom();if(R>0){L[w]=R+d+this.getStyleBottom()+I+O.bottom;};R=this.getWidthLeft();if(R>0){L[l]=R+d+this.getStyleLeft()+I+O.left;};var X=this.getInnerOpacity();if(X<1){this.__dz(Y,X);};if(innerWidth.top>0||innerWidth.right>0||innerWidth.bottom>0||innerWidth.left>0){var W=(innerWidth.top||0)+z+Y.top;var V=(innerWidth.right||0)+z+Y.right;var Q=(innerWidth.bottom||0)+z+Y.bottom;var S=(innerWidth.left||0)+z+Y.left;L[x]={"width":k,"height":k,"position":K,"content":e,"border-top":W,"border-right":V,"border-bottom":Q,"border-left":S,"left":0,"top":0};var M=qx.bom.Style.getCssName(qx.core.Environment.get(i));L[x][M]=u;var N=qx.core.Environment.get(c);if(N){N=qx.bom.Style.getCssName(N);L[x][N]=C;};var P=[];if(Y.top&&innerWidth.top&&Y.top==Y.bottom&&Y.top==Y.right&&Y.top==Y.left&&innerWidth.top==innerWidth.bottom&&innerWidth.top==innerWidth.right&&innerWidth.top==innerWidth.left){P.push(G+innerWidth.top+d+Y.top);}else {if(Y.top){P.push(y+(innerWidth.top||0)+d+Y.top);};if(Y.right){P.push(s+(innerWidth.right||0)+F+Y.right);};if(Y.bottom){P.push(h+(innerWidth.bottom||0)+d+Y.bottom);};if(Y.left){P.push(q+(innerWidth.left||0)+F+Y.left);};};if(P.length>0&&U){U=qx.bom.Style.getCssName(U);if(!L[U]){L[U]=P.join(J);}else {L[U]+=J+P.join(J);};};}else {L[x]={border:0};};},__dz:function(bd,ba){if(!qx.core.Environment.get(B)){{};return;};for(var be in bd){var bb=qx.util.ColorUtil.stringToRgb(bd[be]);bb.push(ba);var bc=qx.util.ColorUtil.rgbToRgbString(bb);bd[be]=bc;};},_applyDoubleBorder:function(){{};},__dA:function(){return {top:this.getWidthTop()+this.getInnerWidthTop(),right:this.getWidthRight()+this.getInnerWidthRight(),bottom:this.getWidthBottom()+this.getInnerWidthBottom(),left:this.getWidthLeft()+this.getInnerWidthLeft()};}}});})();(function(){var a="css.float",b="foo",c="css.borderimage.standardsyntax",d="detect",e="borderRadius",f="boxSizing",g="stretch",h="css.borderradius",j="content",k="css.inlineblock",l="css.gradient.filter",m="css.appearance",n="css.opacity",o="div",p="pointerEvents",q="css.gradient.radial",r="css.pointerevents",s="input",t="color",u="string",v="borderImage",w="userSelect",x="styleFloat",y="css.textShadow.filter",z="css.usermodify",A="flexbox",B='url("foo.png") 4 4 4 4 fill stretch',C="css.boxmodel",D="qx.bom.client.Css",E="css.boxshadow",F="appearance",G="-ms-flexbox",H="placeholder",I="-moz-none",J="backgroundImage",K="css.textShadow",L="DXImageTransform.Microsoft.Shadow",M="flex",N="css.alphaimageloaderneeded",O="css.gradient.legacywebkit",P="css.flexboxSyntax",Q="linear-gradient(0deg, #fff, #000)",R="textShadow",S="auto",T="css.borderimage",U="foo.png",V="rgba(1, 2, 3, 0.5)",W="color=#666666,direction=45",X="radial-gradient(0px 0px, cover, red 50%, blue 100%)",Y="rgba",bG="(",bH="-webkit-flex",bI='url("foo.png") 4 4 4 4 stretch',bC="css.gradient.linear",bD="DXImageTransform.Microsoft.Gradient",bE="css.userselect",bF="span",bM="css.boxsizing",bN="-webkit-gradient(linear,0% 0%,100% 100%,from(white), to(red))",bO="mshtml",ca="css.rgba",bJ=");",bK="4 fill",bL="none",bA="startColorStr=#550000FF, endColorStr=#55FFFF00",bR="progid:",bB="css.placeholder",bS="css.userselect.none",bT="css.textoverflow",bX="inline-block",bP="-moz-inline-box",bY="textOverflow",bQ="userModify",bU="boxShadow",bV="cssFloat",bW="border";qx.Bootstrap.define(D,{statics:{__dB:null,getBoxModel:function(){var content=qx.bom.client.Engine.getName()!==bO||!qx.bom.client.Browser.getQuirksMode();return content?j:bW;},getTextOverflow:function(){return qx.bom.Style.getPropertyName(bY);},getPlaceholder:function(){var i=document.createElement(s);return H in i;},getAppearance:function(){return qx.bom.Style.getPropertyName(F);},getBorderRadius:function(){return qx.bom.Style.getPropertyName(e);},getBoxShadow:function(){return qx.bom.Style.getPropertyName(bU);},getBorderImage:function(){return qx.bom.Style.getPropertyName(v);},getBorderImageSyntax:function(){var cc=qx.bom.client.Css.getBorderImage();if(!cc){return null;};var cb=document.createElement(o);if(cc===v){cb.style[cc]=B;if(cb.style.borderImageSource.indexOf(U)>=0&&cb.style.borderImageSlice.indexOf(bK)>=0&&cb.style.borderImageRepeat.indexOf(g)>=0){return true;};}else {cb.style[cc]=bI;if(cb.style[cc].indexOf(U)>=0){return false;};};return null;},getUserSelect:function(){return qx.bom.Style.getPropertyName(w);},getUserSelectNone:function(){var ce=qx.bom.client.Css.getUserSelect();if(ce){var cd=document.createElement(bF);cd.style[ce]=I;return cd.style[ce]===I?I:bL;};return null;},getUserModify:function(){return qx.bom.Style.getPropertyName(bQ);},getFloat:function(){var cf=document.documentElement.style;return cf.cssFloat!==undefined?bV:cf.styleFloat!==undefined?x:null;},getLinearGradient:function(){qx.bom.client.Css.__dB=false;var cj=Q;var cg=document.createElement(o);var ch=qx.bom.Style.getAppliedStyle(cg,J,cj);if(!ch){cj=bN;var ch=qx.bom.Style.getAppliedStyle(cg,J,cj,false);if(ch){qx.bom.client.Css.__dB=true;};};if(!ch){return null;};var ci=/(.*?)\(/.exec(ch);return ci?ci[1]:null;},getFilterGradient:function(){return qx.bom.client.Css.__dC(bD,bA);},getRadialGradient:function(){var cn=X;var ck=document.createElement(o);var cl=qx.bom.Style.getAppliedStyle(ck,J,cn);if(!cl){return null;};var cm=/(.*?)\(/.exec(cl);return cm?cm[1]:null;},getLegacyWebkitGradient:function(){if(qx.bom.client.Css.__dB===null){qx.bom.client.Css.getLinearGradient();};return qx.bom.client.Css.__dB;},getRgba:function(){var co;try{co=document.createElement(o);}catch(cp){co=document.createElement();};try{co.style[t]=V;if(co.style[t].indexOf(Y)!=-1){return true;};}catch(cq){};return false;},getBoxSizing:function(){return qx.bom.Style.getPropertyName(f);},getInlineBlock:function(){var cr=document.createElement(bF);cr.style.display=bX;if(cr.style.display==bX){return bX;};cr.style.display=bP;if(cr.style.display!==bP){return bP;};return null;},getOpacity:function(){return (typeof document.documentElement.style.opacity==u);},getTextShadow:function(){return !!qx.bom.Style.getPropertyName(R);},getFilterTextShadow:function(){return qx.bom.client.Css.__dC(L,W);},__dC:function(cv,ct){var cu=false;var cw=bR+cv+bG+ct+bJ;var cs=document.createElement(o);document.body.appendChild(cs);cs.style.filter=cw;if(cs.filters&&cs.filters.length>0&&cs.filters.item(cv).enabled==true){cu=true;};document.body.removeChild(cs);return cu;},getAlphaImageLoaderNeeded:function(){return qx.bom.client.Engine.getName()==bO&&qx.bom.client.Browser.getDocumentMode()<9;},getPointerEvents:function(){var cx=document.documentElement;if(p in cx.style){var cz=cx.style.pointerEvents;cx.style.pointerEvents=S;cx.style.pointerEvents=b;var cy=cx.style.pointerEvents==S;cx.style.pointerEvents=cz;return cy;};return false;},getFlexboxSyntax:function(){var cB=null;var cA=document.createElement(d);var cC=[{value:M,syntax:M},{value:G,syntax:A},{value:bH,syntax:M}];for(var i=0;i<cC.length;i++ ){try{cA.style.display=cC[i].value;}catch(cD){return null;};if(cA.style.display===cC[i].value){cB=cC[i].syntax;break;};};cA=null;return cB;}},defer:function(cE){qx.core.Environment.add(bT,cE.getTextOverflow);qx.core.Environment.add(bB,cE.getPlaceholder);qx.core.Environment.add(h,cE.getBorderRadius);qx.core.Environment.add(E,cE.getBoxShadow);qx.core.Environment.add(bC,cE.getLinearGradient);qx.core.Environment.add(l,cE.getFilterGradient);qx.core.Environment.add(q,cE.getRadialGradient);qx.core.Environment.add(O,cE.getLegacyWebkitGradient);qx.core.Environment.add(C,cE.getBoxModel);qx.core.Environment.add(ca,cE.getRgba);qx.core.Environment.add(T,cE.getBorderImage);qx.core.Environment.add(c,cE.getBorderImageSyntax);qx.core.Environment.add(z,cE.getUserModify);qx.core.Environment.add(bE,cE.getUserSelect);qx.core.Environment.add(bS,cE.getUserSelectNone);qx.core.Environment.add(m,cE.getAppearance);qx.core.Environment.add(a,cE.getFloat);qx.core.Environment.add(bM,cE.getBoxSizing);qx.core.Environment.add(k,cE.getInlineBlock);qx.core.Environment.add(n,cE.getOpacity);qx.core.Environment.add(K,cE.getTextShadow);qx.core.Environment.add(y,cE.getFilterTextShadow);qx.core.Environment.add(N,cE.getAlphaImageLoaderNeeded);qx.core.Environment.add(r,cE.getPointerEvents);qx.core.Environment.add(P,cE.getFlexboxSyntax);}});})();(function(){var a="radiusTopRight",b="radiusTopLeft",c="px",d="-webkit-border-bottom-left-radius",e="-webkit-background-clip",f="radiusBottomRight",g="Integer",h="-webkit-border-bottom-right-radius",i="background-clip",j="border-top-left-radius",k="border-top-right-radius",l="border-bottom-left-radius",m="radiusBottomLeft",n="-webkit-border-top-left-radius",o="shorthand",p="-moz-border-radius-bottomright",q="padding-box",r="border-bottom-right-radius",s="qx.ui.decoration.MBorderRadius",t="-moz-border-radius-topright",u="engine.name",v="_applyBorderRadius",w="-webkit-border-top-right-radius",x="webkit",y="-moz-border-radius-topleft",z="-moz-border-radius-bottomleft";qx.Mixin.define(s,{properties:{radiusTopLeft:{nullable:true,check:g,apply:v},radiusTopRight:{nullable:true,check:g,apply:v},radiusBottomLeft:{nullable:true,check:g,apply:v},radiusBottomRight:{nullable:true,check:g,apply:v},radius:{group:[b,a,f,m],mode:o}},members:{_styleBorderRadius:function(A){A[e]=q;A[i]=q;var B=false;var C=this.getRadiusTopLeft();if(C>0){B=true;A[y]=C+c;A[n]=C+c;A[j]=C+c;};C=this.getRadiusTopRight();if(C>0){B=true;A[t]=C+c;A[w]=C+c;A[k]=C+c;};C=this.getRadiusBottomLeft();if(C>0){B=true;A[z]=C+c;A[d]=C+c;A[l]=C+c;};C=this.getRadiusBottomRight();if(C>0){B=true;A[p]=C+c;A[h]=C+c;A[r]=C+c;};if(B&&qx.core.Environment.get(u)==x){A[e]=q;}else {A[i]=q;};},_applyBorderRadius:function(){{};}}});})();(function(){var a="border-width",b="css.borderimage.standardsyntax",c="repeat",d="Boolean",e="-l",f="stretch",g="px ",h="sliceBottom",i="-t",j="Integer",k="solid",l="borderImage",m="-r",n="border-style",o="sliceLeft",p="-b",q="sliceRight",r="px",s="repeatX",t=" fill",u="String",v="vertical",w="",x="transparent",y="round",z='") ',A="shorthand",B="qx.ui.decoration.MBorderImage",C="sliceTop",D="horizontal",E="_applyBorderImage",F="border-color",G='url("',H=" ",I="grid",J="repeatY";qx.Mixin.define(B,{properties:{borderImage:{check:u,nullable:true,apply:E},sliceTop:{check:j,nullable:true,init:null,apply:E},sliceRight:{check:j,nullable:true,init:null,apply:E},sliceBottom:{check:j,nullable:true,init:null,apply:E},sliceLeft:{check:j,nullable:true,init:null,apply:E},slice:{group:[C,q,h,o],mode:A},repeatX:{check:[f,c,y],init:f,apply:E},repeatY:{check:[f,c,y],init:f,apply:E},repeat:{group:[s,J],mode:A},fill:{check:d,init:true,apply:E},borderImageMode:{check:[D,v,I],init:I}},members:{_styleBorderImage:function(K){if(!this.getBorderImage()){return;};var M=qx.util.AliasManager.getInstance().resolve(this.getBorderImage());var O=qx.util.ResourceManager.getInstance().toUri(M);var R=this._getDefaultInsetsForBorderImage();var L=[R.top,R.right,R.bottom,R.left];var P=[this.getRepeatX(),this.getRepeatY()].join(H);var S=this.getFill()&&qx.core.Environment.get(b)?t:w;var N=qx.bom.Style.getPropertyName(l);if(N){var Q=qx.bom.Style.getCssName(N);K[Q]=G+O+z+L.join(H)+S+H+P;};K[n]=k;K[F]=x;K[a]=L.join(g)+r;},_getDefaultInsetsForBorderImage:function(){if(!this.getBorderImage()){return {top:0,right:0,bottom:0,left:0};};var T=qx.util.AliasManager.getInstance().resolve(this.getBorderImage());var U=this.__dD(T);return {top:this.getSliceTop()||U[0],right:this.getSliceRight()||U[1],bottom:this.getSliceBottom()||U[2],left:this.getSliceLeft()||U[3]};},_applyBorderImage:function(){{};},__dD:function(bc){var bb=this.getBorderImageMode();var bd=0;var Y=0;var ba=0;var be=0;var bf=/(.*)(\.[a-z]+)$/.exec(bc);var V=bf[1];var X=bf[2];var W=qx.util.ResourceManager.getInstance();if(bb==I||bb==v){bd=W.getImageHeight(V+i+X);ba=W.getImageHeight(V+p+X);};if(bb==I||bb==D){Y=W.getImageWidth(V+m+X);be=W.getImageWidth(V+e+X);};return [bd,Y,ba,be];}}});})();(function(){var a=" 0",b="),to(",c="px",d="css.borderradius",e="from(",f=")",g="background-image",h="background",i="filter",j="background-size",k="', ",l="0",m="_applyLinearBackgroundGradient",n="-webkit-gradient(linear,",o="startColorPosition",p="background-color",q="deg, ",r="url(",s="css.gradient.legacywebkit",t="EndColorStr='#FF",u="startColor",v="shorthand",w="Color",x="px 100%",y="StartColorStr='#FF",z="vertical",A="",B="transparent",C="qx.ui.decoration.MLinearBackgroundGradient",D="% 100%",E="endColorPosition",F="canvas",G="(",H="css.gradient.linear",I="';)",J="endColor",K=", ",L="css.gradient.filter",M="horizontal",N="Number",O="100% ",P='2d',Q="%",R=" ",S="white",T="linear-gradient",U='progid:DXImageTransform.Microsoft.Gradient(GradientType=',V=",";qx.Mixin.define(C,{properties:{startColor:{check:w,nullable:true,apply:m},endColor:{check:w,nullable:true,apply:m},orientation:{check:[M,z],init:z,apply:m},startColorPosition:{check:N,init:0,apply:m},endColorPosition:{check:N,init:100,apply:m},colorPositionUnit:{check:[c,Q],init:Q,apply:m},gradientStart:{group:[u,o],mode:v},gradientEnd:{group:[J,E],mode:v}},members:{__dE:null,_styleLinearBackgroundGradient:function(W){var bj=this.__dF();var bn=bj.start;var bh=bj.end;var bf;if(!bn||!bh){return;};var bq=this.getColorPositionUnit();if(qx.core.Environment.get(s)){bq=bq===c?A:bq;if(this.getOrientation()==M){var bm=this.getStartColorPosition()+bq+a+bq;var bk=this.getEndColorPosition()+bq+a+bq;}else {var bm=l+bq+R+this.getStartColorPosition()+bq;var bk=l+bq+R+this.getEndColorPosition()+bq;};var bb=e+bn+b+bh+f;bf=n+bm+V+bk+V+bb+f;W[h]=bf;}else if(qx.core.Environment.get(L)&&!qx.core.Environment.get(H)&&qx.core.Environment.get(d)){if(!this.__dE){this.__dE=document.createElement(F);};var X=this.getOrientation()==z;var bj=this.__dF();var bg=X?200:1;var ba=X?1:200;var be=Math.max(100,this.getEndColorPosition()-this.getStartColorPosition());if(bq===c){if(X){bg=Math.max(bg,this.getEndColorPosition()-this.getStartColorPosition());}else {ba=Math.max(ba,this.getEndColorPosition()-this.getStartColorPosition());};}else {if(X){bg=Math.max(bg,(this.getEndColorPosition()-this.getStartColorPosition())*2);}else {ba=Math.max(ba,(this.getEndColorPosition()-this.getStartColorPosition())*2);};};this.__dE.width=ba;this.__dE.height=bg;var bd=this.__dE.getContext(P);if(X){var bp=bd.createLinearGradient(0,0,0,bg);}else {var bp=bd.createLinearGradient(0,0,ba,0);};if(bq===Q){bp.addColorStop(Math.max(0,this.getStartColorPosition())/be,bj.start);bp.addColorStop(this.getEndColorPosition()/be,bj.end);}else {var bc=X?bg:ba;bp.addColorStop(Math.max(0,this.getStartColorPosition())/bc,bj.start);bp.addColorStop(this.getEndColorPosition()/bc,bj.end);};bd.fillStyle=bp;bd.fillRect(0,0,ba,bg);var bf=r+this.__dE.toDataURL()+f;W[g]=bf;if(bq===Q){if(X){W[j]=O+be+Q;}else {W[j]=be+D;};}else {W[j]=X?bg+x:O+ba+c;};}else if(qx.core.Environment.get(L)&&!qx.core.Environment.get(H)){var bj=this.__dF();var bo=this.getOrientation()==M?1:0;var bn=bj.start;var bh=bj.end;if(!qx.util.ColorUtil.isHex6String(bn)){bn=qx.util.ColorUtil.stringToRgb(bn);bn=qx.util.ColorUtil.rgbToHexString(bn);};if(!qx.util.ColorUtil.isHex6String(bh)){bh=qx.util.ColorUtil.stringToRgb(bh);bh=qx.util.ColorUtil.rgbToHexString(bh);};bn=bn.substring(1,bn.length);bh=bh.substring(1,bh.length);bf=U+bo+K+y+bn+k+t+bh+I;if(W[i]){W[i]+=K+bf;}else {W[i]=bf;};if(!W[p]||W[p]==B){W[p]=S;};}else {var br=this.getOrientation()==M?0:270;var bi=bn+R+this.getStartColorPosition()+bq;var Y=bh+R+this.getEndColorPosition()+bq;var bl=qx.core.Environment.get(H);if(bl===T){br=this.getOrientation()==M?br+90:br-90;};bf=bl+G+br+q+bi+V+Y+f;if(W[g]){W[g]+=K+bf;}else {W[g]=bf;};};},__dF:function(){{var bs=qx.theme.manager.Color.getInstance();var bu=bs.resolve(this.getStartColor());var bt=bs.resolve(this.getEndColor());};return {start:bu,end:bt};},_applyLinearBackgroundGradient:function(){{};}}});})();(function(){var a="_applyBoxShadow",b="shadowHorizontalLength",c="Boolean",d="",e="px ",f="css.boxshadow",g="shadowVerticalLength",h="inset ",i="shorthand",j="qx.ui.decoration.MBoxShadow",k="Integer",l="Color",m=",";qx.Mixin.define(j,{properties:{shadowHorizontalLength:{nullable:true,check:k,apply:a},shadowVerticalLength:{nullable:true,check:k,apply:a},shadowBlurRadius:{nullable:true,check:k,apply:a},shadowSpreadRadius:{nullable:true,check:k,apply:a},shadowColor:{nullable:true,check:l,apply:a},inset:{init:false,check:c,apply:a},shadowLength:{group:[b,g],mode:i}},members:{_styleBoxShadow:function(n){var v=qx.core.Environment.get(f);if(!v||this.getShadowVerticalLength()==null&&this.getShadowHorizontalLength()==null){return;};{var r=qx.theme.manager.Color.getInstance();var o=r.resolve(this.getShadowColor());};if(o!=null){var u=this.getShadowVerticalLength()||0;var p=this.getShadowHorizontalLength()||0;var blur=this.getShadowBlurRadius()||0;var t=this.getShadowSpreadRadius()||0;var s=this.getInset()?h:d;var q=s+p+e+u+e+blur+e+t+e+o;v=qx.bom.Style.getCssName(v);if(!n[v]){n[v]=q;}else {n[v]+=m+q;};};},_applyBoxShadow:function(){{};}}});})();(function(){var a="qx.ui.decoration.Decorator",b="_style",c="_getDefaultInsetsFor",d="bottom",e="top",f="left",g="right";qx.Class.define(a,{extend:qx.ui.decoration.Abstract,implement:[qx.ui.decoration.IDecorator],include:[qx.ui.decoration.MBackgroundColor,qx.ui.decoration.MBorderRadius,qx.ui.decoration.MBoxShadow,qx.ui.decoration.MDoubleBorder,qx.ui.decoration.MLinearBackgroundGradient,qx.ui.decoration.MBorderImage],members:{__dG:false,getPadding:function(){var k=this.getInset();var h=this._getDefaultInsetsForBorderImage();var n=k.top-(h.top?h.top:this.getWidthTop());var m=k.right-(h.right?h.right:this.getWidthRight());var j=k.bottom-(h.bottom?h.bottom:this.getWidthBottom());var l=k.left-(h.left?h.left:this.getWidthLeft());return {top:k.top?n:this.getInnerWidthTop(),right:k.right?m:this.getInnerWidthRight(),bottom:k.bottom?j:this.getInnerWidthBottom(),left:k.left?l:this.getInnerWidthLeft()};},getStyles:function(r){if(r){return this._getStyles();};var q={};var p=this._getStyles();for(var o in p){q[qx.lang.String.camelCase(o)]=p[o];};return q;},_getStyles:function(){var s={};for(var name in this){if(name.indexOf(b)==0&&this[name] instanceof Function){this[name](s);};};this.__dG=true;return s;},_getDefaultInsets:function(){var w=[e,g,d,f];var u={};for(var name in this){if(name.indexOf(c)==0&&this[name] instanceof Function){var v=this[name]();for(var i=0;i<w.length;i++ ){var t=w[i];if(u[t]==undefined){u[t]=v[t];};if(v[t]>u[t]){u[t]=v[t];};};};};if(u[e]!=undefined){return u;};return {top:0,right:0,bottom:0,left:0};},_isInitialized:function(){return this.__dG;}}});})();(function(){var a="_applyTheme",b="qx.theme.manager.Font",c="_dynamic",d="Theme",e="changeTheme",f="singleton";qx.Class.define(b,{type:f,extend:qx.util.ValueManager,properties:{theme:{check:d,nullable:true,apply:a,event:e}},members:{resolveDynamic:function(h){var g=this._dynamic;return h instanceof qx.bom.Font?h:g[h];},resolve:function(l){var k=this._dynamic;var i=k[l];if(i){return i;};var j=this.getTheme();if(j!==null&&j.fonts[l]){var m=this.__dI(j.fonts[l]);return k[l]=(new m).set(j.fonts[l]);};return l;},isDynamic:function(q){var p=this._dynamic;if(q&&(q instanceof qx.bom.Font||p[q]!==undefined)){return true;};var o=this.getTheme();if(o!==null&&q&&o.fonts[q]){var n=this.__dI(o.fonts[q]);p[q]=(new n).set(o.fonts[q]);return true;};return false;},__dH:function(s,r){if(s[r].include){var t=s[s[r].include];s[r].include=null;delete s[r].include;s[r]=qx.lang.Object.mergeWith(s[r],t,false);this.__dH(s,r);};},_applyTheme:function(y){var u=this._dynamic;for(var x in u){if(u[x].themed){u[x].dispose();delete u[x];};};if(y){var v=y.fonts;for(var x in v){if(v[x].include&&v[v[x].include]){this.__dH(v,x);};var w=this.__dI(v[x]);u[x]=(new w).set(v[x]);u[x].themed=true;};};this._setDynamic(u);},__dI:function(z){if(z.sources){return qx.bom.webfonts.WebFont;};return qx.bom.Font;}},destruct:function(){this._disposeMap(c);}});})();(function(){var a="Boolean",b="px",c="_applyItalic",d="_applyBold",e="underline",f="_applyTextShadow",g="Integer",h="_applyFamily",j="_applyLineHeight",k='"',m="Array",n="line-through",o="overline",p="Color",q="String",r="",s="italic",t="normal",u="qx.bom.Font",v="bold",w="Number",x="_applyDecoration",y=" ",z="_applySize",A=",",B="_applyColor";qx.Class.define(u,{extend:qx.core.Object,construct:function(D,C){qx.core.Object.call(this);this.__dJ={fontFamily:r,fontSize:null,fontWeight:null,fontStyle:null,textDecoration:null,lineHeight:null,color:null,textShadow:null};if(D!==undefined){this.setSize(D);};if(C!==undefined){this.setFamily(C);};},statics:{fromString:function(H){var I=new qx.bom.Font();var F=H.split(/\s+/);var name=[];var G;for(var i=0;i<F.length;i++ ){switch(G=F[i]){case v:I.setBold(true);break;case s:I.setItalic(true);break;case e:I.setDecoration(e);break;default:var E=parseInt(G,10);if(E==G||qx.lang.String.contains(G,b)){I.setSize(E);}else {name.push(G);};break;};};if(name.length>0){I.setFamily(name);};return I;},fromConfig:function(K){var J=new qx.bom.Font;J.set(K);return J;},__dK:{fontFamily:r,fontSize:r,fontWeight:r,fontStyle:r,textDecoration:r,lineHeight:1.2,color:r,textShadow:r},getDefaultStyles:function(){return this.__dK;}},properties:{size:{check:g,nullable:true,apply:z},lineHeight:{check:w,nullable:true,apply:j},family:{check:m,nullable:true,apply:h},bold:{check:a,nullable:true,apply:d},italic:{check:a,nullable:true,apply:c},decoration:{check:[e,n,o],nullable:true,apply:x},color:{check:p,nullable:true,apply:B},textShadow:{nullable:true,check:q,apply:f}},members:{__dJ:null,_applySize:function(M,L){this.__dJ.fontSize=M===null?null:M+b;},_applyLineHeight:function(O,N){this.__dJ.lineHeight=O===null?null:O;},_applyFamily:function(P,Q){var R=r;for(var i=0,l=P.length;i<l;i++ ){if(P[i].indexOf(y)>0){R+=k+P[i]+k;}else {R+=P[i];};if(i!==l-1){R+=A;};};this.__dJ.fontFamily=R;},_applyBold:function(T,S){this.__dJ.fontWeight=T==null?null:T?v:t;},_applyItalic:function(V,U){this.__dJ.fontStyle=V==null?null:V?s:t;},_applyDecoration:function(X,W){this.__dJ.textDecoration=X==null?null:X;},_applyColor:function(ba,Y){this.__dJ.color=null;if(ba){this.__dJ.color=qx.theme.manager.Color.getInstance().resolve(ba);};},_applyTextShadow:function(bc,bb){this.__dJ.textShadow=bc==null?null:bc;},getStyles:function(){return this.__dJ;}}});})();(function(){var a="changeStatus",b="qx.bom.webfonts.WebFont",c="_applySources",d="",e="qx.event.type.Data";qx.Class.define(b,{extend:qx.bom.Font,events:{"changeStatus":e},properties:{sources:{nullable:true,apply:c}},members:{__dL:null,_applySources:function(h,k){var f=[];for(var i=0,l=h.length;i<l;i++ ){var g=this._quoteFontFamily(h[i].family);f.push(g);var j=h[i].source;qx.bom.webfonts.Manager.getInstance().require(g,j,this._onWebFontChangeStatus,this);};this.setFamily(f.concat(this.getFamily()));},_onWebFontChangeStatus:function(m){var n=m.getData();this.fireDataEvent(a,n);{};},_quoteFontFamily:function(o){return o.replace(/["']/g,d);}}});})();(function(){var a="m",b="os.name",c=")",d="os.version",e="qx.bom.webfonts.Manager",f="svg",g="chrome",h="browser.name",k="singleton",n=",\n",o="src: ",p="mobileSafari",q="'eot)",r="');",s="changeStatus",t="interval",u="#",v="firefox",w="!",y="eot",z="ios",A="'eot')",B="\.(",C="}\n",D="font-family: ",E="browser.documentmode",F="mobile safari",G="safari",H="@font-face.*?",I="",J="ttf",K=";\n",L="') format('svg')",M="') format('woff')",N="('embedded-opentype')",O="browser.version",P="opera",Q="engine.version",R="Couldn't create @font-face rule for WebFont ",S="mshtml",T="engine.name",U="url('",V="src: url('",W="('embedded-opentype)",X="\nfont-style: normal;\nfont-weight: normal;",Y="?#iefix') format('embedded-opentype')",bh="woff",bi="ie",bj=";",bf="@font-face {",bg="') format('truetype')";qx.Class.define(e,{extend:qx.core.Object,type:k,construct:function(){qx.core.Object.call(this);this.__dM=[];this.__dN={};this.__dO=[];this.__dP=this.getPreferredFormats();},statics:{FONT_FORMATS:[y,bh,J,f],VALIDATION_TIMEOUT:5000},members:{__dM:null,__dQ:null,__dN:null,__dP:null,__dO:null,__dR:null,require:function(bm,bn,bo,bq){var bl=[];for(var i=0,l=bn.length;i<l;i++ ){var bp=bn[i].split(u);var bk=qx.util.ResourceManager.getInstance().toUri(bp[0]);if(bp.length>1){bk=bk+u+bp[1];};bl.push(bk);};if(qx.core.Environment.get(T)==S&&(parseInt(qx.core.Environment.get(Q))<9||qx.core.Environment.get(E)<9)){if(!this.__dR){this.__dR=new qx.event.Timer(100);this.__dR.addListener(t,this.__dT,this);};if(!this.__dR.isEnabled()){this.__dR.start();};this.__dO.push([bm,bl,bo,bq]);}else {this.__dS(bm,bl,bo,bq);};},remove:function(bs){var br=null;for(var i=0,l=this.__dM.length;i<l;i++ ){if(this.__dM[i]==bs){br=i;this.__ea(bs);break;};};if(br){qx.lang.Array.removeAt(this.__dM,br);};if(bs in this.__dN){this.__dN[bs].dispose();delete this.__dN[bs];};},getPreferredFormats:function(){var bt=[];var bx=qx.core.Environment.get(h);var bu=qx.core.Environment.get(O);var bw=qx.core.Environment.get(b);var bv=qx.core.Environment.get(d);if((bx==bi&&qx.core.Environment.get(E)>=9)||(bx==v&&bu>=3.6)||(bx==g&&bu>=6)){bt.push(bh);};if((bx==P&&bu>=10)||(bx==G&&bu>=3.1)||(bx==v&&bu>=3.5)||(bx==g&&bu>=4)||(bx==F&&bw==z&&bv>=4.2)){bt.push(J);};if(bx==bi&&bu>=4){bt.push(y);};if(bx==p&&bw==z&&bv>=4.1){bt.push(f);};return bt;},removeStyleSheet:function(){this.__dM=[];if(this.__dQ){qx.bom.Stylesheet.removeSheet(this.__dQ);};this.__dQ=null;},__dS:function(bA,bC,bz,bD){if(!qx.lang.Array.contains(this.__dM,bA)){var bE=this.__dV(bC);var bB=this.__dW(bA,bE);if(!bB){throw new Error(R+bA+w);};if(!this.__dQ){this.__dQ=qx.bom.Stylesheet.createElement();};try{this.__dY(bB);}catch(bF){{};};this.__dM.push(bA);};if(!this.__dN[bA]){this.__dN[bA]=new qx.bom.webfonts.Validator(bA);this.__dN[bA].setTimeout(qx.bom.webfonts.Manager.VALIDATION_TIMEOUT);this.__dN[bA].addListenerOnce(s,this.__dU,this);};if(bz){var by=bD||window;this.__dN[bA].addListenerOnce(s,bz,by);};this.__dN[bA].validate();},__dT:function(){if(this.__dO.length==0){this.__dR.stop();return;};var bG=this.__dO.shift();this.__dS.apply(this,bG);},__dU:function(bH){var bI=bH.getData();if(bI.valid===false){qx.event.Timer.once(function(){this.remove(bI.family);},this,250);};},__dV:function(bJ){var bL=qx.bom.webfonts.Manager.FONT_FORMATS;var bK={};for(var i=0,l=bJ.length;i<l;i++ ){var bM=null;for(var x=0;x<bL.length;x++ ){var bN=new RegExp(B+bL[x]+c);var bO=bN.exec(bJ[i]);if(bO){bM=bO[1];};};if(bM){bK[bM]=bJ[i];};};return bK;},__dW:function(bR,bU){var bT=[];var bP=this.__dP.length>0?this.__dP:qx.bom.webfonts.Manager.FONT_FORMATS;for(var i=0,l=bP.length;i<l;i++ ){var bQ=bP[i];if(bU[bQ]){bT.push(this.__dX(bQ,bU[bQ]));};};var bS=o+bT.join(n)+bj;bS=D+bR+K+bS;bS=bS+X;return bS;},__dX:function(bW,bV){switch(bW){case y:return U+bV+r+V+bV+Y;case bh:return U+bV+M;case J:return U+bV+bg;case f:return U+bV+L;default:return null;};},__dY:function(bY){var bX=bf+bY+C;if(qx.core.Environment.get(h)==bi&&qx.core.Environment.get(E)<9){var ca=this.__eb(this.__dQ.cssText);ca+=bX;this.__dQ.cssText=ca;}else {this.__dQ.insertRule(bX,this.__dQ.cssRules.length);};},__ea:function(cb){var ce=new RegExp(H+cb,a);for(var i=0,l=document.styleSheets.length;i<l;i++ ){var cc=document.styleSheets[i];if(cc.cssText){var cd=cc.cssText.replace(/\n/g,I).replace(/\r/g,I);cd=this.__eb(cd);if(ce.exec(cd)){cd=cd.replace(ce,I);};cc.cssText=cd;}else if(cc.cssRules){for(var j=0,m=cc.cssRules.length;j<m;j++ ){var cd=cc.cssRules[j].cssText.replace(/\n/g,I).replace(/\r/g,I);if(ce.exec(cd)){this.__dQ.deleteRule(j);return;};};};};},__eb:function(cf){return cf.replace(q,A).replace(W,N);}},destruct:function(){if(this.__dR){this.__dR.stop();this.__dR.dispose();};delete this.__dM;this.removeStyleSheet();for(var cg in this.__dN){this.__dN[cg].dispose();};qx.bom.webfonts.Validator.removeDefaultHelperElements();}});})();(function(){var a="qx.event.Timer",b="_applyInterval",c="_applyEnabled",d="Boolean",f="interval",g="qx.event.type.Event",h="Integer";qx.Class.define(a,{extend:qx.core.Object,construct:function(i){qx.core.Object.call(this);this.setEnabled(false);if(i!=null){this.setInterval(i);};var self=this;this.__ec=function(){self._oninterval.call(self);};},events:{"interval":g},statics:{once:function(j,k,l){{};var m=new qx.event.Timer(l);m.__ed=j;m.addListener(f,function(e){m.stop();j.call(k,e);m.dispose();k=null;},k);m.start();return m;}},properties:{enabled:{init:true,check:d,apply:c},interval:{check:h,init:1000,apply:b}},members:{__ee:null,__ec:null,_applyInterval:function(o,n){if(this.getEnabled()){this.restart();};},_applyEnabled:function(q,p){if(p){window.clearInterval(this.__ee);this.__ee=null;}else if(q){this.__ee=window.setInterval(this.__ec,this.getInterval());};},start:function(){this.setEnabled(true);},startWith:function(r){this.setInterval(r);this.start();},stop:function(){this.setEnabled(false);},restart:function(){this.stop();this.start();},restartWith:function(s){this.stop();this.startWith(s);},_oninterval:qx.event.GlobalError.observeMethod(function(){if(this.$$disposed){return;};if(this.getEnabled()){this.fireEvent(f);};})},destruct:function(){if(this.__ee){window.clearInterval(this.__ee);};this.__ee=this.__ec=null;}});})();(function(){var a="sans-serif",b="changeStatus",c="Integer",d="auto",e="qx.event.type.Data",f="0",g="qx.bom.webfonts.Validator",h="interval",i="Georgia",j="WEei",k="visible",l="Times New Roman",m="Arial",n="normal",o="Helvetica",p="__ei",q="350px",r="_applyFontFamily",s="-1000px",t="hidden",u="serif",v="span",w="absolute",x=",";qx.Class.define(g,{extend:qx.core.Object,construct:function(y){qx.core.Object.call(this);if(y){this.setFontFamily(y);this.__ef=this._getRequestedHelpers();};},statics:{COMPARISON_FONTS:{sans:[m,o,a],serif:[l,i,u]},HELPER_CSS:{position:w,margin:f,padding:f,top:s,left:s,fontSize:q,width:d,height:d,lineHeight:n,fontVariant:n,visibility:t},COMPARISON_STRING:j,__eg:null,__eh:null,removeDefaultHelperElements:function(){var z=qx.bom.webfonts.Validator.__eh;if(z){for(var A in z){document.body.removeChild(z[A]);};};delete qx.bom.webfonts.Validator.__eh;}},properties:{fontFamily:{nullable:true,init:null,apply:r},timeout:{check:c,init:5000}},events:{"changeStatus":e},members:{__ef:null,__ei:null,__ej:null,validate:function(){this.__ej=new Date().getTime();if(this.__ei){this.__ei.restart();}else {this.__ei=new qx.event.Timer(100);this.__ei.addListener(h,this.__el,this);qx.event.Timer.once(function(){this.__ei.start();},this,0);};},_reset:function(){if(this.__ef){for(var C in this.__ef){var B=this.__ef[C];document.body.removeChild(B);};this.__ef=null;};},_isFontValid:function(){if(!qx.bom.webfonts.Validator.__eg){this.__ek();};if(!this.__ef){this.__ef=this._getRequestedHelpers();};this.__ef.sans.style.visibility=k;this.__ef.sans.style.visibility=t;this.__ef.serif.style.visibility=k;this.__ef.serif.style.visibility=t;var E=qx.bom.element.Dimension.getWidth(this.__ef.sans);var D=qx.bom.element.Dimension.getWidth(this.__ef.serif);var F=qx.bom.webfonts.Validator;if(E!==F.__eg.sans||D!==F.__eg.serif){return true;};return false;},_getRequestedHelpers:function(){var G=[this.getFontFamily()].concat(qx.bom.webfonts.Validator.COMPARISON_FONTS.sans);var H=[this.getFontFamily()].concat(qx.bom.webfonts.Validator.COMPARISON_FONTS.serif);return {sans:this._getHelperElement(G),serif:this._getHelperElement(H)};},_getHelperElement:function(I){var J=qx.lang.Object.clone(qx.bom.webfonts.Validator.HELPER_CSS);if(I){if(J.fontFamily){J.fontFamily+=x+I.join(x);}else {J.fontFamily=I.join(x);};};var K=document.createElement(v);K.innerHTML=qx.bom.webfonts.Validator.COMPARISON_STRING;qx.bom.element.Style.setStyles(K,J);document.body.appendChild(K);return K;},_applyFontFamily:function(M,L){if(M!==L){this._reset();};},__ek:function(){var N=qx.bom.webfonts.Validator;if(!N.__eh){N.__eh={sans:this._getHelperElement(N.COMPARISON_FONTS.sans),serif:this._getHelperElement(N.COMPARISON_FONTS.serif)};};N.__eg={sans:qx.bom.element.Dimension.getWidth(N.__eh.sans),serif:qx.bom.element.Dimension.getWidth(N.__eh.serif)};},__el:function(){if(this._isFontValid()){this.__ei.stop();this._reset();this.fireDataEvent(b,{family:this.getFontFamily(),valid:true});}else {var O=new Date().getTime();if(O-this.__ej>=this.getTimeout()){this.__ei.stop();this._reset();this.fireDataEvent(b,{family:this.getFontFamily(),valid:false});};};}},destruct:function(){this._reset();this.__ei.stop();this.__ei.removeListener(h,this.__el,this);this._disposeObjects(p);}});})();(function(){var a="mshtml",b="engine.name",c="qx.bom.element.Dimension",d="0px",e="paddingRight",f="paddingLeft",g="opera",h="paddingBottom",i="paddingTop",j="overflowX",k="overflowY";qx.Bootstrap.define(c,{statics:{getWidth:function(m){var l=m.getBoundingClientRect();return Math.round(l.right-l.left);},getHeight:function(o){var n=o.getBoundingClientRect();return Math.round(n.bottom-n.top);},getSize:function(p){return {width:this.getWidth(p),height:this.getHeight(p)};},__em:{visible:true,hidden:true},getContentWidth:function(t){var q=qx.bom.element.Style;var r=qx.bom.element.Style.get(t,j);var s=parseInt(q.get(t,f)||d,10);var w=parseInt(q.get(t,e)||d,10);if(this.__em[r]){var v=t.clientWidth;if((qx.core.Environment.get(b)==g)||qx.dom.Node.isBlockNode(t)){v=v-s-w;};if(qx.core.Environment.get(b)==a){if(v===0&&t.offsetHeight===0){return t.offsetWidth;};};return v;}else {if(t.clientWidth>=t.scrollWidth){return Math.max(t.clientWidth,t.scrollWidth)-s-w;}else {var u=t.scrollWidth-s;if(qx.core.Environment.get(b)==a){u-=w;};return u;};};},getContentHeight:function(B){var x=qx.bom.element.Style;var A=qx.bom.element.Style.get(B,k);var z=parseInt(x.get(B,i)||d,10);var y=parseInt(x.get(B,h)||d,10);if(this.__em[A]){return B.clientHeight-z-y;}else {if(B.clientHeight>=B.scrollHeight){return Math.max(B.clientHeight,B.scrollHeight)-z-y;}else {return B.scrollHeight-z;};};},getContentSize:function(C){return {width:this.getContentWidth(C),height:this.getContentHeight(C)};}}});})();(function(){var a="engine.name",b=");",c="",d=")",e="zoom:1;filter:alpha(opacity=",f="qx.bom.element.Opacity",g="css.opacity",h=";",i="opacity:",j="alpha(opacity=",k="opacity",l="filter";qx.Bootstrap.define(f,{statics:{compile:qx.core.Environment.select(a,{"mshtml":function(m){if(m>=1){m=1;};if(m<0.00001){m=0;};if(qx.core.Environment.get(g)){return i+m+h;}else {return e+(m*100)+b;};},"default":function(n){return i+n+h;}}),set:qx.core.Environment.select(a,{"mshtml":function(q,o){if(qx.core.Environment.get(g)){q.style.opacity=o;}else {var p=qx.bom.element.Style.get(q,l,qx.bom.element.Style.COMPUTED_MODE,false);if(o>=1){o=1;};if(o<0.00001){o=0;};if(!q.currentStyle||!q.currentStyle.hasLayout){q.style.zoom=1;};q.style.filter=p.replace(/alpha\([^\)]*\)/gi,c)+j+o*100+d;};},"default":function(s,r){s.style.opacity=r;}}),reset:qx.core.Environment.select(a,{"mshtml":function(u){if(qx.core.Environment.get(g)){u.style.opacity=c;}else {var t=qx.bom.element.Style.get(u,l,qx.bom.element.Style.COMPUTED_MODE,false);u.style.filter=t.replace(/alpha\([^\)]*\)/gi,c);};},"default":function(v){v.style.opacity=c;}}),get:qx.core.Environment.select(a,{"mshtml":function(z,y){if(qx.core.Environment.get(g)){var w=qx.bom.element.Style.get(z,k,y,false);if(w!=null){return parseFloat(w);};return 1.0;}else {var x=qx.bom.element.Style.get(z,l,y,false);if(x){var w=x.match(/alpha\(opacity=(.*)\)/);if(w&&w[1]){return parseFloat(w[1])/100;};};return 1.0;};},"default":function(C,B){var A=qx.bom.element.Style.get(C,k,B,false);if(A!=null){return parseFloat(A);};return 1.0;}})}});})();(function(){var a="cursor:",b="engine.name",c="",d="mshtml",e="nw-resize",f="engine.version",g="nesw-resize",h="browser.documentmode",i=";",j="nwse-resize",k="qx.bom.element.Cursor",l="ne-resize",m="browser.quirksmode",n="cursor";qx.Bootstrap.define(k,{statics:{__ep:{},compile:function(o){return a+(this.__ep[o]||o)+i;},get:function(q,p){return qx.bom.element.Style.get(q,n,p,false);},set:function(s,r){s.style.cursor=this.__ep[r]||r;},reset:function(t){t.style.cursor=c;}},defer:function(u){if(qx.core.Environment.get(b)==d&&((parseFloat(qx.core.Environment.get(f))<9||qx.core.Environment.get(h)<9)&&!qx.core.Environment.get(m))){u.__ep[g]=l;u.__ep[j]=e;};}});})();(function(){var a="border-box",b="qx.bom.element.BoxSizing",c="css.boxsizing",d="",e="boxSizing",f="content-box",g=":",h=";";qx.Bootstrap.define(b,{statics:{__en:{tags:{button:true,select:true},types:{search:true,button:true,submit:true,reset:true,checkbox:true,radio:true}},__eo:function(j){var i=this.__en;return i.tags[j.tagName.toLowerCase()]||i.types[j.type];},compile:function(k){if(qx.core.Environment.get(c)){var l=qx.bom.Style.getCssName(qx.core.Environment.get(c));return l+g+k+h;}else {{};};},get:function(m){if(qx.core.Environment.get(c)){return qx.bom.element.Style.get(m,e,null,false)||d;};if(qx.bom.Document.isStandardMode(qx.dom.Node.getWindow(m))){if(!this.__eo(m)){return f;};};return a;},set:function(o,n){if(qx.core.Environment.get(c)){try{o.style[qx.core.Environment.get(c)]=n;}catch(p){{};};}else {{};};},reset:function(q){this.set(q,d);}}});})();(function(){var a="clip:auto;",b="rect(",c=")",d=");",e="",f="px",g="Could not parse clip string: ",h="qx.bom.element.Clip",i="string",j="clip:rect(",k=" ",l="clip",m="rect(auto,auto,auto,auto)",n="rect(auto, auto, auto, auto)",o="auto",p=",";qx.Bootstrap.define(h,{statics:{compile:function(q){if(!q){return a;};var v=q.left;var top=q.top;var u=q.width;var t=q.height;var r,s;if(v==null){r=(u==null?o:u+f);v=o;}else {r=(u==null?o:v+u+f);v=v+f;};if(top==null){s=(t==null?o:t+f);top=o;}else {s=(t==null?o:top+t+f);top=top+f;};return j+top+p+r+p+s+p+v+d;},get:function(z,D){var x=qx.bom.element.Style.get(z,l,D,false);var C,top,A,E;var w,y;if(typeof x===i&&x!==o&&x!==e){x=x.trim();if(/\((.*)\)/.test(x)){var F=RegExp.$1;if(/,/.test(F)){var B=F.split(p);}else {var B=F.split(k);};top=B[0].trim();w=B[1].trim();y=B[2].trim();C=B[3].trim();if(C===o){C=null;};if(top===o){top=null;};if(w===o){w=null;};if(y===o){y=null;};if(top!=null){top=parseInt(top,10);};if(w!=null){w=parseInt(w,10);};if(y!=null){y=parseInt(y,10);};if(C!=null){C=parseInt(C,10);};if(w!=null&&C!=null){A=w-C;}else if(w!=null){A=w;};if(y!=null&&top!=null){E=y-top;}else if(y!=null){E=y;};}else {throw new Error(g+x);};};return {left:C||null,top:top||null,width:A||null,height:E||null};},set:function(L,G){if(!G){L.style.clip=m;return;};var M=G.left;var top=G.top;var K=G.width;var J=G.height;var H,I;if(M==null){H=(K==null?o:K+f);M=o;}else {H=(K==null?o:M+K+f);M=M+f;};if(top==null){I=(J==null?o:J+f);top=o;}else {I=(J==null?o:top+J+f);top=top+f;};L.style.clip=b+top+p+H+p+I+p+M+c;},reset:function(N){N.style.clip=n;}}});})();(function(){var a="css.float",b='cssFloat',c="px",d="Cascaded styles are not supported in this browser!",e="css.appearance",f="pixelRight",g="css.userselect",h="css.boxsizing",i="css.textoverflow",j="pixelHeight",k=":",l="pixelTop",m="css.borderimage",n="pixelLeft",o="css.usermodify",p="qx.bom.element.Style",q="",r="pixelBottom",s="pixelWidth",t='float',u=";",v="\"\"",w="style";qx.Bootstrap.define(p,{statics:{__eq:null,__er:null,__es:function(){var y={"appearance":qx.core.Environment.get(e),"userSelect":qx.core.Environment.get(g),"textOverflow":qx.core.Environment.get(i),"borderImage":qx.core.Environment.get(m),"float":qx.core.Environment.get(a),"userModify":qx.core.Environment.get(o),"boxSizing":qx.core.Environment.get(h)};this.__er={};for(var x in qx.lang.Object.clone(y)){if(!y[x]){delete y[x];}else {if(x===t){this.__er[b]=x;}else {this.__er[x]=qx.bom.Style.getCssName(y[x]);};};};this.__eq=y;},__et:function(name){var z=qx.bom.Style.getPropertyName(name);if(z){this.__eq[name]=z;};return z;},__eu:{width:s,height:j,left:n,right:f,top:l,bottom:r},__ev:{clip:qx.bom.element.Clip,cursor:qx.bom.element.Cursor,opacity:qx.bom.element.Opacity,boxSizing:qx.bom.element.BoxSizing},compile:function(A){var D=[];var E=this.__ev;var C=this.__er;var name,B;for(name in A){B=A[name];if(B==null){continue;};name=this.__er[name]||name;if(E[name]){D.push(E[name].compile(B));}else {if(!C[name]){C[name]=qx.bom.Style.getCssName(name);};D.push(C[name],k,B===q?v:B,u);};};return D.join(q);},setCss:function(G,F){G.setAttribute(w,F);},getCss:function(H){return H.getAttribute(w);},isPropertySupported:function(I){return (this.__ev[I]||this.__eq[I]||I in document.documentElement.style);},COMPUTED_MODE:1,CASCADED_MODE:2,LOCAL_MODE:3,set:function(L,name,J,K){{};name=this.__eq[name]||this.__et(name)||name;if(K!==false&&this.__ev[name]){this.__ev[name].set(L,J);}else {L.style[name]=J!==null?J:q;};},setStyles:function(S,M,T){{};var P=this.__eq;var Q=this.__ev;var N=S.style;for(var R in M){var O=M[R];var name=P[R]||this.__et(R)||R;if(O===undefined){if(T!==false&&Q[name]){Q[name].reset(S);}else {N[name]=q;};}else {if(T!==false&&Q[name]){Q[name].set(S,O);}else {N[name]=O!==null?O:q;};};};},reset:function(V,name,U){name=this.__eq[name]||this.__et(name)||name;if(U!==false&&this.__ev[name]){this.__ev[name].reset(V);}else {V.style[name]=q;};},get:function(ba,name,bc,be){name=this.__eq[name]||this.__et(name)||name;if(be!==false&&this.__ev[name]){return this.__ev[name].get(ba,bc);};switch(bc){case this.LOCAL_MODE:return ba.style[name]||q;case this.CASCADED_MODE:if(ba.currentStyle){return ba.currentStyle[name]||q;};throw new Error(d);default:var X=qx.dom.Node.getDocument(ba);var bb=X.defaultView?X.defaultView.getComputedStyle:undefined;if(bb!==undefined){var W=bb(ba,null);if(W&&W[name]){return W[name];};}else {if(!ba.currentStyle){return ba.style[name]||q;};var bg=ba.currentStyle[name]||ba.style[name]||q;if(/^-?[\.\d]+(px)?$/i.test(bg)){return bg;};var bf=this.__eu[name];if(bf&&(bf in ba.style)){var bd=ba.style[name];ba.style[name]=bg||0;var Y=ba.style[bf]+c;ba.style[name]=bd;return Y;};return bg;};return ba.style[name]||q;};}},defer:function(bh){bh.__es();}});})();(function(){var a="engine.name",b="CSS1Compat",c="position:absolute;width:0;height:0;width:1",d="engine.version",e="qx.bom.Document",f="1px",g="div";qx.Bootstrap.define(e,{statics:{isQuirksMode:qx.core.Environment.select(a,{"mshtml":function(h){if(qx.core.Environment.get(d)>=8){return (h||window).document.documentMode===5;}else {return (h||window).document.compatMode!==b;};},"webkit":function(i){if(document.compatMode===undefined){var j=(i||window).document.createElement(g);j.style.cssText=c;return j.style.width===f?true:false;}else {return (i||window).document.compatMode!==b;};},"default":function(k){return (k||window).document.compatMode!==b;}}),isStandardMode:function(l){return !this.isQuirksMode(l);},getWidth:function(m){var o=(m||window).document;var n=qx.bom.Viewport.getWidth(m);var scroll=this.isStandardMode(m)?o.documentElement.scrollWidth:o.body.scrollWidth;return Math.max(scroll,n);},getHeight:function(p){var r=(p||window).document;var q=qx.bom.Viewport.getHeight(p);var scroll=this.isStandardMode(p)?r.documentElement.scrollHeight:r.body.scrollHeight;return Math.max(scroll,q);}}});})();(function(){var a="ios",b="os.name",c="undefined",d="qx.bom.Viewport";qx.Bootstrap.define(d,{statics:{getWidth:function(e){var e=e||window;var f=e.document;return qx.bom.Document.isStandardMode(e)?f.documentElement.clientWidth:f.body.clientWidth;},getHeight:function(g){var g=g||window;var h=g.document;if(qx.core.Environment.get(b)==a&&window.innerHeight!=h.documentElement.clientHeight){return window.innerHeight;};return qx.bom.Document.isStandardMode(g)?h.documentElement.clientHeight:h.body.clientHeight;},getScrollLeft:function(i){var i=i?i:window;if(typeof i.pageXOffset!==c){return i.pageXOffset;};var j=i.document;return j.documentElement.scrollLeft||j.body.scrollLeft;},getScrollTop:function(k){var k=k?k:window;if(typeof k.pageYOffset!==c){return k.pageYOffset;};var l=k.document;return l.documentElement.scrollTop||l.body.scrollTop;},__ew:function(m){var o=this.getWidth(m)>this.getHeight(m)?90:0;var n=m.orientation;if(n==null||Math.abs(n%180)==o){return {"-270":90,"-180":180,"-90":-90,"0":0,"90":90,"180":180,"270":-90};}else {return {"-270":180,"-180":-90,"-90":0,"0":90,"90":180,"180":-90,"270":0};};},__ex:null,getOrientation:function(p){var p=p||window.top;var q=p.orientation;if(q==null){q=this.getWidth(p)>this.getHeight(p)?90:0;}else {if(this.__ex==null){this.__ex=this.__ew(p);};q=this.__ex[q];};return q;},isLandscape:function(r){var s=this.getOrientation(r);return s===-90||s===90;},isPortrait:function(t){var u=this.getOrientation(t);return u===0||u===180;}}});})();(function(){var a="qx.theme.manager.Icon",b="Theme",c="changeTheme",d="_applyTheme",e="singleton";qx.Class.define(a,{type:e,extend:qx.core.Object,properties:{theme:{check:b,nullable:true,apply:d,event:c}},members:{_applyTheme:function(i,g){var h=qx.util.AliasManager.getInstance();if(g){for(var f in g.aliases){h.remove(f);};};if(i){for(var f in i.aliases){h.add(f,i.aliases[f]);};};}}});})();(function(){var a="Missing appearance: ",b="_applyTheme",c="string",d="qx.theme.manager.Appearance",e=":",f="Theme",g="changeTheme",h="/",j="singleton";qx.Class.define(d,{type:j,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__ey={};this.__ez={};},properties:{theme:{check:f,nullable:true,event:g,apply:b}},members:{__eA:{},__ey:null,__ez:null,_applyTheme:function(){this.__ez={};this.__ey={};},__eB:function(y,u,l,p){var r=u.appearances;var m=r[y];if(!m){var x=h;var n=[];var q=y.split(x);var w=qx.lang.Array.clone(q);var t;while(!m&&q.length>0){n.unshift(q.pop());var o=q.join(x);m=r[o];if(m){t=m.alias||m;if(typeof t===c){var v=t+x+n.join(x);return this.__eB(v,u,l,w);};};};for(var i=0;i<n.length-1;i++ ){n.shift();var s=n.join(x);var k=this.__eB(s,u,null,w);if(k){return k;};};if(l!=null){return this.__eB(l,u,null,w);};{};return null;}else if(typeof m===c){return this.__eB(m,u,l,w);}else if(m.include&&!m.style){return this.__eB(m.include,u,l,w);};return y;},styleFrom:function(R,J,K,A){if(!K){K=this.getTheme();};var H=this.__ez;var z=H[R];if(!z){z=H[R]=this.__eB(R,K,A);};var O=K.appearances[z];if(!O){this.warn(a+R);return null;};if(!O.style){return null;};var P=z;if(J){var D=O.$$bits;if(!D){D=O.$$bits={};O.$$length=0;};var E=0;for(var G in J){if(!J[G]){continue;};if(D[G]==null){D[G]=1<<O.$$length++ ;};E+=D[G];};if(E>0){P+=e+E;};};var F=this.__ey;if(F[P]!==undefined){return F[P];};if(!J){J=this.__eA;};var M;if(O.include||O.base){var Q;if(O.include){Q=this.styleFrom(O.include,J,K,A);};var I=O.style(J,Q);M={};if(O.base){var N=this.styleFrom(z,J,O.base,A);if(O.include){for(var C in N){if(!Q.hasOwnProperty(C)&&!I.hasOwnProperty(C)){M[C]=N[C];};};}else {for(var L in N){if(!I.hasOwnProperty(L)){M[L]=N[L];};};};};if(O.include){for(var B in Q){if(!I.hasOwnProperty(B)){M[B]=Q[B];};};};for(var S in I){M[S]=I[S];};}else {M=O.style(J);};return F[P]=M||null;}},destruct:function(){this.__ey=this.__ez=null;}});})();(function(){var b="'!",c="other",d="widgets",e="undefined",f="fonts",g="appearances",h="qx.Theme",j="]",k="Mixin theme is not a valid theme!",m="[Theme ",n="colors",o="decorations",p="' are not compatible '",q="Theme",r="meta",s="The mixins '",t="borders",u="icons";qx.Bootstrap.define(h,{statics:{define:function(name,w){if(!w){var w={};};w.include=this.__eC(w.include);w.patch=this.__eC(w.patch);{};var v={$$type:q,name:name,title:w.title,toString:this.genericToString};if(w.extend){v.supertheme=w.extend;};v.basename=qx.Bootstrap.createNamespace(name,v);this.__eF(v,w);this.__eD(v,w);this.$$registry[name]=v;for(var i=0,a=w.include,l=a.length;i<l;i++ ){this.include(v,a[i]);};for(var i=0,a=w.patch,l=a.length;i<l;i++ ){this.patch(v,a[i]);};},__eC:function(x){if(!x){return [];};if(qx.Bootstrap.isArray(x)){return x;}else {return [x];};},__eD:function(y,z){var A=z.aliases||{};if(z.extend&&z.extend.aliases){qx.Bootstrap.objectMergeWith(A,z.extend.aliases,false);};y.aliases=A;},getAll:function(){return this.$$registry;},getByName:function(name){return this.$$registry[name];},isDefined:function(name){return this.getByName(name)!==undefined;},getTotalNumber:function(){return qx.Bootstrap.objectGetLength(this.$$registry);},genericToString:function(){return m+this.name+j;},__eE:function(C){for(var i=0,B=this.__eG,l=B.length;i<l;i++ ){if(C[B[i]]){return B[i];};};},__eF:function(H,I){var E=this.__eE(I);if(I.extend&&!E){E=I.extend.type;};H.type=E||c;var F=function(){};if(I.extend){F.prototype=new I.extend.$$clazz;};var D=F.prototype;var G=I[E];for(var J in G){D[J]=G[J];if(D[J].base){{};D[J].base=I.extend;};};H.$$clazz=F;H[E]=new F;},$$registry:{},__eG:[n,t,o,f,u,d,g,r],__h:null,__eH:null,__i:function(){},patch:function(N,L){this.__eI(L);var P=this.__eE(L);if(P!==this.__eE(N)){throw new Error(s+N.name+p+L.name+b);};var M=L[P];var K=N.$$clazz.prototype;for(var O in M){K[O]=M[O];};},include:function(T,R){this.__eI(R);var V=R.type;if(V!==T.type){throw new Error(s+T.name+p+R.name+b);};var S=R[V];var Q=T.$$clazz.prototype;for(var U in S){if(Q[U]!==undefined){continue;};Q[U]=S[U];};},__eI:function(W){if(typeof W===e||W==null){var X=new Error(k);{var Y;};throw X;};}}});})();(function(){var a="qx.ui.tooltip.ToolTip",b="Boolean",c="",d="__eJ",f="mouse",g="pointerover",h="interval",i="__eK",j="_applyCurrent",k="widget",l="qx.ui.tooltip.Manager",m="__eM",n="pointermove",o="focusout",p="tooltip-error",q="singleton",r="pointerout";qx.Class.define(l,{type:q,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);qx.event.Registration.addListener(document.body,g,this.__eR,this,true);this.__eJ=new qx.event.Timer();this.__eJ.addListener(h,this.__eO,this);this.__eK=new qx.event.Timer();this.__eK.addListener(h,this.__eP,this);this.__eL={left:0,top:0};},properties:{current:{check:a,nullable:true,apply:j},showInvalidToolTips:{check:b,init:true},showToolTips:{check:b,init:true}},members:{__eL:null,__eK:null,__eJ:null,__eM:null,__eN:null,getSharedTooltip:function(){if(!this.__eM){this.__eM=new qx.ui.tooltip.ToolTip().set({rich:true});};return this.__eM;},getSharedErrorTooltip:function(){if(!this.__eN){this.__eN=new qx.ui.tooltip.ToolTip().set({appearance:p,rich:true});this.__eN.setLabel(c);this.__eN.syncAppearance();};return this.__eN;},_applyCurrent:function(u,t){if(t&&qx.ui.core.Widget.contains(t,u)){return;};if(t){if(!t.isDisposed()){t.exclude();};this.__eJ.stop();this.__eK.stop();};var v=qx.event.Registration;var s=document.body;if(u){this.__eJ.startWith(u.getShowTimeout());v.addListener(s,r,this.__eS,this,true);v.addListener(s,o,this.__eT,this,true);v.addListener(s,n,this.__eQ,this,true);}else {v.removeListener(s,r,this.__eS,this,true);v.removeListener(s,o,this.__eT,this,true);v.removeListener(s,n,this.__eQ,this,true);};},__eO:function(e){var w=this.getCurrent();if(w&&!w.isDisposed()){this.__eK.startWith(w.getHideTimeout());if(w.getPlaceMethod()==k){w.placeToWidget(w.getOpener());}else {w.placeToPoint(this.__eL);};w.show();};this.__eJ.stop();},__eP:function(e){var x=this.getCurrent();if(x&&!x.isDisposed()){x.exclude();};this.__eK.stop();this.resetCurrent();},__eQ:function(e){var y=this.__eL;y.left=Math.round(e.getDocumentLeft());y.top=Math.round(e.getDocumentTop());},__eR:function(e){var z=qx.ui.core.Widget.getWidgetByElement(e.getTarget());this.__eQ(e);this.showToolTip(z);},showToolTip:function(C){if(!C){return;};var D,B,E,A;while(C!=null){D=C.getToolTip();B=C.getToolTipText()||null;E=C.getToolTipIcon()||null;if(qx.Class.hasInterface(C.constructor,qx.ui.form.IForm)&&!C.isValid()){A=C.getInvalidMessage();};if(D||B||E||A){break;};C=C.getLayoutParent();};if(!C||(!C.getEnabled()&&!C.isShowToolTipWhenDisabled())||C.isBlockToolTip()||(!A&&!this.getShowToolTips())||(A&&!this.getShowInvalidToolTips())){return;};if(A){D=this.getSharedErrorTooltip().set({label:A});};if(!D){D=this.getSharedTooltip().set({label:B,icon:E});};this.setCurrent(D);D.setOpener(C);},__eS:function(e){var F=qx.ui.core.Widget.getWidgetByElement(e.getTarget());if(!F){return;};var G=qx.ui.core.Widget.getWidgetByElement(e.getRelatedTarget());if(!G&&e.getPointerType()==f){return;};var H=this.getCurrent();if(H&&(G==H||qx.ui.core.Widget.contains(H,G))){return;};if(G&&F&&qx.ui.core.Widget.contains(F,G)){return;};if(H&&!G){this.setCurrent(null);}else {this.resetCurrent();};},__eT:function(e){var I=qx.ui.core.Widget.getWidgetByElement(e.getTarget());if(!I){return;};var J=this.getCurrent();if(J&&J==I.getToolTip()){this.setCurrent(null);};}},destruct:function(){qx.event.Registration.removeListener(document.body,g,this.__eR,this,true);this._disposeObjects(d,i,m);this.__eL=null;}});})();(function(){var a="qx.ui.core.MLayoutHandling";qx.Mixin.define(a,{members:{setLayout:function(b){this._setLayout(b);},getLayout:function(){return this._getLayout();}},statics:{remap:function(c){c.getLayout=c._getLayout;c.setLayout=c._setLayout;}}});})();(function(){var a="changeWidth",b="Boolean",c="allowShrinkY",d="_applyAlign",e="_applyStretching",f="bottom",g="Integer",h="changeTheme",i="_applyDimension",j="baseline",k="marginBottom",l="qx.ui.core.LayoutItem",m="center",n="marginTop",o="allowGrowX",p="shorthand",q="middle",r="marginLeft",s="qx.dyntheme",t="allowShrinkX",u="top",v="right",w="marginRight",x="abstract",y="_applyMargin",z="allowGrowY",A="left",B="changeHeight";qx.Class.define(l,{type:x,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);if(qx.core.Environment.get(s)){qx.theme.manager.Meta.getInstance().addListener(h,this._onChangeTheme,this);};},properties:{minWidth:{check:g,nullable:true,apply:i,init:null,themeable:true},width:{check:g,event:a,nullable:true,apply:i,init:null,themeable:true},maxWidth:{check:g,nullable:true,apply:i,init:null,themeable:true},minHeight:{check:g,nullable:true,apply:i,init:null,themeable:true},height:{check:g,event:B,nullable:true,apply:i,init:null,themeable:true},maxHeight:{check:g,nullable:true,apply:i,init:null,themeable:true},allowGrowX:{check:b,apply:e,init:true,themeable:true},allowShrinkX:{check:b,apply:e,init:true,themeable:true},allowGrowY:{check:b,apply:e,init:true,themeable:true},allowShrinkY:{check:b,apply:e,init:true,themeable:true},allowStretchX:{group:[o,t],mode:p,themeable:true},allowStretchY:{group:[z,c],mode:p,themeable:true},marginTop:{check:g,init:0,apply:y,themeable:true},marginRight:{check:g,init:0,apply:y,themeable:true},marginBottom:{check:g,init:0,apply:y,themeable:true},marginLeft:{check:g,init:0,apply:y,themeable:true},margin:{group:[n,w,k,r],mode:p,themeable:true},alignX:{check:[A,m,v],nullable:true,apply:d,themeable:true},alignY:{check:[u,q,f,j],nullable:true,apply:d,themeable:true}},members:{_onChangeTheme:qx.core.Environment.select(s,{"true":function(){var E=qx.util.PropertyUtil.getAllProperties(this.constructor);for(var name in E){var D=E[name];if(D.themeable){var C=qx.util.PropertyUtil.getUserValue(this,name);if(C==null){qx.util.PropertyUtil.resetThemed(this,name);};};};},"false":null}),__eU:null,__eV:null,__eW:null,__eX:null,__eY:null,__fa:null,__fb:null,getBounds:function(){return this.__fa||this.__eV||null;},clearSeparators:function(){},renderSeparator:function(F,G){},renderLayout:function(N,top,K,J){{var L;};var I=null;if(this.getHeight()==null&&this._hasHeightForWidth()){var I=this._getHeightForWidth(K);};if(I!=null&&I!==this.__eU){this.__eU=I;qx.ui.core.queue.Layout.add(this);return null;};var H=this.__eV;if(!H){H=this.__eV={};};var M={};if(N!==H.left||top!==H.top){M.position=true;H.left=N;H.top=top;};if(K!==H.width||J!==H.height){M.size=true;H.width=K;H.height=J;};if(this.__eW){M.local=true;delete this.__eW;};if(this.__eY){M.margin=true;delete this.__eY;};return M;},isExcluded:function(){return false;},hasValidLayout:function(){return !this.__eW;},scheduleLayoutUpdate:function(){qx.ui.core.queue.Layout.add(this);},invalidateLayoutCache:function(){this.__eW=true;this.__eX=null;},getSizeHint:function(O){var P=this.__eX;if(P){return P;};if(O===false){return null;};P=this.__eX=this._computeSizeHint();if(this._hasHeightForWidth()&&this.__eU&&this.getHeight()==null){P.height=this.__eU;};if(P.minWidth>P.width){P.width=P.minWidth;};if(P.maxWidth<P.width){P.width=P.maxWidth;};if(!this.getAllowGrowX()){P.maxWidth=P.width;};if(!this.getAllowShrinkX()){P.minWidth=P.width;};if(P.minHeight>P.height){P.height=P.minHeight;};if(P.maxHeight<P.height){P.height=P.maxHeight;};if(!this.getAllowGrowY()){P.maxHeight=P.height;};if(!this.getAllowShrinkY()){P.minHeight=P.height;};return P;},_computeSizeHint:function(){var U=this.getMinWidth()||0;var R=this.getMinHeight()||0;var V=this.getWidth()||U;var T=this.getHeight()||R;var Q=this.getMaxWidth()||Infinity;var S=this.getMaxHeight()||Infinity;return {minWidth:U,width:V,maxWidth:Q,minHeight:R,height:T,maxHeight:S};},_hasHeightForWidth:function(){var W=this._getLayout();if(W){return W.hasHeightForWidth();};return false;},_getHeightForWidth:function(X){var Y=this._getLayout();if(Y&&Y.hasHeightForWidth()){return Y.getHeightForWidth(X);};return null;},_getLayout:function(){return null;},_applyMargin:function(){this.__eY=true;var parent=this.$$parent;if(parent){parent.updateLayoutProperties();};},_applyAlign:function(){var parent=this.$$parent;if(parent){parent.updateLayoutProperties();};},_applyDimension:function(){qx.ui.core.queue.Layout.add(this);},_applyStretching:function(){qx.ui.core.queue.Layout.add(this);},hasUserBounds:function(){return !!this.__fa;},setUserBounds:function(bb,top,ba,bc){this.__fa={left:bb,top:top,width:ba,height:bc};qx.ui.core.queue.Layout.add(this);},resetUserBounds:function(){delete this.__fa;qx.ui.core.queue.Layout.add(this);},__fc:{},setLayoutProperties:function(bf){if(bf==null){return;};var bd=this.__fb;if(!bd){bd=this.__fb={};};var parent=this.getLayoutParent();if(parent){parent.updateLayoutProperties(bf);};for(var be in bf){if(bf[be]==null){delete bd[be];}else {bd[be]=bf[be];};};},getLayoutProperties:function(){return this.__fb||this.__fc;},clearLayoutProperties:function(){delete this.__fb;},updateLayoutProperties:function(bi){var bg=this._getLayout();if(bg){{var bh;};bg.invalidateChildrenCache();};qx.ui.core.queue.Layout.add(this);},getApplicationRoot:function(){return qx.core.Init.getApplication().getRoot();},getLayoutParent:function(){return this.$$parent||null;},setLayoutParent:function(parent){if(this.$$parent===parent){return;};this.$$parent=parent||null;qx.ui.core.queue.Visibility.add(this);},isRootWidget:function(){return false;},_getRoot:function(){var parent=this;while(parent){if(parent.isRootWidget()){return parent;};parent=parent.$$parent;};return null;},clone:function(){var bj=qx.core.Object.prototype.clone.call(this);var bk=this.__fb;if(bk){bj.__fb=qx.lang.Object.clone(bk);};return bj;}},destruct:function(){if(qx.core.Environment.get(s)){qx.theme.manager.Meta.getInstance().removeListener(h,this._onChangeTheme,this);};this.$$parent=this.$$subparent=this.__fb=this.__eV=this.__fa=this.__eX=null;}});})();(function(){var a="$$theme_",b="$$user_",c="qx.util.PropertyUtil",d="$$init_";qx.Class.define(c,{statics:{getProperties:function(e){return e.$$properties;},getAllProperties:function(j){var g={};var f=j;while(f!=qx.core.Object){var i=this.getProperties(f);for(var h in i){g[h]=i[h];};f=f.superclass;};return g;},getUserValue:function(l,k){return l[b+k];},setUserValue:function(n,m,o){n[b+m]=o;},deleteUserValue:function(q,p){delete (q[b+p]);},getInitValue:function(s,r){return s[d+r];},setInitValue:function(u,t,v){u[d+t]=v;},deleteInitValue:function(x,w){delete (x[d+w]);},getThemeValue:function(z,y){return z[a+y];},setThemeValue:function(B,A,C){B[a+A]=C;},deleteThemeValue:function(E,D){delete (E[a+D]);},setThemed:function(H,G,I){var F=qx.core.Property.$$method.setThemed;H[F[G]](I);},resetThemed:function(K,J){var L=qx.core.Property.$$method.resetThemed;K[L[J]]();}}});})();(function(){var a="qx.ui.core.queue.Layout",b="layout";qx.Class.define(a,{statics:{__dO:{},__fd:{},remove:function(c){delete this.__dO[c.$$hash];},add:function(d){this.__dO[d.$$hash]=d;qx.ui.core.queue.Manager.scheduleFlush(b);},isScheduled:function(e){return !!this.__dO[e.$$hash];},flush:function(){var f=this.__ff();for(var i=f.length-1;i>=0;i-- ){var g=f[i];if(g.hasValidLayout()){continue;};if(g.isRootWidget()&&!g.hasUserBounds()){var j=g.getSizeHint();g.renderLayout(0,0,j.width,j.height);}else {var h=g.getBounds();g.renderLayout(h.left,h.top,h.width,h.height);};};},getNestingLevel:function(l){var k=this.__fd;var n=0;var parent=l;while(true){if(k[parent.$$hash]!=null){n+=k[parent.$$hash];break;};if(!parent.$$parent){break;};parent=parent.$$parent;n+=1;};var m=n;while(l&&l!==parent){k[l.$$hash]=m-- ;l=l.$$parent;};return n;},__fe:function(){var t=qx.ui.core.queue.Visibility;this.__fd={};var s=[];var r=this.__dO;var o,q;for(var p in r){o=r[p];if(t.isVisible(o)){q=this.getNestingLevel(o);if(!s[q]){s[q]={};};s[q][p]=o;delete r[p];};};return s;},__ff:function(){var x=[];var z=this.__fe();for(var w=z.length-1;w>=0;w-- ){if(!z[w]){continue;};for(var v in z[w]){var u=z[w][v];if(w==0||u.isRootWidget()||u.hasUserBounds()){x.push(u);u.invalidateLayoutCache();continue;};var B=u.getSizeHint(false);if(B){u.invalidateLayoutCache();var y=u.getSizeHint();var A=(!u.getBounds()||B.minWidth!==y.minWidth||B.width!==y.width||B.maxWidth!==y.maxWidth||B.minHeight!==y.minHeight||B.height!==y.height||B.maxHeight!==y.maxHeight);}else {A=true;};if(A){var parent=u.getLayoutParent();if(!z[w-1]){z[w-1]={};};z[w-1][parent.$$hash]=parent;}else {x.push(u);};};};return x;}}});})();(function(){var a="mshtml",b="engine.name",c="pop.push.reverse.shift.sort.splice.unshift.join.slice",d="number",e="qx.type.BaseArray",f=".";qx.Bootstrap.define(e,{extend:Array,construct:function(g){},members:{toArray:null,valueOf:null,pop:null,push:null,reverse:null,shift:null,sort:null,splice:null,unshift:null,concat:null,join:null,slice:null,toString:null,indexOf:null,lastIndexOf:null,forEach:null,filter:null,map:null,some:null,every:null}});(function(){function h(p){if((qx.core.Environment.get(b)==a)){j.prototype={length:0,$$isArray:true};var n=c.split(f);for(var length=n.length;length;){j.prototype[n[ --length]]=Array.prototype[n[length]];};};var m=Array.prototype.slice;j.prototype.concat=function(){var r=this.slice(0);for(var i=0,length=arguments.length;i<length;i++ ){var q;if(arguments[i] instanceof j){q=m.call(arguments[i],0);}else if(arguments[i] instanceof Array){q=arguments[i];}else {q=[arguments[i]];};r.push.apply(r,q);};return r;};j.prototype.toString=function(){return m.call(this,0).toString();};j.prototype.toLocaleString=function(){return m.call(this,0).toLocaleString();};j.prototype.constructor=j;j.prototype.indexOf=Array.prototype.indexOf;j.prototype.lastIndexOf=Array.prototype.lastIndexOf;j.prototype.forEach=Array.prototype.forEach;j.prototype.some=Array.prototype.some;j.prototype.every=Array.prototype.every;var o=Array.prototype.filter;var l=Array.prototype.map;j.prototype.filter=function(){var s=new this.constructor;s.push.apply(s,o.apply(this,arguments));return s;};j.prototype.map=function(){var t=new this.constructor;t.push.apply(t,l.apply(this,arguments));return t;};j.prototype.slice=function(){var u=new this.constructor;u.push.apply(u,Array.prototype.slice.apply(this,arguments));return u;};j.prototype.splice=function(){var v=new this.constructor;v.push.apply(v,Array.prototype.splice.apply(this,arguments));return v;};j.prototype.toArray=function(){return Array.prototype.slice.call(this,0);};j.prototype.valueOf=function(){return this.length;};return j;};function j(length){if(arguments.length===1&&typeof length===d){this.length=-1<length&&length===length>>.5?length:this.push(length);}else if(arguments.length){this.push.apply(this,arguments);};};function k(){};k.prototype=[];j.prototype=new k;j.prototype.length=0;qx.type.BaseArray=h(j);})();})();(function(){var a="name",b="qxWeb",c="toString",d="$",e="number",f="_",g="data-qx-class",h="basename",j="classname";qx.Bootstrap.define(b,{extend:qx.type.BaseArray,statics:{__ek:[],$$qx:qx,$init:function(p,n){if(p.length&&p.length==1&&p[0]&&p[0].$widget instanceof qxWeb){return p[0].$widget;};var o=[];for(var i=0;i<p.length;i++ ){var m=!!(p[i]&&(p[i].nodeType===1||p[i].nodeType===9||p[i].nodeType===11));if(m){o.push(p[i]);continue;};var k=!!(p[i]&&p[i].history&&p[i].location&&p[i].document);if(k){o.push(p[i]);};};if(p[0]&&p[0].getAttribute&&p[0].getAttribute(g)&&o.length<2){n=qx.Bootstrap.getByName(p[0].getAttribute(g))||n;};var r=qx.lang.Array.cast(o,n);for(var i=0;i<qxWeb.__ek.length;i++ ){qxWeb.__ek[i].call(r);};return r;},$attach:function(t,s){for(var name in t){if(qxWeb.prototype[name]!=undefined&&Array.prototype[name]==undefined&&s!==true){{};}else {qxWeb.prototype[name]=t[name];};};},$attachStatic:function(v,u){for(var name in v){{};qxWeb[name]=v[name];};},$attachAll:function(y,x){for(var name in y.members){if(name.indexOf(d)!==0&&name.indexOf(f)!==0)qxWeb.prototype[name]=y.members[name];};var w;if(x!=null){qxWeb[x]=qxWeb[x]||{};w=qxWeb[x];}else {w=qxWeb;};for(var name in y.statics){if(name.indexOf(d)!==0&&name.indexOf(f)!==0&&name!==a&&name!==h&&name!==j&&name!==c&&name!==name.toUpperCase())w[name]=y.statics[name];};},$attachInit:function(z){this.__ek.push(z);},define:function(name,A){if(A==undefined){A=name;name=null;};return qx.Bootstrap.define.call(qx.Bootstrap,name,A);}},construct:function(C,B){if(!C&&this instanceof qxWeb){return this;};if(!C){C=[];}else if(qx.Bootstrap.isString(C)){if(B instanceof qxWeb&&B.length!=0){B=B[0];};if(B instanceof qxWeb){C=[];}else {C=qx.bom.Selector.query(C,B);};}else if((C.nodeType===1||C.nodeType===9||C.nodeType===11)||(C.history&&C.location&&C.document)){C=[C];};return qxWeb.$init(C,qxWeb);},members:{filter:function(D){if(qx.lang.Type.isFunction(D)){return qxWeb.$init(Array.prototype.filter.call(this,D),this.constructor);};return qxWeb.$init(qx.bom.Selector.matches(D,this),this.constructor);},unique:function(){var E=qx.lang.Array.unique(this);return qxWeb.$init(E,this.constructor);},slice:function(F,G){if(G!==undefined){return qxWeb.$init(Array.prototype.slice.call(this,F,G),this.constructor);};return qxWeb.$init(Array.prototype.slice.call(this,F),this.constructor);},splice:function(H,I,J){return qxWeb.$init(Array.prototype.splice.apply(this,arguments),this.constructor);},map:function(K,L){return qxWeb.$init(Array.prototype.map.apply(this,arguments),qxWeb);},concat:function(N){var M=Array.prototype.slice.call(this,0);for(var i=0;i<arguments.length;i++ ){if(arguments[i] instanceof qxWeb){M=M.concat(Array.prototype.slice.call(arguments[i],0));}else {M.push(arguments[i]);};};return qxWeb.$init(M,this.constructor);},indexOf:function(O,P){if(!O){return -1;};if(!P){P=0;};if(typeof P!==e){return -1;};if(P<0){P=this.length+P;if(P<0){P=0;};};if(qx.lang.Type.isArray(O)){O=O[0];};for(var i=P,l=this.length;i<l;i++ ){if(this[i]===O){return i;};};return -1;},debug:function(){{};return this;},logThis:function(){{var Q,length;};return this;},_forEachElement:function(S,R){for(var i=0,l=this.length;i<l;i++ ){if(this[i]&&(this[i].nodeType===1||this[i].nodeType===11)){S.apply(R||this,[this[i],i,this]);};};return this;},_forEachElementWrapped:function(U,T){this._forEachElement(function(V,X,W){U.apply(this,[qxWeb(V),X,W]);},T);return this;}},defer:function(Y){if(window.q==undefined){q=Y;};}});})();(function(){var a="display",b="",c="block",d="none",e="_getHeight",f="_getContentWidth",g="_getContentHeight",h="hidden",j="_getWidth",k="qx.module.Css",m="absolute";qx.Bootstrap.define(k,{statics:{_getHeight:function(p){var q=this[0];if(q){if(qx.dom.Node.isElement(q)){var n;if(p){var o={display:c,position:m,visibility:h};n=qx.module.Css.__fi(q,o,e,this);}else {n=qx.bom.element.Dimension.getHeight(q);};return n;}else if(qx.dom.Node.isDocument(q)){return qx.bom.Document.getHeight(qx.dom.Node.getWindow(q));}else if(qx.dom.Node.isWindow(q)){return qx.bom.Viewport.getHeight(q);};};return null;},_getWidth:function(t){var u=this[0];if(u){if(qx.dom.Node.isElement(u)){var r;if(t){var s={display:c,position:m,visibility:h};r=qx.module.Css.__fi(u,s,j,this);}else {r=qx.bom.element.Dimension.getWidth(u);};return r;}else if(qx.dom.Node.isDocument(u)){return qx.bom.Document.getWidth(qx.dom.Node.getWindow(u));}else if(qx.dom.Node.isWindow(u)){return qx.bom.Viewport.getWidth(u);};};return null;},_getContentHeight:function(w){var y=this[0];if(qx.dom.Node.isElement(y)){var x;if(w){var v={position:m,visibility:h,display:c};x=qx.module.Css.__fi(y,v,g,this);}else {x=qx.bom.element.Dimension.getContentHeight(y);};return x;};return null;},_getContentWidth:function(B){var z=this[0];if(qx.dom.Node.isElement(z)){var C;if(B){var A={position:m,visibility:h,display:c};C=qx.module.Css.__fi(z,A,f,this);}else {C=qx.bom.element.Dimension.getContentWidth(z);};return C;};return null;},__fg:{},__fh:function(G,D){var F=qx.module.Css.__fg;if(!F[G]){var H=D||document;var E=qxWeb(H.createElement(G)).appendTo(D.body);F[G]=E.getStyle(a);E.remove();};return F[G]||b;},__fi:function(L,I,J,O){var M={};for(var N in I){M[N]=L.style[N];L.style[N]=I[N];};var K=O[J]();for(var N in M){L.style[N]=M[N];};return K;},includeStylesheet:function(Q,P){qx.bom.Stylesheet.includeFile(Q,P);}},members:{getHeight:function(R){return this._getHeight(R);},getWidth:function(S){return this._getWidth(S);},getContentHeight:function(T){return this._getContentHeight(T);},getContentWidth:function(U){return this._getContentWidth(U);},show:function(){this._forEachElementWrapped(function(X){var Y=X.getStyle(a);var W=X[0].$$qPrevDisp;var V;if(Y==d){if(W&&W!=d){V=W;}else {var ba=qxWeb.getDocument(X[0]);V=qx.module.Css.__fh(X[0].tagName,ba);};X.setStyle(a,V);X[0].$$qPrevDisp=d;};});return this;},hide:function(){this._forEachElementWrapped(function(bb){var bc=bb.getStyle(a);if(bc!==d){bb[0].$$qPrevDisp=bc;bb.setStyle(a,d);};});return this;},getPosition:function(){var bd=this[0];if(qx.dom.Node.isElement(bd)){return qx.bom.element.Location.getPosition(bd);};return null;},getOffset:function(be){var bf=this[0];if(bf&&qx.dom.Node.isElement(bf)){return qx.bom.element.Location.get(bf,be);};return null;},setStyle:function(name,bg){if(/\w-\w/.test(name)){name=qx.lang.String.camelCase(name);};this._forEachElement(function(bh){qx.bom.element.Style.set(bh,name,bg);});return this;},getStyle:function(name){if(this[0]&&qx.dom.Node.isElement(this[0])){if(/\w-\w/.test(name)){name=qx.lang.String.camelCase(name);};return qx.bom.element.Style.get(this[0],name);};return null;},setStyles:function(bi){for(var name in bi){this.setStyle(name,bi[name]);};return this;},getStyles:function(bk){var bj={};for(var i=0;i<bk.length;i++ ){bj[bk[i]]=this.getStyle(bk[i]);};return bj;},addClass:function(name){this._forEachElement(function(bl){qx.bom.element.Class.add(bl,name);});return this;},addClasses:function(bm){this._forEachElement(function(bn){qx.bom.element.Class.addClasses(bn,bm);});return this;},removeClass:function(name){this._forEachElement(function(bo){qx.bom.element.Class.remove(bo,name);});return this;},removeClasses:function(bp){this._forEachElement(function(bq){qx.bom.element.Class.removeClasses(bq,bp);});return this;},hasClass:function(name){if(!this[0]||!qx.dom.Node.isElement(this[0])){return false;};return qx.bom.element.Class.has(this[0],name);},getClass:function(){if(!this[0]||!qx.dom.Node.isElement(this[0])){return b;};return qx.bom.element.Class.get(this[0]);},toggleClass:function(name){var br=qx.bom.element.Class;this._forEachElement(function(bs){br.has(bs,name)?br.remove(bs,name):br.add(bs,name);});return this;},toggleClasses:function(bt){for(var i=0,l=bt.length;i<l;i++ ){this.toggleClass(bt[i]);};return this;},replaceClass:function(bv,bu){this._forEachElement(function(bw){qx.bom.element.Class.replace(bw,bv,bu);});return this;}},defer:function(bx){qxWeb.$attachAll(this);qxWeb.$attach({"_getWidth":bx._getWidth,"_getHeight":bx._getHeight,"_getContentHeight":bx._getContentHeight,"_getContentWidth":bx._getContentWidth});}});})();(function(){var a="borderBottomWidth",b="scroll",c="qx.bom.element.Location",d="gecko",e="paddingLeft",f="borderRightWidth",g="auto",h="static",i="borderTopWidth",j="borderLeftWidth",k="marginBottom",l="marginTop",m="overflowY",n="marginLeft",o="border-box",p="padding",q="paddingBottom",r="paddingTop",s="marginRight",t="browser.quirksmode",u="engine.name",v="position",w="margin",x="paddingRight",y="BODY",z="overflowX",A="border";qx.Bootstrap.define(c,{statics:{__fj:function(C,B){return qx.bom.element.Style.get(C,B,qx.bom.element.Style.COMPUTED_MODE,false);},__fk:function(E,D){return parseInt(qx.bom.element.Style.get(E,D,qx.bom.element.Style.COMPUTED_MODE,false),10)||0;},__fl:function(G){var H=0,top=0;var F=qx.dom.Node.getWindow(G);H-=qx.bom.Viewport.getScrollLeft(F);top-=qx.bom.Viewport.getScrollTop(F);return {left:H,top:top};},__fm:qx.core.Environment.select(u,{"mshtml":function(K){var J=qx.dom.Node.getDocument(K);var I=J.body;var L=0;var top=0;L-=I.clientLeft+J.documentElement.clientLeft;top-=I.clientTop+J.documentElement.clientTop;if(!qx.core.Environment.get(t)){L+=this.__fk(I,j);top+=this.__fk(I,i);};return {left:L,top:top};},"webkit":function(O){var N=qx.dom.Node.getDocument(O);var M=N.body;var P=M.offsetLeft;var top=M.offsetTop;return {left:P,top:top};},"gecko":function(R){var Q=qx.dom.Node.getDocument(R).body;var S=Q.offsetLeft;var top=Q.offsetTop;if(qx.bom.element.BoxSizing.get(Q)!==o){S+=this.__fk(Q,j);top+=this.__fk(Q,i);};return {left:S,top:top};},"default":function(U){var T=qx.dom.Node.getDocument(U).body;var V=T.offsetLeft;var top=T.offsetTop;return {left:V,top:top};}}),__fn:function(W){var X=W.getBoundingClientRect();return {left:Math.round(X.left),top:Math.round(X.top)};},get:function(bf,bg){if(bf.tagName==y){var location=this.__fo(bf);var bj=location.left;var top=location.top;}else {var Y=this.__fm(bf);var bd=this.__fn(bf);var scroll=this.__fl(bf);var bj=bd.left+Y.left-scroll.left;var top=bd.top+Y.top-scroll.top;};var ba;var be;if(bf instanceof SVGElement){var bk=bf.getBoundingClientRect();ba=bk.width;be=bk.height;}else {ba=bf.offsetWidth;be=bf.offsetHeight;};var bb=bj+ba;var bc=top+be;if(bg){if(bg==p||bg==b){var bi=qx.bom.element.Style.get(bf,z);if(bi==b||bi==g){bb+=bf.scrollWidth-ba+this.__fk(bf,j)+this.__fk(bf,f);};var bh=qx.bom.element.Style.get(bf,m);if(bh==b||bh==g){bc+=bf.scrollHeight-be+this.__fk(bf,i)+this.__fk(bf,a);};};switch(bg){case p:bj+=this.__fk(bf,e);top+=this.__fk(bf,r);bb-=this.__fk(bf,x);bc-=this.__fk(bf,q);case b:bj-=bf.scrollLeft;top-=bf.scrollTop;bb-=bf.scrollLeft;bc-=bf.scrollTop;case A:bj+=this.__fk(bf,j);top+=this.__fk(bf,i);bb-=this.__fk(bf,f);bc-=this.__fk(bf,a);break;case w:bj-=this.__fk(bf,n);top-=this.__fk(bf,l);bb+=this.__fk(bf,s);bc+=this.__fk(bf,k);break;};};return {left:bj,top:top,right:bb,bottom:bc};},__fo:function(bl){var top=bl.offsetTop;var bm=bl.offsetLeft;top+=this.__fk(bl,l);bm+=this.__fk(bl,n);if(qx.core.Environment.get(u)===d){top+=this.__fk(bl,j);bm+=this.__fk(bl,i);};return {left:bm,top:top};},getLeft:function(bn,bo){return this.get(bn,bo).left;},getTop:function(bp,bq){return this.get(bp,bq).top;},getRight:function(br,bs){return this.get(br,bs).right;},getBottom:function(bt,bu){return this.get(bt,bu).bottom;},getRelative:function(by,bx,bw,bv){var bA=this.get(by,bw);var bz=this.get(bx,bv);return {left:bA.left-bz.left,top:bA.top-bz.top,right:bA.right-bz.right,bottom:bA.bottom-bz.bottom};},getPosition:function(bB){return this.getRelative(bB,this.getOffsetParent(bB));},getOffsetParent:function(bE){if(bE instanceof SVGElement){return document.body;};var bD=bE.offsetParent||document.body;var bC=qx.bom.element.Style;while(bD&&(!/^body|html$/i.test(bD.tagName)&&bC.get(bD,v)===h)){bD=bD.offsetParent;};return bD;}}});})();(function(){var a='',b="g",c="(^|\\s)",d='function',e="(\\s|$)",f="",g="\\b|\\b",h="qx.bom.element.Class",j='SVGAnimatedString',k="html.classlist",m="default",n=" ",o='object',p="$2",q="native",r="\\b",s='undefined';qx.Bootstrap.define(h,{statics:{__fp:/\s+/g,__fq:/^\s+|\s+$/g,add:{"native":function(t,name){if(name.length>0){t.classList.add(name);};return name;},"default":function(u,name){if(!this.has(u,name)){u.className+=(u.className?n:f)+name;};return name;}}[qx.core.Environment.get(k)?q:m],addClasses:{"native":function(w,v){for(var i=0;i<v.length;i++ ){if(v[i].length>0){w.classList.add(v[i]);};};return w.className;},"default":function(y,A){var z={};var B;var x=y.className;if(x){B=x.split(this.__fp);for(var i=0,l=B.length;i<l;i++ ){z[B[i]]=true;};for(var i=0,l=A.length;i<l;i++ ){if(!z[A[i]]){B.push(A[i]);};};}else {B=A;};return y.className=B.join(n);}}[qx.core.Environment.get(k)?q:m],get:function(D){var C=D.className;if(typeof C.split!==d){if(typeof C===o){if(qx.Bootstrap.getClass(C)==j){C=C.baseVal;}else {{};C=a;};};if(typeof C===s){{};C=a;};};return C;},has:{"native":function(E,name){return E.classList.contains(name);},"default":function(G,name){var F=new RegExp(c+name+e);return F.test(G.className);}}[qx.core.Environment.get(k)?q:m],remove:{"native":function(H,name){H.classList.remove(name);return name;},"default":function(J,name){var I=new RegExp(c+name+e);J.className=J.className.replace(I,p);return name;}}[qx.core.Environment.get(k)?q:m],removeClasses:{"native":function(L,K){for(var i=0;i<K.length;i++ ){L.classList.remove(K[i]);};return L.className;},"default":function(O,M){var N=new RegExp(r+M.join(g)+r,b);return O.className=O.className.replace(N,f).replace(this.__fq,f).replace(this.__fp,n);}}[qx.core.Environment.get(k)?q:m],replace:function(R,Q,P){if(!this.has(R,Q)){return f;};this.remove(R,Q);return this.add(R,P);},toggle:{"native":function(T,name,S){if(S===undefined){T.classList.toggle(name);}else {S?this.add(T,name):this.remove(T,name);};return name;},"default":function(V,name,U){if(U==null){U=!this.has(V,name);};U?this.add(V,name):this.remove(V,name);return name;}}[qx.core.Environment.get(k)?q:m]}});})();(function(){var a="ipod",b="pc",c="ps3",d=")",e="device.type",f="psp",g="wii",h="xbox",i="\.",j="iemobile",k="ipad",l="ds",m="(",n="mobile",o="tablet",p="ontouchstart",q="g",r="iphone",s="|",t="qx.bom.client.Device",u="desktop",v="device.name",w="device.touch",x="undefined",y="device.pixelRatio";qx.Bootstrap.define(t,{statics:{__cv:{"Windows Phone":j,"iPod":a,"iPad":k,"iPhone":r,"PSP":f,"PLAYSTATION 3":c,"Nintendo Wii":g,"Nintendo DS":l,"XBOX":h,"Xbox":h},getName:function(){var B=[];for(var A in qx.bom.client.Device.__cv){B.push(A);};var C=new RegExp(m+B.join(s).replace(/\./g,i)+d,q);var z=C.exec(navigator.userAgent);if(z&&z[1]){return qx.bom.client.Device.__cv[z[1]];};return b;},getType:function(){return qx.bom.client.Device.detectDeviceType(navigator.userAgent);},detectDeviceType:function(D){if(qx.bom.client.Device.detectTabletDevice(D)){return o;}else if(qx.bom.client.Device.detectMobileDevice(D)){return n;};return u;},detectMobileDevice:function(E){return /android.+mobile|ip(hone|od)|bada\/|blackberry|BB10|maemo|opera m(ob|in)i|fennec|NetFront|phone|psp|symbian|IEMobile|windows (ce|phone)|xda/i.test(E);},detectTabletDevice:function(G){var H=(/MSIE 10/i.test(G))&&(/ARM/i.test(G))&&!(/windows phone/i.test(G));var F=(!(/android.+mobile|Tablet PC/i.test(G))&&(/Android|ipad|tablet|playbook|silk|kindle|psp/i.test(G)));return H||F;},getDevicePixelRatio:function(){if(typeof window.devicePixelRatio!==x){return window.devicePixelRatio;};return 1;},getTouch:function(){return ((p in window)||window.navigator.maxTouchPoints>0||window.navigator.msMaxTouchPoints>0);}},defer:function(I){qx.core.Environment.add(v,I.getName);qx.core.Environment.add(w,I.getTouch);qx.core.Environment.add(e,I.getType);qx.core.Environment.add(y,I.getDevicePixelRatio);}});})();(function(){var a="foo",b="function",c="event.mouseevent",d="event.help",e="qx.bom.client.Event",f="event.dispatchevent",g="event.auxclick",h="mousewheel",j="event.touch",k="onhelp",l="msPointerEnabled",m="PointerEvent",n="pointerEnabled",o="event.customevent",p="onauxclick",q="documentMode",r="ontouchstart",s="mshtml",t="onhashchange",u="event.mousewheel",v="wheel",w="DOMMouseScroll",x="event.hashchange",y="event.mspointer";qx.Bootstrap.define(e,{statics:{getTouch:function(){return (r in window);},getMsPointer:function(){if(m in window){return true;};if(n in window.navigator){return window.navigator.pointerEnabled;}else if(l in window.navigator){return window.navigator.msPointerEnabled;};return false;},getHelp:function(){return (k in document);},getHashChange:function(){var z=qx.bom.client.Engine.getName();var A=t in window;return (z!==s&&A)||(z===s&&q in document&&document.documentMode>=8&&A);},getDispatchEvent:function(){return typeof document.dispatchEvent==b;},getCustomEvent:function(){if(!window.CustomEvent){return false;};try{new window.CustomEvent(a);return true;}catch(B){return false;};},getMouseEvent:function(){if(!window.MouseEvent){return false;};try{new window.MouseEvent(a);return true;}catch(C){return false;};},getMouseWheel:function(D){if(!D){D=window;};var G=[D,D.document,D.document.body];var F=D;var E=w;for(var i=0;i<G.length;i++ ){if(qx.bom.Event.supportsEvent(G[i],v)){E=v;F=G[i];break;};if(qx.bom.Event.supportsEvent(G[i],h)){E=h;F=G[i];break;};};return {type:E,target:F};},getAuxclickEvent:function(){var H=false;try{H=(p in document.documentElement);}catch(I){};return (H?true:false);}},defer:function(J){qx.core.Environment.add(j,J.getTouch);qx.core.Environment.add(c,J.getMouseEvent);qx.core.Environment.add(f,J.getDispatchEvent);qx.core.Environment.add(o,J.getCustomEvent);qx.core.Environment.add(y,J.getMsPointer);qx.core.Environment.add(d,J.getHelp);qx.core.Environment.add(x,J.getHashChange);qx.core.Environment.add(u,J.getMouseWheel);qx.core.Environment.add(g,J.getAuxclickEvent);}});})();(function(){var a="engine.name",b="event.mspointer",c="device.type",d="env",e="engine.version",f="qx.module.Environment",g="browser.version",h="event.touch",i="device.name",j="browser.quirksmode",k="browser.name",l="browser.documentmode";qx.Bootstrap.define(f,{statics:{get:function(m){return qx.core.Environment.get(m);},add:function(n,o){qx.core.Environment.add(n,o);return this;}},defer:function(p){qx.core.Environment.get(k);qx.core.Environment.get(g);qx.core.Environment.get(j);qx.core.Environment.get(l);qx.core.Environment.get(a);qx.core.Environment.get(e);qx.core.Environment.get(i);qx.core.Environment.get(c);qx.core.Environment.get(h);qx.core.Environment.get(b);qxWeb.$attachAll(this,d);}});})();(function(){var a="qx.module.Polyfill";qx.Bootstrap.define(a,{});})();(function(){var a="mshtml",b="engine.name",c="complete",d="Array",f="pointerout",g="pointerover",h="string",n="load",o="left",p="qx.module.Event",q="undefined",r="DOMContentLoaded",s="browser.documentmode",t="*";qx.Bootstrap.define(p,{statics:{__fr:{},__fs:{on:{},off:{}},__cX:false,ready:function(u){if(document.readyState===c){window.setTimeout(u,1);return;};var v=function(){qx.module.Event.__cX=true;u();};qxWeb(window).on(n,v);var w=function(){qxWeb(window).off(n,v);u();};if(qxWeb.env.get(b)!==a||qxWeb.env.get(s)>8){qx.bom.Event.addNativeListener(document,r,w);}else {var z=function(){if(qx.module.Event.__cX){return;};try{document.documentElement.doScroll(o);if(document.body){w();};}catch(A){window.setTimeout(z,100);};};z();};},$registerEventNormalization:function(E,B){if(!qx.lang.Type.isArray(E)){E=[E];};var C=qx.module.Event.__fr;for(var i=0,l=E.length;i<l;i++ ){var D=E[i];if(qx.lang.Type.isFunction(B)){if(!C[D]){C[D]=[];};C[D].push(B);};};},$unregisterEventNormalization:function(I,F){if(!qx.lang.Type.isArray(I)){I=[I];};var G=qx.module.Event.__fr;for(var i=0,l=I.length;i<l;i++ ){var H=I[i];if(G[H]){qx.lang.Array.remove(G[H],F);};};},$getEventNormalizationRegistry:function(){return qx.module.Event.__fr;},$registerEventHook:function(O,L,K){if(!qx.lang.Type.isArray(O)){O=[O];};var M=qx.module.Event.__fs.on;for(var i=0,l=O.length;i<l;i++ ){var N=O[i];if(qx.lang.Type.isFunction(L)){if(!M[N]){M[N]=[];};M[N].push(L);};};if(!K){return;};var J=qx.module.Event.__fs.off;for(var i=0,l=O.length;i<l;i++ ){var N=O[i];if(qx.lang.Type.isFunction(K)){if(!J[N]){J[N]=[];};J[N].push(K);};};},$unregisterEventHook:function(U,R,Q){if(!qx.lang.Type.isArray(U)){U=[U];};var S=qx.module.Event.__fs.on;for(var i=0,l=U.length;i<l;i++ ){var T=U[i];if(S[T]){qx.lang.Array.remove(S[T],R);};};if(!Q){return;};var P=qx.module.Event.__fs.off;for(var i=0,l=U.length;i<l;i++ ){var T=U[i];if(P[T]){qx.lang.Array.remove(P[T],Q);};};},$getEventHookRegistry:function(){return qx.module.Event.__fs;}},members:{on:function(bd,bb,bc,W){for(var i=0;i<this.length;i++ ){var V=this[i];var Y=bc||qxWeb(V);var X=qx.module.Event.__fs.on;var be=X[t]||[];if(X[bd]){be=be.concat(X[bd]);};for(var j=0,m=be.length;j<m;j++ ){be[j](V,bd,bb,bc);};var ba=function(bf,event){var bh=qx.module.Event.__fr;var bg=bh[t]||[];if(bh[bd]){bg=bg.concat(bh[bd]);};for(var x=0,y=bg.length;x<y;x++ ){event=bg[x](event,bf,bd);};bb.apply(this,[event]);}.bind(Y,V);ba.original=bb;qx.bom.Event.addNativeListener(V,bd,ba,W);if(!V.$$emitter){V.$$emitter=new qx.event.Emitter();};V.$$lastlistenerId=V.$$emitter.on(bd,ba,Y);V.$$emitter.getEntryById(V.$$lastlistenerId).useCapture=!!W;if(!V.__ft){V.__ft={};};if(!V.__ft[bd]){V.__ft[bd]={};};V.__ft[bd][V.$$lastlistenerId]=ba;if(!bc){if(!V.__fu){V.__fu={};};V.__fu[V.$$lastlistenerId]=Y;};};return this;},off:function(bt,bo,bq,bj){var br=(bo===null&&bq===null);for(var j=0;j<this.length;j++ ){var bi=this[j];if(!bi.__ft){continue;};var bv=[];if(bt!==null){bv.push(bt);}else {for(var bm in bi.__ft){bv.push(bm);};};for(var i=0,l=bv.length;i<l;i++ ){for(var bu in bi.__ft[bv[i]]){var bs=bi.__ft[bv[i]][bu];if(br||bs==bo||bs.original==bo){var bl=typeof bi.__fu!==q&&bi.__fu[bu];var bw;if(!bq&&bl){bw=bi.__fu[bu];};var bp=bi.$$emitter.off(bv[i],bs,bw||bq);if(br||bs.original==bo){qx.bom.Event.removeNativeListener(bi,bv[i],bs,bj);};if(bp!==null){delete bi.__ft[bv[i]][bu];};if(bl){delete bi.__fu[bu];};};};var bk=qx.module.Event.__fs.off;var bn=bk[t]||[];if(bk[bt]){bn=bn.concat(bk[bt]);};for(var k=0,m=bn.length;k<m;k++ ){bn[k](bi,bt,bo,bq);};};};return this;},allOff:function(bx){return this.off(bx||null,null,null);},offById:function(bz){var by=this[0].$$emitter.getEntryById(bz);return this.off(by.name,by.listener.original,by.ctx,by.useCapture);},emit:function(bA,bB){for(var j=0;j<this.length;j++ ){var bC=this[j];if(bC.$$emitter){bC.$$emitter.emit(bA,bB);};};return this;},once:function(bE,bD,bG){var self=this;var bF=function(bH){self.off(bE,bF,bG);bD.call(this,bH);};this.on(bE,bF,bG);return this;},hasListener:function(bL,bJ,bK){if(!this[0]||!this[0].$$emitter||!this[0].$$emitter.getListeners()[bL]){return false;};if(bJ){var bM=this[0].$$emitter.getListeners()[bL];for(var i=0;i<bM.length;i++ ){var bI=false;if(bM[i].listener==bJ){bI=true;};if(bM[i].listener.original&&bM[i].listener.original==bJ){bI=true;};if(bI){if(bK!==undefined){if(bM[i].ctx===bK){return true;};}else {return true;};};};return false;};return this[0].$$emitter.getListeners()[bL].length>0;},copyEventsTo:function(bT){var bR=this.concat();var bS=bT.concat();for(var i=bR.length-1;i>=0;i-- ){var bO=bR[i].getElementsByTagName(t);for(var j=0;j<bO.length;j++ ){bR.push(bO[j]);};};for(var i=bS.length-1;i>=0;i-- ){var bO=bS[i].getElementsByTagName(t);for(var j=0;j<bO.length;j++ ){bS.push(bO[j]);};};bS.forEach(function(bU){bU.$$emitter=null;});for(var i=0;i<bR.length;i++ ){var bN=bR[i];if(!bN.$$emitter){continue;};var bP=bN.$$emitter.getListeners();for(var name in bP){for(var j=bP[name].length-1;j>=0;j-- ){var bQ=bP[name][j].listener;if(bQ.original){bQ=bQ.original;};qxWeb(bS[i]).on(name,bQ,bP[name][j].ctx);};};};},hover:function(bV,bW){this.on(g,bV,this);if(qx.lang.Type.isFunction(bW)){this.on(f,bW,this);};return this;},onMatchTarget:function(bY,ca,cc,cb){cb=cb!==undefined?cb:this;var bX=function(e){var cd=qxWeb(e.getTarget());var ce=typeof ca==h?this.find(ca):qxWeb(ca);if(cd.is(ca)){cc.call(cb,cd,qxWeb.object.clone(e));}else {for(var i=0,l=ce.length;i<l;i++ ){if(cd.isChildOf(qxWeb(ce[i]))){cc.call(cb,cd,qxWeb.object.clone(e));break;};};};};this.forEach(function(cf){var cg={target:ca,type:bY,listener:bX,callback:cc,context:cb};if(!cf.$$matchTargetInfo){cf.$$matchTargetInfo=[];};cf.$$matchTargetInfo.push(cg);});this.on(bY,bX);return this;},offMatchTarget:function(ch,ci,ck,cj){cj=cj!==undefined?cj:this;this.forEach(function(cl){if(cl.$$matchTargetInfo&&qxWeb.type.get(cl.$$matchTargetInfo)==d){var cm=cl.$$matchTargetInfo;for(var i=cm.length-1;i>=0;i-- ){var cn=cm[i];if(cn.type==ch&&cn.callback==ck&&cn.context==cj){this.off(ch,cn.listener);cm.splice(i,1);};};if(cm.length===0){cl.$$matchTargetInfo=null;};};},this);return this;},hasMatchListener:function(ct,co,cp,cq){cq=cq!==undefined?cq:this;for(var j=0,l=this.length;j<l;j++ ){var cs=this[j].$$matchTargetInfo||[];for(var i=cs.length-1;i>=0;i-- ){var cr=cs[i];if(cr.type==ct&&cr.callback==cp&&cr.target==co&&cr.context==cq){return true;};};};return false;}},defer:function(cu){qxWeb.$attachAll(this);qxWeb.$attachStatic({"$registerEventNormalization":cu.$registerEventNormalization,"$unregisterEventNormalization":cu.$unregisterEventNormalization,"$getEventNormalizationRegistry":cu.$getEventNormalizationRegistry,"$registerEventHook":cu.$registerEventHook,"$unregisterEventHook":cu.$unregisterEventHook,"$getEventHookRegistry":cu.$getEventHookRegistry});}});})();(function(){var a="qx.module.event.PointerHandler",b="pointerup",c="event.dispatchevent",d="gesturemove",e="pointerover",f="gesturebegin",g="pointerdown",h="pointermove",i="gesturefinish",j="qx.event.handler.Pointer",k="gesturecancel",l="pointercancel",m="pointerout";qx.Bootstrap.define(a,{statics:{TYPES:[h,e,m,g,b,l,f,d,i,k],register:function(o,n){if(!o.$$pointerHandler){if(!qx.core.Environment.get(c)){if(!o.$$emitter){o.$$emitter=new qx.event.Emitter();};};o.$$pointerHandler=new qx.event.handler.PointerCore(o,o.$$emitter);};},unregister:function(r){if(r.$$pointerHandler){if(r.$$pointerHandler.classname===j){return;};var p=r.$$emitter.getListeners();for(var q in p){if(qx.module.event.PointerHandler.TYPES.indexOf(q)!==-1){if(p[q].length>0){return;};};};r.$$pointerHandler.dispose();r.$$pointerHandler=undefined;};}},defer:function(s){qxWeb.$registerEventHook(s.TYPES,s.register,s.unregister);}});})();(function(){var a="qx.event.Emitter",b="*";qx.Bootstrap.define(a,{extend:Object,statics:{__fv:[]},members:{__ft:null,__fw:null,on:function(name,c,d){var e=qx.event.Emitter.__fv.length;this.__fx(name).push({listener:c,ctx:d,id:e,name:name});qx.event.Emitter.__fv.push({name:name,listener:c,ctx:d});return e;},once:function(name,f,g){var h=qx.event.Emitter.__fv.length;this.__fx(name).push({listener:f,ctx:g,once:true,id:h});qx.event.Emitter.__fv.push({name:name,listener:f,ctx:g});return h;},off:function(name,m,k){var l=this.__fx(name);for(var i=l.length-1;i>=0;i-- ){var n=l[i];if(n.listener==m&&n.ctx==k){l.splice(i,1);qx.event.Emitter.__fv[n.id]=null;return n.id;};};return null;},offById:function(p){var o=qx.event.Emitter.__fv[p];if(o){this.off(o.name,o.listener,o.ctx);};return null;},addListener:function(name,q,r){return this.on(name,q,r);},addListenerOnce:function(name,s,t){return this.once(name,s,t);},removeListener:function(name,u,v){this.off(name,u,v);},removeListenerById:function(w){this.offById(w);},emit:function(name,A){var x=this.__fx(name).concat();var y=[];for(var i=0;i<x.length;i++ ){var z=x[i];z.listener.call(z.ctx,A);if(z.once){y.push(z);};};y.forEach(function(B){var C=this.__fx(name);var D=C.indexOf(B);C.splice(D,1);}.bind(this));x=this.__fx(b);for(var i=x.length-1;i>=0;i-- ){var z=x[i];z.listener.call(z.ctx,A);};},getListeners:function(){return this.__ft;},getEntryById:function(F){for(var name in this.__ft){var E=this.__ft[name];for(var i=0,j=E.length;i<j;i++ ){if(E[i].id===F){return E[i];};};};},__fx:function(name){if(this.__ft==null){this.__ft={};};if(this.__ft[name]==null){this.__ft[name]=[];};return this.__ft[name];}}});})();(function(){var a="touchmove",b="os.name",c="mousedown",d="event.dispatchevent",e="MSPointerDown",f="gesturemove",g="pointerover",h="touch",k="mouseout",m="ms",n="Processed",o="pointercancel",p="pointerleave",q="touchstart",r="pointerenter",s="mouse",t="event.mspointer",u="mousemove",v="MSPointerCancel",w="gesturefinish",z="browser.documentmode",A="pointerup",B="touchend",C="osx",D="mouseover",E="$$qx",F="pointerdown",G="MSPointerUp",H="pointermove",I="MSPointerOver",J="gecko",K="mshtml",L="engine.name",M="mouseup",N="touchcancel",O="contextmenu",P="gesturecancel",Q="MSPointerMove",R="MSPointerOut",S="gesturebegin",T="qx.event.handler.PointerCore",U=".",V="device.touch",W="pointerout";qx.Bootstrap.define(T,{extend:Object,statics:{MOUSE_TO_POINTER_MAPPING:{mousedown:F,mouseup:A,mousemove:H,mouseout:W,mouseover:g},TOUCH_TO_POINTER_MAPPING:{touchstart:F,touchend:A,touchmove:H,touchcancel:o},MSPOINTER_TO_POINTER_MAPPING:{MSPointerDown:F,MSPointerMove:H,MSPointerUp:A,MSPointerCancel:o,MSPointerLeave:p,MSPointerEnter:r,MSPointerOver:g,MSPointerOut:W},POINTER_TO_GESTURE_MAPPING:{pointerdown:S,pointerup:w,pointercancel:P,pointermove:f},LEFT_BUTTON:(qx.core.Environment.get(L)==K&&qx.core.Environment.get(z)<=8)?1:0,SIM_MOUSE_DISTANCE:25,SIM_MOUSE_DELAY:2500,__fy:null},construct:function(ba,bb){this.__fz=ba;this.__fA=bb;this.__fB=[];this.__fC=[];this.__fD=[];this._processedFlag=E+this.classname.substr(this.classname.lastIndexOf(U)+1)+n;var Y=qx.core.Environment.get(L);var X=parseInt(qx.core.Environment.get(z),10);if(Y==K&&X==10){this.__fB=[e,Q,G,v,I,R,F,H,A,o,g,W];this._initPointerObserver();}else {if(qx.core.Environment.get(t)){this.__fE=true;};this.__fB=[F,H,A,o,g,W];this._initPointerObserver();};if(!qx.core.Environment.get(t)){if(qx.core.Environment.get(V)){this.__fB=[q,B,a,N];this._initObserver(this._onTouchEvent);};this.__fB=[c,M,u,D,k,O];this._initObserver(this._onMouseEvent);};},members:{__fz:null,__fA:null,__fB:null,__fE:false,__fF:null,__fG:0,__fC:null,__fH:null,__fD:null,_processedFlag:null,_initPointerObserver:function(){this._initObserver(this._onPointerEvent);},_initObserver:function(bc,bd){this.__fF=qx.lang.Function.listener(bc,this);this.__fB.forEach(function(be){if(bd&&qx.dom.Node.isDocument(this.__fz)){if(!this.__fz.$$emitter){this.__fz.$$emitter=new qx.event.Emitter();};this.__fz.$$emitter.on(be,this.__fF);}else {qx.bom.Event.addNativeListener(this.__fz,be,this.__fF);};}.bind(this));},_onPointerEvent:function(bh){if(!qx.core.Environment.get(t)||(qx.core.Environment.get(z)===10&&bh.type.toLowerCase().indexOf(m)==-1)){return;};if(!this.__fE){bh.stopPropagation();};var bf=qx.event.handler.PointerCore.MSPOINTER_TO_POINTER_MAPPING[bh.type]||bh.type;var bi=qx.bom.Event.getTarget(bh);var bg=new qx.event.type.dom.Pointer(bf,bh);this._fireEvent(bg,bf,bi);},_onTouchEvent:function(bl){if(bl[this._processedFlag]){return;};bl[this._processedFlag]=true;var bm=qx.event.handler.PointerCore.TOUCH_TO_POINTER_MAPPING[bl.type];var bo=bl.changedTouches;this._determineActiveTouches(bl.type,bo);if(bl.touches.length<this.__fD.length){for(var i=this.__fD.length-1;i>=0;i-- ){var bq=new qx.event.type.dom.Pointer(o,bl,{identifier:this.__fD[i].identifier,target:bl.target,pointerType:h,pointerId:this.__fD[i].identifier+2});this._fireEvent(bq,o,bl.target);};this.__fH=null;this.__fD=[];return;};if(bl.type==q&&this.__fH===null){this.__fH=bo[0].identifier;};for(var i=0,l=bo.length;i<l;i++ ){var bp=bo[i];var bn=bl.view.document.elementFromPoint(bp.clientX,bp.clientY)||bl.target;var bk={clientX:bp.clientX,clientY:bp.clientY,pageX:bp.pageX,pageY:bp.pageY,identifier:bp.identifier,screenX:bp.screenX,screenY:bp.screenY,target:bn,pointerType:h,pointerId:bp.identifier+2};if(bl.type==q){var bj=new qx.event.type.dom.Pointer(g,bl,bk);this._fireEvent(bj,g,bk.target);};if(bp.identifier==this.__fH){bk.isPrimary=true;bk.button=0;bk.buttons=1;qx.event.handler.PointerCore.__fy={"x":bp.clientX,"y":bp.clientY,"time":new Date().getTime()};};var br=new qx.event.type.dom.Pointer(bm,bl,bk);this._fireEvent(br,bm,bk.target);if(bl.type==B||bl.type==N){var bs=new qx.event.type.dom.Pointer(W,bl,bk);this._fireEvent(bs,W,bl.target);if(this.__fH==bp.identifier){this.__fH=null;};};};},_onMouseEvent:function(bt){if(bt[this._processedFlag]){return;};bt[this._processedFlag]=true;if(this._isSimulatedMouseEvent(bt.clientX,bt.clientY)){return;};if(bt.type==c){this.__fC[bt.which]=1;}else if(bt.type==M){if(qx.core.Environment.get(b)==C&&qx.core.Environment.get(L)==J){if(this.__fC[bt.which]!=1&&bt.ctrlKey){this.__fC[1]=0;};};this.__fC[bt.which]=0;};var bv=qx.event.handler.PointerCore.MOUSE_TO_POINTER_MAPPING[bt.type];var bu=qx.bom.Event.getTarget(bt);var bw=qx.lang.Array.sum(this.__fC);var bz={pointerType:s,pointerId:1};if(this.__fG!=bw&&bw!==0&&this.__fG!==0){var bx=new qx.event.type.dom.Pointer(H,bt,bz);this._fireEvent(bx,H,bu);};this.__fG=bw;if(bt.type==c&&bw>1){return;};if(bt.type==M&&bw>0){return;};if(bt.type==O){this.__fC[bt.which]=0;return;};var by=new qx.event.type.dom.Pointer(bv,bt,bz);this._fireEvent(by,bv,bu);},_determineActiveTouches:function(bD,bC){if(bD==q){for(var i=0;i<bC.length;i++ ){this.__fD.push(bC[i]);};}else if(bD==B||bD==N){var bA=[];for(var i=0;i<this.__fD.length;i++ ){var bB=true;for(var j=0;j<bC.length;j++ ){if(this.__fD[i].identifier==bC[j].identifier){bB=false;break;};};if(bB){bA.push(this.__fD[i]);};};this.__fD=bA;};},_isSimulatedMouseEvent:function(x,y){var bF=qx.event.handler.PointerCore.__fy;if(bF){var bG=new Date().getTime()-bF.time;var bE=qx.event.handler.PointerCore.SIM_MOUSE_DISTANCE;var bI=Math.abs(x-qx.event.handler.PointerCore.__fy.x);var bH=Math.abs(y-qx.event.handler.PointerCore.__fy.y);if(bG<qx.event.handler.PointerCore.SIM_MOUSE_DELAY){if(bI<bE||bH<bE){return true;};};};return false;},_stopObserver:function(){for(var i=0;i<this.__fB.length;i++ ){qx.bom.Event.removeNativeListener(this.__fz,this.__fB[i],this.__fF);};},_fireEvent:function(bK,bJ,bL){bL=bL||bK.target;bJ=bJ||bK.type;var bM;if((bK.pointerType!==s||bK.button<=qx.event.handler.PointerCore.LEFT_BUTTON)&&(bJ==F||bJ==A||bJ==H)){bM=new qx.event.type.dom.Pointer(qx.event.handler.PointerCore.POINTER_TO_GESTURE_MAPPING[bJ],bK);qx.event.type.dom.Pointer.normalize(bM);bM.srcElement=bL;};if(qx.core.Environment.get(d)){if(!this.__fE){bL.dispatchEvent(bK);};if(bM){bL.dispatchEvent(bM);};}else {bK.srcElement=bL;while(bL){if(bL.$$emitter){bK.currentTarget=bL;if(!bK._stopped){bL.$$emitter.emit(bJ,bK);};if(bM&&!bM._stopped){bM.currentTarget=bL;bL.$$emitter.emit(bM.type,bM);};};bL=bL.parentNode;};};},dispose:function(){this._stopObserver();this.__fz=this.__fA=null;}}});})();(function(){var a="qx.event.type.dom.Custom",b="UIEvents",c="function",d="event.customevent",e="object";qx.Bootstrap.define(a,{extend:Object,statics:{PROPERTIES:{bubbles:false,cancelable:true}},construct:function(f,g,h){this._type=f;this._event=this._createEvent();this._initEvent(g,h);this._event._original=g;this._event.preventDefault=function(){if(this._original.preventDefault){this._original.preventDefault();}else {try{this._original.returnValue=false;}catch(i){};};};if(this._event.stopPropagation){this._event._nativeStopPropagation=this._event.stopPropagation;};this._event.stopPropagation=function(){this._stopped=true;if(this._nativeStopPropagation){this._original.stopPropagation();this._nativeStopPropagation();}else {this._original.cancelBubble=true;};};return this._event;},members:{_type:null,_event:null,_createEvent:function(){var j;if(qx.core.Environment.get(d)){j=new window.CustomEvent(this._type);}else if(typeof document.createEvent==c){j=document.createEvent(b);}else if(typeof document.createEventObject==e){j={};j.type=this._type;};return j;},_initEvent:function(k,m){m=m||{};var l=qx.lang.Object.clone(qx.event.type.dom.Custom.PROPERTIES);for(var n in m){l[n]=m[n];};if(this._event.initEvent){this._event.initEvent(this._type,l.bubbles,l.cancelable);};for(var n in l){this._event[n]=l[n];};}}});})();(function(){var a="bubbles",b="event.mouseevent",c="getScreenLeft",d="getPointerType",e="touch",f="ctrlKey",g="altKey",h="gecko",j="view",k="os.name",m="button",n="string",o="relatedTarget",p="buttons",q="mouse",r="clientX",s="qx.event.type.dom.Pointer",t="UIEvents",u="ios",v="pageY",w="cancelable",x="screenX",y="shiftKey",z="",A="number",B="detail",C="toElement",D="fromElement",E="getViewportLeft",F="function",G="clientY",H="os.version",I="engine.name",J="undefined",K="getViewportTop",L="screenY",M="getScreenTop",N="pen",O="metaKey",P="pageX",Q="object",R="getDocumentTop",S="which",T="getDocumentLeft";qx.Bootstrap.define(s,{extend:qx.event.type.dom.Custom,statics:{MOUSE_PROPERTIES:[a,w,j,B,x,L,r,G,P,v,f,g,y,O,m,S,o,D,C],POINTER_PROPERTIES:{pointerId:1,width:0,height:0,pressure:0.5,tiltX:0,tiltY:0,pointerType:z,isPrimary:false},READONLY_PROPERTIES:[],BIND_METHODS:[d,E,K,T,R,c,M],getPointerType:function(){if(typeof this.pointerType==n){return this.pointerType;};if(typeof this.pointerType==A){if(this.pointerType==this.MSPOINTER_TYPE_MOUSE){return q;};if(this.pointerType==this.MSPOINTER_TYPE_PEN){return N;};if(this.pointerType==this.MSPOINTER_TYPE_TOUCH){return e;};};return z;},getViewportLeft:function(){return this.clientX;},getViewportTop:function(){return this.clientY;},getDocumentLeft:function(){if(this.pageX!==undefined){return this.pageX;}else {var U=qx.dom.Node.getWindow(this.srcElement);return this.clientX+qx.bom.Viewport.getScrollLeft(U);};},getDocumentTop:function(){if(this.pageY!==undefined){return this.pageY;}else {var V=qx.dom.Node.getWindow(this.srcElement);return this.clientY+qx.bom.Viewport.getScrollTop(V);};},getScreenLeft:function(){return this.screenX;},getScreenTop:function(){return this.screenY;},normalize:function(event){var W=qx.event.type.dom.Pointer.BIND_METHODS;for(var i=0,l=W.length;i<l;i++ ){if(typeof event[W[i]]!=F){event[W[i]]=qx.event.type.dom.Pointer[W[i]].bind(event);};};}},construct:function(X,Y,ba){return qx.event.type.dom.Custom.call(this,X,Y,ba);},members:{_createEvent:function(){var bb;if(qx.core.Environment.get(b)){bb=new window.MouseEvent(this._type);}else if(typeof document.createEvent==F){bb=document.createEvent(t);}else if(typeof document.createEventObject==Q){bb={};bb.type=this._type;};return bb;},_initEvent:function(bc,bd){bd=bd||{};var bg=this._event;var bh={};qx.event.type.dom.Pointer.normalize(bc);Object.keys(qx.event.type.dom.Pointer.POINTER_PROPERTIES).concat(qx.event.type.dom.Pointer.MOUSE_PROPERTIES).forEach(function(bi){if(typeof bd[bi]!==J){bh[bi]=bd[bi];}else if(typeof bc[bi]!==J){bh[bi]=bc[bi];}else if(typeof qx.event.type.dom.Pointer.POINTER_PROPERTIES[bi]!==J){bh[bi]=qx.event.type.dom.Pointer.POINTER_PROPERTIES[bi];};});var bf;switch(bc.which){case 1:bf=1;break;case 2:bf=4;break;case 3:bf=2;break;default:bf=0;};if(bf!==undefined){bh.buttons=bf;bh.pressure=bf?0.5:0;};if(bg.initMouseEvent){bg.initMouseEvent(this._type,bh.bubbles,bh.cancelable,bh.view,bh.detail,bh.screenX,bh.screenY,bh.clientX,bh.clientY,bh.ctrlKey,bh.altKey,bh.shiftKey,bh.metaKey,bh.button,bh.relatedTarget);}else if(bg.initUIEvent){bg.initUIEvent(this._type,bh.bubbles,bh.cancelable,bh.view,bh.detail);};for(var be in bh){if(bg[be]!==bh[be]&&qx.event.type.dom.Pointer.READONLY_PROPERTIES.indexOf(be)===-1){bg[be]=bh[be];};};switch(bg.pointerType){case bc.MSPOINTER_TYPE_MOUSE:bg.pointerType=q;break;case bc.MSPOINTER_TYPE_PEN:bg.pointerType=N;break;case bc.MSPOINTER_TYPE_TOUCH:bg.pointerType=e;break;};if(bg.pointerType==q){bg.isPrimary=true;};}},defer:function(bj){if(qx.core.Environment.get(I)==h){bj.READONLY_PROPERTIES.push(p);}else if(qx.core.Environment.get(k)==u&&parseFloat(qx.core.Environment.get(H))>=8){bj.READONLY_PROPERTIES=bj.READONLY_PROPERTIES.concat(bj.MOUSE_PROPERTIES);};}});})();(function(){var a="start",b="animationEnd",c="",d="none",e="browser.name",f="browser.version",g="qx.module.Animation",h="animationIteration",j="end",k="animationStart",l="ease-in",m="iteration",n="ease-out",o="ie",p="display";qx.Bootstrap.define(g,{events:{"animationStart":undefined,"animationIteration":undefined,"animationEnd":undefined},statics:{_fadeOut:{duration:700,timing:n,keep:100,keyFrames:{'0':{opacity:1},'100':{opacity:0,display:d}}},_fadeIn:{duration:700,timing:l,keep:100,keyFrames:{'0':{opacity:0},'100':{opacity:1}}},_animate:function(s,q,r){this._forEachElement(function(t,i){if(t.$$animation){t.$$animation.stop();};var u;if(r){u=qx.bom.element.Animation.animateReverse(t,s,q);}else {u=qx.bom.element.Animation.animate(t,s,q);};var self=this;if(i==0){u.on(a,function(){self.emit(k);},u);u.on(m,function(){self.emit(h);},u);};u.on(j,function(){for(var i=0;i<self.length;i++ ){if(self[i].$$animation){return;};};self.emit(b);},t);});}},members:{getAnimationHandles:function(){var v=[];for(var i=0;i<this.length;i++ ){v[i]=this[i].$$animation;};return v;},animate:function(x,w){qx.module.Animation._animate.bind(this)(x,w,false);return this;},animateReverse:function(z,y){qx.module.Animation._animate.bind(this)(z,y,true);return this;},play:function(){for(var i=0;i<this.length;i++ ){var A=this[i].$$animation;if(A){A.play();};};return this;},pause:function(){for(var i=0;i<this.length;i++ ){var B=this[i].$$animation;if(B){B.pause();};};return this;},stop:function(){for(var i=0;i<this.length;i++ ){var C=this[i].$$animation;if(C){C.stop();};};return this;},isPlaying:function(){for(var i=0;i<this.length;i++ ){var D=this[i].$$animation;if(D&&D.isPlaying()){return true;};};return false;},isEnded:function(){for(var i=0;i<this.length;i++ ){var E=this[i].$$animation;if(E&&!E.isEnded()){return false;};};return true;},fadeIn:function(F){this.setStyle(p,c);return this.animate(qx.module.Animation._fadeIn,F);},fadeOut:function(G){return this.animate(qx.module.Animation._fadeOut,G);}},defer:function(H){qxWeb.$attachAll(this);if(qxWeb.env.get(e)===o&&qxWeb.env.get(f)<=9){H._fadeIn.keyFrames[100].opacity=0.99;};}});})();(function(){var a="css.animation",b="translate",c="rotate",d="skew",e="scale",f="qx.bom.element.Animation";qx.Bootstrap.define(f,{statics:{animate:function(h,k,g){var j=qx.bom.element.Animation.__fI(h,k.keyFrames);if(qx.core.Environment.get(a)&&j){return qx.bom.element.AnimationCss.animate(h,k,g);}else {return qx.bom.element.AnimationJs.animate(h,k,g);};},animateReverse:function(m,o,l){var n=qx.bom.element.Animation.__fI(m,o.keyFrames);if(qx.core.Environment.get(a)&&n){return qx.bom.element.AnimationCss.animateReverse(m,o,l);}else {return qx.bom.element.AnimationJs.animateReverse(m,o,l);};},__fI:function(p,t){var r=[];for(var v in t){var s=t[v];for(var u in s){if(r.indexOf(u)==-1){r.push(u);};};};var q=[e,c,d,b];for(var i=0;i<r.length;i++ ){var u=qx.lang.String.camelCase(r[i]);if(!(u in p.style)){if(q.indexOf(r[i])!=-1){continue;};if(qx.bom.Style.getPropertyName(u)){continue;};return false;};};return true;}}});})();(function(){var a="oAnimationStart",b="animationend",c="MSAnimationStart",d="oRequestAnimationFrame",f="AnimationFillMode",g="webkitAnimationStart",h="MSAnimationEnd",j="requestAnimationFrame",k="mozRequestAnimationFrame",l="webkitanimationend",m="css.animation.requestframe",n="AnimationPlayState",o="",p="MSAnimationIteration",q="animation",r="oAnimationEnd",s="@",t="animationiteration",u="webkitAnimationEnd",v="webkitRequestAnimationFrame",w=" name",x="qx.bom.client.CssAnimation",y="css.animation",z="oAnimationIteration",A="webkitanimationiteration",B="-keyframes",C="msRequestAnimationFrame",D="@keyframes",E="webkitAnimationIteration",F="animationstart",G="webkitanimationstart";qx.Bootstrap.define(x,{statics:{getSupport:function(){var name=qx.bom.client.CssAnimation.getName();if(name!=null){return {"name":name,"play-state":qx.bom.client.CssAnimation.getPlayState(),"start-event":qx.bom.client.CssAnimation.getAnimationStart(),"iteration-event":qx.bom.client.CssAnimation.getAnimationIteration(),"end-event":qx.bom.client.CssAnimation.getAnimationEnd(),"fill-mode":qx.bom.client.CssAnimation.getFillMode(),"keyframes":qx.bom.client.CssAnimation.getKeyFrames()};};return null;},getFillMode:function(){return qx.bom.Style.getPropertyName(f);},getPlayState:function(){return qx.bom.Style.getPropertyName(n);},getName:function(){return qx.bom.Style.getPropertyName(q);},getAnimationStart:function(){if(qx.bom.Event.supportsEvent(window,G)){return g;};var H={"msAnimation":c,"WebkitAnimation":g,"MozAnimation":F,"OAnimation":a,"animation":F};return H[this.getName()];},getAnimationIteration:function(){if(qx.bom.Event.supportsEvent(window,A)){return E;};var I={"msAnimation":p,"WebkitAnimation":E,"MozAnimation":t,"OAnimation":z,"animation":t};return I[this.getName()];},getAnimationEnd:function(){if(qx.bom.Event.supportsEvent(window,l)){return u;};var J={"msAnimation":h,"WebkitAnimation":u,"MozAnimation":b,"OAnimation":r,"animation":b};return J[this.getName()];},getKeyFrames:function(){var K=qx.bom.Style.VENDOR_PREFIXES;var N=[];for(var i=0;i<K.length;i++ ){var M=s+qx.bom.Style.getCssName(K[i])+B;N.push(M);};N.unshift(D);var L=qx.bom.Stylesheet.createElement();for(var i=0;i<N.length;i++ ){try{qx.bom.Stylesheet.addRule(L,N[i]+w,o);return N[i];}catch(e){};};return null;},getRequestAnimationFrame:function(){var O=[j,C,v,k,d];for(var i=0;i<O.length;i++ ){if(window[O[i]]!=undefined){return O[i];};};return null;}},defer:function(P){qx.core.Environment.add(y,P.getSupport);qx.core.Environment.add(m,P.getRequestAnimationFrame);}});})();(function(){var a="fill-mode",b="os.name",c="repeat",d="os.version",f="timing",g="start",h="end",i="Anni",j="alternate",k="keep",l="visibilitychange",m=":",n="ios",o="} ",p="name",q="iteration-event",r="",s="origin",t="forwards",u="start-event",v="iteration",w="end-event",x="css.animation",y="ms ",z="% {",A=" ",B="linear",C=";",D="qx.bom.element.AnimationCss",E="keyframes";qx.Bootstrap.define(D,{statics:{__dn:null,__fJ:i,__cl:0,__dk:{},__fK:{"scale":true,"rotate":true,"skew":true,"translate":true},__fL:qx.core.Environment.get(x),animateReverse:function(G,H,F){return this._animate(G,H,F,true);},animate:function(J,K,I){return this._animate(J,K,I,false);},_animate:function(L,S,R,N){this.__fQ(S);{};var P=S.keep;if(P!=null&&(N||(S.alternate&&S.repeat%2==0))){P=100-P;};if(!this.__dn){this.__dn=qx.bom.Stylesheet.createElement();};var O=S.keyFrames;if(R==undefined){R=S.duration;};if(this.__fL!=null){var name=this.__fS(O,N);var M=name+A+R+y+S.timing+A+(S.delay?S.delay+y:r)+S.repeat+A+(S.alternate?j:r);qx.bom.Event.addNativeListener(L,this.__fL[u],this.__fM);qx.bom.Event.addNativeListener(L,this.__fL[q],this.__fN);qx.bom.Event.addNativeListener(L,this.__fL[w],this.__fO);{};L.style[qx.lang.String.camelCase(this.__fL[p])]=M;if(P&&P==100&&this.__fL[a]){L.style[this.__fL[a]]=t;};};var Q=new qx.bom.element.AnimationHandle();Q.desc=S;Q.el=L;Q.keep=P;L.$$animation=Q;if(S.origin!=null){qx.bom.element.Transform.setOrigin(L,S.origin);};if(this.__fL==null){window.setTimeout(function(){qx.bom.element.AnimationCss.__fO({target:L});},0);};return Q;},__fM:function(e){if(e.target.$$animation){e.target.$$animation.emit(g,e.target);};},__fN:function(e){if(e.target!=null&&e.target.$$animation!=null){e.target.$$animation.emit(v,e.target);};},__fO:function(e){var T=e.target;var U=T.$$animation;if(!U){return;};var W=U.desc;if(qx.bom.element.AnimationCss.__fL!=null){var V=qx.lang.String.camelCase(qx.bom.element.AnimationCss.__fL[p]);T.style[V]=r;qx.bom.Event.removeNativeListener(T,qx.bom.element.AnimationCss.__fL[p],qx.bom.element.AnimationCss.__fO);};if(W.origin!=null){qx.bom.element.Transform.setOrigin(T,r);};qx.bom.element.AnimationCss.__fP(T,W.keyFrames[U.keep]);T.$$animation=null;U.el=null;U.ended=true;U.emit(h,T);},__fP:function(X,Y){var bb;for(var ba in Y){if(ba in qx.bom.element.AnimationCss.__fK){if(!bb){bb={};};bb[ba]=Y[ba];}else {X.style[qx.lang.String.camelCase(ba)]=Y[ba];};};if(bb){qx.bom.element.Transform.transform(X,bb);};},__fQ:function(bc){if(!bc.hasOwnProperty(j)){bc.alternate=false;};if(!bc.hasOwnProperty(k)){bc.keep=null;};if(!bc.hasOwnProperty(c)){bc.repeat=1;};if(!bc.hasOwnProperty(f)){bc.timing=B;};if(!bc.hasOwnProperty(s)){bc.origin=null;};},__fR:null,__fS:function(frames,be){var bh=r;for(var bl in frames){bh+=(be?-(bl-100):bl)+z;var bg=frames[bl];var bj;for(var bd in bg){if(bd in this.__fK){if(!bj){bj={};};bj[bd]=bg[bd];}else {var bk=qx.bom.Style.getPropertyName(bd);var bf=(bk!==null)?qx.bom.Style.getCssName(bk):r;bh+=(bf||bd)+m+bg[bd]+C;};};if(bj){bh+=qx.bom.element.Transform.getCss(bj);};bh+=o;};if(this.__dk[bh]){return this.__dk[bh];};var name=this.__fJ+this.__cl++ ;var bi=this.__fL[E]+A+name;qx.bom.Stylesheet.addRule(this.__dn,bi,bh);this.__dk[bh]=name;return name;},__fT:function(){this.__cl=0;if(this.__dn){this.__dn.ownerNode.remove();this.__dn=null;this.__dk={};};}},defer:function(bm){if(qx.core.Environment.get(b)===n&&parseInt(qx.core.Environment.get(d))>=8){document.addEventListener(l,function(){if(!document.hidden){bm.__fT();};},false);};}});})();(function(){var a="css.animation",b="Element",c="",d="qx.bom.element.AnimationHandle",e="play-state",f="paused",g="running";qx.Bootstrap.define(d,{extend:qx.event.Emitter,construct:function(){var h=qx.core.Environment.get(a);this.__fU=h&&h[e];this.__fV=true;},events:{"start":b,"end":b,"iteration":b},members:{__fU:null,__fV:false,__fW:false,isPlaying:function(){return this.__fV;},isEnded:function(){return this.__fW;},isPaused:function(){return this.el.style[this.__fU]==f;},pause:function(){if(this.el){this.el.style[this.__fU]=f;this.el.$$animation.__fV=false;if(this.animationId&&qx.bom.element.AnimationJs){qx.bom.element.AnimationJs.pause(this);};};},play:function(){if(this.el){this.el.style[this.__fU]=g;this.el.$$animation.__fV=true;if(this.i!=undefined&&qx.bom.element.AnimationJs){qx.bom.element.AnimationJs.play(this);};};},stop:function(){if(this.el&&qx.core.Environment.get(a)&&!this.jsAnimation){this.el.style[this.__fU]=c;this.el.style[qx.core.Environment.get(a).name]=c;this.el.$$animation.__fV=false;this.el.$$animation.__fW=true;}else if(this.jsAnimation){this.stopped=true;qx.bom.element.AnimationJs.stop(this);};}}});})();(function(){var c="cm",d="mm",e="0",f="pt",g="pc",h="",k="%",l="em",m="qx.bom.element.AnimationJs",n="infinite",o="#",p="in",q="px",r="start",s="end",t="ex",u=";",v="undefined",w="iteration",y="string",z=":";qx.Bootstrap.define(m,{statics:{__fX:30,__fY:[k,p,c,d,l,t,f,g,q],__fK:{"scale":true,"rotate":true,"skew":true,"translate":true},animate:function(B,C,A){return this._animate(B,C,A,false);},animateReverse:function(E,F,D){return this._animate(E,F,D,true);},_animate:function(G,Q,P,I){if(G.$$animation){return G.$$animation;};Q=qx.lang.Object.clone(Q,true);if(P==undefined){P=Q.duration;};var L=Q.keyFrames;var J=this.__gi(L);var K=this.__gh(P,J);var N=parseInt(P/K,10);this.__ga(L,G);var O=this.__gc(N,K,J,L,P,Q.timing);var H=new qx.bom.element.AnimationHandle();H.jsAnimation=true;if(I){O.reverse();H.reverse=true;};H.desc=Q;H.el=G;H.delta=O;H.stepTime=K;H.steps=N;G.$$animation=H;H.i=0;H.initValues={};H.repeatSteps=this.__gf(N,Q.repeat);var M=Q.delay||0;var self=this;H.delayId=window.setTimeout(function(){H.delayId=null;self.play(H);},M);return H;},__ga:function(V,R){var Y={};for(var U in V){for(var name in V[U]){var S=qx.bom.Style.getPropertyName(name);if(S&&S!=name){var X=qx.bom.Style.getCssName(S);V[U][X]=V[U][name];delete V[U][name];name=X;};if(Y[name]==undefined){var W=V[U][name];if(typeof W==y){Y[name]=this.__gd(W);}else {Y[name]=h;};};};};for(var U in V){var T=V[U];for(var name in Y){if(T[name]==undefined){if(name in R.style){if(window.getComputedStyle){T[name]=getComputedStyle(R,null)[name];}else {T[name]=R.style[name];};}else {T[name]=R[name];};if(T[name]===h&&this.__fY.indexOf(Y[name])!=-1){T[name]=e+Y[name];};};};};},__gb:function(bb){bb=qx.lang.Object.clone(bb);var bc;for(var name in bb){if(name in this.__fK){if(!bc){bc={};};bc[name]=bb[name];delete bb[name];};};if(bc){var ba=qx.bom.element.Transform.getCss(bc).split(z);if(ba.length>1){bb[ba[0]]=ba[1].replace(u,h);};};return bb;},__gc:function(bw,bh,bo,bi,be,bq){var bp=new Array(bw);var bm=1;bp[0]=this.__gb(bi[0]);var bt=bi[0];var bj=bi[bo[bm]];var bf=Math.floor(bo[bm]/(bh/be*100));var bs=1;for(var i=1;i<bp.length;i++ ){if(i*bh/be*100>bo[bm]){bt=bj;bm++ ;bj=bi[bo[bm]];bf=Math.floor(bo[bm]/(bh/be*100))-bf;bs=1;};bp[i]={};var bd;for(var name in bj){var br=bj[name]+h;if(name in this.__fK){if(!bd){bd={};};if(qx.Bootstrap.isArray(bt[name])){if(!qx.Bootstrap.isArray(bj[name])){bj[name]=[bj[name]];};bd[name]=[];for(var j=0;j<bj[name].length;j++ ){var bu=bj[name][j]+h;var x=bs/bf;bd[name][j]=this.__ge(bu,bt[name],bq,x);};}else {var x=bs/bf;bd[name]=this.__ge(br,bt[name],bq,x);};}else if(br.charAt(0)==o){var bl=qx.util.ColorUtil.cssStringToRgb(bt[name]);var bk=qx.util.ColorUtil.cssStringToRgb(br);var bg=[];for(var j=0;j<bl.length;j++ ){var bv=bl[j]-bk[j];var x=bs/bf;var bn=qx.bom.AnimationFrame.calculateTiming(bq,x);bg[j]=parseInt(bl[j]-bv*bn,10);};bp[i][name]=qx.util.ColorUtil.rgbToHexString(bg);}else if(!isNaN(parseFloat(br))){var x=bs/bf;bp[i][name]=this.__ge(br,bt[name],bq,x);}else {bp[i][name]=bt[name]+h;};};if(bd){var bx=qx.bom.element.Transform.getCss(bd).split(z);if(bx.length>1){bp[i][bx[0]]=bx[1].replace(u,h);};};bs++ ;};bp[bp.length-1]=this.__gb(bi[100]);return bp;},__gd:function(by){return by.substring((parseFloat(by)+h).length,by.length);},__ge:function(bC,bB,bz,x){var bA=parseFloat(bC)-parseFloat(bB);return (parseFloat(bB)+bA*qx.bom.AnimationFrame.calculateTiming(bz,x))+this.__gd(bC);},play:function(bD){bD.emit(r,bD.el);var bE=window.setInterval(function(){bD.repeatSteps-- ;var bF=bD.delta[bD.i%bD.steps];if(bD.i===0){for(var name in bF){if(bD.initValues[name]===undefined){if(bD.el[name]!==undefined){bD.initValues[name]=bD.el[name];}else if(qx.bom.element.Style){bD.initValues[name]=qx.bom.element.Style.get(bD.el,qx.lang.String.camelCase(name));}else {bD.initValues[name]=bD.el.style[qx.lang.String.camelCase(name)];};};};};qx.bom.element.AnimationJs.__gg(bD.el,bF);bD.i++ ;if(bD.i%bD.steps==0){bD.emit(w,bD.el);if(bD.desc.alternate){bD.delta.reverse();};};if(bD.repeatSteps<0){qx.bom.element.AnimationJs.stop(bD);};},bD.stepTime);bD.animationId=bE;return bD;},pause:function(bG){window.clearInterval(bG.animationId);bG.animationId=null;return bG;},stop:function(bK){var bJ=bK.desc;var bH=bK.el;var bI=bK.initValues;if(bK.animationId){window.clearInterval(bK.animationId);};if(bK.delayId){window.clearTimeout(bK.delayId);};if(bH==undefined){return bK;};var bL=bJ.keep;if(bL!=undefined&&!bK.stopped){if(bK.reverse||(bJ.alternate&&bJ.repeat&&bJ.repeat%2==0)){bL=100-bL;};this.__gg(bH,bJ.keyFrames[bL]);}else {this.__gg(bH,bI);};bH.$$animation=null;bK.el=null;bK.ended=true;bK.animationId=null;bK.emit(s,bH);return bK;},__gf:function(bN,bM){if(bM==undefined){return bN;};if(bM==n){return Number.MAX_VALUE;};return bN*bM;},__gg:function(bP,bO){for(var bQ in bO){if(bO[bQ]===undefined){continue;};if(typeof bP.style[bQ]===v&&bQ in bP){bP[bQ]=bO[bQ];continue;};var name=qx.bom.Style.getPropertyName(bQ)||bQ;if(qx.bom.element.Style){qx.bom.element.Style.set(bP,name,bO[bQ]);}else {bP.style[name]=bO[bQ];};};},__gh:function(bT,bR){var bU=100;for(var i=0;i<bR.length-1;i++ ){bU=Math.min(bU,bR[i+1]-bR[i]);};var bS=bT*bU/100;while(bS>this.__fX){bS=bS/2;};return Math.round(bS);},__gi:function(bW){var bV=Object.keys(bW);for(var i=0;i<bV.length;i++ ){bV[i]=parseInt(bV[i],10);};bV.sort(function(a,b){return a-b;});return bV;}}});})();(function(){var a="css.transform.3d",b="backfaceVisibility",c="transformStyle",d="css.transform",e="transformOrigin",f="qx.bom.client.CssTransform",g="transform",h="perspective",i="perspectiveOrigin";qx.Bootstrap.define(f,{statics:{getSupport:function(){var name=qx.bom.client.CssTransform.getName();if(name!=null){return {"name":name,"style":qx.bom.client.CssTransform.getStyle(),"origin":qx.bom.client.CssTransform.getOrigin(),"3d":qx.bom.client.CssTransform.get3D(),"perspective":qx.bom.client.CssTransform.getPerspective(),"perspective-origin":qx.bom.client.CssTransform.getPerspectiveOrigin(),"backface-visibility":qx.bom.client.CssTransform.getBackFaceVisibility()};};return null;},getStyle:function(){return qx.bom.Style.getPropertyName(c);},getPerspective:function(){return qx.bom.Style.getPropertyName(h);},getPerspectiveOrigin:function(){return qx.bom.Style.getPropertyName(i);},getBackFaceVisibility:function(){return qx.bom.Style.getPropertyName(b);},getOrigin:function(){return qx.bom.Style.getPropertyName(e);},getName:function(){return qx.bom.Style.getPropertyName(g);},get3D:function(){return qx.bom.client.CssTransform.getPerspective()!=null;}},defer:function(j){qx.core.Environment.add(d,j.getSupport);qx.core.Environment.add(a,j.get3D);}});})();(function(){var a="backface-visibility",b="css.transform.3d",c=") ",d="px",e="scale",f="Z",g="X",h=", ",j="visible",k=":",l="3d",m="name",n="",o="origin",p="(",q="qx.bom.element.Transform",r="perspective",s="Y",t="css.transform",u="translate",v="perspective-origin",w="hidden",x=";",y=" ",z="style";qx.Bootstrap.define(q,{statics:{__gj:qx.core.Environment.get(t),transform:function(A,C){var D=this.getTransformValue(C);if(this.__gj!=null){var B=this.__gj[m];A.style[B]=D;};},translate:function(E,F){this.transform(E,{translate:F});},scale:function(G,H){this.transform(G,{scale:H});},rotate:function(I,J){this.transform(I,{rotate:J});},skew:function(K,L){this.transform(K,{skew:L});},getCss:function(N){var O=this.getTransformValue(N);if(this.__gj!=null){var M=this.__gj[m];return qx.bom.Style.getCssName(M)+k+O+x;};return n;},setOrigin:function(P,Q){if(this.__gj!=null){P.style[this.__gj[o]]=Q;};},getOrigin:function(R){if(this.__gj!=null){return R.style[this.__gj[o]];};return n;},setStyle:function(S,T){if(this.__gj!=null){S.style[this.__gj[z]]=T;};},getStyle:function(U){if(this.__gj!=null){return U.style[this.__gj[z]];};return n;},setPerspective:function(V,W){if(this.__gj!=null){V.style[this.__gj[r]]=W+d;};},getPerspective:function(X){if(this.__gj!=null){return X.style[this.__gj[r]];};return n;},setPerspectiveOrigin:function(Y,ba){if(this.__gj!=null){Y.style[this.__gj[v]]=ba;};},getPerspectiveOrigin:function(bb){if(this.__gj!=null){var bc=bb.style[this.__gj[v]];if(bc!=n){return bc;}else {var be=bb.style[this.__gj[v]+g];var bd=bb.style[this.__gj[v]+s];if(be!=n){return be+y+bd;};};};return n;},setBackfaceVisibility:function(bf,bg){if(this.__gj!=null){bf.style[this.__gj[a]]=bg?j:w;};},getBackfaceVisibility:function(bh){if(this.__gj!=null){return bh.style[this.__gj[a]]==j;};return true;},getTransformValue:function(bl){var bm=n;var bi=[u,e];for(var bj in bl){var bk=bl[bj];if(qx.Bootstrap.isArray(bk)){if(bk.length===3&&bi.indexOf(bj)>-1&&qx.core.Environment.get(b)){bm+=this._compute3dProperty(bj,bk);}else {bm+=this._computeAxisProperties(bj,bk);};}else {bm+=bj+p+bk+c;};};return bm.trim();},_compute3dProperty:function(bo,bn){var bp=n;bo+=l;for(var i=0;i<bn.length;i++ ){if(bn[i]==null){bn[i]=0;};};bp+=bo+p+bn.join(h)+c;return bp;},_computeAxisProperties:function(bq,br){var bt=n;var bs=[g,s,f];for(var i=0;i<br.length;i++ ){if(br[i]==null||(i==2&&!qx.core.Environment.get(b))){continue;};bt+=bq+bs[i]+p;bt+=br[i];bt+=c;};return bt;}}});})();(function(){var b="ease-in-out",c="Number",d="css.animation.requestframe",e="qx.bom.AnimationFrame",f="frame",g="end",h="linear",j="ease-in",k="ease-out";qx.Bootstrap.define(e,{extend:qx.event.Emitter,events:{"end":undefined,"frame":c},members:{__gk:false,startSequence:function(l){this.__gk=false;var m=+(new Date());var n=function(p){if(this.__gk){this.id=null;return;};if(p>=m+l){this.emit(g);this.id=null;}else {var o=Math.max(p-m,0);this.emit(f,o);this.id=qx.bom.AnimationFrame.request(n,this);};};this.id=qx.bom.AnimationFrame.request(n,this);},cancelSequence:function(){this.__gk=true;}},statics:{TIMEOUT:30,calculateTiming:function(q,x){if(q==j){var a=[3.1223e-7,0.0757,1.2646,-0.167,-0.4387,0.2654];}else if(q==k){var a=[-7.0198e-8,1.652,-0.551,-0.0458,0.1255,-0.1807];}else if(q==h){return x;}else if(q==b){var a=[2.482e-7,-0.2289,3.3466,-1.0857,-1.7354,0.7034];}else {var a=[-0.0021,0.2472,9.8054,-21.6869,17.7611,-5.1226];};var y=0;for(var i=0;i<a.length;i++ ){y+=a[i]*Math.pow(x,i);};return y;},request:function(r,t){var s=qx.core.Environment.get(d);var u=function(v){if(v<1e10){v=this.__gl+v;};v=v||+(new Date());r.call(t,v);};if(s){return window[s](u);}else {return window.setTimeout(function(){u();},qx.bom.AnimationFrame.TIMEOUT);};}},defer:function(w){w.__gl=window.performance&&performance.timing&&performance.timing.navigationStart;if(!w.__gl){w.__gl=Date.now();};}});})();(function(){var a="qx.util.DeferredCallManager",b="singleton";qx.Class.define(a,{extend:qx.core.Object,type:b,construct:function(){this.__gm={};this.__gn=qx.lang.Function.bind(this.__gr,this);this.__go=false;},members:{__gp:null,__gq:null,__gm:null,__go:null,__gn:null,schedule:function(d){if(this.__gp==null){this.__gp=window.setTimeout(this.__gn,0);};var c=d.toHashCode();if(this.__gq&&this.__gq[c]){return;};this.__gm[c]=d;this.__go=true;},cancel:function(f){var e=f.toHashCode();if(this.__gq&&this.__gq[e]){this.__gq[e]=null;return;};delete this.__gm[e];if(qx.lang.Object.isEmpty(this.__gm)&&this.__gp!=null){window.clearTimeout(this.__gp);this.__gp=null;};},__gr:qx.event.GlobalError.observeMethod(function(){this.__gp=null;while(this.__go){this.__gq=qx.lang.Object.clone(this.__gm);this.__gm={};this.__go=false;for(var h in this.__gq){var g=this.__gq[h];if(g){this.__gq[h]=null;g.call();};};};this.__gq=null;})},destruct:function(){if(this.__gp!=null){window.clearTimeout(this.__gp);};this.__gn=this.__gm=null;}});})();(function(){var a="qx.util.DeferredCall";qx.Class.define(a,{extend:qx.core.Object,construct:function(b,c){qx.core.Object.call(this);this.__A=b;this.__C=c||null;this.__gs=qx.util.DeferredCallManager.getInstance();},members:{__A:null,__C:null,__gs:null,cancel:function(){this.__gs.cancel(this);},schedule:function(){this.__gs.schedule(this);},call:function(){{var d;};this.__C?this.__A.apply(this.__C):this.__A();}},destruct:function(){this.cancel();this.__C=this.__A=this.__gs=null;}});})();(function(){var a="Child is already in: ",b="text",c="qx.html.Element",d="|capture|",f="focus",g="blur",h="div",j="class",k="deactivate",m="css.userselect",n="animationEnd",o="capture",p="visible",q="Root elements could not be inserted into other ones.",r="Has no children!",s="|bubble|",t="releaseCapture",u="Could not move to same index!",v="element",w="",z="qxSelectable",A="tabIndex",B="off",C="on",D="qx.html.Iframe",E="activate",F="__gO",G="Has no parent to remove from.",H="mshtml",I="engine.name",J="none",K="Has no child: ",L="scroll",M=" ",N="hidden",O="Has no child at this position!",P="css.userselect.none",Q="Could not overwrite existing element!";qx.Class.define(c,{extend:qx.core.Object,construct:function(T,R,S){qx.core.Object.call(this);this.__gt=T||h;this.__gu=R||null;this.__gv=S||null;},statics:{DEBUG:false,_modified:{},_visibility:{},_scroll:{},_actions:[],__gw:{},__gx:null,__gy:null,_scheduleFlush:function(U){qx.html.Element.__ha.schedule();},flush:function(){var bh;{};var Y=this.__gz();var W=Y.getFocus();if(W&&this.__gB(W)){Y.blur(W);};var bo=Y.getActive();if(bo&&this.__gB(bo)){qx.bom.Element.deactivate(bo);};var bc=this.__gA();if(bc&&this.__gB(bc)){qx.bom.Element.releaseCapture(bc);};var bi=[];var bj=this._modified;for(var bg in bj){bh=bj[bg];if(bh.__gS()||bh.classname==D){if(bh.__gC&&qx.dom.Hierarchy.isRendered(bh.__gC)){bi.push(bh);}else {{};bh.__gR();};delete bj[bg];};};for(var i=0,l=bi.length;i<l;i++ ){bh=bi[i];{};bh.__gR();};var be=this._visibility;for(var bg in be){bh=be[bg];var bk=bh.__gC;if(!bk){delete be[bg];continue;};{};if(!bh.$$disposed){bk.style.display=bh.__gE?w:J;if((qx.core.Environment.get(I)==H)){if(!(document.documentMode>=8)){bk.style.visibility=bh.__gE?p:N;};};};delete be[bg];};var scroll=this._scroll;for(var bg in scroll){bh=scroll[bg];var X=bh.__gC;if(X&&X.offsetWidth){var bb=true;if(bh.__gH!=null){bh.__gC.scrollLeft=bh.__gH;delete bh.__gH;};if(bh.__gI!=null){bh.__gC.scrollTop=bh.__gI;delete bh.__gI;};var bl=bh.__gF;if(bl!=null){var bf=bl.element.getDomElement();if(bf&&bf.offsetWidth){qx.bom.element.Scroll.intoViewX(bf,X,bl.align);delete bh.__gF;}else {bb=false;};};var bm=bh.__gG;if(bm!=null){var bf=bm.element.getDomElement();if(bf&&bf.offsetWidth){qx.bom.element.Scroll.intoViewY(bf,X,bm.align);delete bh.__gG;}else {bb=false;};};if(bb){delete scroll[bg];};};};var ba={"releaseCapture":1,"blur":1,"deactivate":1};for(var i=0;i<this._actions.length;i++ ){var bn=this._actions[i];var bk=bn.element.__gC;if(!bk||!ba[bn.type]&&!bn.element.__gS()){continue;};var bd=bn.args;bd.unshift(bk);qx.bom.Element[bn.type].apply(qx.bom.Element,bd);};this._actions=[];for(var bg in this.__gw){var V=this.__gw[bg];var X=V.element.__gC;if(X){qx.bom.Selection.set(X,V.start,V.end);delete this.__gw[bg];};};qx.event.handler.Appear.refresh();},__gz:function(){if(!this.__gx){var bp=qx.event.Registration.getManager(window);this.__gx=bp.getHandler(qx.event.handler.Focus);};return this.__gx;},__gA:function(){if(!this.__gy){var bq=qx.event.Registration.getManager(window);this.__gy=bq.getDispatcher(qx.event.dispatch.MouseCapture);};return this.__gy.getCaptureElement();},__gB:function(br){var bs=qx.core.ObjectRegistry.fromHashCode(br.$$element);return bs&&!bs.__gS();}},members:{__gt:null,__gC:null,__dd:false,__gD:true,__gE:true,__gF:null,__gG:null,__gH:null,__gI:null,__gJ:null,__gK:null,__gL:null,__gu:null,__gv:null,__gM:null,__gN:null,__gO:null,__gP:null,__gQ:null,_scheduleChildrenUpdate:function(){if(this.__gP){return;};this.__gP=true;qx.html.Element._modified[this.$$hash]=this;qx.html.Element._scheduleFlush(v);},_createDomElement:function(){return qx.dom.Element.create(this.__gt);},__gR:function(){{};var length;var bt=this.__gO;if(bt){length=bt.length;var bu;for(var i=0;i<length;i++ ){bu=bt[i];if(bu.__gE&&bu.__gD&&!bu.__gC){bu.__gR();};};};if(!this.__gC){this.__gC=this._createDomElement();this.__gC.$$element=this.$$hash;this._copyData(false);if(bt&&length>0){this._insertChildren();};}else {this._syncData();if(this.__gP){this._syncChildren();};};delete this.__gP;},_insertChildren:function(){var bv=this.__gO;var length=bv.length;var bx;if(length>2){var bw=document.createDocumentFragment();for(var i=0;i<length;i++ ){bx=bv[i];if(bx.__gC&&bx.__gD){bw.appendChild(bx.__gC);};};this.__gC.appendChild(bw);}else {var bw=this.__gC;for(var i=0;i<length;i++ ){bx=bv[i];if(bx.__gC&&bx.__gD){bw.appendChild(bx.__gC);};};};},_syncChildren:function(){var bH=qx.core.ObjectRegistry;var by=this.__gO;var bF=by.length;var bz;var bD;var bB=this.__gC;var bG=bB.childNodes;var bA=0;var bE;{var bC;};for(var i=bG.length-1;i>=0;i-- ){bE=bG[i];bD=bH.fromHashCode(bE.$$element);if(!bD||!bD.__gD||bD.__gQ!==this){bB.removeChild(bE);{};};};for(var i=0;i<bF;i++ ){bz=by[i];if(bz.__gD){bD=bz.__gC;bE=bG[bA];if(!bD){continue;};if(bD!=bE){if(bE){bB.insertBefore(bD,bE);}else {bB.appendChild(bD);};{};};bA++ ;};};{};},_copyData:function(bJ){var bL=this.__gC;var bN=this.__gv;if(bN){var bK=qx.bom.element.Attribute;for(var bM in bN){bK.set(bL,bM,bN[bM]);};};var bN=this.__gu;if(bN){var bI=qx.bom.element.Style;if(bJ){bI.setStyles(bL,bN);}else {bI.setCss(bL,bI.compile(bN));};};var bN=this.__gM;if(bN){for(var bM in bN){this._applyProperty(bM,bN[bM]);};};var bN=this.__gN;if(bN){qx.event.Registration.getManager(bL).importListeners(bL,bN);delete this.__gN;};},_syncData:function(){var bS=this.__gC;var bR=qx.bom.element.Attribute;var bP=qx.bom.element.Style;var bQ=this.__gK;if(bQ){var bV=this.__gv;if(bV){var bT;for(var bU in bQ){bT=bV[bU];if(bT!==undefined){bR.set(bS,bU,bT);}else {bR.reset(bS,bU);};};};this.__gK=null;};var bQ=this.__gJ;if(bQ){var bV=this.__gu;if(bV){var bO={};for(var bU in bQ){bO[bU]=bV[bU];};bP.setStyles(bS,bO);};this.__gJ=null;};var bQ=this.__gL;if(bQ){var bV=this.__gM;if(bV){var bT;for(var bU in bQ){this._applyProperty(bU,bV[bU]);};};this.__gL=null;};},__gS:function(){var bW=this;while(bW){if(bW.__dd){return true;};if(!bW.__gD||!bW.__gE){return false;};bW=bW.__gQ;};return false;},__gT:function(bX){if(bX.__gQ===this){throw new Error(a+bX);};if(bX.__dd){throw new Error(q);};if(bX.__gQ){bX.__gQ.remove(bX);};bX.__gQ=this;if(!this.__gO){this.__gO=[];};if(this.__gC){this._scheduleChildrenUpdate();};},__gU:function(bY){if(bY.__gQ!==this){throw new Error(K+bY);};if(this.__gC){this._scheduleChildrenUpdate();};delete bY.__gQ;},__gV:function(ca){if(ca.__gQ!==this){throw new Error(K+ca);};if(this.__gC){this._scheduleChildrenUpdate();};},getChildren:function(){return this.__gO||null;},getChild:function(cb){var cc=this.__gO;return cc&&cc[cb]||null;},hasChildren:function(){var cd=this.__gO;return cd&&cd[0]!==undefined;},indexOf:function(cf){var ce=this.__gO;return ce?ce.indexOf(cf):-1;},hasChild:function(ch){var cg=this.__gO;return cg&&cg.indexOf(ch)!==-1;},add:function(ci){if(arguments[1]){for(var i=0,l=arguments.length;i<l;i++ ){this.__gT(arguments[i]);};this.__gO.push.apply(this.__gO,arguments);}else {this.__gT(ci);this.__gO.push(ci);};return this;},addAt:function(ck,cj){this.__gT(ck);qx.lang.Array.insertAt(this.__gO,ck,cj);return this;},remove:function(cl){var cm=this.__gO;if(!cm){return this;};if(arguments[1]){var cn;for(var i=0,l=arguments.length;i<l;i++ ){cn=arguments[i];this.__gU(cn);qx.lang.Array.remove(cm,cn);};}else {this.__gU(cl);qx.lang.Array.remove(cm,cl);};return this;},removeAt:function(co){var cp=this.__gO;if(!cp){throw new Error(r);};var cq=cp[co];if(!cq){throw new Error(O);};this.__gU(cq);qx.lang.Array.removeAt(this.__gO,co);return this;},removeAll:function(){var cr=this.__gO;if(cr){for(var i=0,l=cr.length;i<l;i++ ){this.__gU(cr[i]);};cr.length=0;};return this;},getParent:function(){return this.__gQ||null;},insertInto:function(parent,cs){parent.__gT(this);if(cs==null){parent.__gO.push(this);}else {qx.lang.Array.insertAt(this.__gO,this,cs);};return this;},insertBefore:function(ct){var parent=ct.__gQ;parent.__gT(this);qx.lang.Array.insertBefore(parent.__gO,this,ct);return this;},insertAfter:function(cu){var parent=cu.__gQ;parent.__gT(this);qx.lang.Array.insertAfter(parent.__gO,this,cu);return this;},moveTo:function(cv){var parent=this.__gQ;parent.__gV(this);var cw=parent.__gO.indexOf(this);if(cw===cv){throw new Error(u);}else if(cw<cv){cv-- ;};qx.lang.Array.removeAt(parent.__gO,cw);qx.lang.Array.insertAt(parent.__gO,this,cv);return this;},moveBefore:function(cx){var parent=this.__gQ;return this.moveTo(parent.__gO.indexOf(cx));},moveAfter:function(cy){var parent=this.__gQ;return this.moveTo(parent.__gO.indexOf(cy)+1);},free:function(){var parent=this.__gQ;if(!parent){throw new Error(G);};if(!parent.__gO){return this;};parent.__gU(this);qx.lang.Array.remove(parent.__gO,this);return this;},getDomElement:function(){return this.__gC||null;},getNodeName:function(){return this.__gt;},setNodeName:function(name){this.__gt=name;},setRoot:function(cz){this.__dd=cz;},useMarkup:function(cA){if(this.__gC){throw new Error(Q);};if(qx.core.Environment.get(I)==H){var cB=document.createElement(h);}else {var cB=qx.dom.Element.getHelperElement();};cB.innerHTML=cA;this.useElement(cB.firstChild);return this.__gC;},useElement:function(cC){if(this.__gC){throw new Error(Q);};this.__gC=cC;this.__gC.$$element=this.$$hash;this._copyData(true);},isFocusable:function(){var cE=this.getAttribute(A);if(cE>=1){return true;};var cD=qx.event.handler.Focus.FOCUSABLE_ELEMENTS;if(cE>=0&&cD[this.__gt]){return true;};return false;},setSelectable:function(cG){this.setAttribute(z,cG?C:B);var cF=qx.core.Environment.get(m);if(cF){this.setStyle(cF,cG?b:qx.core.Environment.get(P));};},isNativelyFocusable:function(){return !!qx.event.handler.Focus.FOCUSABLE_ELEMENTS[this.__gt];},include:function(){if(this.__gD){return this;};delete this.__gD;if(this.__gQ){this.__gQ._scheduleChildrenUpdate();};return this;},exclude:function(){if(!this.__gD){return this;};this.__gD=false;if(this.__gQ){this.__gQ._scheduleChildrenUpdate();};return this;},isIncluded:function(){return this.__gD===true;},fadeIn:function(cH){var cI=qxWeb(this.__gC);if(cI.isPlaying()){cI.stop();};if(!this.__gC){this.__gR();cI.push(this.__gC);};if(this.__gC){cI.fadeIn(cH);return cI.getAnimationHandles()[0];};},fadeOut:function(cJ){var cK=qxWeb(this.__gC);if(cK.isPlaying()){cK.stop();};if(this.__gC){cK.fadeOut(cJ).once(n,function(){this.hide();qx.html.Element.flush();},this);return cK.getAnimationHandles()[0];};},show:function(){if(this.__gE){return this;};if(this.__gC){qx.html.Element._visibility[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};if(this.__gQ){this.__gQ._scheduleChildrenUpdate();};delete this.__gE;return this;},hide:function(){if(!this.__gE){return this;};if(this.__gC){qx.html.Element._visibility[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};this.__gE=false;return this;},isVisible:function(){return this.__gE===true;},scrollChildIntoViewX:function(cO,cM,cP){var cL=this.__gC;var cN=cO.getDomElement();if(cP!==false&&cL&&cL.offsetWidth&&cN&&cN.offsetWidth){qx.bom.element.Scroll.intoViewX(cN,cL,cM);}else {this.__gF={element:cO,align:cM};qx.html.Element._scroll[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};delete this.__gH;},scrollChildIntoViewY:function(cT,cR,cU){var cQ=this.__gC;var cS=cT.getDomElement();if(cU!==false&&cQ&&cQ.offsetWidth&&cS&&cS.offsetWidth){qx.bom.element.Scroll.intoViewY(cS,cQ,cR);}else {this.__gG={element:cT,align:cR};qx.html.Element._scroll[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};delete this.__gI;},scrollToX:function(x,cV){var cW=this.__gC;if(cV!==true&&cW&&cW.offsetWidth){cW.scrollLeft=x;delete this.__gH;}else {this.__gH=x;qx.html.Element._scroll[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};delete this.__gF;},getScrollX:function(){var cX=this.__gC;if(cX){return cX.scrollLeft;};return this.__gH||0;},scrollToY:function(y,da){var cY=this.__gC;if(da!==true&&cY&&cY.offsetWidth){cY.scrollTop=y;delete this.__gI;}else {this.__gI=y;qx.html.Element._scroll[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};delete this.__gG;},getScrollY:function(){var dc=this.__gC;if(dc){return dc.scrollTop;};return this.__gI||0;},disableScrolling:function(){this.enableScrolling();this.scrollToX(0);this.scrollToY(0);this.addListener(L,this.__gX,this);},enableScrolling:function(){this.removeListener(L,this.__gX,this);},__gW:null,__gX:function(e){if(!this.__gW){this.__gW=true;this.__gC.scrollTop=0;this.__gC.scrollLeft=0;delete this.__gW;};},getTextSelection:function(){var dd=this.__gC;if(dd){return qx.bom.Selection.get(dd);};return null;},getTextSelectionLength:function(){var de=this.__gC;if(de){return qx.bom.Selection.getLength(de);};return null;},getTextSelectionStart:function(){var df=this.__gC;if(df){return qx.bom.Selection.getStart(df);};return null;},getTextSelectionEnd:function(){var dg=this.__gC;if(dg){return qx.bom.Selection.getEnd(dg);};return null;},setTextSelection:function(dh,di){var dj=this.__gC;if(dj){qx.bom.Selection.set(dj,dh,di);return;};qx.html.Element.__gw[this.toHashCode()]={element:this,start:dh,end:di};qx.html.Element._scheduleFlush(v);},clearTextSelection:function(){var dk=this.__gC;if(dk){qx.bom.Selection.clear(dk);};delete qx.html.Element.__gw[this.toHashCode()];},__gY:function(dl,dm){var dn=qx.html.Element._actions;dn.push({type:dl,element:this,args:dm||[]});qx.html.Element._scheduleFlush(v);},focus:function(){this.__gY(f);},blur:function(){this.__gY(g);},activate:function(){this.__gY(E);},deactivate:function(){this.__gY(k);},capture:function(dp){this.__gY(o,[dp!==false]);},releaseCapture:function(){this.__gY(t);},setStyle:function(dq,dr,ds){if(!this.__gu){this.__gu={};};if(this.__gu[dq]==dr){return this;};if(dr==null){delete this.__gu[dq];}else {this.__gu[dq]=dr;};if(this.__gC){if(ds){qx.bom.element.Style.set(this.__gC,dq,dr);return this;};if(!this.__gJ){this.__gJ={};};this.__gJ[dq]=true;qx.html.Element._modified[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};return this;},setStyles:function(du,dw){var dv=qx.bom.element.Style;if(!this.__gu){this.__gu={};};if(this.__gC){if(!this.__gJ){this.__gJ={};};for(var dt in du){var dx=du[dt];if(this.__gu[dt]==dx){continue;};if(dx==null){delete this.__gu[dt];}else {this.__gu[dt]=dx;};if(dw){dv.set(this.__gC,dt,dx);continue;};this.__gJ[dt]=true;};qx.html.Element._modified[this.$$hash]=this;qx.html.Element._scheduleFlush(v);}else {for(var dt in du){var dx=du[dt];if(this.__gu[dt]==dx){continue;};if(dx==null){delete this.__gu[dt];}else {this.__gu[dt]=dx;};};};return this;},removeStyle:function(dz,dy){this.setStyle(dz,null,dy);return this;},getStyle:function(dA){return this.__gu?this.__gu[dA]:null;},getAllStyles:function(){return this.__gu||null;},setAttribute:function(dB,dC,dD){if(!this.__gv){this.__gv={};};if(this.__gv[dB]==dC){return this;};if(dC==null){delete this.__gv[dB];}else {this.__gv[dB]=dC;};if(this.__gC){if(dD){qx.bom.element.Attribute.set(this.__gC,dB,dC);return this;};if(!this.__gK){this.__gK={};};this.__gK[dB]=true;qx.html.Element._modified[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};return this;},setAttributes:function(dE,dF){for(var dG in dE){this.setAttribute(dG,dE[dG],dF);};return this;},removeAttribute:function(dI,dH){return this.setAttribute(dI,null,dH);},getAttribute:function(dJ){return this.__gv?this.__gv[dJ]:null;},addClass:function(name){var dK=((this.getAttribute(j)||w)+M+name).trim();this.setAttribute(j,dK);},removeClass:function(name){var dL=this.getAttribute(j);if(dL){this.setAttribute(j,(dL.replace(name,w)).trim());};},_applyProperty:function(name,dM){},_setProperty:function(dN,dO,dP){if(!this.__gM){this.__gM={};};if(this.__gM[dN]==dO){return this;};if(dO==null){delete this.__gM[dN];}else {this.__gM[dN]=dO;};if(this.__gC){if(dP){this._applyProperty(dN,dO);return this;};if(!this.__gL){this.__gL={};};this.__gL[dN]=true;qx.html.Element._modified[this.$$hash]=this;qx.html.Element._scheduleFlush(v);};return this;},_removeProperty:function(dR,dQ){return this._setProperty(dR,null,dQ);},_getProperty:function(dT){var dS=this.__gM;if(!dS){return null;};var dU=dS[dT];return dU==null?null:dU;},addListener:function(ea,dW,self,dV){if(this.$$disposed){return null;};{var dX;};if(this.__gC){return qx.event.Registration.addListener(this.__gC,ea,dW,self,dV);};if(!this.__gN){this.__gN={};};if(dV==null){dV=false;};var dY=qx.event.Manager.getNextUniqueId();var eb=ea+(dV?d:s)+dY;this.__gN[eb]={type:ea,listener:dW,self:self,capture:dV,unique:dY};return eb;},removeListener:function(ej,ed,self,ec){if(this.$$disposed){return null;};{var eh;};if(this.__gC){if(ed.$$wrapped_callback&&ed.$$wrapped_callback[ej+this.$$hash]){var ee=ed.$$wrapped_callback[ej+this.$$hash];delete ed.$$wrapped_callback[ej+this.$$hash];ed=ee;};qx.event.Registration.removeListener(this.__gC,ej,ed,self,ec);}else {var ef=this.__gN;var ei;if(ec==null){ec=false;};for(var eg in ef){ei=ef[eg];if(ei.listener===ed&&ei.self===self&&ei.capture===ec&&ei.type===ej){delete ef[eg];break;};};};return this;},removeListenerById:function(ek){if(this.$$disposed){return null;};if(this.__gC){qx.event.Registration.removeListenerById(this.__gC,ek);}else {delete this.__gN[ek];};return this;},hasListener:function(en,em){if(this.$$disposed){return false;};if(this.__gC){return qx.event.Registration.hasListener(this.__gC,en,em);};var eo=this.__gN;var eq;if(em==null){em=false;};for(var ep in eo){eq=eo[ep];if(eq.capture===em&&eq.type===en){return true;};};return false;},getListeners:function(){if(this.$$disposed){return null;};if(this.__gC){return qx.event.Registration.getManager(this.__gC).serializeListeners(this.__gC);};var er=[];for(var et in this.__gN){var es=this.__gN[et];er.push({type:es.type,handler:es.listener,self:es.self,capture:es.capture});};return er;}},defer:function(eu){eu.__ha=new qx.util.DeferredCall(eu.flush,eu);},destruct:function(){if(this.$$hash){delete qx.html.Element._modified[this.$$hash];delete qx.html.Element._scroll[this.$$hash];};var ev=this.__gC;if(ev){qx.event.Registration.getManager(ev).removeAllListeners(ev);ev.$$element=w;};if(!qx.core.ObjectRegistry.inShutDown){var parent=this.__gQ;if(parent&&!parent.$$disposed){parent.remove(this);};};this._disposeArray(F);this.__gv=this.__gu=this.__gN=this.__gM=this.__gK=this.__gJ=this.__gL=this.__gC=this.__gQ=this.__gF=this.__gG=null;}});})();(function(){var a="qx.event.handler.Appear",b="engine.name",c="mshtml",d="disappear",e="appear",f="browser.documentmode";qx.Class.define(a,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(g){qx.core.Object.call(this);this.__gs=g;this.__hb={};qx.event.handler.Appear.__hc[this.$$hash]=this;},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{appear:true,disappear:true},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE,IGNORE_CAN_HANDLE:true,__hc:{},refresh:function(){var h=this.__hc;for(var i in h){h[i].refresh();};}},members:{__gs:null,__hb:null,canHandleEvent:function(k,j){},registerEvent:function(o,p,m){var n=qx.core.ObjectRegistry.toHashCode(o)+p;var l=this.__hb;if(l&&!l[n]){l[n]=o;o.$$displayed=o.offsetWidth>0;};},unregisterEvent:function(t,u,r){var s=qx.core.ObjectRegistry.toHashCode(t)+u;var q=this.__hb;if(!q){return;};if(q[s]){delete q[s];};},refresh:function(){var A=this.__hb;var x;var y=qx.core.Environment.get(b)==c&&qx.core.Environment.get(f)<9;for(var v in A){x=A[v];var w=x.offsetWidth>0;if(!w&&y){w=x.offsetWidth>0;};if((!!x.$$displayed)!==w){x.$$displayed=w;var z=qx.event.Registration.createEvent(w?e:d);this.__gs.dispatchEvent(x,z);};};}},destruct:function(){this.__gs=this.__hb=null;delete qx.event.handler.Appear.__hc[this.$$hash];},defer:function(B){qx.event.Registration.addHandler(B);}});})();(function(){var a="abstract",b="Missing implementation",c="qx.event.dispatch.AbstractBubbling";qx.Class.define(c,{extend:qx.core.Object,implement:qx.event.IEventDispatcher,type:a,construct:function(d){this._manager=d;},members:{_getParent:function(e){throw new Error(b);},canDispatchEvent:function(g,event,f){return event.getBubbles();},dispatchEvent:function(l,event,w){var parent=l;var s=this._manager;var o,x;var n;var v,u;var y;var q=[];o=s.getListeners(l,w,true);x=s.getListeners(l,w,false);if(o){q.push(o);};if(x){q.push(x);};var parent=this._getParent(l);var k=[];var h=[];var m=[];var p=[];while(parent!=null){o=s.getListeners(parent,w,true);if(o){m.push(o);p.push(parent);};x=s.getListeners(parent,w,false);if(x){k.push(x);h.push(parent);};parent=this._getParent(parent);};event.setEventPhase(qx.event.type.Event.CAPTURING_PHASE);for(var i=m.length-1;i>=0;i-- ){y=p[i];event.setCurrentTarget(y);n=m[i];for(var j=0,r=n.length;j<r;j++ ){v=n[j];u=v.context||y;{};v.handler.call(u,event);};if(event.getPropagationStopped()){return;};};event.setEventPhase(qx.event.type.Event.AT_TARGET);event.setCurrentTarget(l);for(var i=0,t=q.length;i<t;i++ ){n=q[i];for(var j=0,r=n.length;j<r;j++ ){v=n[j];u=v.context||l;{};v.handler.call(u,event);};if(event.getPropagationStopped()){return;};};event.setEventPhase(qx.event.type.Event.BUBBLING_PHASE);for(var i=0,t=k.length;i<t;i++ ){y=h[i];event.setCurrentTarget(y);n=k[i];for(var j=0,r=n.length;j<r;j++ ){v=n[j];u=v.context||y;{};v.handler.call(u,event);};if(event.getPropagationStopped()){return;};};}}});})();(function(){var a="qx.event.dispatch.DomBubbling";qx.Class.define(a,{extend:qx.event.dispatch.AbstractBubbling,statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL},members:{_getParent:function(b){return b.parentNode;},canDispatchEvent:function(d,event,c){return d.nodeType!==undefined&&event.getBubbles();}},defer:function(e){qx.event.Registration.addDispatcher(e);}});})();(function(){var a="os.name",b="opera",c="engine.name",d="qx.event.type.Dom",e="osx";qx.Class.define(d,{extend:qx.event.type.Native,statics:{SHIFT_MASK:1,CTRL_MASK:2,ALT_MASK:4,META_MASK:8},members:{_cloneNativeEvent:function(f,g){var g=qx.event.type.Native.prototype._cloneNativeEvent.call(this,f,g);g.shiftKey=f.shiftKey;g.ctrlKey=f.ctrlKey;g.altKey=f.altKey;g.metaKey=f.metaKey;return g;},getModifiers:function(){var h=0;var i=this._native;if(i.shiftKey){h|=qx.event.type.Dom.SHIFT_MASK;};if(i.ctrlKey){h|=qx.event.type.Dom.CTRL_MASK;};if(i.altKey){h|=qx.event.type.Dom.ALT_MASK;};if(i.metaKey){h|=qx.event.type.Dom.META_MASK;};return h;},isCtrlPressed:function(){return this._native.ctrlKey;},isShiftPressed:function(){return this._native.shiftKey;},isAltPressed:function(){return this._native.altKey;},isMetaPressed:function(){return this._native.metaKey;},isCtrlOrCommandPressed:function(){if(qx.core.Environment.get(a)==e&&qx.core.Environment.get(c)!=b){return this._native.metaKey;}else {return this._native.ctrlKey;};}}});})();(function(){var a="mshtml",b="engine.name",c="click",d="middle",e="none",f="contextmenu",g="qx.event.type.Mouse",h="browser.documentmode",i="left",j="right",k="browser.name",l="ie";qx.Class.define(g,{extend:qx.event.type.Dom,members:{_cloneNativeEvent:function(m,n){var n=qx.event.type.Dom.prototype._cloneNativeEvent.call(this,m,n);n.button=m.button;n.clientX=Math.round(m.clientX);n.clientY=Math.round(m.clientY);n.pageX=m.pageX?Math.round(m.pageX):undefined;n.pageY=m.pageY?Math.round(m.pageY):undefined;n.screenX=Math.round(m.screenX);n.screenY=Math.round(m.screenY);n.wheelDelta=m.wheelDelta;n.wheelDeltaX=m.wheelDeltaX;n.wheelDeltaY=m.wheelDeltaY;n.delta=m.delta;n.deltaX=m.deltaX;n.deltaY=m.deltaY;n.deltaZ=m.deltaZ;n.detail=m.detail;n.axis=m.axis;n.wheelX=m.wheelX;n.wheelY=m.wheelY;n.HORIZONTAL_AXIS=m.HORIZONTAL_AXIS;n.srcElement=m.srcElement;n.target=m.target;return n;},__hd:{'0':i,'2':j,'1':d},__he:{'0':e,'1':i,'2':j,'4':d},__hf:{'1':i,'2':j,'4':d},stop:function(){this.stopPropagation();},getButton:function(){switch(this._type){case f:return j;case c:if(qx.core.Environment.get(k)===l&&qx.core.Environment.get(h)<9){return i;};default:if(!(qx.core.Environment.get(b)==a&&qx.core.Environment.get(h)<=8)){if(this._native.button===-1){return this.__he[this._native.buttons]||e;};return this.__hd[this._native.button]||e;}else {return this.__hf[this._native.button]||e;};};},isLeftPressed:function(){return this.getButton()===i;},isMiddlePressed:function(){return this.getButton()===d;},isRightPressed:function(){return this.getButton()===j;},getRelatedTarget:function(){return this._relatedTarget;},getViewportLeft:function(){return Math.round(this._native.clientX);},getViewportTop:function(){return Math.round(this._native.clientY);},getDocumentLeft:function(){if(this._native.pageX!==undefined){return Math.round(this._native.pageX);}else if(this._native.srcElement){var o=qx.dom.Node.getWindow(this._native.srcElement);return Math.round(this._native.clientX)+qx.bom.Viewport.getScrollLeft(o);}else {return Math.round(this._native.clientX)+qx.bom.Viewport.getScrollLeft(window);};},getDocumentTop:function(){if(this._native.pageY!==undefined){return Math.round(this._native.pageY);}else if(this._native.srcElement){var p=qx.dom.Node.getWindow(this._native.srcElement);return Math.round(this._native.clientY)+qx.bom.Viewport.getScrollTop(p);}else {return Math.round(this._native.clientY)+qx.bom.Viewport.getScrollTop(window);};},getScreenLeft:function(){return Math.round(this._native.screenX);},getScreenTop:function(){return Math.round(this._native.screenY);}}});})();(function(){var a="",b="mouse",c="number",d="touch",e="qx.event.type.Pointer",f="pen",g="string";qx.Class.define(e,{extend:qx.event.type.Mouse,members:{_cloneNativeEvent:function(h,i){i=qx.event.type.Mouse.prototype._cloneNativeEvent.call(this,h,i);i.pointerId=h.pointerId;i.width=h.width;i.height=h.height;i.pressure=h.pressure;i.tiltX=h.tiltX;i.tiltY=h.tiltY;i.pointerType=h.pointerType;i.isPrimary=h.isPrimary;i._original=h._original;i.MSPOINTER_TYPE_MOUSE=h.MSPOINTER_TYPE_MOUSE;i.MSPOINTER_TYPE_PEN=h.MSPOINTER_TYPE_PEN;i.MSPOINTER_TYPE_TOUCH=h.MSPOINTER_TYPE_TOUCH;return i;},getDocumentLeft:function(){var x=qx.event.type.Mouse.prototype.getDocumentLeft.call(this);if(x==0&&this.getPointerType()==d&&this._native._original!==undefined){x=Math.round(this._native._original.changedTouches[0].pageX)||0;};return x;},getDocumentTop:function(){var y=qx.event.type.Mouse.prototype.getDocumentTop.call(this);if(y==0&&this.getPointerType()==d&&this._native._original!==undefined){y=Math.round(this._native._original.changedTouches[0].pageY)||0;};return y;},getPointerId:function(){return this._native.pointerId||0;},getWidth:function(){return this._native.width||0;},getHeight:function(){return this._native.height||0;},getPressure:function(){return this._native.pressure||0;},getTiltX:function(){return this._native.tiltX||0;},getTiltY:function(){return this._native.tiltY||0;},getOriginalTarget:function(){if(this._native&&this._native._original){var j=this._native._original;try{if(j.type.indexOf(d)==0){if(j.changedTouches[0]){return document.elementFromPoint(j.changedTouches[0].clientX,j.changedTouches[0].clientY);};};}catch(k){return qx.bom.Event.getTarget(this._native);};return qx.bom.Event.getTarget(j);}else if(this._native){return qx.bom.Event.getTarget(this._native);};return qx.event.type.Mouse.prototype.getOriginalTarget.call(this);},getPointerType:function(){if(typeof this._native.pointerType==g){return this._native.pointerType;};if(typeof this._native.pointerType==c){if(this._native.pointerType==this._native.MSPOINTER_TYPE_MOUSE){return b;};if(this._native.pointerType==this._native.MSPOINTER_TYPE_PEN){return f;};if(this._native.pointerType==this._native.MSPOINTER_TYPE_TOUCH){return d;};};return a;},isPrimary:function(){return !!this._native.isPrimary;}}});})();(function(){var a="mshtml",b="engine.name",c="pointerup",d="dispose",e="useraction",f="mouse",g="pointercancel",h="pointerdown",i="pointermove",j="qx.event.handler.Pointer",k="browser.documentmode",l="qxanonymous";qx.Class.define(j,{extend:qx.event.handler.PointerCore,implement:qx.event.IEventHandler,statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{pointermove:1,pointerover:1,pointerout:1,pointerdown:1,pointerup:1,pointercancel:1,gesturebegin:1,gesturemove:1,gesturefinish:1,gesturecancel:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE+qx.event.IEventHandler.TARGET_DOCUMENT,IGNORE_CAN_HANDLE:true},construct:function(m){this.__gs=m;this.__cz=m.getWindow();this.__dd=this.__cz.document;qx.event.handler.PointerCore.apply(this,[this.__dd]);},members:{__gs:null,__cz:null,__dd:null,canHandleEvent:function(o,n){},registerEvent:function(r,q,p){},unregisterEvent:function(u,t,s){},_initPointerObserver:function(){var v=false;if(qx.core.Environment.get(b)==a&&qx.core.Environment.get(k)<9){v=true;};this._initObserver(this._onPointerEvent,v);},_fireEvent:function(w,x,y){if(!y){y=qx.bom.Event.getTarget(w);};while(y&&y.getAttribute&&y.getAttribute(l)){y=y.parentNode;};if(!x){x=w.type;};x=qx.event.handler.PointerCore.MSPOINTER_TO_POINTER_MAPPING[x]||x;if(y&&y.nodeType){qx.event.type.dom.Pointer.normalize(w);w.srcElement=y;qx.event.Registration.fireEvent(y,x,qx.event.type.Pointer,[w,y,null,true,true]);if((w.getPointerType()!==f||w.button<=qx.event.handler.PointerCore.LEFT_BUTTON)&&(x==h||x==c||x==i||x==g)){qx.event.Registration.fireEvent(this.__dd,qx.event.handler.PointerCore.POINTER_TO_GESTURE_MAPPING[x],qx.event.type.Pointer,[w,y,null,false,false]);};qx.event.Registration.fireEvent(this.__cz,e,qx.event.type.Data,[x]);};},_onPointerEvent:function(z){if(z._original&&z._original[this._processedFlag]){return;};var A=qx.event.handler.PointerCore.MSPOINTER_TO_POINTER_MAPPING[z.type]||z.type;this._fireEvent(z,A,qx.bom.Event.getTarget(z));},dispose:function(){this.__hg(d);this.__gs=this.__cz=this.__dd=null;},__hg:function(C,B){qx.event.handler.PointerCore.prototype[C].apply(this,B||[]);}},defer:function(D){qx.event.Registration.addHandler(D);qx.event.Registration.getManager(document).getHandler(D);}});})();(function(){var a="qx.event.type.Tap";qx.Class.define(a,{extend:qx.event.type.Pointer});})();(function(){var a="qx.event.type.Track";qx.Class.define(a,{extend:qx.event.type.Pointer,members:{_cloneNativeEvent:function(b,c){var c=qx.event.type.Pointer.prototype._cloneNativeEvent.call(this,b,c);c.delta=b.delta;return c;},getDelta:function(){return this._native.delta;}}});})();(function(){var a="qx.event.type.Swipe";qx.Class.define(a,{extend:qx.event.type.Pointer,members:{_cloneNativeEvent:function(b,c){var c=qx.event.type.Pointer.prototype._cloneNativeEvent.call(this,b,c);c.swipe=b.swipe;return c;},getStartTime:function(){return this._native.swipe.startTime;},getDuration:function(){return this._native.swipe.duration;},getAxis:function(){return this._native.swipe.axis;},getDirection:function(){return this._native.swipe.direction;},getVelocity:function(){return this._native.swipe.velocity;},getDistance:function(){return this._native.swipe.distance;}}});})();(function(){var a="qx.event.type.Rotate";qx.Class.define(a,{extend:qx.event.type.Pointer,members:{_cloneNativeEvent:function(b,c){var c=qx.event.type.Pointer.prototype._cloneNativeEvent.call(this,b,c);c.angle=b.angle;return c;},getAngle:function(){return this._native.angle;}}});})();(function(){var a="qx.event.type.Roll";qx.Class.define(a,{extend:qx.event.type.Pointer,members:{stop:function(){this.stopPropagation();this.preventDefault();},_cloneNativeEvent:function(b,c){var c=qx.event.type.Pointer.prototype._cloneNativeEvent.call(this,b,c);c.delta=b.delta;c.momentum=b.momentum;c.timeoutId=b.timeoutId;return c;},getMomentum:function(){return this._native.momentum;},stopMomentum:function(){if(this._native.timeoutId){qx.event.Registration.getManager(this._originalTarget).getHandler(qx.event.handler.Gesture).stopMomentum(this._native.timeoutId);};},getDelta:function(){return this._native.delta;}}});})();(function(){var a="qx.event.type.Pinch";qx.Class.define(a,{extend:qx.event.type.Pointer,members:{_cloneNativeEvent:function(b,c){var c=qx.event.type.Pointer.prototype._cloneNativeEvent.call(this,b,c);c.scale=b.scale;return c;},getScale:function(){return this._native.scale;}}});})();(function(){var a="swipe",b="pinch",c="event.dispatchevent",d="gesturemove",e="touch",f="longtap",g="event.mousewheel",h="roll",i="dblclick",j="wheel",k="rotate",l="trackstart",m="gesturefinish",n="y",o="browser.documentmode",p="dbltap",q="qx.event.handler.GestureCore",r="right",s="mshtml",t="engine.name",u="gesturecancel",v="gesturebegin",w="track",z="trackend",A="left",B="tap",C="down",D="x",E="up";qx.Bootstrap.define(q,{extend:Object,statics:{TYPES:[B,a,f,p,w,l,z,k,b,h],GESTURE_EVENTS:[v,m,d,u],TAP_MAX_DISTANCE:{"touch":40,"mouse":5,"pen":20},DOUBLETAP_MAX_DISTANCE:{"touch":10,"mouse":4,"pen":10},SWIPE_DIRECTION:{x:[A,r],y:[E,C]},LONGTAP_TIME:500,DOUBLETAP_TIME:500,ROLL_FACTOR:18},construct:function(F,G){this.__fz=F;this.__fA=G;this.__hh={};this.__hi={};this.__hj={};this.__hk={};this._initObserver();},members:{__fz:null,__fA:null,__hh:null,__hl:null,__hm:null,__hn:null,__ho:null,__hi:null,__hp:null,__hj:null,__hq:null,__hk:null,_initObserver:function(){qx.event.handler.GestureCore.GESTURE_EVENTS.forEach(function(I){qxWeb(this.__fz).on(I,this.checkAndFireGesture,this);}.bind(this));if(qx.core.Environment.get(t)==s&&qx.core.Environment.get(o)<9){qxWeb(this.__fz).on(i,this._onDblClick,this);};var H=qx.core.Environment.get(g);qxWeb(H.target).on(H.type,this._fireRoll,this);},_stopObserver:function(){qx.event.handler.GestureCore.GESTURE_EVENTS.forEach(function(K){qxWeb(this.__fz).off(K,this.checkAndFireGesture,this);}.bind(this));if(qx.core.Environment.get(t)==s&&qx.core.Environment.get(o)<9){qxWeb(this.__fz).off(i,this._onDblClick,this);};var J=qx.core.Environment.get(g);qxWeb(J.target).off(J.type,this._fireRoll,this);},checkAndFireGesture:function(L,M,N){if(!M){M=L.type;};if(!N){N=qx.bom.Event.getTarget(L);};if(M==v){this.gestureBegin(L,N);}else if(M==d){this.gestureMove(L,N);}else if(M==m){this.gestureFinish(L,N);}else if(M==u){this.gestureCancel(L.pointerId);};},gestureBegin:function(O,P){if(this.__hh[O.pointerId]){this.__hy(this.__hh[O.pointerId]);delete this.__hh[O.pointerId];};if(this._hasIntermediaryHandler(P)){return;};this.__hh[O.pointerId]={"startTime":new Date().getTime(),"lastEventTime":new Date().getTime(),"startX":O.clientX,"startY":O.clientY,"clientX":O.clientX,"clientY":O.clientY,"velocityX":0,"velocityY":0,"target":P,"isTap":true,"isPrimary":O.isPrimary,"longTapTimer":window.setTimeout(this.__hx.bind(this,O,P),qx.event.handler.GestureCore.LONGTAP_TIME)};if(O.isPrimary){this.__hn=false;this.__hm=P;this.__hu(l,O,P);}else {this.__hn=true;if(Object.keys(this.__hh).length===2){this.__ho=this._calcAngle();this.__hq=this._calcDistance();};};},gestureMove:function(R,S){var T=this.__hh[R.pointerId];if(T){var Q=T.clientX;var U=T.clientY;T.clientX=R.clientX;T.clientY=R.clientY;T.lastEventTime=new Date().getTime();if(Q){T.velocityX=T.clientX-Q;};if(U){T.velocityY=T.clientY-U;};if(Object.keys(this.__hh).length===2){this.__hv(R,T.target);this.__hw(R,T.target);};if(!this.__hn){this.__hu(w,R,T.target);this._fireRoll(R,e,T.target);};if(T.isTap){T.isTap=this._isBelowTapMaxDistance(R);if(!T.isTap){this.__hy(T);};};};},_hasIntermediaryHandler:function(V){while(V&&V!==this.__fz){if(V.$$gestureHandler){return true;};V=V.parentNode;};return false;},gestureFinish:function(X,Y){if(!this.__hh[X.pointerId]){return;};var bf=this.__hh[X.pointerId];this.__hy(bf);if(this._hasIntermediaryHandler(Y)){return;};this.__hr(bf.velocityX,bf.velocityY,X,bf.target);this.__hu(z,X,bf.target);if(bf.isTap){if(Y!==bf.target){delete this.__hh[X.pointerId];return;};this._fireEvent(X,B,X.target||Y);var ba=false;if(Object.keys(this.__hi).length>0){var be=Date.now()-qx.event.handler.GestureCore.DOUBLETAP_TIME;for(var bg in this.__hi){if(bg<be){delete this.__hi[bg];}else {var W=this.__hi[bg];var bc=this.__hs(W.x,W.y,X.clientX,X.clientY,X.getPointerType());var bd=W.target===(X.target||Y);var bh=W.button===X.button;if(bc&&bh&&bd){ba=true;delete this.__hi[bg];this._fireEvent(X,p,X.target||Y);};};};};if(!ba){this.__hi[Date.now()]={x:X.clientX,y:X.clientY,target:X.target||Y,button:X.button};};}else if(!this._isBelowTapMaxDistance(X)){var bb=this.__ht(X,Y);if(bb){X.swipe=bb;this._fireEvent(X,a,bf.target||Y);};};delete this.__hh[X.pointerId];},stopMomentum:function(bi){this.__hj[bi]=true;},gestureCancel:function(bj){if(this.__hh[bj]){this.__hy(this.__hh[bj]);delete this.__hh[bj];};if(this.__hk[bj]){this.stopMomentum(this.__hk[bj]);delete this.__hk[bj];};},updateGestureTarget:function(bk,bl){this.__hh[bk].target=bl;},__hr:function(bq,br,bn,bo,bt){var bs=bn.timeoutId;if(!bt&&this.__hk[bn.pointerId]){this.stopMomentum(this.__hk[bn.pointerId]);};if((Math.abs(br)<1&&Math.abs(bq)<1)||this.__hj[bs]||!this.getWindow()){delete this.__hj[bs];delete this.__hk[bn.pointerId];return;};if(!bt){bt=1;var bp=2.8;br=br/bp;bq=bq/bp;};bt+=0.0006;br=br/bt;bq=bq/bt;var bm=qx.bom.AnimationFrame.request(qx.lang.Function.bind(function(bu,bv,bw,bx,by){this.__hr(bu,bv,bw,bx,by);},this,bq,br,bn,bo,bt));bq=Math.round(bq*100)/100;br=Math.round(br*100)/100;bn.delta={x:-bq,y:-br};bn.momentum=true;bn.timeoutId=bm;this.__hk[bn.pointerId]=bm;this._fireEvent(bn,h,bn.target||bo);},_calcAngle:function(){var bA=null;var bB=null;for(var bz in this.__hh){var bC=this.__hh[bz];if(bA===null){bA=bC;}else {bB=bC;};};var x=bA.clientX-bB.clientX;var y=bA.clientY-bB.clientY;return (360+Math.atan2(y,x)*(180/Math.PI))%360;},_calcDistance:function(){var bD=null;var bE=null;for(var bG in this.__hh){var bH=this.__hh[bG];if(bD===null){bD=bH;}else {bE=bH;};};var bF=Math.sqrt(Math.pow(bD.clientX-bE.clientX,2)+Math.pow(bD.clientY-bE.clientY,2));return bF;},_isBelowTapMaxDistance:function(bJ){var bK=this._getDeltaCoordinates(bJ);var bI=qx.event.handler.GestureCore.TAP_MAX_DISTANCE[bJ.getPointerType()];if(!bK){return null;};return (Math.abs(bK.x)<=bI&&Math.abs(bK.y)<=bI);},__hs:function(bL,bP,bQ,bR,bS){var bO=qx.event.handler.GestureCore;var bM=Math.abs(bL-bQ)<bO.DOUBLETAP_MAX_DISTANCE[bS];var bN=Math.abs(bP-bR)<bO.DOUBLETAP_MAX_DISTANCE[bS];return bM&&bN;},_getDeltaCoordinates:function(bV){var bW=this.__hh[bV.pointerId];if(!bW){return null;};var bT=bV.clientX-bW.startX;var bU=bV.clientY-bW.startY;var bX=D;if(Math.abs(bT/bU)<1){bX=n;};return {"x":bT,"y":bU,"axis":bX};},_fireEvent:function(ca,cc,cb){if(!this.__fz){return;};var bY;if(qx.core.Environment.get(c)){bY=new qx.event.type.dom.Custom(cc,ca,{bubbles:true,swipe:ca.swipe,scale:ca.scale,angle:ca.angle,delta:ca.delta,pointerType:ca.pointerType,momentum:ca.momentum});cb.dispatchEvent(bY);}else if(this.__fA){bY=new qx.event.type.dom.Custom(cc,ca,{target:this.__fz,currentTarget:this.__fz,srcElement:this.__fz,swipe:ca.swipe,scale:ca.scale,angle:ca.angle,delta:ca.delta,pointerType:ca.pointerType,momentum:ca.momentum});this.__fA.emit(cc,ca);};},_onDblClick:function(cd){var ce=qx.bom.Event.getTarget(cd);this._fireEvent(cd,B,ce);this._fireEvent(cd,p,ce);},__ht:function(ch,ci){var co=this.__hh[ch.pointerId];if(!co){return null;};var ck=qx.event.handler.GestureCore;var cn=this._getDeltaCoordinates(ch);var cl=new Date().getTime()-co.startTime;var cp=(Math.abs(cn.x)>=Math.abs(cn.y))?D:n;var cf=cn[cp];var cg=ck.SWIPE_DIRECTION[cp][cf<0?0:1];var cm=(cl!==0)?cf/cl:0;var cj={startTime:co.startTime,duration:cl,axis:cp,direction:cg,distance:cf,velocity:cm};return cj;},__hu:function(cq,cr,cs){cr.delta=this._getDeltaCoordinates(cr);this._fireEvent(cr,cq,cr.target||cs);},_fireRoll:function(cu,ct,cv){if(cu.type===qx.core.Environment.get(g).type){cu.delta={x:qx.util.Wheel.getDelta(cu,D)*qx.event.handler.GestureCore.ROLL_FACTOR,y:qx.util.Wheel.getDelta(cu,n)*qx.event.handler.GestureCore.ROLL_FACTOR};cu.delta.axis=Math.abs(cu.delta.x/cu.delta.y)<1?n:D;cu.pointerType=j;}else {var cw=this.__hh[cu.pointerId];cu.delta={x:-cw.velocityX,y:-cw.velocityY,axis:Math.abs(cw.velocityX/cw.velocityY)<1?n:D};};this._fireEvent(cu,h,cu.target||cv);},__hv:function(cx,cz){if(!cx.isPrimary){var cy=this._calcAngle();cx.angle=Math.round((cy-this.__ho)%360);this._fireEvent(cx,k,this.__hm);};},__hw:function(cC,cD){if(!cC.isPrimary){var cA=this._calcDistance();var cB=cA/this.__hq;cC.scale=(Math.round(cB*100)/100);this._fireEvent(cC,b,this.__hm);};},__hx:function(cE,cF){var cG=this.__hh[cE.pointerId];if(cG){this._fireEvent(cE,f,cE.target||cF);cG.longTapTimer=null;cG.isTap=false;};},__hy:function(cH){if(cH.longTapTimer){window.clearTimeout(cH.longTapTimer);cH.longTapTimer=null;};},dispose:function(){for(var cI in this.__hh){this.__hy(cI);};this._stopObserver();this.__fz=this.__fA=null;}}});})();(function(){var a="x",b="y",c="qx.util.Wheel";qx.Bootstrap.define(c,{statics:{MAXSCROLL:null,MINSCROLL:null,FACTOR:1,getDelta:function(e,d){if(d===undefined){var f=0;if(e.wheelDelta!==undefined){f=-e.wheelDelta;}else if(e.detail!==0){f=e.detail;}else if(e.deltaY!==undefined){f=e.deltaY;};return this.__hz(f);};if(d===a){var x=0;if(e.wheelDelta!==undefined){if(e.wheelDeltaX!==undefined){x=e.wheelDeltaX?this.__hz(-e.wheelDeltaX):0;};}else {if(e.axis&&e.axis==e.HORIZONTAL_AXIS&&(e.detail!==undefined)&&(e.detail>0)){x=this.__hz(e.detail);}else if(e.deltaX!==undefined){x=this.__hz(e.deltaX);};};return x;};if(d===b){var y=0;if(e.wheelDelta!==undefined){if(e.wheelDeltaY!==undefined){y=e.wheelDeltaY?this.__hz(-e.wheelDeltaY):0;}else {y=this.__hz(-e.wheelDelta);};}else {if(!(e.axis&&e.axis==e.HORIZONTAL_AXIS)&&(e.detail!==undefined)&&(e.detail>0)){y=this.__hz(e.detail);}else if(e.deltaY!==undefined){y=this.__hz(e.deltaY);};};return y;};return 0;},__hz:function(j){var g=Math.abs(j);if(g===0){return 0;};if(qx.util.Wheel.MINSCROLL==null||qx.util.Wheel.MINSCROLL>g){qx.util.Wheel.MINSCROLL=g;this.__hA();};if(qx.util.Wheel.MAXSCROLL==null||qx.util.Wheel.MAXSCROLL<g){qx.util.Wheel.MAXSCROLL=g;this.__hA();};if(qx.util.Wheel.MAXSCROLL===g&&qx.util.Wheel.MINSCROLL===g){return 2*(j/g);};var h=qx.util.Wheel.MAXSCROLL-qx.util.Wheel.MINSCROLL;var i=(j/h)*Math.log(h)*qx.util.Wheel.FACTOR;return i<0?Math.min(i,-1):Math.max(i,1);},__hA:function(){var k=qx.util.Wheel.MAXSCROLL||0;var n=qx.util.Wheel.MINSCROLL||k;if(k<=n){return;};var l=k-n;var m=(k/l)*Math.log(l);if(m==0){m=1;};qx.util.Wheel.FACTOR=6/m;}}});})();(function(){var a="dblclick",b="mshtml",c="engine.name",d="dispose",e="useraction",f="gesturemove",g="gesturecancel",h="checkAndFireGesture",i="gesturebegin",j="qx.event.handler.Gesture",k="gesturefinish",l="browser.documentmode";qx.Class.define(j,{extend:qx.event.handler.GestureCore,implement:qx.event.IEventHandler,statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{tap:1,swipe:1,longtap:1,dbltap:1,rotate:1,pinch:1,track:1,trackstart:1,trackend:1,roll:1},GESTURE_EVENTS:[i,k,f,g],TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE+qx.event.IEventHandler.TARGET_DOCUMENT,IGNORE_CAN_HANDLE:true,EVENT_CLASSES:{"tap":qx.event.type.Tap,"longtap":qx.event.type.Tap,"dbltap":qx.event.type.Tap,"swipe":qx.event.type.Swipe,"rotate":qx.event.type.Rotate,"pinch":qx.event.type.Pinch,"track":qx.event.type.Track,"trackstart":qx.event.type.Track,"trackend":qx.event.type.Track,"roll":qx.event.type.Roll}},construct:function(m){this.__gs=m;this.__cz=m.getWindow();this.__dd=this.__cz.document;qx.event.handler.GestureCore.apply(this,[this.__dd]);},members:{__gs:null,__cz:null,__dd:null,__ft:null,__hB:null,__hC:null,getWindow:function(){return this.__cz;},canHandleEvent:function(o,n){},registerEvent:function(r,q,p){},unregisterEvent:function(u,t,s){},_initObserver:function(){this.__ft=qx.lang.Function.listener(this.checkAndFireGesture,this);qx.event.handler.Gesture.GESTURE_EVENTS.forEach(function(w){qx.event.Registration.addListener(this.__dd,w,this.__ft,this);}.bind(this));if(qx.core.Environment.get(c)==b&&qx.core.Environment.get(l)<9){this.__hB=qx.lang.Function.listener(this._onDblClick,this);qx.bom.Event.addNativeListener(this.__dd,a,this.__hB);};var v=qx.bom.client.Event.getMouseWheel(this.__cz);this.__hC=qx.lang.Function.listener(this._fireRoll,this);qx.bom.Event.addNativeListener(v.target,v.type,this.__hC,true);},checkAndFireGesture:function(y,x,z){this.__hg(h,[y.getNativeEvent(),y.getType(),y.getTarget()]);},_stopObserver:function(){qx.event.handler.Gesture.GESTURE_EVENTS.forEach(function(B){qx.event.Registration.removeListener(this.__dd,B,this.__ft);}.bind(this));if(qx.core.Environment.get(c)==b&&qx.core.Environment.get(l)<9){qx.bom.Event.removeNativeListener(this.__dd,a,this.__hB);};var A=qx.bom.client.Event.getMouseWheel(this.__cz);qx.bom.Event.removeNativeListener(A.target,A.type,this.__hC);},_hasIntermediaryHandler:function(C){return false;},_fireEvent:function(E,D,F){if(!F){F=qx.bom.Event.getTarget(E);};if(!D){D=E.type;};var G=qx.event.handler.Gesture.EVENT_CLASSES[D]||qx.event.type.Pointer;if(F&&F.nodeType){qx.event.Registration.fireEvent(F,D,G,[E,F,null,true,true]);};qx.event.Registration.fireEvent(this.__cz,e,qx.event.type.Data,[D]);},dispose:function(){this._stopObserver();this.__hg(d);this.__gs=this.__cz=this.__dd=this.__hB=null;},__hg:function(I,H){qx.event.handler.GestureCore.prototype[I].apply(this,H||[]);}},defer:function(J){qx.event.Registration.addHandler(J);qx.event.Registration.getManager(document).getHandler(J);}});})();(function(){var a="-",b="qx.event.handler.Element",c="load",d="iframe";qx.Class.define(b,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(e){qx.core.Object.call(this);this._manager=e;this._registeredEvents={};},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{abort:true,load:true,scroll:true,select:true,reset:true,submit:true},CANCELABLE:{selectstart:true},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE,IGNORE_CAN_HANDLE:false},members:{canHandleEvent:function(g,f){if(f===c){return g.tagName.toLowerCase()!==d;}else {return true;};},registerEvent:function(j,l,i){var m=qx.core.ObjectRegistry.toHashCode(j);var h=m+a+l;var k=qx.lang.Function.listener(this._onNative,this,h);qx.bom.Event.addNativeListener(j,l,k);this._registeredEvents[h]={element:j,type:l,listener:k};},unregisterEvent:function(p,r,o){var s=this._registeredEvents;if(!s){return;};var t=qx.core.ObjectRegistry.toHashCode(p);var n=t+a+r;var q=this._registeredEvents[n];if(q){qx.bom.Event.removeNativeListener(p,r,q.listener);};delete this._registeredEvents[n];},_onNative:qx.event.GlobalError.observeMethod(function(v,u){var w=this._registeredEvents;if(!w){return;};var y=w[u];var x=this.constructor.CANCELABLE[y.type];qx.event.Registration.fireNonBubblingEvent(y.element,y.type,qx.event.type.Native,[v,undefined,undefined,undefined,x]);})},destruct:function(){var z;var A=this._registeredEvents;for(var B in A){z=A[B];qx.bom.Event.removeNativeListener(z.element,z.type,z.listener);};this._manager=this._registeredEvents=null;},defer:function(C){qx.event.Registration.addHandler(C);}});})();(function(){var a="qx.event.handler.UserAction";qx.Class.define(a,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(b){qx.core.Object.call(this);this.__gs=b;this.__cz=b.getWindow();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{useraction:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true},members:{__gs:null,__cz:null,canHandleEvent:function(d,c){},registerEvent:function(g,f,e){},unregisterEvent:function(j,i,h){}},destruct:function(){this.__gs=this.__cz=null;},defer:function(k){qx.event.Registration.addHandler(k);}});})();(function(){var a="dblclick",b="os.name",c="mouseup",d="mousedown",e="useraction",f="webkit",g="contextmenu",h="mousewheel",i="auxclick",j="mouseover",k="mouseout",l="gecko",m="ios",n="click",o="mousemove",p="qx.event.handler.Mouse",q="on",r="engine.name";qx.Class.define(p,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(s){qx.core.Object.call(this);this.__gs=s;this.__cz=s.getWindow();this.__dd=this.__cz.document;this._initButtonObserver();this._initMoveObserver();this._initWheelObserver();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{mousemove:1,mouseover:1,mouseout:1,mousedown:1,mouseup:1,click:1,auxclick:1,dblclick:1,contextmenu:1,mousewheel:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE+qx.event.IEventHandler.TARGET_DOCUMENT+qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true},members:{__hD:null,__hE:null,__hF:null,__hG:null,__hH:null,__gs:null,__cz:null,__dd:null,__hI:null,canHandleEvent:function(u,t){},registerEvent:qx.core.Environment.get(b)===m?function(x,w,v){x[q+w]=(function(){return null;});}:(function(){return null;}),unregisterEvent:qx.core.Environment.get(b)===m?function(A,z,y){A[q+z]=undefined;}:(function(){return null;}),__hJ:function(B,C,D){if(!D){D=qx.bom.Event.getTarget(B);};if(D&&D.nodeType){qx.event.Registration.fireEvent(D,C||B.type,C==h?qx.event.type.MouseWheel:qx.event.type.Mouse,[B,D,null,true,true]);};qx.event.Registration.fireEvent(this.__cz,e,qx.event.type.Data,[C||B.type]);},preventNextClick:function(){this.__hI=true;},_initButtonObserver:function(){this.__hD=qx.lang.Function.listener(this._onButtonEvent,this);var Event=qx.bom.Event;Event.addNativeListener(this.__dd,d,this.__hD);Event.addNativeListener(this.__dd,c,this.__hD);Event.addNativeListener(this.__dd,n,this.__hD);Event.addNativeListener(this.__dd,i,this.__hD);Event.addNativeListener(this.__dd,a,this.__hD);Event.addNativeListener(this.__dd,g,this.__hD);},_initMoveObserver:function(){this.__hE=qx.lang.Function.listener(this._onMoveEvent,this);var Event=qx.bom.Event;Event.addNativeListener(this.__dd,o,this.__hE);Event.addNativeListener(this.__dd,j,this.__hE);Event.addNativeListener(this.__dd,k,this.__hE);},_initWheelObserver:function(){this.__hF=qx.lang.Function.listener(this._onWheelEvent,this);var E=qx.bom.client.Event.getMouseWheel(this.__cz);qx.bom.Event.addNativeListener(E.target,E.type,this.__hF);},_stopButtonObserver:function(){var Event=qx.bom.Event;Event.removeNativeListener(this.__dd,d,this.__hD);Event.removeNativeListener(this.__dd,c,this.__hD);Event.removeNativeListener(this.__dd,n,this.__hD);Event.removeNativeListener(this.__dd,a,this.__hD);Event.removeNativeListener(this.__dd,g,this.__hD);},_stopMoveObserver:function(){var Event=qx.bom.Event;Event.removeNativeListener(this.__dd,o,this.__hE);Event.removeNativeListener(this.__dd,j,this.__hE);Event.removeNativeListener(this.__dd,k,this.__hE);},_stopWheelObserver:function(){var F=qx.bom.client.Event.getMouseWheel(this.__cz);qx.bom.Event.removeNativeListener(F.target,F.type,this.__hF);},_onMoveEvent:qx.event.GlobalError.observeMethod(function(G){this.__hJ(G);}),_onButtonEvent:qx.event.GlobalError.observeMethod(function(J){var I=J.type;var K=qx.bom.Event.getTarget(J);if(I==n&&this.__hI){delete this.__hI;return;};if(qx.core.Environment.get(r)==l||qx.core.Environment.get(r)==f){if(K&&K.nodeType==3){K=K.parentNode;};};var H=qx.event.handler.DragDrop&&this.__gs.getHandler(qx.event.handler.DragDrop).isSessionActive();if(H&&I==n){return;};if(this.__hL){this.__hL(J,I,K);};this.__hJ(J,I,K);if(I==i&&J.button==1){this.__hJ(J,n,K);};if(this.__hK){this.__hK(J,I,K);};if(this.__hM&&!H){this.__hM(J,I,K);};this.__hG=I;}),_onWheelEvent:qx.event.GlobalError.observeMethod(function(L){this.__hJ(L,h);}),__hK:qx.core.Environment.select(r,{"opera":function(M,N,O){if(N==c&&M.button==2){this.__hJ(M,g,O);};},"default":null}),__hL:qx.core.Environment.select(r,{"mshtml":function(P,Q,R){if(P.target!==undefined){return;};if(Q==c&&this.__hG==n){this.__hJ(P,d,R);}else if(Q==a){this.__hJ(P,n,R);};},"default":null}),__hM:qx.core.Environment.select(r,{"mshtml":null,"default":function(T,S,U){switch(S){case d:this.__hH=U;break;case c:if(U!==this.__hH){var V=qx.dom.Hierarchy.getCommonParent(U,this.__hH);if(V){this.__hJ(T,n,V);};};};}})},destruct:function(){this._stopButtonObserver();this._stopMoveObserver();this._stopWheelObserver();this.__gs=this.__cz=this.__dd=this.__hH=null;},defer:function(W){qx.event.Registration.addHandler(W);}});})();(function(){var a="qx.event.type.MouseWheel";qx.Class.define(a,{extend:qx.event.type.Mouse,members:{stop:function(){this.stopPropagation();this.preventDefault();},getWheelDelta:function(b){return qx.util.Wheel.getDelta(this._native,b);}}});})();(function(){var a="qx.dom.Hierarchy",b="previousSibling",c="html.element.contains",d="html.element.compareDocumentPosition",e="nextSibling",f="parentNode",g="*";qx.Bootstrap.define(a,{statics:{getNodeIndex:function(h){var i=0;while(h&&(h=h.previousSibling)){i++ ;};return i;},getElementIndex:function(l){var j=0;var k=qx.dom.Node.ELEMENT;while(l&&(l=l.previousSibling)){if(l.nodeType==k){j++ ;};};return j;},getNextElementSibling:function(m){while(m&&(m=m.nextSibling)&&!qx.dom.Node.isElement(m)){continue;};return m||null;},getPreviousElementSibling:function(n){while(n&&(n=n.previousSibling)&&!qx.dom.Node.isElement(n)){continue;};return n||null;},contains:function(q,p){if(qx.core.Environment.get(c)){if(qx.dom.Node.isDocument(q)){var o=qx.dom.Node.getDocument(p);return q&&o==q;}else if(qx.dom.Node.isDocument(p)){return false;}else {return q.contains(p);};}else if(qx.core.Environment.get(d)){return !!(q.compareDocumentPosition(p)&16);}else {while(p){if(q==p){return true;};p=p.parentNode;};return false;};},isRendered:function(s){var r=s.ownerDocument||s.document;if(qx.core.Environment.get(c)){if(!s.parentNode){return false;};return r.body.contains(s);}else if(qx.core.Environment.get(d)){return !!(r.compareDocumentPosition(s)&16);}else {while(s){if(s==r.body){return true;};s=s.parentNode;};return false;};},isDescendantOf:function(u,t){return this.contains(t,u);},getCommonParent:function(w,x){if(w===x){return w;};if(qx.core.Environment.get(c)){while(w&&qx.dom.Node.isElement(w)){if(w.contains(x)){return w;};w=w.parentNode;};return null;}else {var v=[];while(w||x){if(w){if(qx.lang.Array.contains(v,w)){return w;};v.push(w);w=w.parentNode;};if(x){if(qx.lang.Array.contains(v,x)){return x;};v.push(x);x=x.parentNode;};};return null;};},getAncestors:function(y){return this._recursivelyCollect(y,f);},getChildElements:function(A){A=A.firstChild;if(!A){return [];};var z=this.getNextSiblings(A);if(A.nodeType===1){z.unshift(A);};return z;},getDescendants:function(B){return qx.lang.Array.fromCollection(B.getElementsByTagName(g));},getFirstDescendant:function(C){C=C.firstChild;while(C&&C.nodeType!=1){C=C.nextSibling;};return C;},getLastDescendant:function(D){D=D.lastChild;while(D&&D.nodeType!=1){D=D.previousSibling;};return D;},getPreviousSiblings:function(E){return this._recursivelyCollect(E,b);},getNextSiblings:function(F){return this._recursivelyCollect(F,e);},_recursivelyCollect:function(I,G){var H=[];while(I=I[G]){if(I.nodeType==1){H.push(I);};};return H;},getSiblings:function(J){return this.getPreviousSiblings(J).reverse().concat(this.getNextSiblings(J));},isEmpty:function(K){K=K.firstChild;while(K){if(K.nodeType===qx.dom.Node.ELEMENT||K.nodeType===qx.dom.Node.TEXT){return false;};K=K.nextSibling;};return true;},cleanWhitespace:function(N){var L=N.firstChild;while(L){var M=L.nextSibling;if(L.nodeType==3&&!/\S/.test(L.nodeValue)){N.removeChild(L);};L=M;};}}});})();(function(){var a="mshtml",b="engine.name",c="keypress",d="useraction",e="win",f="text",g="keyinput",h="os.name",i="webkit",j="input",k="gecko",l="off",m="keydown",n="autoComplete",o="keyup",p="qx.event.handler.Keyboard";qx.Class.define(p,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(q){qx.core.Object.call(this);this.__gs=q;this.__cz=q.getWindow();if((qx.core.Environment.get(b)==k)){this.__dd=this.__cz;}else {this.__dd=this.__cz.document.documentElement;};this.__hN={};this._initKeyObserver();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{keyup:1,keydown:1,keypress:1,keyinput:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE,IGNORE_CAN_HANDLE:true},members:{__hO:null,__gs:null,__cz:null,__dd:null,__hN:null,__hP:null,__hQ:null,__hR:null,canHandleEvent:function(s,r){},registerEvent:function(v,u,t){},unregisterEvent:function(y,x,w){},_fireInputEvent:function(A,z){var B=this.__hS();if(B&&B.offsetWidth!=0){var event=qx.event.Registration.createEvent(g,qx.event.type.KeyInput,[A,B,z]);this.__gs.dispatchEvent(B,event);};if(this.__cz){qx.event.Registration.fireEvent(this.__cz,d,qx.event.type.Data,[g]);};},_fireSequenceEvent:function(D,F,C){var E=this.__hS();var G=D.keyCode;var event=qx.event.Registration.createEvent(F,qx.event.type.KeySequence,[D,E,C]);this.__gs.dispatchEvent(E,event);if(qx.core.Environment.get(b)==a||qx.core.Environment.get(b)==i){if(F==m&&event.getDefaultPrevented()){if(!qx.event.util.Keyboard.isNonPrintableKeyCode(G)&&!this._emulateKeyPress[G]){this._fireSequenceEvent(D,c,C);};};};if(this.__cz){qx.event.Registration.fireEvent(this.__cz,d,qx.event.type.Data,[F]);};},__hS:function(){var H=this.__gs.getHandler(qx.event.handler.Focus);var I=H.getActive();if(!I||I.offsetWidth==0){I=H.getFocus();};if(!I||I.offsetWidth==0){I=this.__gs.getWindow().document.body;};return I;},_initKeyObserver:function(){this.__hO=qx.lang.Function.listener(this.__hT,this);this.__hR=qx.lang.Function.listener(this.__hV,this);var Event=qx.bom.Event;Event.addNativeListener(this.__dd,o,this.__hO);Event.addNativeListener(this.__dd,m,this.__hO);Event.addNativeListener(this.__dd,c,this.__hR);},_stopKeyObserver:function(){var Event=qx.bom.Event;Event.removeNativeListener(this.__dd,o,this.__hO);Event.removeNativeListener(this.__dd,m,this.__hO);Event.removeNativeListener(this.__dd,c,this.__hR);for(var K in (this.__hQ||{})){var J=this.__hQ[K];Event.removeNativeListener(J.target,c,J.callback);};delete (this.__hQ);},__hT:qx.event.GlobalError.observeMethod(qx.core.Environment.select(b,{"mshtml":function(N){N=window.event||N;var O=N.keyCode;var M=0;var L=N.type;if(!(this.__hN[O]==m&&L==m)){this._idealKeyHandler(O,M,L,N);};if(L==m){if(qx.event.util.Keyboard.isNonPrintableKeyCode(O)||this._emulateKeyPress[O]){this._idealKeyHandler(O,M,c,N);};};this.__hN[O]=L;},"gecko":function(Q){var S=0;var U=Q.keyCode;var T=Q.type;var R=qx.event.util.Keyboard;if(qx.core.Environment.get(h)==e){var P=U?R.keyCodeToIdentifier(U):R.charCodeToIdentifier(S);if(!(this.__hN[P]==m&&T==m)){this._idealKeyHandler(U,S,T,Q);};this.__hN[P]=T;}else {this._idealKeyHandler(U,S,T,Q);};this.__hU(Q.target,T,U);},"webkit":function(X){var Y=0;var W=0;var V=X.type;Y=X.keyCode;this._idealKeyHandler(Y,W,V,X);if(V==m){if(qx.event.util.Keyboard.isNonPrintableKeyCode(Y)||this._emulateKeyPress[Y]){this._idealKeyHandler(Y,W,c,X);};};this.__hN[Y]=V;},"opera":function(ba){this.__hP=ba.keyCode;this._idealKeyHandler(ba.keyCode,0,ba.type,ba);}})),__hU:qx.core.Environment.select(b,{"gecko":function(bc,be,bf){if(be===m&&(bf==33||bf==34||bf==38||bf==40)&&bc.type==f&&bc.tagName.toLowerCase()===j&&bc.getAttribute(n)!==l){if(!this.__hQ){this.__hQ={};};var bb=qx.core.ObjectRegistry.toHashCode(bc);if(this.__hQ[bb]){return;};var self=this;this.__hQ[bb]={target:bc,callback:function(bg){qx.bom.Event.stopPropagation(bg);self.__hV(bg);}};var bd=qx.event.GlobalError.observeMethod(this.__hQ[bb].callback);qx.bom.Event.addNativeListener(bc,c,bd);};},"default":null}),__hV:qx.event.GlobalError.observeMethod(qx.core.Environment.select(b,{"mshtml":function(bh){bh=window.event||bh;if(this._charCode2KeyCode[bh.keyCode]){this._idealKeyHandler(this._charCode2KeyCode[bh.keyCode],0,bh.type,bh);}else {this._idealKeyHandler(0,bh.keyCode,bh.type,bh);};},"gecko":function(bi){var bj=bi.charCode;var bk=bi.type;this._idealKeyHandler(bi.keyCode,bj,bk,bi);},"webkit":function(bl){if(this._charCode2KeyCode[bl.keyCode]){this._idealKeyHandler(this._charCode2KeyCode[bl.keyCode],0,bl.type,bl);}else {this._idealKeyHandler(0,bl.keyCode,bl.type,bl);};},"opera":function(bm){var bo=bm.keyCode;var bn=bm.type;if(bo!=this.__hP){this._idealKeyHandler(0,this.__hP,bn,bm);}else {if(qx.event.util.Keyboard.keyCodeToIdentifierMap[bm.keyCode]){this._idealKeyHandler(bm.keyCode,0,bm.type,bm);}else {this._idealKeyHandler(0,bm.keyCode,bm.type,bm);};};}})),_idealKeyHandler:function(bs,bq,bt,br){var bp;if(bs||(!bs&&!bq)){bp=qx.event.util.Keyboard.keyCodeToIdentifier(bs);this._fireSequenceEvent(br,bt,bp);}else {bp=qx.event.util.Keyboard.charCodeToIdentifier(bq);this._fireSequenceEvent(br,c,bp);this._fireInputEvent(br,bq);};},_emulateKeyPress:qx.core.Environment.select(b,{"mshtml":{'8':true,'9':true},"webkit":{'8':true,'9':true,'27':true},"default":{}}),_identifierToKeyCode:function(bu){return qx.event.util.Keyboard.identifierToKeyCodeMap[bu]||bu.charCodeAt(0);}},destruct:function(){this._stopKeyObserver();this.__hP=this.__gs=this.__cz=this.__dd=this.__hN=null;},defer:function(bv,bw){qx.event.Registration.addHandler(bv);if((qx.core.Environment.get(b)==a)||qx.core.Environment.get(b)==i){bw._charCode2KeyCode={'13':13,'27':27};};}});})();(function(){var a="qx.event.type.KeyInput";qx.Class.define(a,{extend:qx.event.type.Dom,members:{init:function(c,d,b){qx.event.type.Dom.prototype.init.call(this,c,d,null,true,true);this._charCode=b;return this;},clone:function(e){var f=qx.event.type.Dom.prototype.clone.call(this,e);f._charCode=this._charCode;return f;},getCharCode:function(){return this._charCode;},getChar:function(){return String.fromCharCode(this._charCode);}}});})();(function(){var a="qx.event.type.KeySequence";qx.Class.define(a,{extend:qx.event.type.Dom,members:{init:function(c,d,b){qx.event.type.Dom.prototype.init.call(this,c,d,null,true,true);this._keyCode=c.keyCode;this._identifier=b;return this;},clone:function(e){var f=qx.event.type.Dom.prototype.clone.call(this,e);f._keyCode=this._keyCode;f._identifier=this._identifier;return f;},getKeyIdentifier:function(){return this._identifier;},getKeyCode:function(){return this._keyCode;},isPrintable:function(){return qx.event.util.Keyboard.isPrintableKeyIdentifier(this._identifier);}}});})();(function(){var a="-",b="PageUp",c="Escape",d="Enter",e="+",f="PrintScreen",g="os.name",h="7",i="A",j="Space",k="Left",l="5",m="F5",n="Down",o="Up",p="3",q="Meta",r="F11",s="0",t="F6",u="PageDown",v="osx",w="CapsLock",x="Insert",y="F8",z="Scroll",A="Control",B="Tab",C="Shift",D="End",E="Pause",F="Unidentified",G="/",H="8",I="Z",J="*",K="cmd",L="F1",M="F4",N="Home",O="qx.event.util.Keyboard",P="F2",Q="6",R="F7",S="Apps",T="4",U="F12",V="Alt",W="2",X="NumLock",Y="Delete",bn="1",bo="Win",bp="Backspace",bj="F9",bk="F10",bl="Right",bm="F3",bq="9",br=",";qx.Bootstrap.define(O,{statics:{specialCharCodeMap:{'8':bp,'9':B,'13':d,'27':c,'32':j},numpadToCharCode:{'96':s.charCodeAt(0),'97':bn.charCodeAt(0),'98':W.charCodeAt(0),'99':p.charCodeAt(0),'100':T.charCodeAt(0),'101':l.charCodeAt(0),'102':Q.charCodeAt(0),'103':h.charCodeAt(0),'104':H.charCodeAt(0),'105':bq.charCodeAt(0),'106':J.charCodeAt(0),'107':e.charCodeAt(0),'109':a.charCodeAt(0),'110':br.charCodeAt(0),'111':G.charCodeAt(0)},keyCodeToIdentifierMap:{'16':C,'17':A,'18':V,'20':w,'224':q,'37':k,'38':o,'39':bl,'40':n,'33':b,'34':u,'35':D,'36':N,'45':x,'46':Y,'112':L,'113':P,'114':bm,'115':M,'116':m,'117':t,'118':R,'119':y,'120':bj,'121':bk,'122':r,'123':U,'144':X,'44':f,'145':z,'19':E,'91':qx.core.Environment.get(g)==v?K:bo,'92':bo,'93':qx.core.Environment.get(g)==v?K:S},charCodeA:i.charCodeAt(0),charCodeZ:I.charCodeAt(0),charCode0:s.charCodeAt(0),charCode9:bq.charCodeAt(0),keyCodeToIdentifier:function(bs){if(this.isIdentifiableKeyCode(bs)){var bt=this.numpadToCharCode[bs];if(bt){return String.fromCharCode(bt);};return (this.keyCodeToIdentifierMap[bs]||this.specialCharCodeMap[bs]||String.fromCharCode(bs));}else {return F;};},charCodeToIdentifier:function(bu){return this.specialCharCodeMap[bu]||String.fromCharCode(bu).toUpperCase();},isIdentifiableKeyCode:function(bv){if(bv>=this.charCodeA&&bv<=this.charCodeZ){return true;};if(bv>=this.charCode0&&bv<=this.charCode9){return true;};if(this.specialCharCodeMap[bv]){return true;};if(this.numpadToCharCode[bv]){return true;};if(this.isNonPrintableKeyCode(bv)){return true;};return false;},isNonPrintableKeyCode:function(bw){return this.keyCodeToIdentifierMap[bw]?true:false;},isValidKeyIdentifier:function(bx){if(this.identifierToKeyCodeMap[bx]){return true;};if(bx.length!=1){return false;};if(bx>=s&&bx<=bq){return true;};if(bx>=i&&bx<=I){return true;};switch(bx){case e:case a:case J:case G:case br:return true;default:return false;};},isPrintableKeyIdentifier:function(by){if(by===j){return true;}else {return this.identifierToKeyCodeMap[by]?false:true;};}},defer:function(bz,bA){if(!bz.identifierToKeyCodeMap){bz.identifierToKeyCodeMap={};for(var bB in bz.keyCodeToIdentifierMap){bz.identifierToKeyCodeMap[bz.keyCodeToIdentifierMap[bB]]=parseInt(bB,10);};for(var bB in bz.specialCharCodeMap){bz.identifierToKeyCodeMap[bz.specialCharCodeMap[bB]]=parseInt(bB,10);};};}});})();(function(){var a="selectstart",b="os.name",c="blur",d="mousedown",e="focus",f="os.version",g="qx.event.handler.Focus",h="_applyFocus",i="DOMFocusIn",j="deactivate",k="browser.name",l="textarea",m="_applyActive",n='character',o="input",p="ios",q="",r="qxSelectable",s="tabIndex",t="off",u="on",v="activate",w="focusin",x="mshtml",y="engine.name",z="mouseup",A="DOMFocusOut",B="focusout",C="qxKeepFocus",D="draggesture",E="qxKeepActive";qx.Class.define(g,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(F){qx.core.Object.call(this);this._manager=F;this._window=F.getWindow();this._document=this._window.document;this._root=this._document.documentElement;this._body=this._document.body;if((qx.core.Environment.get(b)==p&&parseFloat(qx.core.Environment.get(f))>6)&&(!qx.application.Inline||!qx.core.Init.getApplication() instanceof qx.application.Inline)){this.__hW=true;};this._initObserver();},properties:{active:{apply:m,nullable:true},focus:{apply:h,nullable:true}},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{focus:1,blur:1,focusin:1,focusout:1,activate:1,deactivate:1},IGNORE_CAN_HANDLE:true,FOCUSABLE_ELEMENTS:qx.core.Environment.select(y,{"mshtml":{a:1,body:1,button:1,frame:1,iframe:1,img:1,input:1,object:1,select:1,textarea:1},"gecko":{a:1,body:1,button:1,frame:1,iframe:1,img:1,input:1,object:1,select:1,textarea:1},"opera":{button:1,input:1,select:1,textarea:1},"webkit":{button:1,input:1,select:1,textarea:1}})},members:{__hX:null,__hY:null,__ia:null,__ib:null,__ic:null,__id:null,__ie:null,__if:null,__ig:null,__ih:null,__ii:q,__ij:q,__hW:false,__ik:null,canHandleEvent:function(H,G){},registerEvent:function(K,J,I){},unregisterEvent:function(N,M,L){},focus:function(O){if((qx.core.Environment.get(y)==x)){window.setTimeout(function(){try{O.focus();var P=qx.bom.Selection.get(O);if(P.length==0){var Q=O.createTextRange();Q.moveStart(n,O.value.length);Q.collapse();Q.select();};}catch(R){};},0);}else {try{O.focus();}catch(S){};};this.setFocus(O);this.setActive(O);},activate:function(T){this.setActive(T);},blur:function(U){try{U.blur();}catch(V){};if(this.getActive()===U){this.resetActive();};if(this.getFocus()===U){this.resetFocus();};},deactivate:function(W){if(this.getActive()===W){this.resetActive();};},tryActivate:function(Y){var X=this.__iy(Y);if(X){this.setActive(X);};},__hJ:function(ba,bc,bf,be){var bd=qx.event.Registration;var bb=bd.createEvent(bf,qx.event.type.Focus,[ba,bc,be]);bd.dispatchEvent(ba,bb);},_windowFocused:true,__il:function(){if(this._windowFocused){this._windowFocused=false;this.__hJ(this._window,null,c,false);};},__im:function(){if(!this._windowFocused){this._windowFocused=true;this.__hJ(this._window,null,e,false);};},_initObserver:qx.core.Environment.select(y,{"gecko":function(){this.__hX=qx.lang.Function.listener(this.__is,this);this.__hY=qx.lang.Function.listener(this.__it,this);this.__ia=qx.lang.Function.listener(this.__ir,this);this.__ib=qx.lang.Function.listener(this.__iq,this);this.__ic=qx.lang.Function.listener(this.__in,this);qx.bom.Event.addNativeListener(this._document,d,this.__hX,true);qx.bom.Event.addNativeListener(this._document,z,this.__hY,true);qx.bom.Event.addNativeListener(this._window,e,this.__ia,true);qx.bom.Event.addNativeListener(this._window,c,this.__ib,true);qx.bom.Event.addNativeListener(this._window,D,this.__ic,true);},"mshtml":function(){this.__hX=qx.lang.Function.listener(this.__is,this);this.__hY=qx.lang.Function.listener(this.__it,this);this.__ie=qx.lang.Function.listener(this.__io,this);this.__if=qx.lang.Function.listener(this.__ip,this);this.__id=qx.lang.Function.listener(this.__iv,this);qx.bom.Event.addNativeListener(this._document,d,this.__hX);qx.bom.Event.addNativeListener(this._document,z,this.__hY);qx.bom.Event.addNativeListener(this._document,w,this.__ie);qx.bom.Event.addNativeListener(this._document,B,this.__if);qx.bom.Event.addNativeListener(this._document,a,this.__id);},"webkit":qx.core.Environment.select(k,{"edge":function(bg){this.__hX=qx.lang.Function.listener(this.__is,this);this.__hY=qx.lang.Function.listener(this.__it,this);this.__if=qx.lang.Function.listener(this.__ip,this);this.__ie=qx.lang.Function.listener(this.__io,this);this.__id=qx.lang.Function.listener(this.__iv,this);qx.bom.Event.addNativeListener(this._document,d,this.__hX,true);qx.bom.Event.addNativeListener(this._document,z,this.__hY,true);qx.bom.Event.addNativeListener(this._document,a,this.__id,false);qx.bom.Event.addNativeListener(this._document,w,this.__ie);qx.bom.Event.addNativeListener(this._document,B,this.__if);},"default":function(bh){this.__hX=qx.lang.Function.listener(this.__is,this);this.__hY=qx.lang.Function.listener(this.__it,this);this.__if=qx.lang.Function.listener(this.__ip,this);this.__ia=qx.lang.Function.listener(this.__ir,this);this.__ib=qx.lang.Function.listener(this.__iq,this);this.__id=qx.lang.Function.listener(this.__iv,this);qx.bom.Event.addNativeListener(this._document,d,this.__hX,true);qx.bom.Event.addNativeListener(this._document,z,this.__hY,true);qx.bom.Event.addNativeListener(this._document,a,this.__id,false);qx.bom.Event.addNativeListener(this._window,A,this.__if,true);qx.bom.Event.addNativeListener(this._window,e,this.__ia,true);qx.bom.Event.addNativeListener(this._window,c,this.__ib,true);}}),"opera":function(){this.__hX=qx.lang.Function.listener(this.__is,this);this.__hY=qx.lang.Function.listener(this.__it,this);this.__ie=qx.lang.Function.listener(this.__io,this);this.__if=qx.lang.Function.listener(this.__ip,this);qx.bom.Event.addNativeListener(this._document,d,this.__hX,true);qx.bom.Event.addNativeListener(this._document,z,this.__hY,true);qx.bom.Event.addNativeListener(this._window,i,this.__ie,true);qx.bom.Event.addNativeListener(this._window,A,this.__if,true);}}),_stopObserver:qx.core.Environment.select(y,{"gecko":function(){qx.bom.Event.removeNativeListener(this._document,d,this.__hX,true);qx.bom.Event.removeNativeListener(this._document,z,this.__hY,true);qx.bom.Event.removeNativeListener(this._window,e,this.__ia,true);qx.bom.Event.removeNativeListener(this._window,c,this.__ib,true);qx.bom.Event.removeNativeListener(this._window,D,this.__ic,true);},"mshtml":function(){qx.bom.Event.removeNativeListener(this._document,d,this.__hX);qx.bom.Event.removeNativeListener(this._document,z,this.__hY);qx.bom.Event.removeNativeListener(this._document,w,this.__ie);qx.bom.Event.removeNativeListener(this._document,B,this.__if);qx.bom.Event.removeNativeListener(this._document,a,this.__id);},"webkit":qx.core.Environment.select(k,{"edge":function(){qx.bom.Event.removeNativeListener(this._document,d,this.__hX);qx.bom.Event.removeNativeListener(this._document,z,this.__hY);qx.bom.Event.removeNativeListener(this._document,w,this.__ie);qx.bom.Event.removeNativeListener(this._document,B,this.__if);qx.bom.Event.removeNativeListener(this._document,a,this.__id);},"default":function(){qx.bom.Event.removeNativeListener(this._document,d,this.__hX,true);qx.bom.Event.removeNativeListener(this._document,z,this.__hY,true);qx.bom.Event.removeNativeListener(this._document,a,this.__id,false);qx.bom.Event.removeNativeListener(this._window,A,this.__if,true);qx.bom.Event.removeNativeListener(this._window,e,this.__ia,true);qx.bom.Event.removeNativeListener(this._window,c,this.__ib,true);}}),"opera":function(){qx.bom.Event.removeNativeListener(this._document,d,this.__hX,true);qx.bom.Event.removeNativeListener(this._document,z,this.__hY,true);qx.bom.Event.removeNativeListener(this._window,i,this.__ie,true);qx.bom.Event.removeNativeListener(this._window,A,this.__if,true);}}),__in:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"gecko":function(bi){var bj=qx.bom.Event.getTarget(bi);if(!this.__iz(bj)){qx.bom.Event.preventDefault(bi);};},"default":null})),__io:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(bl){this.__im();var bm=qx.bom.Event.getTarget(bl);var bk=this.__ix(bm);if(bk){this.setFocus(bk);};this.tryActivate(bm);},"webkit":qx.core.Environment.select(k,{"edge":function(bo){this.__im();var bp=qx.bom.Event.getTarget(bo);var bn=this.__ix(bp);if(bn){this.setFocus(bn);};this.tryActivate(bp);},"default":null}),"opera":function(bq){var br=qx.bom.Event.getTarget(bq);if(br==this._document||br==this._window){this.__im();if(this.__ig){this.setFocus(this.__ig);delete this.__ig;};if(this.__ih){this.setActive(this.__ih);delete this.__ih;};}else {this.setFocus(br);this.tryActivate(br);if(!this.__iz(br)){br.selectionStart=0;br.selectionEnd=0;};};},"default":null})),__ip:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(bs){var bt=qx.bom.Event.getRelatedTarget(bs);if(bt==null){this.__il();this.resetFocus();this.resetActive();};},"webkit":qx.core.Environment.select(k,{"edge":function(bu){var bv=qx.bom.Event.getRelatedTarget(bu);if(bv==null){this.__il();this.resetFocus();this.resetActive();};},"default":function(bw){var bx=qx.bom.Event.getTarget(bw);if(bx===this.getFocus()){this.resetFocus();};if(bx===this.getActive()){this.resetActive();};}}),"opera":function(by){var bz=qx.bom.Event.getTarget(by);if(bz==this._document){this.__il();this.__ig=this.getFocus();this.__ih=this.getActive();this.resetFocus();this.resetActive();}else {if(bz===this.getFocus()){this.resetFocus();};if(bz===this.getActive()){this.resetActive();};};},"default":null})),__iq:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"gecko":function(bA){var bB=qx.bom.Event.getTarget(bA);if(bB===this._window||bB===this._document){this.__il();this.resetActive();this.resetFocus();};},"webkit":function(bC){var bD=qx.bom.Event.getTarget(bC);if(bD===this._window||bD===this._document){this.__il();this.__ig=this.getFocus();this.__ih=this.getActive();this.resetActive();this.resetFocus();};},"default":null})),__ir:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"gecko":function(bE){var bF=qx.bom.Event.getTarget(bE);if(bF===this._window||bF===this._document){this.__im();bF=this._body;};this.setFocus(bF);this.tryActivate(bF);},"webkit":function(bG){var bH=qx.bom.Event.getTarget(bG);if(bH===this._window||bH===this._document){this.__im();if(this.__ig){this.setFocus(this.__ig);delete this.__ig;};if(this.__ih){this.setActive(this.__ih);delete this.__ih;};}else {this.__ik=bG.relatedTarget;this.setFocus(bH);this.__ik=null;this.tryActivate(bH);};},"default":null})),__is:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(bJ){var bK=qx.bom.Event.getTarget(bJ);var bI=this.__ix(bK);if(bI){if(!this.__iz(bK)){bK.unselectable=u;try{document.selection.empty();}catch(bL){};try{bI.focus();}catch(bM){};};}else {qx.bom.Event.preventDefault(bJ);if(!this.__iz(bK)){bK.unselectable=u;};};},"webkit":function(bO){var bP=qx.bom.Event.getTarget(bO);var bN=this.__ix(bP);if(bN){this.setFocus(bN);}else {qx.bom.Event.preventDefault(bO);};},"gecko":function(bR){var bS=qx.bom.Event.getTarget(bR);var bQ=this.__ix(bS);if(bQ){this.setFocus(bQ);}else {qx.bom.Event.preventDefault(bR);};},"opera":function(bV){var bW=qx.bom.Event.getTarget(bV);var bT=this.__ix(bW);if(!this.__iz(bW)){qx.bom.Event.preventDefault(bV);if(bT){var bU=this.getFocus();if(bU&&bU.selectionEnd){bU.selectionStart=0;bU.selectionEnd=0;bU.blur();};if(bT){this.setFocus(bT);};};}else if(bT){this.setFocus(bT);};},"default":null})),__it:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(bX){var bY=qx.bom.Event.getTarget(bX);if(bY.unselectable){bY.unselectable=t;};this.tryActivate(this.__iu(bY));},"gecko":function(ca){var cb=qx.bom.Event.getTarget(ca);while(cb&&cb.offsetWidth===undefined){cb=cb.parentNode;};if(cb){this.tryActivate(cb);};},"webkit":function(cc){var cd=qx.bom.Event.getTarget(cc);this.tryActivate(this.__iu(cd));},"opera":function(ce){var cf=qx.bom.Event.getTarget(ce);this.tryActivate(this.__iu(cf));},"default":null})),__iu:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(cg){var ch=this.getFocus();if(ch&&cg!=ch&&(ch.nodeName.toLowerCase()===o||ch.nodeName.toLowerCase()===l)){cg=ch;};return cg;},"webkit":function(ci){var cj=this.getFocus();if(cj&&ci!=cj&&(cj.nodeName.toLowerCase()===o||cj.nodeName.toLowerCase()===l)){ci=cj;};return ci;},"default":function(ck){return ck;}})),__iv:qx.event.GlobalError.observeMethod(qx.core.Environment.select(y,{"mshtml":function(cl){var cm=qx.bom.Event.getTarget(cl);if(!this.__iz(cm)){qx.bom.Event.preventDefault(cl);};},"webkit":function(cn){var co=qx.bom.Event.getTarget(cn);if(!this.__iz(co)){qx.bom.Event.preventDefault(cn);};},"default":null})),__iw:function(cp){var cq=qx.bom.element.Attribute.get(cp,s);if(cq>=1){return true;};var cr=qx.event.handler.Focus.FOCUSABLE_ELEMENTS;if(cq>=0&&cr[cp.tagName]){return true;};return false;},__ix:function(cs){while(cs&&cs.nodeType===1){if(cs.getAttribute(C)==u){return null;};if(this.__iw(cs)){return cs;};cs=cs.parentNode;};return this._body;},__iy:function(ct){var cu=ct;while(ct&&ct.nodeType===1){if(ct.getAttribute(E)==u){return null;};ct=ct.parentNode;};return cu;},__iz:function(cv){while(cv&&cv.nodeType===1){var cw=cv.getAttribute(r);if(cw!=null){return cw===u;};cv=cv.parentNode;};return true;},_applyActive:function(cy,cx){if(cx){this.__hJ(cx,cy,j,true);};if(cy){this.__hJ(cy,cx,v,true);};if(this.__hW){window.scrollTo(0,0);};},_applyFocus:function(cA,cz){if(cz){this.__hJ(cz,cA,B,true);};if(cA){this.__hJ(cA,cz,w,true);};if(cz){this.__hJ(cz,cA,c,false);};if(cA){this.__hJ(cA,cz||this.__ik,e,false);};}},destruct:function(){this._stopObserver();this._manager=this._window=this._document=this._root=this._body=this.__iA=this.__ik=null;},defer:function(cC){qx.event.Registration.addHandler(cC);var cD=cC.FOCUSABLE_ELEMENTS;for(var cB in cD){cD[cB.toUpperCase()]=1;};}});})();(function(){var a="engine.name",b="qx.bom.Selection",c="character",d="button",e='character',f="#text",g="webkit",h="input",i="gecko",j="EndToEnd",k="opera",l="StartToStart",m="html.selection",n="textarea",o="body";qx.Bootstrap.define(b,{statics:{getSelectionObject:qx.core.Environment.select(m,{"selection":function(p){return p.selection;},"default":function(q){return qx.dom.Node.getWindow(q).getSelection();}}),get:qx.core.Environment.select(m,{"selection":function(r){var s=qx.bom.Range.get(qx.dom.Node.getDocument(r));return s.text;},"default":function(t){if(this.__iB(t)){return t.value.substring(t.selectionStart,t.selectionEnd);}else {return this.getSelectionObject(qx.dom.Node.getDocument(t)).toString();};}}),getLength:qx.core.Environment.select(m,{"selection":function(u){var w=this.get(u);var v=qx.util.StringSplit.split(w,/\r\n/);return w.length-(v.length-1);},"default":function(x){if(qx.core.Environment.get(a)==k){var B,C,A;if(this.__iB(x)){var z=x.selectionStart;var y=x.selectionEnd;B=x.value.substring(z,y);C=y-z;}else {B=qx.bom.Selection.get(x);C=B.length;};A=qx.util.StringSplit.split(B,/\r\n/);return C-(A.length-1);};if(this.__iB(x)){return x.selectionEnd-x.selectionStart;}else {return this.get(x).length;};}}),getStart:qx.core.Environment.select(m,{"selection":function(D){if(this.__iB(D)){var I=qx.bom.Range.get();if(!D.contains(I.parentElement())){return -1;};var J=qx.bom.Range.get(D);var H=D.value.length;J.moveToBookmark(I.getBookmark());J.moveEnd(e,H);return H-J.text.length;}else {var J=qx.bom.Range.get(D);var F=J.parentElement();var K=qx.bom.Range.get();try{K.moveToElementText(F);}catch(M){return 0;};var E=qx.bom.Range.get(qx.dom.Node.getBodyElement(D));E.setEndPoint(l,J);E.setEndPoint(j,K);if(K.compareEndPoints(l,E)==0){return 0;};var G;var L=0;while(true){G=E.moveStart(c,-1);if(K.compareEndPoints(l,E)==0){break;};if(G==0){break;}else {L++ ;};};return  ++L;};},"default":function(N){if(qx.core.Environment.get(a)===i||qx.core.Environment.get(a)===g){if(this.__iB(N)){return N.selectionStart;}else {var P=qx.dom.Node.getDocument(N);var O=this.getSelectionObject(P);if(O.anchorOffset<O.focusOffset){return O.anchorOffset;}else {return O.focusOffset;};};};if(this.__iB(N)){return N.selectionStart;}else {return qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(N)).anchorOffset;};}}),getEnd:qx.core.Environment.select(m,{"selection":function(Q){if(this.__iB(Q)){var V=qx.bom.Range.get();if(!Q.contains(V.parentElement())){return -1;};var W=qx.bom.Range.get(Q);var U=Q.value.length;W.moveToBookmark(V.getBookmark());W.moveStart(e,-U);return W.text.length;}else {var W=qx.bom.Range.get(Q);var S=W.parentElement();var X=qx.bom.Range.get();try{X.moveToElementText(S);}catch(ba){return 0;};var U=X.text.length;var R=qx.bom.Range.get(qx.dom.Node.getBodyElement(Q));R.setEndPoint(j,W);R.setEndPoint(l,X);if(X.compareEndPoints(j,R)==0){return U-1;};var T;var Y=0;while(true){T=R.moveEnd(c,1);if(X.compareEndPoints(j,R)==0){break;};if(T==0){break;}else {Y++ ;};};return U-( ++Y);};},"default":function(bb){if(qx.core.Environment.get(a)===i||qx.core.Environment.get(a)===g){if(this.__iB(bb)){return bb.selectionEnd;}else {var bd=qx.dom.Node.getDocument(bb);var bc=this.getSelectionObject(bd);if(bc.focusOffset>bc.anchorOffset){return bc.focusOffset;}else {return bc.anchorOffset;};};};if(this.__iB(bb)){return bb.selectionEnd;}else {return qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(bb)).focusOffset;};}}),__iB:function(be){return qx.dom.Node.isElement(be)&&(be.nodeName.toLowerCase()==h||be.nodeName.toLowerCase()==n);},set:qx.core.Environment.select(m,{"selection":function(bf,bi,bh){var bg;if(qx.dom.Node.isDocument(bf)){bf=bf.body;};if(qx.dom.Node.isElement(bf)||qx.dom.Node.isText(bf)){switch(bf.nodeName.toLowerCase()){case h:case n:case d:if(bh===undefined){bh=bf.value.length;};if(bi>=0&&bi<=bf.value.length&&bh>=0&&bh<=bf.value.length){bg=qx.bom.Range.get(bf);bg.collapse(true);bg.moveStart(c,bi);bg.moveEnd(c,bh-bi);bg.select();return true;};break;case f:if(bh===undefined){bh=bf.nodeValue.length;};if(bi>=0&&bi<=bf.nodeValue.length&&bh>=0&&bh<=bf.nodeValue.length){bg=qx.bom.Range.get(qx.dom.Node.getBodyElement(bf));bg.moveToElementText(bf.parentNode);bg.collapse(true);bg.moveStart(c,bi);bg.moveEnd(c,bh-bi);bg.select();return true;};break;default:if(bh===undefined){bh=bf.childNodes.length-1;};if(bf.childNodes[bi]&&bf.childNodes[bh]){bg=qx.bom.Range.get(qx.dom.Node.getBodyElement(bf));bg.moveToElementText(bf.childNodes[bi]);bg.collapse(true);var bj=qx.bom.Range.get(qx.dom.Node.getBodyElement(bf));bj.moveToElementText(bf.childNodes[bh]);bg.setEndPoint(j,bj);bg.select();return true;};};};return false;},"default":function(bk,bp,bm){var bn=bk.nodeName.toLowerCase();if(qx.dom.Node.isElement(bk)&&(bn==h||bn==n)){if(bm===undefined){bm=bk.value.length;};if(bp>=0&&bp<=bk.value.length&&bm>=0&&bm<=bk.value.length){bk.focus();bk.select();bk.setSelectionRange(bp,bm);return true;};}else {var bq=false;var bl=qx.dom.Node.getWindow(bk).getSelection();var bo=qx.bom.Range.get(bk);if(qx.dom.Node.isText(bk)){if(bm===undefined){bm=bk.length;};if(bp>=0&&bp<bk.length&&bm>=0&&bm<=bk.length){bq=true;};}else if(qx.dom.Node.isElement(bk)){if(bm===undefined){bm=bk.childNodes.length-1;};if(bp>=0&&bk.childNodes[bp]&&bm>=0&&bk.childNodes[bm]){bq=true;};}else if(qx.dom.Node.isDocument(bk)){bk=bk.body;if(bm===undefined){bm=bk.childNodes.length-1;};if(bp>=0&&bk.childNodes[bp]&&bm>=0&&bk.childNodes[bm]){bq=true;};};if(bq){if(!bl.isCollapsed){bl.collapseToStart();};bo.setStart(bk,bp);if(qx.dom.Node.isText(bk)){bo.setEnd(bk,bm);}else {bo.setEndAfter(bk.childNodes[bm]);};if(bl.rangeCount>0){bl.removeAllRanges();};bl.addRange(bo);return true;};};return false;}}),setAll:function(br){return qx.bom.Selection.set(br,0);},clear:qx.core.Environment.select(m,{"selection":function(bs){var bu=qx.bom.Range.get(bs);var parent=bu.parentElement();var bv=qx.bom.Range.get(qx.dom.Node.getDocument(bs));if(qx.dom.Node.isText(bs)){bs=bs.parentNode;};if(parent==bv.parentElement()&&parent==bs){var bt=qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(bs));bt.empty();};},"default":function(bw){var bB=qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(bw));var bx=bw.nodeName.toLowerCase();if(qx.dom.Node.isElement(bw)&&(bx==h||bx==n)){bw.setSelectionRange(0,0);if(qx.bom.Element&&qx.bom.Element.blur){qx.bom.Element.blur(bw);};}else if(qx.dom.Node.isDocument(bw)||bx==o){bB.collapse(bw.body?bw.body:bw,0);}else {var by=qx.bom.Range.get(bw);if(!by.collapsed){var bz;var bA=by.commonAncestorContainer;if(qx.dom.Node.isElement(bw)&&qx.dom.Node.isText(bA)){bz=bA.parentNode;}else {bz=bA;};if(bz==bw){bB.collapse(bw,0);};};};}})}});})();(function(){var a="qx.bom.Range",b="text",c="password",d="file",e="submit",f="reset",g="textarea",h="input",i="hidden",j="html.selection",k="button",l="body";qx.Bootstrap.define(a,{statics:{get:qx.core.Environment.select(j,{"selection":function(m){if(qx.dom.Node.isElement(m)){switch(m.nodeName.toLowerCase()){case h:switch(m.type){case b:case c:case i:case k:case f:case d:case e:return m.createTextRange();default:return qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(m)).createRange();};break;case g:case l:case k:return m.createTextRange();default:return qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(m)).createRange();};}else {if(m==null){m=window;};return qx.bom.Selection.getSelectionObject(qx.dom.Node.getDocument(m)).createRange();};},"default":function(n){var o=qx.dom.Node.getDocument(n);var p=qx.bom.Selection.getSelectionObject(o);if(p.rangeCount>0){return p.getRangeAt(0);}else {return o.createRange();};}})}});})();(function(){var a="m",b="g",c="^",d="",e="qx.util.StringSplit",f="i",g="$(?!\\s)",h="[object RegExp]",j="y";qx.Bootstrap.define(e,{statics:{split:function(k,p,o){if(Object.prototype.toString.call(p)!==h){return String.prototype.split.call(k,p,o);};var r=[],l=0,m=(p.ignoreCase?f:d)+(p.multiline?a:d)+(p.sticky?j:d),p=RegExp(p.source,m+b),n,t,q,u,s=/()??/.exec(d)[1]===undefined;k=k+d;if(!s){n=RegExp(c+p.source+g,m);};if(o===undefined||+o<0){o=Infinity;}else {o=Math.floor(+o);if(!o){return [];};};while(t=p.exec(k)){q=t.index+t[0].length;if(q>l){r.push(k.slice(l,t.index));if(!s&&t.length>1){t[0].replace(n,function(){for(var i=1;i<arguments.length-2;i++ ){if(arguments[i]===undefined){t[i]=undefined;};};});};if(t.length>1&&t.index<k.length){Array.prototype.push.apply(r,t.slice(1));};u=t[0].length;l=q;if(r.length>=o){break;};};if(p.lastIndex===t.index){p.lastIndex++ ;};};if(l===k.length){if(u||!p.test(d)){r.push(d);};}else {r.push(k.slice(l));};return r.length>o?r.slice(0,o):r;}}});})();(function(){var a="qx.event.type.Focus";qx.Class.define(a,{extend:qx.event.type.Event,members:{init:function(d,b,c){qx.event.type.Event.prototype.init.call(this,c,false);this._target=d;this._relatedTarget=b;return this;}}});})();(function(){var a="touchmove",b="os.name",c="MSPointerDown",d="android",e="engine.version",f="pointercancel",g="qx.event.handler.TouchCore",h="event.mspointer",j="MSPointerCancel",k="y",l="browser.documentmode",m="pointer-events",n="pointerup",o="touchend",p="pointerdown",q="MSPointerUp",r="right",s="mshtml",t="engine.name",u="undefined",v="touchcancel",w="MSPointerMove",z="webkit",A="none",B="left",C="pointermove",D="down",E="x",F="up",G="touchstart";qx.Bootstrap.define(g,{extend:Object,statics:{TAP_MAX_DISTANCE:qx.core.Environment.get(b)!=d?10:40,SWIPE_DIRECTION:{x:[B,r],y:[F,D]},SWIPE_MIN_DISTANCE:qx.core.Environment.get(b)!=d?11:41,SWIPE_MIN_VELOCITY:0,LONGTAP_TIME:500},construct:function(H,I){this.__iC=H;this.__fA=I;this._initTouchObserver();this.__iD=[];this.__iE={};},members:{__iC:null,__fA:null,__iF:null,__iG:null,__iE:null,__iH:null,__iI:null,__iJ:null,__iD:null,__iK:null,_initTouchObserver:function(){this.__iF=qx.lang.Function.listener(this._onTouchEvent,this);this.__iK=[G,a,o,v];if(qx.core.Environment.get(h)){var J=parseInt(qx.core.Environment.get(e),10);if(J==10){this.__iK=[c,w,q,j];}else {this.__iK=[p,C,n,f];};};for(var i=0;i<this.__iK.length;i++ ){qx.bom.Event.addNativeListener(this.__iC,this.__iK[i],this.__iF);};},_stopTouchObserver:function(){for(var i=0;i<this.__iK.length;i++ ){qx.bom.Event.removeNativeListener(this.__iC,this.__iK[i],this.__iF);};},_onTouchEvent:function(K){this._commonTouchEventHandler(K);},_getScalingDistance:function(M,L){return (Math.sqrt(Math.pow(M.pageX-L.pageX,2)+Math.pow(M.pageY-L.pageY,2)));},_getRotationAngle:function(O,N){var x=O.pageX-N.pageX;var y=O.pageY-N.pageY;return (Math.atan2(y,x)*180/Math.PI);},_calcTouchesDelta:function(P){var Q=[];for(var i=0;i<P.length;i++ ){Q.push(this._calcSingleTouchDelta(P[i]));};return Q;},_calcSingleTouchDelta:function(U){if(this.__iE.hasOwnProperty(U.identifier)){var T=this.__iE[U.identifier];var R=Math.floor(U.clientX-T[0]);var S=Math.floor(U.clientY-T[1]);var V=E;if(Math.abs(R/S)<1){V=k;};return {"x":R,"y":S,"axis":V,"identifier":U.identifier};}else {return {"x":0,"y":0,"axis":null,"identifier":U.identifier};};},_commonTouchEventHandler:function(X,bc){var bc=bc||X.type;if(qx.core.Environment.get(h)){bc=this._mapPointerEvent(bc);var W=this._detectTouchesByPointer(X,bc);X.changedTouches=W;X.targetTouches=W;X.touches=W;};X.delta=[];if(bc==G){this.__iG=this._getTarget(X);if(X.touches&&X.touches.length>1){this.__iI=this._getScalingDistance(X.touches[0],X.touches[1]);this.__iJ=this._getRotationAngle(X.touches[0],X.touches[1]);};for(var i=0;i<X.changedTouches.length;i++ ){var bb=X.changedTouches[i];this.__iE[bb.identifier]=[bb.clientX,bb.clientY];};};if(bc==a){if(typeof X.scale==u&&X.targetTouches.length>1){var Y=this._getScalingDistance(X.targetTouches[0],X.targetTouches[1]);X.scale=Y/this.__iI;};if((typeof X.rotation==u||qx.core.Environment.get(h))&&X.targetTouches.length>1){var ba=this._getRotationAngle(X.targetTouches[0],X.targetTouches[1]);X._rotation=ba-this.__iJ;};X.delta=this._calcTouchesDelta(X.targetTouches);};this._fireEvent(X,bc,this.__iG);if(qx.core.Environment.get(h)){if(bc==o||bc==v){delete this.__iD[X.pointerId];};};if((bc==o||bc==v)&&X.changedTouches[0]){delete this.__iE[X.changedTouches[0].identifier];};},_detectTouchesByPointer:function(bf,bh){var be=[];if(bh==G){this.__iD[bf.pointerId]=bf;}else if(bh==a){this.__iD[bf.pointerId]=bf;};for(var bg in this.__iD){var bd=this.__iD[bg];be.push(bd);};return be;},_mapPointerEvent:function(bi){bi=bi.toLowerCase();if(bi.indexOf(p)!==-1){return G;}else if(bi.indexOf(n)!==-1){return o;}else if(bi.indexOf(C)!==-1){return a;}else if(bi.indexOf(f)!==-1){return v;};return bi;},_getTarget:function(bk){var bl=qx.bom.Event.getTarget(bk);if(qx.core.Environment.get(t)==z){if(bl&&bl.nodeType==3){bl=bl.parentNode;};}else if(qx.core.Environment.get(t)==s&&qx.core.Environment.get(l)<11){var bj=this.__iL(bk);if(bj){bl=bj;};};return bl;},__iL:function(bo){var bm=null;var bn=null;if(bo&&bo.touches&&bo.touches.length!==0){bm=bo.touches[0].clientX;bn=bo.touches[0].clientY;};var bq=document.msElementsFromPoint(bm,bn);if(bq){for(var i=0;i<bq.length;i++ ){var br=bq[i];var bp=qx.bom.element.Style.get(br,m,3);if(bp!=A){return br;};};};return null;},_fireEvent:function(bs,bt,bu){if(!bu){bu=this._getTarget(bs);};var bt=bt||bs.type;if(bu&&bu.nodeType&&this.__fA){this.__fA.emit(bt,bs);};},dispose:function(){this._stopTouchObserver();this.__iG=this.__iC=this.__iK=this.__iD=this.__fA=this.__iI=this.__iJ=null;}}});})();(function(){var a="resize",b="os.name",c="qx.event.handler.Orientation",d="landscape",e="android",f="portrait",g="orientationchange";qx.Class.define(c,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(h){qx.core.Object.call(this);this.__gs=h;this.__cz=h.getWindow();this._initObserver();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{orientationchange:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true},members:{__gs:null,__cz:null,__iM:null,_currentOrientation:null,__iN:null,canHandleEvent:function(j,i){},registerEvent:function(m,l,k){},unregisterEvent:function(p,o,n){},_initObserver:function(){this.__iN=qx.lang.Function.listener(this._onNative,this);this.__iM=qx.bom.Event.supportsEvent(this.__cz,g)?g:a;var Event=qx.bom.Event;Event.addNativeListener(this.__cz,this.__iM,this.__iN);},_stopObserver:function(){var Event=qx.bom.Event;Event.removeNativeListener(this.__cz,this.__iM,this.__iN);},_onNative:qx.event.GlobalError.observeMethod(function(q){var r=0;if(qx.core.Environment.get(b)==e){r=300;};qx.lang.Function.delay(this._onOrientationChange,r,this,q);}),_onOrientationChange:function(s){var u=qx.bom.Viewport;var t=u.getOrientation(s.target);if(this._currentOrientation!=t){this._currentOrientation=t;var v=u.isLandscape(s.target)?d:f;qx.event.Registration.fireEvent(this.__cz,g,qx.event.type.Orientation,[t,v]);};}},destruct:function(){this._stopObserver();this.__gs=this.__cz=null;},defer:function(w){qx.event.Registration.addHandler(w);}});})();(function(){var a="landscape",b="qx.event.type.Orientation",c="portrait";qx.Class.define(b,{extend:qx.event.type.Event,members:{__iO:null,__iP:null,init:function(d,e){qx.event.type.Event.prototype.init.call(this,false,false);this.__iO=d;this.__iP=e;return this;},clone:function(f){var g=qx.event.type.Event.prototype.clone.call(this,f);g.__iO=this.__iO;g.__iP=this.__iP;return g;},getOrientation:function(){return this.__iO;},isLandscape:function(){return this.__iP==a;},isPortrait:function(){return this.__iP==c;}}});})();(function(){var a="touchmove",b="dispose",c="useraction",d="touchend",e="event.touch",f="touchstart",g="qx.event.handler.Touch";qx.Class.define(g,{extend:qx.event.handler.TouchCore,implement:qx.event.IEventHandler,construct:function(h){this.__gs=h;this.__cz=h.getWindow();this.__dd=this.__cz.document;qx.event.handler.TouchCore.apply(this,[this.__dd]);},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{touchstart:1,touchmove:1,touchend:1,touchcancel:1,tap:1,longtap:1,swipe:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE+qx.event.IEventHandler.TARGET_DOCUMENT,IGNORE_CAN_HANDLE:true,MOUSE_TO_TOUCH_MAPPING:{"mousedown":f,"mousemove":a,"mouseup":d}},members:{__gs:null,__cz:null,__dd:null,__iQ:false,canHandleEvent:function(j,i){},registerEvent:function(m,l,k){},unregisterEvent:function(p,o,n){},_fireEvent:function(r,q,s,t){if(!s){s=this._getTarget(r);};var q=q||r.type;if(s&&s.nodeType){qx.event.Registration.fireEvent(s,q,t||qx.event.type.Touch,[r,s,null,true,true]);};qx.event.Registration.fireEvent(this.__cz,c,qx.event.type.Data,[q]);},_onTouchEvent:qx.event.GlobalError.observeMethod(function(u){this._commonTouchEventHandler(u);}),dispose:function(){this.__hg(b);this.__gs=this.__cz=this.__dd=null;},__hg:function(w,v){qx.event.handler.TouchCore.prototype[w].apply(this,v||[]);}},defer:function(x){qx.event.Registration.addHandler(x);if(qx.core.Environment.get(e)){qx.event.Registration.getManager(document).getHandler(x);};}});})();(function(){var a="touchcancel",b="qx.event.type.Touch",c="touchend",d="undefined";qx.Class.define(b,{extend:qx.event.type.Dom,members:{_cloneNativeEvent:function(e,f){var f=qx.event.type.Dom.prototype._cloneNativeEvent.call(this,e,f);f.pageX=e.pageX;f.pageY=e.pageY;f.offsetX=e.offsetX;f.offsetY=e.offsetY;f.layerX=(e.offsetX||e.layerX);f.layerY=(e.offsetY||e.layerY);f.scale=e.scale;f.rotation=e.rotation;f._rotation=e._rotation;f.delta=e.delta;f.srcElement=e.srcElement;f.targetTouches=[];for(var i=0;i<e.targetTouches.length;i++ ){f.targetTouches[i]=e.targetTouches[i];};f.changedTouches=[];for(i=0;i<e.changedTouches.length;i++ ){f.changedTouches[i]=e.changedTouches[i];};f.touches=[];for(i=0;i<e.touches.length;i++ ){f.touches[i]=e.touches[i];};return f;},stop:function(){this.stopPropagation();},getAllTouches:function(){return this._native.touches;},getTargetTouches:function(){return this._native.targetTouches;},getChangedTargetTouches:function(){return this._native.changedTouches;},isMultiTouch:function(){return this.__iS().length>1;},getScale:function(){return this._native.scale;},getRotation:function(){if(typeof this._native._rotation===d){return this._native.rotation;}else {return this._native._rotation;};},getDelta:function(){return this._native.delta;},getDocumentLeft:function(g){return this.__iR(g).pageX;},getDocumentTop:function(h){return this.__iR(h).pageY;},getScreenLeft:function(j){return this.__iR(j).screenX;},getScreenTop:function(k){return this.__iR(k).screenY;},getViewportLeft:function(l){return this.__iR(l).clientX;},getViewportTop:function(m){return this.__iR(m).clientY;},getIdentifier:function(n){return this.__iR(n).identifier;},__iR:function(o){o=o==null?0:o;return this.__iS()[o];},__iS:function(){var p=(this._isTouchEnd()?this.getChangedTargetTouches():this.getTargetTouches());return p;},_isTouchEnd:function(){return (this.getType()==c||this.getType()==a);}}});})();(function(){var a="text",b="engine.version",c="keydown",d="radio",f="textarea",g="password",h="propertychange",j="select-multiple",k="change",m="input",n="value",p="select",q="browser.documentmode",r="browser.version",s="opera",t="keyup",u="mshtml",v="engine.name",w="keypress",x="checkbox",y="qx.event.handler.Input",z="checked";qx.Class.define(y,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(){qx.core.Object.call(this);this._onChangeCheckedWrapper=qx.lang.Function.listener(this._onChangeChecked,this);this._onChangeValueWrapper=qx.lang.Function.listener(this._onChangeValue,this);this._onInputWrapper=qx.lang.Function.listener(this._onInput,this);this._onPropertyWrapper=qx.lang.Function.listener(this._onProperty,this);if((qx.core.Environment.get(v)==s)){this._onKeyDownWrapper=qx.lang.Function.listener(this._onKeyDown,this);this._onKeyUpWrapper=qx.lang.Function.listener(this._onKeyUp,this);};},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{input:1,change:1},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE,IGNORE_CAN_HANDLE:false},members:{__iT:false,__iU:null,__iV:null,__iW:null,canHandleEvent:function(C,B){var A=C.tagName.toLowerCase();if(B===m&&(A===m||A===f)){return true;};if(B===k&&(A===m||A===f||A===p)){return true;};return false;},registerEvent:function(H,G,E){if(qx.core.Environment.get(v)==u&&(qx.core.Environment.get(b)<9||(qx.core.Environment.get(b)>=9&&qx.core.Environment.get(q)<9))){if(!H.__iX){var F=H.tagName.toLowerCase();var D=H.type;if(D===a||D===g||F===f||D===x||D===d){qx.bom.Event.addNativeListener(H,h,this._onPropertyWrapper);};if(D!==x&&D!==d){qx.bom.Event.addNativeListener(H,k,this._onChangeValueWrapper);};if(D===a||D===g){this._onKeyPressWrapped=qx.lang.Function.listener(this._onKeyPress,this,H);qx.bom.Event.addNativeListener(H,w,this._onKeyPressWrapped);};H.__iX=true;};}else {if(G===m){this.__iY(H);}else if(G===k){if(H.type===d||H.type===x){qx.bom.Event.addNativeListener(H,k,this._onChangeCheckedWrapper);}else {qx.bom.Event.addNativeListener(H,k,this._onChangeValueWrapper);};if((qx.core.Environment.get(v)==s)||(qx.core.Environment.get(v)==u)){if(H.type===a||H.type===g){this._onKeyPressWrapped=qx.lang.Function.listener(this._onKeyPress,this,H);qx.bom.Event.addNativeListener(H,w,this._onKeyPressWrapped);};};};};},__iY:qx.core.Environment.select(v,{"mshtml":function(I){if(qx.core.Environment.get(b)>=9&&qx.core.Environment.get(q)>=9){qx.bom.Event.addNativeListener(I,m,this._onInputWrapper);if(I.type===a||I.type===g||I.type===f){this._inputFixWrapper=qx.lang.Function.listener(this._inputFix,this,I);qx.bom.Event.addNativeListener(I,t,this._inputFixWrapper);};};},"webkit":function(K){var J=K.tagName.toLowerCase();if(parseFloat(qx.core.Environment.get(b))<532&&J==f){qx.bom.Event.addNativeListener(K,w,this._onInputWrapper);};qx.bom.Event.addNativeListener(K,m,this._onInputWrapper);},"opera":function(L){qx.bom.Event.addNativeListener(L,t,this._onKeyUpWrapper);qx.bom.Event.addNativeListener(L,c,this._onKeyDownWrapper);qx.bom.Event.addNativeListener(L,m,this._onInputWrapper);},"default":function(M){qx.bom.Event.addNativeListener(M,m,this._onInputWrapper);}}),unregisterEvent:function(Q,P){if(qx.core.Environment.get(v)==u&&qx.core.Environment.get(b)<9&&qx.core.Environment.get(q)<9){if(Q.__iX){var O=Q.tagName.toLowerCase();var N=Q.type;if(N===a||N===g||O===f||N===x||N===d){qx.bom.Event.removeNativeListener(Q,h,this._onPropertyWrapper);};if(N!==x&&N!==d){qx.bom.Event.removeNativeListener(Q,k,this._onChangeValueWrapper);};if(N===a||N===g){qx.bom.Event.removeNativeListener(Q,w,this._onKeyPressWrapped);};try{delete Q.__iX;}catch(R){Q.__iX=null;};};}else {if(P===m){this.__ja(Q);}else if(P===k){if(Q.type===d||Q.type===x){qx.bom.Event.removeNativeListener(Q,k,this._onChangeCheckedWrapper);}else {qx.bom.Event.removeNativeListener(Q,k,this._onChangeValueWrapper);};};if((qx.core.Environment.get(v)==s)||(qx.core.Environment.get(v)==u)){if(Q.type===a||Q.type===g){qx.bom.Event.removeNativeListener(Q,w,this._onKeyPressWrapped);};};};},__ja:qx.core.Environment.select(v,{"mshtml":function(S){if(qx.core.Environment.get(b)>=9&&qx.core.Environment.get(q)>=9){qx.bom.Event.removeNativeListener(S,m,this._onInputWrapper);if(S.type===a||S.type===g||S.type===f){qx.bom.Event.removeNativeListener(S,t,this._inputFixWrapper);};};},"webkit":function(U){var T=U.tagName.toLowerCase();if(parseFloat(qx.core.Environment.get(b))<532&&T==f){qx.bom.Event.removeNativeListener(U,w,this._onInputWrapper);};qx.bom.Event.removeNativeListener(U,m,this._onInputWrapper);},"opera":function(V){qx.bom.Event.removeNativeListener(V,t,this._onKeyUpWrapper);qx.bom.Event.removeNativeListener(V,c,this._onKeyDownWrapper);qx.bom.Event.removeNativeListener(V,m,this._onInputWrapper);},"default":function(W){qx.bom.Event.removeNativeListener(W,m,this._onInputWrapper);}}),_onKeyPress:qx.core.Environment.select(v,{"mshtml":function(e,X){if(e.keyCode===13){if(X.value!==this.__iV){this.__iV=X.value;qx.event.Registration.fireEvent(X,k,qx.event.type.Data,[X.value]);};};},"opera":function(e,Y){if(e.keyCode===13){if(Y.value!==this.__iV){this.__iV=Y.value;qx.event.Registration.fireEvent(Y,k,qx.event.type.Data,[Y.value]);};};},"default":null}),_inputFix:qx.core.Environment.select(v,{"mshtml":function(e,ba){if(e.keyCode===46||e.keyCode===8){if(ba.value!==this.__iW){this.__iW=ba.value;qx.event.Registration.fireEvent(ba,m,qx.event.type.Data,[ba.value]);};};},"default":null}),_onKeyDown:qx.core.Environment.select(v,{"opera":function(e){if(e.keyCode===13){this.__iT=true;};},"default":null}),_onKeyUp:qx.core.Environment.select(v,{"opera":function(e){if(e.keyCode===13){this.__iT=false;};},"default":null}),_onInput:qx.event.GlobalError.observeMethod(function(e){var bc=qx.bom.Event.getTarget(e);var bb=bc.tagName.toLowerCase();if(!this.__iT||bb!==m){if((qx.core.Environment.get(v)==s)&&qx.core.Environment.get(r)<10.6){this.__iU=window.setTimeout(function(){qx.event.Registration.fireEvent(bc,m,qx.event.type.Data,[bc.value]);},0);}else {qx.event.Registration.fireEvent(bc,m,qx.event.type.Data,[bc.value]);};};}),_onChangeValue:qx.event.GlobalError.observeMethod(function(e){var bd=qx.bom.Event.getTarget(e);var be=bd.value;if(bd.type===j){var be=[];for(var i=0,o=bd.options,l=o.length;i<l;i++ ){if(o[i].selected){be.push(o[i].value);};};};qx.event.Registration.fireEvent(bd,k,qx.event.type.Data,[be]);}),_onChangeChecked:qx.event.GlobalError.observeMethod(function(e){var bf=qx.bom.Event.getTarget(e);if(bf.type===d){if(bf.checked){qx.event.Registration.fireEvent(bf,k,qx.event.type.Data,[bf.value]);};}else {qx.event.Registration.fireEvent(bf,k,qx.event.type.Data,[bf.checked]);};}),_onProperty:qx.core.Environment.select(v,{"mshtml":qx.event.GlobalError.observeMethod(function(e){var bg=qx.bom.Event.getTarget(e);var bh=e.propertyName;if(bh===n&&(bg.type===a||bg.type===g||bg.tagName.toLowerCase()===f)){if(!bg.$$inValueSet){qx.event.Registration.fireEvent(bg,m,qx.event.type.Data,[bg.value]);};}else if(bh===z){if(bg.type===x){qx.event.Registration.fireEvent(bg,k,qx.event.type.Data,[bg.checked]);}else if(bg.checked){qx.event.Registration.fireEvent(bg,k,qx.event.type.Data,[bg.value]);};};}),"default":function(){}})},defer:function(bi){qx.event.Registration.addHandler(bi);}});})();(function(){var a="offline",b="qx.event.handler.Offline",c="online";qx.Class.define(b,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(d){qx.core.Object.call(this);this.__gs=d;this.__cz=d.getWindow();this._initObserver();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{online:true,offline:true},TARGET_CHECK:qx.event.IEventHandler.TARGET_WINDOW,IGNORE_CAN_HANDLE:true},members:{__gs:null,__cz:null,__iN:null,canHandleEvent:function(f,e){},registerEvent:function(i,h,g){},unregisterEvent:function(l,k,j){},_initObserver:function(){this.__iN=qx.lang.Function.listener(this._onNative,this);qx.bom.Event.addNativeListener(this.__cz,a,this.__iN);qx.bom.Event.addNativeListener(this.__cz,c,this.__iN);},_stopObserver:function(){qx.bom.Event.removeNativeListener(this.__cz,a,this.__iN);qx.bom.Event.removeNativeListener(this.__cz,c,this.__iN);},_onNative:qx.event.GlobalError.observeMethod(function(m){qx.event.Registration.fireEvent(this.__cz,m.type,qx.event.type.Event,[]);}),isOnline:function(){return !!this.__cz.navigator.onLine;}},destruct:function(){this.__gs=null;this._stopObserver();delete qx.event.handler.Appear.__instances[this.$$hash];},defer:function(n){qx.event.Registration.addHandler(n);}});})();(function(){var a="mshtml",b="engine.name",c="qx.bom.Element";qx.Class.define(c,{statics:{addListener:function(g,f,d,self,e){return qx.event.Registration.addListener(g,f,d,self,e);},removeListener:function(n,m,h,self,k){return qx.event.Registration.removeListener(n,m,h,self,k);},removeListenerById:function(o,p){return qx.event.Registration.removeListenerById(o,p);},hasListener:function(s,r,q){return qx.event.Registration.hasListener(s,r,q);},focus:function(t){qx.event.Registration.getManager(t).getHandler(qx.event.handler.Focus).focus(t);},blur:function(u){qx.event.Registration.getManager(u).getHandler(qx.event.handler.Focus).blur(u);},activate:function(v){qx.event.Registration.getManager(v).getHandler(qx.event.handler.Focus).activate(v);},deactivate:function(w){qx.event.Registration.getManager(w).getHandler(qx.event.handler.Focus).deactivate(w);},capture:function(y,x){qx.event.Registration.getManager(y).getDispatcher(qx.event.dispatch.MouseCapture).activateCapture(y,x);},releaseCapture:function(z){qx.event.Registration.getManager(z).getDispatcher(qx.event.dispatch.MouseCapture).releaseCapture(z);},clone:function(E,L){var C;if(L||((qx.core.Environment.get(b)==a)&&!qx.xml.Document.isXmlDocument(E))){var G=qx.event.Registration.getManager(E);var A=qx.dom.Hierarchy.getDescendants(E);A.push(E);};if((qx.core.Environment.get(b)==a)){for(var i=0,l=A.length;i<l;i++ ){G.toggleAttachedEvents(A[i],false);};};var C=E.cloneNode(true);if((qx.core.Environment.get(b)==a)){for(var i=0,l=A.length;i<l;i++ ){G.toggleAttachedEvents(A[i],true);};};if(L===true){var K=qx.dom.Hierarchy.getDescendants(C);K.push(C);var B,J,I,D;for(var i=0,H=A.length;i<H;i++ ){I=A[i];B=G.serializeListeners(I);if(B.length>0){J=K[i];for(var j=0,F=B.length;j<F;j++ ){D=B[j];G.addListener(J,D.type,D.handler,D.self,D.capture);};};};};return C;}}});})();(function(){var a="mshtml",b="engine.name",c="blur",d="losecapture",e="focus",f="os.version",g="click",h="qx.event.dispatch.MouseCapture",i="capture",j="scroll",k="browser.documentmode";qx.Class.define(h,{extend:qx.event.dispatch.AbstractBubbling,construct:function(l,m){qx.event.dispatch.AbstractBubbling.call(this,l);this.__cz=l.getWindow();this.__cB=m;l.addListener(this.__cz,c,this.releaseCapture,this);l.addListener(this.__cz,e,this.releaseCapture,this);l.addListener(this.__cz,j,this.releaseCapture,this);},statics:{PRIORITY:qx.event.Registration.PRIORITY_FIRST},members:{__cB:null,__jb:null,__jc:true,__cz:null,_getParent:function(n){return n.parentNode;},canDispatchEvent:function(p,event,o){return !!(this.__jb&&this.__jd[o]);},dispatchEvent:function(r,event,q){if(q==g){event.stopPropagation();this.releaseCapture();return;};if(this.__jc||!qx.dom.Hierarchy.contains(this.__jb,r)){r=this.__jb;};qx.event.dispatch.AbstractBubbling.prototype.dispatchEvent.call(this,r,event,q);},__jd:{"mouseup":1,"mousedown":1,"click":1,"dblclick":1,"mousemove":1,"mouseout":1,"mouseover":1,"pointerdown":1,"pointerup":1,"pointermove":1,"pointerover":1,"pointerout":1,"tap":1,"dbltap":1},activateCapture:function(u,s){var s=s!==false;if(this.__jb===u&&this.__jc==s){return;};if(this.__jb){this.releaseCapture();};if(this.hasNativeCapture){this.nativeSetCapture(u,s);var self=this;var t=function(){qx.bom.Event.removeNativeListener(u,d,t);self.releaseCapture();};qx.bom.Event.addNativeListener(u,d,t);};this.__jc=s;this.__jb=u;this.__cB.fireEvent(u,i,qx.event.type.Event,[true,false]);},getCaptureElement:function(){return this.__jb;},releaseCapture:function(){var v=this.__jb;if(!v){return;};this.__jb=null;this.__cB.fireEvent(v,d,qx.event.type.Event,[true,false]);this.nativeReleaseCapture(v);},hasNativeCapture:(qx.core.Environment.get(b)==a&&qx.core.Environment.get(k)<9||(parseInt(qx.core.Environment.get(f),10)>7&&qx.core.Environment.get(k)>9)),nativeSetCapture:qx.core.Environment.select(b,{"mshtml":function(x,w){x.setCapture(w!==false);},"default":(function(){})}),nativeReleaseCapture:qx.core.Environment.select(b,{"mshtml":function(y){y.releaseCapture();},"default":(function(){})})},destruct:function(){this.__jb=this.__cz=this.__cB=null;},defer:function(z){qx.event.Registration.addDispatcher(z);}});})();(function(){var a="qx.event.handler.Capture";qx.Class.define(a,{extend:qx.core.Object,implement:qx.event.IEventHandler,statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{capture:true,losecapture:true},TARGET_CHECK:qx.event.IEventHandler.TARGET_DOMNODE,IGNORE_CAN_HANDLE:true},members:{canHandleEvent:function(c,b){},registerEvent:function(f,e,d){},unregisterEvent:function(i,h,g){}},defer:function(j){qx.event.Registration.addHandler(j);}});})();(function(){var a="function",b="plugin.silverlight.version",c="Silverlight",d="Skype.Detection",f="QuickTimeCheckObject.QuickTimeCheck.1",g="Adobe Acrobat",h="plugin.windowsmedia",k="QuickTime",l="plugin.silverlight",m="pdf",n="wmv",o="qx.bom.client.Plugin",p="application/x-skype",q=',',r="plugin.divx",s='=',t="Chrome PDF Viewer",u="divx",v="Windows Media",w="",x="mshtml",y="skype.click2call",z="plugin.skype",A="plugin.gears",B="plugin.quicktime",C="plugin.windowsmedia.version",D="quicktime",E="DivX Web Player",F="AgControl.AgControl",G="Microsoft.XMLHTTP",H="silverlight",I="plugin.pdf",J="plugin.pdf.version",K="MSXML2.DOMDocument.6.0",L="WMPlayer.OCX.7",M="AcroPDF.PDF",N="plugin.activex",O="plugin.quicktime.version",P="plugin.divx.version",Q="npdivx.DivXBrowserPlugin.1",R="object";qx.Bootstrap.define(o,{statics:{getGears:function(){return !!(window.google&&window.google.gears);},getActiveX:function(){if(typeof window.ActiveXObject===a){return true;};try{return (typeof (new window.ActiveXObject(G))===R||typeof (new window.ActiveXObject(K))===R);}catch(S){return false;};},getSkype:function(){if(qx.bom.client.Plugin.getActiveX()){try{new ActiveXObject(d);return true;}catch(e){};};var T=navigator.mimeTypes;if(T){if(p in T){return true;};for(var i=0;i<T.length;i++ ){var U=T[i];if(U.type.indexOf(y)!=-1){return true;};};};return false;},__je:{quicktime:{plugin:[k],control:f},wmv:{plugin:[v],control:L},divx:{plugin:[E],control:Q},silverlight:{plugin:[c],control:F},pdf:{plugin:[t,g],control:M}},getQuicktimeVersion:function(){var V=qx.bom.client.Plugin.__je[D];return qx.bom.client.Plugin.__jf(V.control,V.plugin);},getWindowsMediaVersion:function(){var W=qx.bom.client.Plugin.__je[n];return qx.bom.client.Plugin.__jf(W.control,W.plugin,true);},getDivXVersion:function(){var X=qx.bom.client.Plugin.__je[u];return qx.bom.client.Plugin.__jf(X.control,X.plugin);},getSilverlightVersion:function(){var Y=qx.bom.client.Plugin.__je[H];return qx.bom.client.Plugin.__jf(Y.control,Y.plugin);},getPdfVersion:function(){var ba=qx.bom.client.Plugin.__je[m];return qx.bom.client.Plugin.__jf(ba.control,ba.plugin);},getQuicktime:function(){var bb=qx.bom.client.Plugin.__je[D];return qx.bom.client.Plugin.__jg(bb.control,bb.plugin);},getWindowsMedia:function(){var bc=qx.bom.client.Plugin.__je[n];return qx.bom.client.Plugin.__jg(bc.control,bc.plugin,true);},getDivX:function(){var bd=qx.bom.client.Plugin.__je[u];return qx.bom.client.Plugin.__jg(bd.control,bd.plugin);},getSilverlight:function(){var be=qx.bom.client.Plugin.__je[H];return qx.bom.client.Plugin.__jg(be.control,be.plugin);},getPdf:function(){var bf=qx.bom.client.Plugin.__je[m];return qx.bom.client.Plugin.__jg(bf.control,bf.plugin);},__jf:function(bo,bk,bj){var bg=qx.bom.client.Plugin.__jg(bo,bk,bj);if(!bg){return w;};if(qx.bom.client.Engine.getName()==x&&(qx.bom.client.Browser.getDocumentMode()<11||bj)){try{var bh=new ActiveXObject(bo);var bm;if(bh.GetVersions&&bh.GetVersions()){bm=bh.GetVersions().split(q);if(bm.length>1){bm=bm[0].split(s);if(bm.length===2){return bm[1];};};};bm=bh.versionInfo;if(bm!=undefined){return bm;};bm=bh.version;if(bm!=undefined){return bm;};bm=bh.settings.version;if(bm!=undefined){return bm;};}catch(bp){return w;};return w;}else {var bn=navigator.plugins;var bl=/([0-9]\.[0-9])/g;for(var i=0;i<bn.length;i++ ){var bi=bn[i];for(var j=0;j<bk.length;j++ ){if(bi.name.indexOf(bk[j])!==-1){if(bl.test(bi.name)||bl.test(bi.description)){return RegExp.$1;};};};};return w;};},__jg:function(bt,br,bq){if(qx.bom.client.Engine.getName()==x&&(qx.bom.client.Browser.getDocumentMode()<11||bq)){if(!this.getActiveX()){return false;};try{new ActiveXObject(bt);}catch(bu){return false;};return true;}else {var bs=navigator.plugins;if(!bs){return false;};var name;for(var i=0;i<bs.length;i++ ){name=bs[i].name;for(var j=0;j<br.length;j++ ){if(name.indexOf(br[j])!==-1){return true;};};};return false;};}},defer:function(bv){qx.core.Environment.add(A,bv.getGears);qx.core.Environment.add(B,bv.getQuicktime);qx.core.Environment.add(O,bv.getQuicktimeVersion);qx.core.Environment.add(h,bv.getWindowsMedia);qx.core.Environment.add(C,bv.getWindowsMediaVersion);qx.core.Environment.add(r,bv.getDivX);qx.core.Environment.add(P,bv.getDivXVersion);qx.core.Environment.add(l,bv.getSilverlight);qx.core.Environment.add(b,bv.getSilverlightVersion);qx.core.Environment.add(I,bv.getPdf);qx.core.Environment.add(J,bv.getPdfVersion);qx.core.Environment.add(N,bv.getActiveX);qx.core.Environment.add(z,bv.getSkype);}});})();(function(){var a='<\?xml version="1.0" encoding="utf-8"?>\n<',b="MSXML2.DOMDocument.3.0",c="qx.xml.Document",d="",e=" />",f="xml.domparser",g="SelectionLanguage",h="'",j="MSXML2.XMLHTTP.3.0",k="plugin.activex",m="No XML implementation available!",n="MSXML2.XMLHTTP.6.0",o="xml.implementation",p=" xmlns='",q="text/xml",r="XPath",s="MSXML2.DOMDocument.6.0",t="HTML";qx.Bootstrap.define(c,{statics:{DOMDOC:null,XMLHTTP:null,isXmlDocument:function(u){if(u.nodeType===9){return u.documentElement.nodeName!==t;}else if(u.ownerDocument){return this.isXmlDocument(u.ownerDocument);}else {return false;};},create:function(v,w){if(qx.core.Environment.get(k)){var x=new ActiveXObject(this.DOMDOC);if(this.DOMDOC==b){x.setProperty(g,r);};if(w){var y=a;y+=w;if(v){y+=p+v+h;};y+=e;x.loadXML(y);};return x;};if(qx.core.Environment.get(o)){return document.implementation.createDocument(v||d,w||d,null);};throw new Error(m);},fromString:function(A){if(qx.core.Environment.get(k)){var B=qx.xml.Document.create();B.loadXML(A);return B;};if(qx.core.Environment.get(f)){var z=new DOMParser();return z.parseFromString(A,q);};throw new Error(m);}},defer:function(D){if(qx.core.Environment.get(k)){var C=[s,b];var E=[n,j];for(var i=0,l=C.length;i<l;i++ ){try{new ActiveXObject(C[i]);new ActiveXObject(E[i]);}catch(F){continue;};D.DOMDOC=C[i];D.XMLHTTP=E[i];break;};};}});})();(function(){var a="function",b="xml.implementation",c="xml.attributens",d="xml.selectnodes",e="<a></a>",f="xml.getqualifieditem",g="SelectionLanguage",h="xml.getelementsbytagnamens",i="qx.bom.client.Xml",j="xml.domproperties",k="xml.selectsinglenode",l="1.0",m="xml.createnode",n="xml.domparser",o="getProperty",p="undefined",q="XML",r="string",s="xml.createelementns";qx.Bootstrap.define(i,{statics:{getImplementation:function(){return document.implementation&&document.implementation.hasFeature&&document.implementation.hasFeature(q,l);},getDomParser:function(){return typeof window.DOMParser!==p;},getSelectSingleNode:function(){return typeof qx.xml.Document.create().selectSingleNode!==p;},getSelectNodes:function(){return typeof qx.xml.Document.create().selectNodes!==p;},getElementsByTagNameNS:function(){return typeof qx.xml.Document.create().getElementsByTagNameNS!==p;},getDomProperties:function(){var t=qx.xml.Document.create();return (o in t&&typeof t.getProperty(g)===r);},getAttributeNS:function(){var u=qx.xml.Document.fromString(e).documentElement;return typeof u.getAttributeNS===a&&typeof u.setAttributeNS===a;},getCreateElementNS:function(){return typeof qx.xml.Document.create().createElementNS===a;},getCreateNode:function(){return typeof qx.xml.Document.create().createNode!==p;},getQualifiedItem:function(){var v=qx.xml.Document.fromString(e).documentElement;return typeof v.attributes.getQualifiedItem!==p;}},defer:function(w){qx.core.Environment.add(b,w.getImplementation);qx.core.Environment.add(n,w.getDomParser);qx.core.Environment.add(k,w.getSelectSingleNode);qx.core.Environment.add(d,w.getSelectNodes);qx.core.Environment.add(h,w.getElementsByTagNameNS);qx.core.Environment.add(j,w.getDomProperties);qx.core.Environment.add(c,w.getAttributeNS);qx.core.Environment.add(s,w.getCreateElementNS);qx.core.Environment.add(m,w.getCreateNode);qx.core.Environment.add(f,w.getQualifiedItem);}});})();(function(){var a="borderBottomWidth",b="visible",d="engine.name",e="borderTopWidth",f="top",g="borderLeftStyle",h="none",i="overflow",j="right",k="bottom",l="borderLeftWidth",m="100px",n="-moz-scrollbars-vertical",o="borderRightStyle",p="hidden",q="div",r="left",u="qx.bom.element.Scroll",v="borderRightWidth",w="scroll",x="overflowY";qx.Class.define(u,{statics:{__jh:null,getScrollbarWidth:function(){if(this.__jh!==null){return this.__jh;};var y=qx.bom.element.Style;var A=function(E,F){return parseInt(y.get(E,F),10)||0;};var B=function(G){return (y.get(G,o)==h?0:A(G,v));};var C=function(H){return (y.get(H,g)==h?0:A(H,l));};var D=qx.core.Environment.select(d,{"mshtml":function(I){if(y.get(I,x)==p||I.clientWidth==0){return B(I);};return Math.max(0,I.offsetWidth-I.clientLeft-I.clientWidth);},"default":function(J){if(J.clientWidth==0){var L=y.get(J,i);var K=(L==w||L==n?16:0);return Math.max(0,B(J)+K);};return Math.max(0,(J.offsetWidth-J.clientWidth-C(J)));}});var z=function(M){return D(M)-B(M);};var t=document.createElement(q);var s=t.style;s.height=s.width=m;s.overflow=w;document.body.appendChild(t);var c=z(t);this.__jh=c;document.body.removeChild(t);return this.__jh;},intoViewX:function(bi,stop,bh){var parent=bi.parentNode;var bg=qx.dom.Node.getDocument(bi);var Y=bg.body;var be,Q,V;var R,P,S;var bb,T,O;var X,bc,bd,ba;var bf,U,bj;var N=bh===r;var W=bh===j;stop=stop?stop.parentNode:bg;while(parent&&parent!=stop){if(parent.scrollWidth>parent.clientWidth&&(parent===Y||qx.bom.element.Style.get(parent,x)!=b)){if(parent===Y){Q=parent.scrollLeft;V=Q+qx.bom.Viewport.getWidth();R=qx.bom.Viewport.getWidth();P=parent.clientWidth;S=parent.scrollWidth;bb=0;T=0;O=0;}else {be=qx.bom.element.Location.get(parent);Q=be.left;V=be.right;R=parent.offsetWidth;P=parent.clientWidth;S=parent.scrollWidth;bb=parseInt(qx.bom.element.Style.get(parent,l),10)||0;T=parseInt(qx.bom.element.Style.get(parent,v),10)||0;O=R-P-bb-T;};X=qx.bom.element.Location.get(bi);bc=X.left;bd=X.right;ba=bi.offsetWidth;bf=bc-Q-bb;U=bd-V+T;bj=0;if(N){bj=bf;}else if(W){bj=U+O;}else if(bf<0||ba>P){bj=bf;}else if(U>0){bj=U+O;};parent.scrollLeft+=bj;qx.event.Registration.fireNonBubblingEvent(parent,w);};if(parent===Y){break;};parent=parent.parentNode;};},intoViewY:function(bD,stop,bC){var parent=bD.parentNode;var bB=qx.dom.Node.getDocument(bD);var bk=bB.body;var by,bt,bw;var bE,bx,bu;var bp,bl,bA;var br,bs,bq,bm;var bn,bv,bz;var bo=bC===f;var bF=bC===k;stop=stop?stop.parentNode:bB;while(parent&&parent!=stop){if(parent.scrollHeight>parent.clientHeight&&(parent===bk||qx.bom.element.Style.get(parent,x)!=b)){if(parent===bk){bt=parent.scrollTop;bw=bt+qx.bom.Viewport.getHeight();bE=qx.bom.Viewport.getHeight();bx=parent.clientHeight;bu=parent.scrollHeight;bp=0;bl=0;bA=0;}else {by=qx.bom.element.Location.get(parent);bt=by.top;bw=by.bottom;bE=parent.offsetHeight;bx=parent.clientHeight;bu=parent.scrollHeight;bp=parseInt(qx.bom.element.Style.get(parent,e),10)||0;bl=parseInt(qx.bom.element.Style.get(parent,a),10)||0;bA=bE-bx-bp-bl;};br=qx.bom.element.Location.get(bD);bs=br.top;bq=br.bottom;bm=bD.offsetHeight;bn=bs-bt-bp;bv=bq-bw+bl;bz=0;if(bo){bz=bn;}else if(bF){bz=bv+bA;}else if(bn<0||bm>bx){bz=bn;}else if(bv>0){bz=bv+bA;};parent.scrollTop+=bz;qx.event.Registration.fireNonBubblingEvent(parent,w);};if(parent===bk){break;};parent=parent.parentNode;};},intoView:function(bI,stop,bH,bG){this.intoViewX(bI,stop,bH);this.intoViewY(bI,stop,bG);}}});})();(function(){var a="useraction",b=" due to exceptions in user code. The application has to be reloaded!",c="event.touch",d="qx.ui.core.queue.Manager",f=" times in a row",g="Fatal Error: Flush terminated ";qx.Class.define(d,{statics:{__ji:false,__gk:false,__jj:{},__jk:0,MAX_RETRIES:10,scheduleFlush:function(h){var self=qx.ui.core.queue.Manager;self.__jj[h]=true;if(!self.__ji){self.__gk=false;qx.bom.AnimationFrame.request(function(){if(self.__gk){self.__gk=false;return;};self.flush();},self);self.__ji=true;};},flush:function(){var self=qx.ui.core.queue.Manager;if(self.__jl){return;};self.__jl=true;self.__gk=true;var i=self.__jj;self.__jm(function(){while(i.visibility||i.widget||i.appearance||i.layout||i.element){if(i.widget){delete i.widget;{qx.ui.core.queue.Widget.flush();};};if(i.visibility){delete i.visibility;{qx.ui.core.queue.Visibility.flush();};};if(i.appearance){delete i.appearance;{qx.ui.core.queue.Appearance.flush();};};if(i.widget||i.visibility||i.appearance){continue;};if(i.layout){delete i.layout;{qx.ui.core.queue.Layout.flush();};};if(i.widget||i.visibility||i.appearance||i.layout){continue;};if(i.element){delete i.element;qx.html.Element.flush();};};},function(){self.__ji=false;});self.__jm(function(){if(i.dispose){delete i.dispose;{qx.ui.core.queue.Dispose.flush();};};},function(){self.__jl=false;});self.__jk=0;},__jm:function(j,k){var self=qx.ui.core.queue.Manager;try{j();}catch(e){{};self.__ji=false;self.__jl=false;self.__jk+=1;if(self.__jk<=self.MAX_RETRIES){self.scheduleFlush();}else {throw new Error(g+(self.__jk-1)+f+b);};throw e;}finally{k();};},__jn:function(e){qx.ui.core.queue.Manager.flush();}},defer:function(l){qx.html.Element._scheduleFlush=l.scheduleFlush;qx.event.Registration.addListener(window,a,qx.core.Environment.get(c)?l.__jn:l.flush);}});})();(function(){var a="qx.ui.core.queue.Widget",b="widget",c="$$default";qx.Class.define(a,{statics:{__dO:[],__jj:{},remove:function(e,g){var d=this.__dO;if(!qx.lang.Array.contains(d,e)){return;};var f=e.$$hash;if(g==null){qx.lang.Array.remove(d,e);delete this.__jj[f];return;};if(this.__jj[f]){delete this.__jj[f][g];if(qx.lang.Object.getLength(this.__jj[f])==0){qx.lang.Array.remove(d,e);};};},add:function(j,l){var h=this.__dO;if(!qx.lang.Array.contains(h,j)){h.unshift(j);};if(l==null){l=c;};var k=j.$$hash;if(!this.__jj[k]){this.__jj[k]={};};this.__jj[k][l]=true;qx.ui.core.queue.Manager.scheduleFlush(b);},flush:function(){var m=this.__dO;var n,o;for(var i=m.length-1;i>=0;i-- ){n=m[i];o=this.__jj[n.$$hash];m.splice(i,1);n.syncWidget(o);};if(m.length!=0){return;};this.__dO=[];this.__jj={};}}});})();(function(){var a="qx.ui.core.queue.Visibility",b="visibility";qx.Class.define(a,{statics:{__dO:[],__cP:{},remove:function(c){delete this.__cP[c.$$hash];qx.lang.Array.remove(this.__dO,c);},isVisible:function(d){return this.__cP[d.$$hash]||false;},__jo:function(f){var h=this.__cP;var g=f.$$hash;var e;if(f.isExcluded()){e=false;}else {var parent=f.$$parent;if(parent){e=this.__jo(parent);}else {e=f.isRootWidget();};};return h[g]=e;},add:function(k){var j=this.__dO;if(qx.lang.Array.contains(j,k)){return;};j.unshift(k);qx.ui.core.queue.Manager.scheduleFlush(b);},flush:function(){var o=this.__dO;var p=this.__cP;for(var i=o.length-1;i>=0;i-- ){var n=o[i].$$hash;if(p[n]!=null){o[i].addChildrenToQueue(o);};};var l={};for(var i=o.length-1;i>=0;i-- ){var n=o[i].$$hash;l[n]=p[n];p[n]=null;};for(var i=o.length-1;i>=0;i-- ){var m=o[i];var n=m.$$hash;o.splice(i,1);if(p[n]==null){this.__jo(m);};if(p[n]&&p[n]!=l[n]){m.checkAppearanceNeeds();};};this.__dO=[];}}});})();(function(){var a="appearance",b="qx.ui.core.queue.Appearance";qx.Class.define(b,{statics:{__dO:[],remove:function(c){qx.lang.Array.remove(this.__dO,c);},add:function(e){var d=this.__dO;if(qx.lang.Array.contains(d,e)){return;};d.unshift(e);qx.ui.core.queue.Manager.scheduleFlush(a);},has:function(f){return qx.lang.Array.contains(this.__dO,f);},flush:function(){var j=qx.ui.core.queue.Visibility;var g=this.__dO;var h;for(var i=g.length-1;i>=0;i-- ){h=g[i];g.splice(i,1);if(j.isVisible(h)){h.syncAppearance();}else {h.$$stateChanges=true;};};}}});})();(function(){var a="dispose",b="qx.ui.core.queue.Dispose";qx.Class.define(b,{statics:{__dO:[],add:function(d){var c=this.__dO;if(qx.lang.Array.contains(c,d)){return;};c.unshift(d);qx.ui.core.queue.Manager.scheduleFlush(a);},isEmpty:function(){return this.__dO.length==0;},flush:function(){var e=this.__dO;for(var i=e.length-1;i>=0;i-- ){var f=e[i];e.splice(i,1);f.dispose();};if(e.length!=0){return;};this.__dO=[];}}});})();(function(){var a="backgroundColor",b="drag",c="_applyNativeContextMenu",d="touch",f="div",g="_applyBackgroundColor",h="qx.event.type.Data",j="__ju",k="_applyFocusable",m=" requires a layout, but no one was defined!",n="qx.event.type.KeyInput",o="focused",p="disabled",q="move",r="createChildControl",s="qxanonymous",t="Unsupported control: ",u="dragstart",v="Font",w="opera",x="dragchange",y="_applyEnabled",z="_applySelectable",A="Number",B="_applyKeepActive",C="qx.event.type.Pinch",D="dragend",E="_applyVisibility",F="Child control '",G="qxDraggable",H="qx.event.type.Roll",I="syncAppearance",J="paddingLeft",K="__jp",L="' of widget ",M="qx.event.type.Mouse",N="_applyPadding",O="#",P="At least one child in control ",Q="visible",R="qx.event.type.Event",S="qx.event.type.MouseWheel",T="_applyCursor",U="changeVisibility",V="_applyDraggable",W="resize",X="Decorator",Y="Remove Error: ",cJ="zIndex",cK="changeTextColor",cL="$$widget",cF="changeContextMenu",cG="on",cH="paddingTop",cI="opacity",cQ="This widget has no children!",cR="changeSelectable",cS="_applyAnonymous",cT="none",cM="outline",cN="hidden",cO="_applyAppearance",cP="hovered",cX="_applyOpacity",dA="Boolean",em="px",cY="qx.ui.core.Widget",cU="longtap",cV="default",eh="TabIndex property must be between 1 and 32000",cW="_applyFont",da="cursor",db="qxDroppable",dc="' already created!",dh="changeZIndex",di=": ",dj="Color",dd="changeEnabled",de="Abstract method call: _getContentHeightForWidth()!",df="changeFont",dg="qx.event.type.Focus",dn="_applyDecorator",dp="_applyZIndex",dq="_applyTextColor",dr="__jw",dk="Widget is not focusable!",dl="qx.ui.menu.Menu",ei="engine.name",dm="qx.event.type.Drag",dv="qx.event.type.KeySequence",dw="excluded",ek="DOM element is not yet created!",dx="_applyToolTipText",ds="Exception while creating child control '",dt="qx.event.type.Rotate",ej="_applyDroppable",du=" is not a child of this widget!",dy="true",dz="widget",dL="changeDecorator",dK="qx.event.type.Tap",dJ="Integer",dP="_applyTabIndex",dO="changeAppearance",dN="qx.event.type.Track",dM="shorthand",dE="/",dD="String",dC="border-box",dB="",dI="_applyContextMenu",dH="changeToolTipText",dG="padding",dF="tabIndex",dW="paddingBottom",dV="beforeContextmenuOpen",dU="changeNativeContextMenu",dT="undefined",eb="qx.ui.tooltip.ToolTip",ea="__jt",dY="contextmenu",dX="_applyKeepFocus",dS="paddingRight",dR="changeBackgroundColor",dQ="changeLocale",ee="qx.event.type.Pointer",ed="qxKeepFocus",ec="qx.event.type.Touch",eg="qxKeepActive",ef="absolute";qx.Class.define(cY,{extend:qx.ui.core.LayoutItem,include:[qx.locale.MTranslation],construct:function(){qx.ui.core.LayoutItem.call(this);this.__jp=this.__jv();this.initFocusable();this.initSelectable();this.initNativeContextMenu();},events:{appear:R,disappear:R,createChildControl:h,resize:h,move:h,syncAppearance:h,mousemove:M,mouseover:M,mouseout:M,mousedown:M,mouseup:M,click:M,auxclick:M,dblclick:M,contextmenu:M,beforeContextmenuOpen:h,mousewheel:S,touchstart:ec,touchend:ec,touchmove:ec,touchcancel:ec,tap:dK,longtap:dK,dbltap:dK,swipe:ec,rotate:dt,pinch:C,track:dN,roll:H,pointermove:ee,pointerover:ee,pointerout:ee,pointerdown:ee,pointerup:ee,pointercancel:ee,keyup:dv,keydown:dv,keypress:dv,keyinput:n,focus:dg,blur:dg,focusin:dg,focusout:dg,activate:dg,deactivate:dg,capture:R,losecapture:R,drop:dm,dragleave:dm,dragover:dm,drag:dm,dragstart:dm,dragend:dm,dragchange:dm,droprequest:dm},properties:{paddingTop:{check:dJ,init:0,apply:N,themeable:true},paddingRight:{check:dJ,init:0,apply:N,themeable:true},paddingBottom:{check:dJ,init:0,apply:N,themeable:true},paddingLeft:{check:dJ,init:0,apply:N,themeable:true},padding:{group:[cH,dS,dW,J],mode:dM,themeable:true},zIndex:{nullable:true,init:10,apply:dp,event:dh,check:dJ,themeable:true},decorator:{nullable:true,init:null,apply:dn,event:dL,check:X,themeable:true},backgroundColor:{nullable:true,check:dj,apply:g,event:dR,themeable:true},textColor:{nullable:true,check:dj,apply:dq,event:cK,themeable:true,inheritable:true},font:{nullable:true,apply:cW,check:v,event:df,themeable:true,inheritable:true,dereference:true},opacity:{check:A,apply:cX,themeable:true,nullable:true,init:null},cursor:{check:dD,apply:T,themeable:true,inheritable:true,nullable:true,init:null},toolTip:{check:eb,nullable:true},toolTipText:{check:dD,nullable:true,event:dH,apply:dx},toolTipIcon:{check:dD,nullable:true,event:dH},blockToolTip:{check:dA,init:false},showToolTipWhenDisabled:{check:dA,init:false},visibility:{check:[Q,cN,dw],init:Q,apply:E,event:U},enabled:{init:true,check:dA,inheritable:true,apply:y,event:dd},anonymous:{init:false,check:dA,apply:cS},tabIndex:{check:dJ,nullable:true,apply:dP},focusable:{check:dA,init:false,apply:k},keepFocus:{check:dA,init:false,apply:dX},keepActive:{check:dA,init:false,apply:B},draggable:{check:dA,init:false,apply:V},droppable:{check:dA,init:false,apply:ej},selectable:{check:dA,init:false,event:cR,apply:z},contextMenu:{check:dl,apply:dI,nullable:true,event:cF},nativeContextMenu:{check:dA,init:false,themeable:true,event:dU,apply:c},appearance:{check:dD,init:dz,apply:cO,event:dO}},statics:{DEBUG:false,getWidgetByElement:function(eq,eo){while(eq){var en=eq.$$widget;if(en!=null){var ep=qx.core.ObjectRegistry.fromHashCode(en);if(!eo||!ep.getAnonymous()){return ep;};};try{eq=eq.parentNode;}catch(e){return null;};};return null;},contains:function(parent,er){while(er){er=er.getLayoutParent();if(parent==er){return true;};};return false;},__jq:new qx.util.ObjectPool()},members:{__jp:null,__jr:null,__js:null,__jt:null,_getLayout:function(){return this.__jt;},_setLayout:function(es){{};if(this.__jt){this.__jt.connectToWidget(null);};if(es){es.connectToWidget(this);};this.__jt=es;qx.ui.core.queue.Layout.add(this);},setLayoutParent:function(parent){if(this.$$parent===parent){return;};var content=this.getContentElement();if(this.$$parent&&!this.$$parent.$$disposed){this.$$parent.getContentElement().remove(content);};this.$$parent=parent||null;if(parent&&!parent.$$disposed){this.$$parent.getContentElement().add(content);};this.$$refreshInheritables();qx.ui.core.queue.Visibility.add(this);},_updateInsets:null,renderLayout:function(ez,top,ew,eu){var eA=qx.ui.core.LayoutItem.prototype.renderLayout.call(this,ez,top,ew,eu);if(!eA){return null;};if(qx.lang.Object.isEmpty(eA)&&!this._updateInsets){return null;};var content=this.getContentElement();var eD=eA.size||this._updateInsets;var eB=em;var et={};if(eA.position){et.left=ez+eB;et.top=top+eB;};if(eD||eA.margin){et.width=ew+eB;et.height=eu+eB;};if(Object.keys(et).length>0){content.setStyles(et);};if(eD||eA.local||eA.margin){if(this.__jt&&this.hasLayoutChildren()){var ey=this.getInsets();var innerWidth=ew-ey.left-ey.right;var innerHeight=eu-ey.top-ey.bottom;var eC=this.getDecorator();var ex={left:0,right:0,top:0,bottom:0};if(eC){eC=qx.theme.manager.Decoration.getInstance().resolve(eC);ex=eC.getPadding();};var ev={top:this.getPaddingTop()+ex.top,right:this.getPaddingRight()+ex.right,bottom:this.getPaddingBottom()+ex.bottom,left:this.getPaddingLeft()+ex.left};this.__jt.renderLayout(innerWidth,innerHeight,ev);}else if(this.hasLayoutChildren()){throw new Error(P+this._findTopControl()+m);};};if(eA.position&&this.hasListener(q)){this.fireDataEvent(q,this.getBounds());};if(eA.size&&this.hasListener(W)){this.fireDataEvent(W,this.getBounds());};delete this._updateInsets;return eA;},__ju:null,clearSeparators:function(){var eF=this.__ju;if(!eF){return;};var eG=qx.ui.core.Widget.__jq;var content=this.getContentElement();var eE;for(var i=0,l=eF.length;i<l;i++ ){eE=eF[i];eG.poolObject(eE);content.remove(eE.getContentElement());};eF.length=0;},renderSeparator:function(eI,eJ){var eH=qx.ui.core.Widget.__jq.getObject(qx.ui.core.Widget);eH.set({decorator:eI});var eL=eH.getContentElement();this.getContentElement().add(eL);var eK=eL.getDomElement();if(eK){eK.style.top=eJ.top+em;eK.style.left=eJ.left+em;eK.style.width=eJ.width+em;eK.style.height=eJ.height+em;}else {eL.setStyles({left:eJ.left+em,top:eJ.top+em,width:eJ.width+em,height:eJ.height+em});};if(!this.__ju){this.__ju=[];};this.__ju.push(eH);},_computeSizeHint:function(){var eS=this.getWidth();var eM=this.getMinWidth();var eN=this.getMaxWidth();var eQ=this.getHeight();var eO=this.getMinHeight();var eP=this.getMaxHeight();{};var eT=this._getContentHint();var eR=this.getInsets();var eV=eR.left+eR.right;var eU=eR.top+eR.bottom;if(eS==null){eS=eT.width+eV;};if(eQ==null){eQ=eT.height+eU;};if(eM==null){eM=eV;if(eT.minWidth!=null){eM+=eT.minWidth;if(eM>eN&&eN!=null){eM=eN;};};};if(eO==null){eO=eU;if(eT.minHeight!=null){eO+=eT.minHeight;if(eO>eP&&eP!=null){eO=eP;};};};if(eN==null){if(eT.maxWidth==null){eN=Infinity;}else {eN=eT.maxWidth+eV;if(eN<eM&&eM!=null){eN=eM;};};};if(eP==null){if(eT.maxHeight==null){eP=Infinity;}else {eP=eT.maxHeight+eU;if(eP<eO&&eO!=null){eP=eO;};};};return {width:eS,minWidth:eM,maxWidth:eN,height:eQ,minHeight:eO,maxHeight:eP};},invalidateLayoutCache:function(){qx.ui.core.LayoutItem.prototype.invalidateLayoutCache.call(this);if(this.__jt){this.__jt.invalidateLayoutCache();};},_getContentHint:function(){var eX=this.__jt;if(eX){if(this.hasLayoutChildren()){var eY=eX.getSizeHint();{var eW;};return eY;}else {return {width:0,height:0};};}else {return {width:100,height:50};};},_getHeightForWidth:function(fe){var fd=this.getInsets();var fa=fd.left+fd.right;var fg=fd.top+fd.bottom;var ff=fe-fa;var fb=this._getLayout();if(fb&&fb.hasHeightForWidth()){var fh=fb.getHeightForWidth(ff);}else {fh=this._getContentHeightForWidth(ff);};var fc=fh+fg;return fc;},_getContentHeightForWidth:function(fi){throw new Error(de);},getInsets:function(){var top=this.getPaddingTop();var fj=this.getPaddingRight();var fk=this.getPaddingBottom();var fn=this.getPaddingLeft();if(this.getDecorator()){var fm=qx.theme.manager.Decoration.getInstance().resolve(this.getDecorator());var fl=fm.getInsets();{};top+=fl.top;fj+=fl.right;fk+=fl.bottom;fn+=fl.left;};return {"top":top,"right":fj,"bottom":fk,"left":fn};},getInnerSize:function(){var fp=this.getBounds();if(!fp){return null;};var fo=this.getInsets();return {width:fp.width-fo.left-fo.right,height:fp.height-fo.top-fo.bottom};},fadeOut:function(fq){return this.getContentElement().fadeOut(fq);},fadeIn:function(fr){return this.getContentElement().fadeIn(fr);},_applyAnonymous:function(fs){if(fs){this.getContentElement().setAttribute(s,dy);}else {this.getContentElement().removeAttribute(s);};},show:function(){this.setVisibility(Q);},hide:function(){this.setVisibility(cN);},exclude:function(){this.setVisibility(dw);},isVisible:function(){return this.getVisibility()===Q;},isHidden:function(){return this.getVisibility()!==Q;},isExcluded:function(){return this.getVisibility()===dw;},isSeeable:function(){qx.ui.core.queue.Manager.flush();var ft=this.getContentElement().getDomElement();if(ft){return ft.offsetWidth>0;};return false;},__jv:function(){var fv=this._createContentElement();fv.setAttribute(cL,this.toHashCode());fv.setStyles({"touch-action":cT,"-ms-touch-action":cT});{};var fu={"zIndex":10,"boxSizing":dC};if(!qx.ui.root.Inline||!(this instanceof qx.ui.root.Inline)){fu.position=ef;};fv.setStyles(fu);return fv;},_createContentElement:function(){return new qx.html.Element(f,{overflowX:cN,overflowY:cN});},getContentElement:function(){return this.__jp;},__jw:null,getLayoutChildren:function(){var fx=this.__jw;if(!fx){return this.__jx;};var fy;for(var i=0,l=fx.length;i<l;i++ ){var fw=fx[i];if(fw.hasUserBounds()||fw.isExcluded()){if(fy==null){fy=fx.concat();};qx.lang.Array.remove(fy,fw);};};return fy||fx;},scheduleLayoutUpdate:function(){qx.ui.core.queue.Layout.add(this);},invalidateLayoutChildren:function(){var fz=this.__jt;if(fz){fz.invalidateChildrenCache();};qx.ui.core.queue.Layout.add(this);},hasLayoutChildren:function(){var fB=this.__jw;if(!fB){return false;};var fA;for(var i=0,l=fB.length;i<l;i++ ){fA=fB[i];if(!fA.hasUserBounds()&&!fA.isExcluded()){return true;};};return false;},getChildrenContainer:function(){return this;},__jx:[],_getChildren:function(){return this.__jw||this.__jx;},_indexOf:function(fD){var fC=this.__jw;if(!fC){return -1;};return fC.indexOf(fD);},_hasChildren:function(){var fE=this.__jw;return fE!=null&&(!!fE[0]);},addChildrenToQueue:function(fF){var fG=this.__jw;if(!fG){return;};var fH;for(var i=0,l=fG.length;i<l;i++ ){fH=fG[i];fF.push(fH);fH.addChildrenToQueue(fF);};},_add:function(fJ,fI){{};if(fJ.getLayoutParent()==this){qx.lang.Array.remove(this.__jw,fJ);};if(this.__jw){this.__jw.push(fJ);}else {this.__jw=[fJ];};this.__jy(fJ,fI);},_addAt:function(fN,fK,fM){if(!this.__jw){this.__jw=[];};if(fN.getLayoutParent()==this){qx.lang.Array.remove(this.__jw,fN);};var fL=this.__jw[fK];if(fL===fN){fN.setLayoutProperties(fM);};if(fL){qx.lang.Array.insertBefore(this.__jw,fN,fL);}else {this.__jw.push(fN);};this.__jy(fN,fM);},_addBefore:function(fO,fQ,fP){{};if(fO==fQ){return;};if(!this.__jw){this.__jw=[];};if(fO.getLayoutParent()==this){qx.lang.Array.remove(this.__jw,fO);};qx.lang.Array.insertBefore(this.__jw,fO,fQ);this.__jy(fO,fP);},_addAfter:function(fT,fR,fS){{};if(fT==fR){return;};if(!this.__jw){this.__jw=[];};if(fT.getLayoutParent()==this){qx.lang.Array.remove(this.__jw,fT);};qx.lang.Array.insertAfter(this.__jw,fT,fR);this.__jy(fT,fS);},_remove:function(fU){if(!this.__jw){throw new Error(cQ);};qx.lang.Array.remove(this.__jw,fU);this.__jz(fU);},_removeAt:function(fV){if(!this.__jw){throw new Error(cQ);};var fW=this.__jw[fV];qx.lang.Array.removeAt(this.__jw,fV);this.__jz(fW);return fW;},_removeAll:function(){if(!this.__jw){return [];};var fX=this.__jw.concat();this.__jw.length=0;for(var i=fX.length-1;i>=0;i-- ){this.__jz(fX[i]);};qx.ui.core.queue.Layout.add(this);return fX;},_afterAddChild:null,_afterRemoveChild:null,__jy:function(ga,fY){{};var parent=ga.getLayoutParent();if(parent&&parent!=this){parent._remove(ga);};ga.setLayoutParent(this);if(fY){ga.setLayoutProperties(fY);}else {this.updateLayoutProperties();};if(this._afterAddChild){this._afterAddChild(ga);};},__jz:function(gb){{};if(gb.getLayoutParent()!==this){throw new Error(Y+gb+du);};gb.setLayoutParent(null);if(this.__jt){this.__jt.invalidateChildrenCache();};qx.ui.core.queue.Layout.add(this);if(this._afterRemoveChild){this._afterRemoveChild(gb);};},capture:function(gc){this.getContentElement().capture(gc);},releaseCapture:function(){this.getContentElement().releaseCapture();},isCapturing:function(){var gd=this.getContentElement().getDomElement();if(!gd){return false;};var ge=qx.event.Registration.getManager(gd);var gf=ge.getDispatcher(qx.event.dispatch.MouseCapture);return gd==gf.getCaptureElement();},_applyPadding:function(gh,gg,name){this._updateInsets=true;qx.ui.core.queue.Layout.add(this);this.__jA(name,gh);},__jA:function(gi,gl){var content=this.getContentElement();var gj=this.getDecorator();gj=qx.theme.manager.Decoration.getInstance().resolve(gj);if(gj){var gk=qx.Bootstrap.firstLow(gi.replace(dG,dB));gl+=gj.getPadding()[gk]||0;};content.setStyle(gi,gl+em);},_applyDecorator:function(gn,gm){var content=this.getContentElement();if(gm){gm=qx.theme.manager.Decoration.getInstance().getCssClassName(gm);content.removeClass(gm);};if(gn){gn=qx.theme.manager.Decoration.getInstance().addCssClass(gn);content.addClass(gn);};if(gn||gm){qx.ui.core.queue.Layout.add(this);};},_applyToolTipText:function(gq,gp){{if(this.__js){return;};var go=qx.locale.Manager.getInstance();this.__js=go.addListener(dQ,function(){var gr=this.getToolTipText();if(gr&&gr.translate){this.setToolTipText(gr.translate());};},this);};},_applyTextColor:function(gt,gs){},_applyZIndex:function(gv,gu){this.getContentElement().setStyle(cJ,gv==null?0:gv);},_applyVisibility:function(gx,gw){var content=this.getContentElement();if(gx===Q){content.show();}else {content.hide();};var parent=this.$$parent;if(parent&&(gw==null||gx==null||gw===dw||gx===dw)){parent.invalidateLayoutChildren();};qx.ui.core.queue.Visibility.add(this);},_applyOpacity:function(gz,gy){this.getContentElement().setStyle(cI,gz==1?null:gz);},_applyCursor:function(gB,gA){if(gB==null&&!this.isSelectable()){gB=cV;};this.getContentElement().setStyle(da,gB,qx.core.Environment.get(ei)==w);},_applyBackgroundColor:function(gF,gE){var gD=this.getBackgroundColor();var content=this.getContentElement();var gC=qx.theme.manager.Color.getInstance().resolve(gD);content.setStyle(a,gC);},_applyFont:function(gH,gG){},_onChangeTheme:function(){if(this.isDisposed()){return;};qx.ui.core.LayoutItem.prototype._onChangeTheme.call(this);this.updateAppearance();var gI=this.getDecorator();this._applyDecorator(null,gI);this._applyDecorator(gI);gI=this.getFont();if(qx.lang.Type.isString(gI)){this._applyFont(gI,gI);};gI=this.getTextColor();if(qx.lang.Type.isString(gI)){this._applyTextColor(gI,gI);};gI=this.getBackgroundColor();if(qx.lang.Type.isString(gI)){this._applyBackgroundColor(gI,gI);};},__jB:null,$$stateChanges:null,_forwardStates:null,hasState:function(gK){var gJ=this.__jB;return !!gJ&&!!gJ[gK];},addState:function(gO){var gN=this.__jB;if(!gN){gN=this.__jB={};};if(gN[gO]){return;};this.__jB[gO]=true;if(gO===cP){this.syncAppearance();}else if(!qx.ui.core.queue.Visibility.isVisible(this)){this.$$stateChanges=true;}else {qx.ui.core.queue.Appearance.add(this);};var forward=this._forwardStates;var gM=this.__jE;if(forward&&forward[gO]&&gM){var gL;for(var gP in gM){gL=gM[gP];if(gL instanceof qx.ui.core.Widget){gM[gP].addState(gO);};};};},removeState:function(gT){var gS=this.__jB;if(!gS||!gS[gT]){return;};delete this.__jB[gT];if(gT===cP){this.syncAppearance();}else if(!qx.ui.core.queue.Visibility.isVisible(this)){this.$$stateChanges=true;}else {qx.ui.core.queue.Appearance.add(this);};var forward=this._forwardStates;var gR=this.__jE;if(forward&&forward[gT]&&gR){for(var gU in gR){var gQ=gR[gU];if(gQ instanceof qx.ui.core.Widget){gQ.removeState(gT);};};};},replaceState:function(gW,ha){var gY=this.__jB;if(!gY){gY=this.__jB={};};if(!gY[ha]){gY[ha]=true;};if(gY[gW]){delete gY[gW];};if(!qx.ui.core.queue.Visibility.isVisible(this)){this.$$stateChanges=true;}else {qx.ui.core.queue.Appearance.add(this);};var forward=this._forwardStates;var gX=this.__jE;if(forward&&forward[ha]&&gX){for(var hb in gX){var gV=gX[hb];if(gV instanceof qx.ui.core.Widget){gV.replaceState(gW,ha);};};};},__jC:null,__jD:null,syncAppearance:function(){var hg=this.__jB;var hf=this.__jC;var hh=qx.theme.manager.Appearance.getInstance();var hd=qx.core.Property.$$method.setThemed;var hl=qx.core.Property.$$method.resetThemed;if(this.__jD){delete this.__jD;if(hf){var hc=hh.styleFrom(hf,hg,null,this.getAppearance());hf=null;};};if(!hf){var he=this;var hi=[];do {hi.push(he.$$subcontrol||he.getAppearance());}while(he=he.$$subparent);hf=hi.reverse().join(dE).replace(/#[0-9]+/g,dB);this.__jC=hf;};var hk=hh.styleFrom(hf,hg,null,this.getAppearance());if(hk){if(hc){for(var hj in hc){if(hk[hj]===undefined){this[hl[hj]]();};};};{var hj;};for(var hj in hk){hk[hj]===undefined?this[hl[hj]]():this[hd[hj]](hk[hj]);};}else if(hc){for(var hj in hc){this[hl[hj]]();};};this.fireDataEvent(I,this.__jB);},_applyAppearance:function(hn,hm){this.updateAppearance();},checkAppearanceNeeds:function(){if(!this.__jr){qx.ui.core.queue.Appearance.add(this);this.__jr=true;}else if(this.$$stateChanges){qx.ui.core.queue.Appearance.add(this);delete this.$$stateChanges;};},updateAppearance:function(){this.__jD=true;qx.ui.core.queue.Appearance.add(this);var hq=this.__jE;if(hq){var ho;for(var hp in hq){ho=hq[hp];if(ho instanceof qx.ui.core.Widget){ho.updateAppearance();};};};},syncWidget:function(hr){},getEventTarget:function(){var hs=this;while(hs.getAnonymous()){hs=hs.getLayoutParent();if(!hs){return null;};};return hs;},getFocusTarget:function(){var ht=this;if(!ht.getEnabled()){return null;};while(ht.getAnonymous()||!ht.getFocusable()){ht=ht.getLayoutParent();if(!ht||!ht.getEnabled()){return null;};};return ht;},getFocusElement:function(){return this.getContentElement();},isTabable:function(){return (!!this.getContentElement().getDomElement())&&this.isFocusable();},_applyFocusable:function(hw,hu){var hv=this.getFocusElement();if(hw){var hx=this.getTabIndex();if(hx==null){hx=1;};hv.setAttribute(dF,hx);hv.setStyle(cM,cT);}else {if(hv.isNativelyFocusable()){hv.setAttribute(dF,-1);}else if(hu){hv.setAttribute(dF,null);};};},_applyKeepFocus:function(hz){var hy=this.getFocusElement();hy.setAttribute(ed,hz?cG:null);},_applyKeepActive:function(hB){var hA=this.getContentElement();hA.setAttribute(eg,hB?cG:null);},_applyTabIndex:function(hC){if(hC==null){hC=1;}else if(hC<1||hC>32000){throw new Error(eh);};if(this.getFocusable()&&hC!=null){this.getFocusElement().setAttribute(dF,hC);};},_applySelectable:function(hE,hD){if(hD!==null){this._applyCursor(this.getCursor());};this.getContentElement().setSelectable(hE);},_applyEnabled:function(hG,hF){if(hG===false){this.addState(p);this.removeState(cP);if(this.isFocusable()){this.removeState(o);this._applyFocusable(false,true);};if(this.isDraggable()){this._applyDraggable(false,true);};if(this.isDroppable()){this._applyDroppable(false,true);};}else {this.removeState(p);if(this.isFocusable()){this._applyFocusable(true,false);};if(this.isDraggable()){this._applyDraggable(true,false);};if(this.isDroppable()){this._applyDroppable(true,false);};};},_applyNativeContextMenu:function(hI,hH,name){},_applyContextMenu:function(hK,hJ){if(hJ){hJ.removeState(dY);if(hJ.getOpener()==this){hJ.resetOpener();};if(!hK){this.removeListener(dY,this._onContextMenuOpen);this.removeListener(cU,this._onContextMenuOpen);hJ.removeListener(U,this._onBeforeContextMenuOpen,this);};};if(hK){hK.setOpener(this);hK.addState(dY);if(!hJ){this.addListener(dY,this._onContextMenuOpen);this.addListener(cU,this._onContextMenuOpen);hK.addListener(U,this._onBeforeContextMenuOpen,this);};};},_onContextMenuOpen:function(e){if(e.getType()==cU){if(e.getPointerType()!==d){return;};};this.getContextMenu().openAtPointer(e);e.stop();},_onBeforeContextMenuOpen:function(e){if(e.getData()==Q&&this.hasListener(dV)){this.fireDataEvent(dV,e);};},_onStopEvent:function(e){e.stopPropagation();},_getDragDropCursor:function(){return qx.ui.core.DragDropCursor.getInstance();},_applyDraggable:function(hM,hL){if(!this.isEnabled()&&hM===true){hM=false;};this._getDragDropCursor();if(hM){this.addListener(u,this._onDragStart);this.addListener(b,this._onDrag);this.addListener(D,this._onDragEnd);this.addListener(x,this._onDragChange);}else {this.removeListener(u,this._onDragStart);this.removeListener(b,this._onDrag);this.removeListener(D,this._onDragEnd);this.removeListener(x,this._onDragChange);};this.getContentElement().setAttribute(G,hM?cG:null);},_applyDroppable:function(hO,hN){if(!this.isEnabled()&&hO===true){hO=false;};this.getContentElement().setAttribute(db,hO?cG:null);},_onDragStart:function(e){this._getDragDropCursor().placeToPointer(e);this.getApplicationRoot().setGlobalCursor(cV);},_onDrag:function(e){this._getDragDropCursor().placeToPointer(e);},_onDragEnd:function(e){this._getDragDropCursor().moveTo(-1000,-1000);this.getApplicationRoot().resetGlobalCursor();},_onDragChange:function(e){var hP=this._getDragDropCursor();var hQ=e.getCurrentAction();hQ?hP.setAction(hQ):hP.resetAction();},visualizeFocus:function(){this.addState(o);},visualizeBlur:function(){this.removeState(o);},scrollChildIntoView:function(hV,hU,hT,hS){hS=typeof hS==dT?true:hS;var hR=qx.ui.core.queue.Layout;var parent;if(hS){hS=!hR.isScheduled(hV);parent=hV.getLayoutParent();if(hS&&parent){hS=!hR.isScheduled(parent);if(hS){parent.getChildren().forEach(function(hW){hS=hS&&!hR.isScheduled(hW);});};};};this.scrollChildIntoViewX(hV,hU,hS);this.scrollChildIntoViewY(hV,hT,hS);},scrollChildIntoViewX:function(ia,hX,hY){this.getContentElement().scrollChildIntoViewX(ia.getContentElement(),hX,hY);},scrollChildIntoViewY:function(ie,ib,ic){this.getContentElement().scrollChildIntoViewY(ie.getContentElement(),ib,ic);},focus:function(){if(this.isFocusable()){this.getFocusElement().focus();}else {throw new Error(dk);};},blur:function(){if(this.isFocusable()){this.getFocusElement().blur();}else {throw new Error(dk);};},activate:function(){this.getContentElement().activate();},deactivate:function(){this.getContentElement().deactivate();},tabFocus:function(){this.getFocusElement().focus();},hasChildControl:function(ig){if(!this.__jE){return false;};return !!this.__jE[ig];},__jE:null,_getCreatedChildControls:function(){return this.__jE;},getChildControl:function(ij,ii){if(!this.__jE){if(ii){return null;};this.__jE={};};var ih=this.__jE[ij];if(ih){return ih;};if(ii===true){return null;};return this._createChildControl(ij);},_showChildControl:function(il){var ik=this.getChildControl(il);ik.show();return ik;},_excludeChildControl:function(io){var im=this.getChildControl(io,true);if(im){im.exclude();};},_isChildControlVisible:function(iq){var ip=this.getChildControl(iq,true);if(ip){return ip.isVisible();};return false;},_releaseChildControl:function(iu){var ir=this.getChildControl(iu,false);if(!ir){throw new Error(t+iu);};delete ir.$$subcontrol;delete ir.$$subparent;var is=this.__jB;var forward=this._forwardStates;if(is&&forward&&ir instanceof qx.ui.core.Widget){for(var it in is){if(forward[it]){ir.removeState(it);};};};delete this.__jE[iu];return ir;},_createChildControl:function(iz){if(!this.__jE){this.__jE={};}else if(this.__jE[iz]){throw new Error(F+iz+dc);};var iw=iz.indexOf(O);try{if(iw==-1){var iv=this._createChildControlImpl(iz);}else {var iv=this._createChildControlImpl(iz.substring(0,iw),iz.substring(iw+1,iz.length));};}catch(iA){iA.message=ds+iz+L+this.toString()+di+iA.message;throw iA;};if(!iv){throw new Error(t+iz);};iv.$$subcontrol=iz;iv.$$subparent=this;var ix=this.__jB;var forward=this._forwardStates;if(ix&&forward&&iv instanceof qx.ui.core.Widget){for(var iy in ix){if(forward[iy]){iv.addState(iy);};};};this.fireDataEvent(r,iv);return this.__jE[iz]=iv;},_createChildControlImpl:function(iC,iB){return null;},_disposeChildControls:function(){var iG=this.__jE;if(!iG){return;};var iE=qx.ui.core.Widget;for(var iF in iG){var iD=iG[iF];if(!iE.contains(this,iD)){iD.destroy();}else {iD.dispose();};};delete this.__jE;},_findTopControl:function(){var iH=this;while(iH){if(!iH.$$subparent){return iH;};iH=iH.$$subparent;};return null;},getContentLocation:function(iJ){var iI=this.getContentElement().getDomElement();return iI?qx.bom.element.Location.get(iI,iJ):null;},setDomLeft:function(iL){var iK=this.getContentElement().getDomElement();if(iK){iK.style.left=iL+em;}else {throw new Error(ek);};},setDomTop:function(iN){var iM=this.getContentElement().getDomElement();if(iM){iM.style.top=iN+em;}else {throw new Error(ek);};},setDomPosition:function(iP,top){var iO=this.getContentElement().getDomElement();if(iO){iO.style.left=iP+em;iO.style.top=top+em;}else {throw new Error(ek);};},destroy:function(){if(this.$$disposed){return;};var parent=this.$$parent;if(parent){parent._remove(this);};qx.ui.core.queue.Dispose.add(this);},clone:function(){var iQ=qx.ui.core.LayoutItem.prototype.clone.call(this);if(this.getChildren){var iR=this.getChildren();for(var i=0,l=iR.length;i<l;i++ ){iQ.add(iR[i].clone());};};return iQ;}},destruct:function(){if(!qx.core.ObjectRegistry.inShutDown){{if(this.__js){qx.locale.Manager.getInstance().removeListenerById(this.__js);};};var iS=this.getContentElement();if(iS){iS.setAttribute(cL,null,true);};this._disposeChildControls();qx.ui.core.queue.Appearance.remove(this);qx.ui.core.queue.Layout.remove(this);qx.ui.core.queue.Visibility.remove(this);qx.ui.core.queue.Widget.remove(this);};if(this.getContextMenu()){this.setContextMenu(null);};if(!qx.core.ObjectRegistry.inShutDown){this.clearSeparators();this.__ju=null;}else {this._disposeArray(j);};this._disposeArray(dr);this.__jB=this.__jE=null;this._disposeObjects(ea,K);}});})();(function(){var a="blur",b="activate",c="focus",d="qx.ui.core.EventHandler";qx.Class.define(d,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(){qx.core.Object.call(this);this.__gs=qx.event.Registration.getManager(window);},statics:{PRIORITY:qx.event.Registration.PRIORITY_FIRST,SUPPORTED_TYPES:{mousemove:1,mouseover:1,mouseout:1,mousedown:1,mouseup:1,click:1,auxclick:1,dblclick:1,contextmenu:1,mousewheel:1,keyup:1,keydown:1,keypress:1,keyinput:1,capture:1,losecapture:1,focusin:1,focusout:1,focus:1,blur:1,activate:1,deactivate:1,appear:1,disappear:1,dragstart:1,dragend:1,dragover:1,dragleave:1,drop:1,drag:1,dragchange:1,droprequest:1,touchstart:1,touchend:1,touchmove:1,touchcancel:1,tap:1,longtap:1,swipe:1,dbltap:1,track:1,trackend:1,trackstart:1,pinch:1,rotate:1,roll:1,pointermove:1,pointerover:1,pointerout:1,pointerdown:1,pointerup:1,pointercancel:1},IGNORE_CAN_HANDLE:false},members:{__gs:null,__ld:{focusin:1,focusout:1,focus:1,blur:1},__le:{mouseover:1,mouseout:1,appear:1,disappear:1},canHandleEvent:function(f,e){return f instanceof qx.ui.core.Widget;},_dispatchEvent:function(j){var o=j.getTarget();var n=qx.ui.core.Widget.getWidgetByElement(o);var p=false;while(n&&n.isAnonymous()){var p=true;n=n.getLayoutParent();};if(n&&p&&j.getType()==b){n.getContentElement().activate();};if(this.__ld[j.getType()]){n=n&&n.getFocusTarget();if(!n){return;};};if(j.getRelatedTarget){var w=j.getRelatedTarget();var v=qx.ui.core.Widget.getWidgetByElement(w);while(v&&v.isAnonymous()){v=v.getLayoutParent();};if(v){if(this.__ld[j.getType()]){v=v.getFocusTarget();};if(v===n){return;};};};var r=j.getCurrentTarget();var t=qx.ui.core.Widget.getWidgetByElement(r);if(!t||t.isAnonymous()){return;};if(this.__ld[j.getType()]){t=t.getFocusTarget();};var u=j.getType();if(!t||!(t.isEnabled()||this.__le[u])){return;};var g=j.getEventPhase()==qx.event.type.Event.CAPTURING_PHASE;var q=this.__gs.getListeners(t,u,g);if(j.getEventPhase()==qx.event.type.Event.AT_TARGET){if(!q){q=[];};var h=this.__gs.getListeners(t,u,!g);if(h){q=q.concat(h);};};if(!q||q.length===0){return;};var k=qx.event.Pool.getInstance().getObject(j.constructor);j.clone(k);k.setTarget(n);k.setRelatedTarget(v||null);k.setCurrentTarget(t);var x=j.getOriginalTarget();if(x){var m=qx.ui.core.Widget.getWidgetByElement(x);while(m&&m.isAnonymous()){m=m.getLayoutParent();};k.setOriginalTarget(m);}else {k.setOriginalTarget(o);};for(var i=0,l=q.length;i<l;i++ ){var s=q[i].context||t;q[i].handler.call(s,k);};if(k.getPropagationStopped()){j.stopPropagation();};if(k.getDefaultPrevented()){j.preventDefault();};qx.event.Pool.getInstance().poolObject(k);},registerEvent:function(A,z,y){var B;if(z===c||z===a){B=A.getFocusElement();}else {B=A.getContentElement();};if(B){B.addListener(z,this._dispatchEvent,this,y);};},unregisterEvent:function(E,D,C){var F;if(D===c||D===a){F=E.getFocusElement();}else {F=E.getContentElement();};if(F){F.removeListener(D,this._dispatchEvent,this,C);};}},destruct:function(){this.__gs=null;},defer:function(G){qx.event.Registration.addHandler(G);}});})();(function(){var a="blur",b="qxDraggable",c="touch",d="qx.ui.core.Widget",f="longtap",g="Escape",h="drag",i="keydown",j="Unsupported data type: ",k="roll",l="drop",m="qxDroppable",n="qx.event.handler.DragDrop",o="mouse",p="This method must not be used outside the drop event listener!",q="Control",r="Shift",s="!",t="alias",u="droprequest",v="copy",w="pointerup",x="dragstart",y="move",z="pointerdown",A="dragchange",B="on",C="Alt",D="keyup",E="keypress",F="dragleave",G="dragend",H="dragover",I="left",J="Please use a droprequest listener to the drag source to fill the manager with data!",K="pointermove";qx.Class.define(n,{extend:qx.core.Object,implement:qx.event.IEventHandler,construct:function(L){qx.core.Object.call(this);this.__gs=L;this.__dd=L.getWindow().document.documentElement;this.__gs.addListener(this.__dd,f,this._onLongtap,this);this.__gs.addListener(this.__dd,z,this._onPointerdown,this);qx.event.Registration.addListener(window,a,this._onWindowBlur,this);this.__jR();},statics:{PRIORITY:qx.event.Registration.PRIORITY_NORMAL,SUPPORTED_TYPES:{dragstart:1,dragend:1,dragover:1,dragleave:1,drop:1,drag:1,dragchange:1,droprequest:1},IGNORE_CAN_HANDLE:true,ALLOWED_BUTTONS:[I],MIN_DRAG_DISTANCE:5},properties:{cursor:{check:d,nullable:true,init:null}},members:{__gs:null,__dd:null,__jF:null,__jG:null,__jH:null,__jI:null,__jJ:null,__c:null,__jK:null,__jL:null,__jM:false,__jN:false,__jO:false,__jP:null,__jQ:null,canHandleEvent:function(N,M){},registerEvent:function(Q,P,O){},unregisterEvent:function(T,S,R){},addType:function(U){this.__jH[U]=true;},addAction:function(V){this.__jI[V]=true;},supportsType:function(W){return !!this.__jH[W];},supportsAction:function(X){return !!this.__jI[X];},setDropAllowed:function(Y){this.__jN=Y;this.__jS();},getData:function(ba){if(!this.__jN||!this.__jF){throw new Error(p);};if(!this.__jH[ba]){throw new Error(j+ba+s);};if(!this.__c[ba]){this.__jK=ba;this.__hJ(u,this.__jG,this.__jF,false);};if(!this.__c[ba]){throw new Error(J);};return this.__c[ba]||null;},getCurrentAction:function(){this.__jS();return this.__jL;},getDragTarget:function(){return this.__jP;},addData:function(bb,bc){this.__c[bb]=bc;},getCurrentType:function(){return this.__jK;},isSessionActive:function(){return this.__jM;},__jR:function(){this.__jH={};this.__jI={};this.__jJ={};this.__c={};},__jS:function(){if(this.__jG==null){return;};var bg=this.__jI;var bd=this.__jJ;var be=null;if(this.__jN){if(bd.Shift&&bd.Control&&bg.alias){be=t;}else if(bd.Shift&&bd.Alt&&bg.copy){be=v;}else if(bd.Shift&&bg.move){be=y;}else if(bd.Alt&&bg.alias){be=t;}else if(bd.Control&&bg.copy){be=v;}else if(bg.move){be=y;}else if(bg.copy){be=v;}else if(bg.alias){be=t;};};var bf=this.__jL;if(be!=bf){if(this.__jF){this.__jL=be;this.__jO=this.__hJ(A,this.__jF,this.__jG,true);if(!this.__jO){be=null;};};if(be!=bf){this.__jL=be;this.__hJ(A,this.__jG,this.__jF,false);};};},__hJ:function(bm,bi,bj,bk,bn){var bl=qx.event.Registration;var bh=bl.createEvent(bm,qx.event.type.Drag,[bk,bn]);if(bi!==bj){bh.setRelatedTarget(bj);};return bl.dispatchEvent(bi,bh);},__jT:function(bo){while(bo&&bo.nodeType==1){if(bo.getAttribute(b)==B){return bo;};bo=bo.parentNode;};return null;},__jU:function(bp){while(bp&&bp.nodeType==1){if(bp.getAttribute(m)==B){return bp;};bp=bp.parentNode;};return null;},clearSession:function(){this.__gs.removeListener(this.__dd,K,this._onPointermove,this);this.__gs.removeListener(this.__dd,w,this._onPointerup,this,true);this.__gs.removeListener(this.__dd,i,this._onKeyDown,this,true);this.__gs.removeListener(this.__dd,D,this._onKeyUp,this,true);this.__gs.removeListener(this.__dd,E,this._onKeyPress,this,true);this.__gs.removeListener(this.__dd,k,this._onRoll,this,true);if(this.__jG){this.__hJ(G,this.__jG,this.__jF,false);};this.__jN=false;this.__jF=null;if(this.__jP){this.__jP.removeState(h);this.__jP=null;};this.__jG=null;this.__jM=false;this.__jQ=null;this.__jR();},_onLongtap:function(e){if(e.getPointerType()!=c){return;};this.__gs.addListener(this.__dd,k,this._onRoll,this,true);this._start(e);},_start:function(e){var bq=qx.event.handler.DragDrop.ALLOWED_BUTTONS.indexOf(e.getButton())!==-1;if(!e.isPrimary()||!bq){return false;};var bs=this.__jQ?this.__jQ.target:e.getTarget();var br=this.__jT(bs);if(br){this.__jG=br;var bt=qx.ui.core.Widget.getWidgetByElement(this.__jQ.original);while(bt&&bt.isAnonymous()){bt=bt.getLayoutParent();};if(bt){this.__jP=bt;bt.addState(h);};if(!this.__hJ(x,this.__jG,this.__jF,true,e)){return false;};this.__gs.addListener(this.__dd,i,this._onKeyDown,this,true);this.__gs.addListener(this.__dd,D,this._onKeyUp,this,true);this.__gs.addListener(this.__dd,E,this._onKeyPress,this,true);this.__jM=true;return true;};},_onPointerdown:function(e){if(e.isPrimary()){this.__jQ={target:e.getTarget(),original:e.getOriginalTarget(),left:e.getDocumentLeft(),top:e.getDocumentTop()};this.__gs.addListener(this.__dd,K,this._onPointermove,this);this.__gs.addListener(this.__dd,w,this._onPointerup,this,true);};},_onPointermove:function(e){if(!e.isPrimary()){return;};if(!this.__jM&&e.getPointerType()==o){var bA=this._getDelta(e);var bu=qx.event.handler.DragDrop.MIN_DRAG_DISTANCE;if(bA&&(Math.abs(bA.x)>bu||Math.abs(bA.y)>bu)){if(!this._start(e)){this.clearSession();return;};};};if(!this.__jM){return;};if(!this.__hJ(h,this.__jG,this.__jF,true,e)){this.clearSession();};var bv=e.getTarget();var by=this.getCursor();if(!by){by=qx.ui.core.DragDropCursor.getInstance();};var bx=by.getContentElement().getDomElement();if(bv!==bx){var bw=this.__jU(bv);if(bw&&bw!=this.__jF){if(this.__jF){this.__hJ(F,this.__jF,this.__jG,false,e);};this.__jN=true;this.__jF=bw;this.__jN=this.__hJ(H,bw,this.__jG,true,e);}else if(!bw&&this.__jF){this.__hJ(F,this.__jF,this.__jG,false,e);this.__jF=null;this.__jN=false;qx.event.Timer.once(this.__jS,this,0);};};var bz=this.__jJ;bz.Control=e.isCtrlPressed();bz.Shift=e.isShiftPressed();bz.Alt=e.isAltPressed();this.__jS();},_getDelta:function(e){if(!this.__jQ){return null;};var bB=e.getDocumentLeft()-this.__jQ.left;var bC=e.getDocumentTop()-this.__jQ.top;return {"x":bB,"y":bC};},_onPointerup:function(e){if(!e.isPrimary()){return;};if(this.__jN&&this.__jO){this.__hJ(l,this.__jF,this.__jG,false,e);};if(e.getTarget()==this.__jG){e.stopPropagation();};this.clearSession();},_onRoll:function(e){e.stop();},_onWindowBlur:function(e){this.clearSession();},_onKeyDown:function(e){var bD=e.getKeyIdentifier();switch(bD){case C:case q:case r:if(!this.__jJ[bD]){this.__jJ[bD]=true;this.__jS();};};},_onKeyUp:function(e){var bE=e.getKeyIdentifier();switch(bE){case C:case q:case r:if(this.__jJ[bE]){this.__jJ[bE]=false;this.__jS();};};},_onKeyPress:function(e){var bF=e.getKeyIdentifier();switch(bF){case g:this.clearSession();};}},destruct:function(){qx.event.Registration.removeListener(window,a,this._onWindowBlur,this);this.__jG=this.__jF=this.__gs=this.__dd=this.__jH=this.__jI=this.__jJ=this.__c=null;},defer:function(bG){qx.event.Registration.addHandler(bG);}});})();(function(){var a="qx.event.type.Drag",b="touch";qx.Class.define(a,{extend:qx.event.type.Event,members:{init:function(c,d){qx.event.type.Event.prototype.init.call(this,true,c);if(d){this._native=d.getNativeEvent()||null;this._originalTarget=d.getOriginalTarget()||null;}else {this._native=null;this._originalTarget=null;};return this;},clone:function(e){var f=qx.event.type.Event.prototype.clone.call(this,e);f._native=this._native;return f;},getDocumentLeft:function(){if(this._native==null){return 0;};var x=this._native.pageX;if(x!==undefined){if(x==0&&this._native.pointerType==b){x=this._native._original.changedTouches[0].pageX||0;};return Math.round(x);}else {var g=qx.dom.Node.getWindow(this._native.srcElement);return Math.round(this._native.clientX)+qx.bom.Viewport.getScrollLeft(g);};},getDocumentTop:function(){if(this._native==null){return 0;};var y=this._native.pageY;if(y!==undefined){if(y==0&&this._native.pointerType==b){y=this._native._original.changedTouches[0].pageY||0;};return Math.round(y);}else {var h=qx.dom.Node.getWindow(this._native.srcElement);return Math.round(this._native.clientY)+qx.bom.Viewport.getScrollTop(h);};},getManager:function(){return qx.event.Registration.getManager(this.getTarget()).getHandler(qx.event.handler.DragDrop);},addType:function(i){this.getManager().addType(i);},addAction:function(j){this.getManager().addAction(j);},supportsType:function(k){return this.getManager().supportsType(k);},supportsAction:function(l){return this.getManager().supportsAction(l);},addData:function(m,n){this.getManager().addData(m,n);},getData:function(o){return this.getManager().getData(o);},getCurrentType:function(){return this.getManager().getCurrentType();},getCurrentAction:function(){if(this.getDefaultPrevented()){return null;};return this.getManager().getCurrentAction();},setDropAllowed:function(p){this.getManager().setDropAllowed(p);},getDragTarget:function(){return this.getManager().getDragTarget();},stopSession:function(){this.getManager().clearSession();}}});})();(function(){var a="best-fit",b="placementRight",c="Boolean",d="bottom-right",e="' ",f="widget",g="placementLeft",h="qx.ui.core.MPlacement",i="left-top",j="Integer",k="left-middle",l="right-middle",m="top-center",n="[qx.ui.core.MPlacement.setMoveDirection()], the value was '",o="offsetRight",p="interval",q="keep-align",r="bottom-left",s="pointer",t="direct",u="shorthand",v="Invalid value for the parameter 'direction' ",w="offsetLeft",x="top-left",y="appear",z="offsetBottom",A="top",B="top-right",C="offsetTop",D="but 'top' or 'left' are allowed.",E="right-bottom",F="disappear",G="right-top",H="bottom-center",I="left-bottom",J="left";qx.Mixin.define(h,{statics:{__gE:null,__jV:J,setVisibleElement:function(K){this.__gE=K;},getVisibleElement:function(){return this.__gE;},setMoveDirection:function(L){if(L===A||L===J){this.__jV=L;}else {throw new Error(v+n+L+e+D);};},getMoveDirection:function(){return this.__jV;}},properties:{position:{check:[x,m,B,r,H,d,i,k,I,G,l,E],init:r,themeable:true},placeMethod:{check:[f,s],init:s,themeable:true},domMove:{check:c,init:false},placementModeX:{check:[t,q,a],init:q,themeable:true},placementModeY:{check:[t,q,a],init:q,themeable:true},offsetLeft:{check:j,init:0,themeable:true},offsetTop:{check:j,init:0,themeable:true},offsetRight:{check:j,init:0,themeable:true},offsetBottom:{check:j,init:0,themeable:true},offset:{group:[C,o,z,w],mode:u,themeable:true}},members:{__jW:null,__jX:null,__jY:null,getLayoutLocation:function(N){var P,O,R,top;O=N.getBounds();if(!O){return null;};R=O.left;top=O.top;var Q=O;N=N.getLayoutParent();while(N&&!N.isRootWidget()){O=N.getBounds();R+=O.left;top+=O.top;P=N.getInsets();R+=P.left;top+=P.top;N=N.getLayoutParent();};if(N.isRootWidget()){var M=N.getContentLocation();if(M){R+=M.left;top+=M.top;};};return {left:R,top:top,right:R+Q.width,bottom:top+Q.height};},moveTo:function(Y,top){var X=qx.ui.core.MPlacement.getVisibleElement();if(X){var W=this.getBounds();var V=X.getContentLocation();if(W&&V){var U=top+W.height;var T=Y+W.width;if((T>V.left&&Y<V.right)&&(U>V.top&&top<V.bottom)){var S=qx.ui.core.MPlacement.getMoveDirection();if(S===J){Y=Math.max(V.left-W.width,0);}else {top=Math.max(V.top-W.height,0);};};};};if(this.getDomMove()){this.setDomPosition(Y,top);}else {this.setLayoutProperties({left:Y,top:top});};},placeToWidget:function(bc,ba){if(ba){this.__ka();this.__jW=qx.lang.Function.bind(this.placeToWidget,this,bc,false);qx.event.Idle.getInstance().addListener(p,this.__jW);this.__jY=function(){this.__ka();};this.addListener(F,this.__jY,this);};var bb=bc.getContentLocation()||this.getLayoutLocation(bc);if(bb!=null){this._place(bb);return true;}else {return false;};},__ka:function(){if(this.__jW){qx.event.Idle.getInstance().removeListener(p,this.__jW);this.__jW=null;};if(this.__jY){this.removeListener(F,this.__jY,this);this.__jY=null;};},placeToPointer:function(event){var be=Math.round(event.getDocumentLeft());var top=Math.round(event.getDocumentTop());var bd={left:be,top:top,right:be,bottom:top};this._place(bd);},placeToElement:function(bh,bf){var location=qx.bom.element.Location.get(bh);var bg={left:location.left,top:location.top,right:location.left+bh.offsetWidth,bottom:location.top+bh.offsetHeight};if(bf){this.__jW=qx.lang.Function.bind(this.placeToElement,this,bh,false);qx.event.Idle.getInstance().addListener(p,this.__jW);this.addListener(F,function(){if(this.__jW){qx.event.Idle.getInstance().removeListener(p,this.__jW);this.__jW=null;};},this);};this._place(bg);},placeToPoint:function(bj){var bi={left:bj.left,top:bj.top,right:bj.left,bottom:bj.top};this._place(bi);},_getPlacementOffsets:function(){return {left:this.getOffsetLeft(),top:this.getOffsetTop(),right:this.getOffsetRight(),bottom:this.getOffsetBottom()};},__kb:function(bk){var bl=null;if(this._computePlacementSize){var bl=this._computePlacementSize();}else if(this.isVisible()){var bl=this.getBounds();};if(bl==null){this.addListenerOnce(y,function(){this.__kb(bk);},this);}else {bk.call(this,bl);};},_place:function(bm){this.__kb(function(bo){var bn=qx.util.placement.Placement.compute(bo,this.getLayoutParent().getBounds(),bm,this._getPlacementOffsets(),this.getPosition(),this.getPlacementModeX(),this.getPlacementModeY());this.removeState(g);this.removeState(b);this.addState(bm.left<bn.left?b:g);this.moveTo(bn.left,bn.top);});}},destruct:function(){this.__ka();}});})();(function(){var a="Number",b="interval",c="_applyTimeoutInterval",d="qx.event.type.Event",e="qx.event.Idle",f="singleton";qx.Class.define(e,{extend:qx.core.Object,type:f,construct:function(){qx.core.Object.call(this);var g=new qx.event.Timer(this.getTimeoutInterval());g.addListener(b,this._onInterval,this);g.start();this.__de=g;},events:{"interval":d},properties:{timeoutInterval:{check:a,init:100,apply:c}},members:{__de:null,_applyTimeoutInterval:function(h){this.__de.setInterval(h);},_onInterval:function(){this.fireEvent(b);}},destruct:function(){if(this.__de){this.__de.stop();};this.__de=null;}});})();(function(){var a="-",b="align-start",c="best-fit",d="qx.util.placement.Placement",e='__kc',f="middle",g="bottom",h="keep-align",i="align-end",j="align-center",k="Invalid 'mode' argument!'",l="center",m="edge-start",n="Class",o="direct",p="top",q="left",r="right",s="edge-end";qx.Class.define(d,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__kc=qx.util.placement.DirectAxis;},properties:{axisX:{check:n},axisY:{check:n},edge:{check:[p,r,g,q],init:p},align:{check:[p,r,g,q,l,f],init:r}},statics:{__kd:null,compute:function(D,w,t,u,C,x,y){this.__kd=this.__kd||new qx.util.placement.Placement();var A=C.split(a);var z=A[0];var v=A[1];{var B;};this.__kd.set({axisX:this.__kh(x),axisY:this.__kh(y),edge:z,align:v});return this.__kd.compute(D,w,t,u);},__ke:null,__kf:null,__kg:null,__kh:function(E){switch(E){case o:this.__ke=this.__ke||qx.util.placement.DirectAxis;return this.__ke;case h:this.__kf=this.__kf||qx.util.placement.KeepAlignAxis;return this.__kf;case c:this.__kg=this.__kg||qx.util.placement.BestFitAxis;return this.__kg;default:throw new Error(k);};}},members:{__kc:null,compute:function(K,H,F,G){{};var I=this.getAxisX()||this.__kc;var L=I.computeStart(K.width,{start:F.left,end:F.right},{start:G.left,end:G.right},H.width,this.__ki());var J=this.getAxisY()||this.__kc;var top=J.computeStart(K.height,{start:F.top,end:F.bottom},{start:G.top,end:G.bottom},H.height,this.__kj());return {left:L,top:top};},__ki:function(){var N=this.getEdge();var M=this.getAlign();if(N==q){return m;}else if(N==r){return s;}else if(M==q){return b;}else if(M==l){return j;}else if(M==r){return i;};},__kj:function(){var P=this.getEdge();var O=this.getAlign();if(P==p){return m;}else if(P==g){return s;}else if(O==p){return b;}else if(O==f){return j;}else if(O==g){return i;};}},destruct:function(){this._disposeObjects(e);}});})();(function(){var a="align-start",b="align-end",c="qx.util.placement.AbstractAxis",d="edge-start",e="align-center",f="abstract method call!",g="edge-end";qx.Bootstrap.define(c,{extend:Object,statics:{computeStart:function(j,k,l,h,i){throw new Error(f);},_moveToEdgeAndAlign:function(n,o,p,m){switch(m){case d:return o.start-p.end-n;case g:return o.end+p.start;case a:return o.start+p.start;case e:return o.start+parseInt((o.end-o.start-n)/2,10)+p.start;case b:return o.end-p.end-n;};},_isInRange:function(r,s,q){return r>=0&&r+s<=q;}}});})();(function(){var a="qx.util.placement.DirectAxis";qx.Bootstrap.define(a,{statics:{_moveToEdgeAndAlign:qx.util.placement.AbstractAxis._moveToEdgeAndAlign,computeStart:function(d,e,f,b,c){return this._moveToEdgeAndAlign(d,e,f,c);}}});})();(function(){var a="qx.util.placement.KeepAlignAxis",b="edge-start",c="edge-end";qx.Bootstrap.define(a,{statics:{_moveToEdgeAndAlign:qx.util.placement.AbstractAxis._moveToEdgeAndAlign,_isInRange:qx.util.placement.AbstractAxis._isInRange,computeStart:function(k,f,g,d,j){var i=this._moveToEdgeAndAlign(k,f,g,j);var e,h;if(this._isInRange(i,k,d)){return i;};if(j==b||j==c){e=f.start-g.end;h=f.end+g.start;}else {e=f.end-g.end;h=f.start+g.start;};if(e>d-h){i=Math.max(0,e-k);}else {i=h;};return i;}}});})();(function(){var a="qx.util.placement.BestFitAxis";qx.Bootstrap.define(a,{statics:{_isInRange:qx.util.placement.AbstractAxis._isInRange,_moveToEdgeAndAlign:qx.util.placement.AbstractAxis._moveToEdgeAndAlign,computeStart:function(g,c,d,b,f){var e=this._moveToEdgeAndAlign(g,c,d,f);if(this._isInRange(e,g,b)){return e;};if(e<0){e=Math.min(0,b-g);};if(e+g>b){e=Math.max(0,b-g);};return e;}}});})();(function(){var a="Image could not be loaded: ",b="Boolean",c="px",d=".png",e="background-image",f="engine.version",g="scale",h="changeSource",j="x",l="div",m="aborted",n="background-size",o="nonScaled",p="3",q="qx.ui.basic.Image",r="top",s="0 0",t=", no-repeat",u="loaded",v="backgroundImage",w="backgroundRepeat",x="-disabled.$1",y="class",z="qx.event.type.Event",A="image",B="loadingFailed",C="css.alphaimageloaderneeded",D="1.5",E="String",F="browser.documentmode",G="backgroundPosition",H="border-box",I="left",J="_applySource",K="__kk",L="$$widget",M="@",N="px, ",O='.',P="scaled",Q=", ",R="2",S="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7",T="mshtml",U="engine.name",V=", 0 0",W="_applyScale",X="position",Y="replacement",bl="img",bm="no-repeat",bn="background-position",bh="hidden",bi="alphaScaled",bj=",",bk="absolute";qx.Class.define(q,{extend:qx.ui.core.Widget,construct:function(bo){this.__kk={};qx.ui.core.Widget.call(this);if(bo){this.setSource(bo);};},properties:{source:{check:E,init:null,nullable:true,event:h,apply:J,themeable:true},scale:{check:b,init:false,themeable:true,apply:W},appearance:{refine:true,init:A},allowShrinkX:{refine:true,init:false},allowShrinkY:{refine:true,init:false},allowGrowX:{refine:true,init:false},allowGrowY:{refine:true,init:false}},events:{loadingFailed:z,loaded:z,aborted:z},statics:{PLACEHOLDER_IMAGE:S},members:{__kl:null,__km:null,__iP:null,__kk:null,__kn:null,__ko:null,__kp:0,_onChangeTheme:function(){qx.ui.core.Widget.prototype._onChangeTheme.call(this);this._styleSource();},getContentElement:function(){return this.__kt();},_createContentElement:function(){return this.__kt();},_getContentHint:function(){return {width:this.__kl||0,height:this.__km||0};},_applyDecorator:function(br,bq){qx.ui.core.Widget.prototype._applyDecorator.call(this,br,bq);var bs=this.getSource();bs=qx.util.AliasManager.getInstance().resolve(bs);var bp=this.getContentElement();if(this.__ko){bp=bp.getChild(0);};this.__kC(bp,bs);},_applyPadding:function(bu,bt,name){qx.ui.core.Widget.prototype._applyPadding.call(this,bu,bt,name);var bv=this.getContentElement();if(this.__ko){bv.getChild(0).setStyles({top:this.getPaddingTop()||0,left:this.getPaddingLeft()||0});}else {bv.setPadding(this.getPaddingLeft()||0,this.getPaddingTop()||0);};},renderLayout:function(by,top,bw,bz){qx.ui.core.Widget.prototype.renderLayout.call(this,by,top,bw,bz);var bx=this.getContentElement();if(this.__ko){bx.getChild(0).setStyles({width:bw-(this.getPaddingLeft()||0)-(this.getPaddingRight()||0),height:bz-(this.getPaddingTop()||0)-(this.getPaddingBottom()||0),top:this.getPaddingTop()||0,left:this.getPaddingLeft()||0});};},_applyEnabled:function(bB,bA){qx.ui.core.Widget.prototype._applyEnabled.call(this,bB,bA);if(this.getSource()){this._styleSource();};},_applySource:function(bD,bC){if(bC){if(qx.io.ImageLoader.isLoading(bC)){qx.io.ImageLoader.abort(bC);};};this._styleSource();},_applyScale:function(bE){this._styleSource();},__kq:function(bF){this.__iP=bF;},__kr:function(){if(this.__iP==null){var bH=this.getSource();var bG=false;if(bH!=null){bG=qx.lang.String.endsWith(bH,d);};if(this.getScale()&&bG&&qx.core.Environment.get(C)){this.__iP=bi;}else if(this.getScale()){this.__iP=P;}else {this.__iP=o;};};return this.__iP;},__ks:function(bK){var bJ;var bI;if(bK==bi){bJ=true;bI=l;}else if(bK==o){bJ=false;bI=l;}else {bJ=true;bI=bl;};var bM=new qx.html.Image(bI);bM.setAttribute(L,this.toHashCode());bM.setScale(bJ);bM.setStyles({"overflowX":bh,"overflowY":bh,"boxSizing":H});if(qx.core.Environment.get(C)){var bL=this.__ko=new qx.html.Element(l);bL.setAttribute(L,this.toHashCode());bL.setStyle(X,bk);bL.add(bM);return bL;};return bM;},__kt:function(){if(this.$$disposed){return null;};var bN=this.__kr();if(this.__kk[bN]==null){this.__kk[bN]=this.__ks(bN);};var bO=this.__kk[bN];if(!this.__kn){this.__kn=bO;};return bO;},_styleSource:function(){var bT=qx.util.AliasManager.getInstance();var bS=qx.util.ResourceManager.getInstance();var bV=bT.resolve(this.getSource());var bU=this.getContentElement();if(this.__ko){bU=bU.getChild(0);};if(!bV){bU.resetSource();return;};this.__kw(bV);if((qx.core.Environment.get(U)==T)&&(parseInt(qx.core.Environment.get(f),10)<9||qx.core.Environment.get(F)<9)){var bQ=this.getScale()?g:bm;bU.tagNameHint=qx.bom.element.Decoration.getTagName(bQ,bV);};var bR=this.__kv();if(qx.util.ResourceManager.getInstance().has(bV)){var bW=this._findHighResolutionSource(bV);if(bW){var bY=bS.getImageHeight(bV);var bX=bS.getImageWidth(bV);this.setWidth(bY);this.setHeight(bX);var bP=bY+N+bX+c;this.__kn.setStyle(n,bP);this.setSource(bW);bV=bW;};this.__ky(bR,bV);this.__ku();}else if(qx.io.ImageLoader.isLoaded(bV)){this.__kz(bR,bV);this.__ku();}else {this.__kA(bR,bV);};},__ku:function(){this.__kp++ ;qx.bom.AnimationFrame.request(function(ca){if(ca===this.__kp){this.fireEvent(u);}else {this.fireEvent(m);};}.bind(this,this.__kp));},__kv:function(){var cb=this.__kn;if(this.__ko){cb=cb.getChild(0);};return cb;},__kw:qx.core.Environment.select(U,{"mshtml":function(cd){var ce=qx.core.Environment.get(C);var cc=qx.lang.String.endsWith(cd,d);if(ce&&cc){if(this.getScale()&&this.__kr()!=bi){this.__kq(bi);}else if(!this.getScale()&&this.__kr()!=o){this.__kq(o);};}else {if(this.getScale()&&this.__kr()!=P){this.__kq(P);}else if(!this.getScale()&&this.__kr()!=o){this.__kq(o);};};this.__kx(this.__kt());},"default":function(cf){if(this.getScale()&&this.__kr()!=P){this.__kq(P);}else if(!this.getScale()&&this.__kr(o)){this.__kq(o);};this.__kx(this.__kt());}}),__kx:function(cj){var ci=this.__kn;if(ci!=cj){if(ci!=null){var cu=c;var cg={};var co=this.getBounds();if(co!=null){cg.width=co.width+cu;cg.height=co.height+cu;};var cp=this.getInsets();cg.left=parseInt(ci.getStyle(I)||cp.left)+cu;cg.top=parseInt(ci.getStyle(r)||cp.top)+cu;cg.zIndex=10;var cm=this.__ko?cj.getChild(0):cj;cm.setStyles(cg,true);cm.setSelectable(this.getSelectable());if(!ci.isVisible()){cj.hide();};if(!ci.isIncluded()){cj.exclude();};var cr=ci.getParent();if(cr){var ch=cr.getChildren().indexOf(ci);cr.removeAt(ch);cr.addAt(cj,ch);};var cl=cm.getNodeName();cm.setSource(null);var ck=this.__kv();cm.tagNameHint=cl;cm.setAttribute(y,ck.getAttribute(y));qx.html.Element.flush();var ct=ck.getDomElement();var cs=cj.getDomElement();var cq=ci.getListeners()||[];cq.forEach(function(cv){cj.addListener(cv.type,cv.handler,cv.self,cv.capture);});if(ct&&cs){var cn=ct.$$hash;ct.$$hash=cs.$$hash;cs.$$hash=cn;};this.__kn=cj;};};},__ky:function(cx,cz){var cy=qx.util.ResourceManager.getInstance();if(!this.getEnabled()){var cw=cz.replace(/\.([a-z]+)$/,x);if(cy.has(cw)){cz=cw;this.addState(Y);}else {this.removeState(Y);};};if(cx.getSource()===cz){return;};this.__kC(cx,cz);this.__kE(cy.getImageWidth(cz),cy.getImageHeight(cz));},__kz:function(cA,cE){var cC=qx.io.ImageLoader;this.__kC(cA,cE);var cD=cC.getWidth(cE);var cB=cC.getHeight(cE);this.__kE(cD,cB);},__kA:function(cF,cI){var cJ=qx.io.ImageLoader;{var cH,cG,self;};if(!cJ.isFailed(cI)){cJ.load(cI,this.__kD,this);}else {if(cF!=null){cF.resetSource();};};},__kC:function(cK,cO){if(cK.getNodeName()==l){var cS=qx.theme.manager.Decoration.getInstance().resolve(this.getDecorator());if(cS){var cP=(cS.getStartColor()&&cS.getEndColor());var cN=cS.getBackgroundImage();if(cP||cN){var cL=this.getScale()?g:bm;var cM=qx.bom.element.Decoration.getAttributes(cO,cL);var cR=cS.getStyles(true);var cQ={"backgroundImage":cM.style.backgroundImage,"backgroundPosition":(cM.style.backgroundPosition||s),"backgroundRepeat":(cM.style.backgroundRepeat||bm)};if(cN){cQ[G]+=bj+cR[bn]||s;cQ[w]+=Q+cS.getBackgroundRepeat();};if(cP){cQ[G]+=V;cQ[w]+=t;};cQ[v]+=bj+cR[e];cK.setStyles(cQ);return;};}else {cK.setSource(null);};};cK.setSource(cO);},_findHighResolutionSource:function(cT){var cW=[p,R,D];var cV=parseFloat(qx.bom.client.Device.getDevicePixelRatio().toFixed(2));if(cV<=1){return false;};var i=cW.length;while(i>0&&cV>cW[ --i]){};var cU;var k;for(k=i;k>=0;k-- ){cU=this._getHighResolutionSource(cT,cW[k]);if(cU){return cU;};};for(k=i+1;k<cW.length;k++ ){cU=this._getHighResolutionSource(cT,cW[k]);if(cU){return cU;};};return null;},_getHighResolutionSource:function(cX,cY){var db=cX.lastIndexOf(O);if(db>-1){var da=M+cY+j;var dc=cX.slice(0,db)+da+cX.slice(db);if(qx.util.ResourceManager.getInstance().has(dc)){return dc;};};return null;},__kD:function(dd,de){if(this.$$disposed===true){return;};if(dd!==qx.util.AliasManager.getInstance().resolve(this.getSource())){this.fireEvent(m);return;};if(de.failed){this.warn(a+dd);this.fireEvent(B);}else if(de.aborted){this.fireEvent(m);return;}else {this.fireEvent(u);};this.__kz(this.__kv(),dd);},__kE:function(df,dg){if(df!==this.__kl||dg!==this.__km){this.__kl=df;this.__km=dg;qx.ui.core.queue.Layout.add(this);};}},destruct:function(){for(var dh in this.__kk){if(this.__kk.hasOwnProperty(dh)){this.__kk[dh].setAttribute(L,null,true);};};delete this.__kn;if(this.__ko){delete this.__ko;};this._disposeMap(K);}});})();(function(){var a="mshtml",b='img',c="",d="qx.globalErrorHandling",e="load",f="qx.io.ImageLoader";qx.Bootstrap.define(f,{statics:{__cP:{},__kF:{width:null,height:null},__kG:/\.(png|gif|jpg|jpeg|bmp)\b/i,__kH:/^data:image\/(png|gif|jpg|jpeg|bmp)\b/i,isLoaded:function(g){var h=this.__cP[g];return !!(h&&h.loaded);},isFailed:function(j){var k=this.__cP[j];return !!(k&&k.failed);},isLoading:function(m){var n=this.__cP[m];return !!(n&&n.loading);},getFormat:function(r){var q=this.__cP[r];if(!q||!q.format){var o=this.__kH.exec(r);if(o!=null){var p=(q&&qx.lang.Type.isNumber(q.width)?q.width:this.__kF.width);var s=(q&&qx.lang.Type.isNumber(q.height)?q.height:this.__kF.height);q={loaded:true,format:o[1],width:p,height:s};};};return q?q.format:null;},getSize:function(t){var u=this.__cP[t];return u?{width:u.width,height:u.height}:this.__kF;},getWidth:function(v){var w=this.__cP[v];return w?w.width:null;},getHeight:function(x){var y=this.__cP[x];return y?y.height:null;},load:function(B,A,C){var D=this.__cP[B];if(!D){D=this.__cP[B]={};};if(A&&!C){C=window;};if(D.loaded||D.loading||D.failed){if(A){if(D.loading){D.callbacks.push(A,C);}else {A.call(C,B,D);};};}else {D.loading=true;D.callbacks=[];if(A){D.callbacks.push(A,C);};var z=document.createElement(b);var E=qx.lang.Function.listener(this.__kI,this,z,B);z.onload=E;z.onerror=E;z.src=B;D.element=z;};},abort:function(F){var I=this.__cP[F];if(I&&!I.loaded){I.aborted=true;var H=I.callbacks;var G=I.element;G.onload=G.onerror=null;G.src=c;delete I.callbacks;delete I.element;delete I.loading;for(var i=0,l=H.length;i<l;i+=2){H[i].call(H[i+1],F,I);};};this.__cP[F]=null;},__kI:function(){var J=qx.core.Environment.select(d,{"true":qx.event.GlobalError.observeMethod(this.__kJ),"false":this.__kJ});J.apply(this,arguments);},__kJ:function(event,L,K){var P=this.__cP[K];if(qx.bom.client.Engine.getName()==a&&parseFloat(qx.bom.client.Engine.getVersion())===11){document.body.appendChild(L);};var M=function(Q){return (Q&&Q.height!==0);};if(event.type===e&&M(L)){P.loaded=true;P.width=L.width;P.height=L.height;var N=this.__kG.exec(K);if(N!=null){P.format=N[1];};}else {P.failed=true;};if(qx.bom.client.Engine.getName()==a&&parseFloat(qx.bom.client.Engine.getVersion())===11){document.body.removeChild(L);};L.onload=L.onerror=null;var O=P.callbacks;delete P.loading;delete P.callbacks;delete P.element;for(var i=0,l=O.length;i<l;i+=2){O[i].call(O[i+1],K,P);};},dispose:function(){this.__cP={};}}});})();(function(){var a="source",b="engine.name",c="",d="mshtml",e="px",f="px ",g="no-repeat",h="backgroundImage",i="scale",j="webkit",k="div",l="qx.html.Image",m="qx/static/blank.gif",n="backgroundPosition";qx.Class.define(l,{extend:qx.html.Element,members:{__kK:null,__kL:null,tagNameHint:null,setPadding:function(o,p){this.__kL=o;this.__kK=p;if(this.getNodeName()==k){this.setStyle(n,o+f+p+e);};},_applyProperty:function(name,t){qx.html.Element.prototype._applyProperty.call(this,name,t);if(name===a){var s=this.getDomElement();var q=this.getAllStyles();if(this.getNodeName()==k&&this.getStyle(h)){q.backgroundRepeat=null;};var u=this._getProperty(a);var r=this._getProperty(i);var v=r?i:g;if(u!=null){u=u||null;q.paddingTop=this.__kK;q.paddingLeft=this.__kL;qx.bom.element.Decoration.update(s,u,v,q);};};},_removeProperty:function(x,w){if(x==a){this._setProperty(x,c,w);}else {this._setProperty(x,null,w);};},_createDomElement:function(){var z=this._getProperty(i);var A=z?i:g;if((qx.core.Environment.get(b)==d)){var y=this._getProperty(a);if(this.tagNameHint!=null){this.setNodeName(this.tagNameHint);}else {this.setNodeName(qx.bom.element.Decoration.getTagName(A,y));};}else {this.setNodeName(qx.bom.element.Decoration.getTagName(A));};return qx.html.Element.prototype._createDomElement.call(this);},_copyData:function(B){return qx.html.Element.prototype._copyData.call(this,true);},setSource:function(C){this._setProperty(a,C);return this;},getSource:function(){return this._getProperty(a);},resetSource:function(){if((qx.core.Environment.get(b)==j)){this._setProperty(a,m);}else {this._removeProperty(a,true);};return this;},setScale:function(D){this._setProperty(i,D);return this;},getScale:function(){return this._getProperty(i);}}});})();(function(){var a="qx/icon",b="repeat",c="px",d=".png",f="crop",g="px ",h="background-image",i="scale",j="no-repeat",k="div",l="Potential clipped image candidate: ",m="progid:DXImageTransform.Microsoft.AlphaImageLoader(src='",n='<div style="',o="scale-x",p="css.alphaimageloaderneeded",q="repeat-y",r='<img src="',s="qx.bom.element.Decoration",t="Image modification not possible because elements could not be replaced at runtime anymore!",u="', sizingMethod='",v="",w='"/>',x="png",y="img",z="')",A='"></div>',B="mshtml",C="engine.name",D='" style="',E="none",F="b64",G="webkit",H=" ",I="repeat-x",J="background-repeat",K="DXImageTransform.Microsoft.AlphaImageLoader",L="qx/static/blank.gif",M="scale-y",N="absolute";qx.Class.define(s,{statics:{DEBUG:false,__kM:{},__kN:qx.core.Environment.select(C,{"mshtml":{"scale-x":true,"scale-y":true,"scale":true,"no-repeat":true},"default":null}),__kO:{"scale-x":y,"scale-y":y,"scale":y,"repeat":k,"no-repeat":k,"repeat-x":k,"repeat-y":k},update:function(R,S,P,O){var T=this.getTagName(P,S);if(T!=R.tagName.toLowerCase()){throw new Error(t);};var Q=this.getAttributes(S,P,O);if(T===y){R.src=Q.src||qx.util.ResourceManager.getInstance().toUri(L);};if(R.style.backgroundPosition!=v&&Q.style.backgroundPosition===undefined){Q.style.backgroundPosition=null;};if(R.style.clip!=v&&Q.style.clip===undefined){Q.style.clip=null;};qx.bom.element.Style.setStyles(R,Q.style);if(qx.core.Environment.get(p)){try{R.filters[K].apply();}catch(e){};};},create:function(X,V,U){var Y=this.getTagName(V,X);var W=this.getAttributes(X,V,U);var ba=qx.bom.element.Style.compile(W.style);if(Y===y){return r+W.src+D+ba+w;}else {return n+ba+A;};},getTagName:function(bc,bb){if(bb&&qx.core.Environment.get(p)&&this.__kN[bc]&&qx.lang.String.endsWith(bb,d)){return k;};return this.__kO[bc];},getAttributes:function(bh,be,bd){if(!bd){bd={};};if(!bd.position){bd.position=N;};if((qx.core.Environment.get(C)==B)){bd.fontSize=0;bd.lineHeight=0;}else if((qx.core.Environment.get(C)==G)){bd.WebkitUserDrag=E;};var bf=qx.util.ResourceManager.getInstance().getImageFormat(bh)||qx.io.ImageLoader.getFormat(bh);{};var bi;if(qx.core.Environment.get(p)&&this.__kN[be]&&bf===x){var bj=this.__kQ(bh);this.__kP(bd,bj.width,bj.height);bi=this.processAlphaFix(bd,be,bh);}else {delete bd.clip;if(be===i){bi=this.__kR(bd,be,bh);}else if(be===o||be===M){bi=this.__kS(bd,be,bh);}else {bi=this.__kV(bd,be,bh);};};return bi;},__kP:function(bl,bk,bm){if(bl.width==null&&bk!=null){bl.width=bk+c;};if(bl.height==null&&bm!=null){bl.height=bm+c;};},__kQ:function(bn){var bo=qx.util.ResourceManager.getInstance().getImageWidth(bn)||qx.io.ImageLoader.getWidth(bn);var bp=qx.util.ResourceManager.getInstance().getImageHeight(bn)||qx.io.ImageLoader.getHeight(bn);return {width:bo,height:bp};},processAlphaFix:function(bs,bt,br){if(bt==b||bt==I||bt==q){return bs;};var bu=bt==j?f:i;var bq=m+qx.util.ResourceManager.getInstance().toUri(br)+u+bu+z;bs.filter=bq;bs.backgroundImage=bs.backgroundRepeat=v;delete bs[h];delete bs[J];return {style:bs};},__kR:function(bw,bx,bv){var by=qx.util.ResourceManager.getInstance().toUri(bv);var bz=this.__kQ(bv);this.__kP(bw,bz.width,bz.height);return {src:by,style:bw};},__kS:function(bA,bB,bD){var bC=qx.util.ResourceManager.getInstance();var bG=bC.getCombinedFormat(bD);var bI=this.__kQ(bD);var bE;if(bG){var bH=bC.getData(bD);var bF=bH[4];if(bG==F){bE=bC.toDataUri(bD);}else {bE=bC.toUri(bF);};if(bB===o){bA=this.__kT(bA,bH,bI.height);}else {bA=this.__kU(bA,bH,bI.width);};return {src:bE,style:bA};}else {{};if(bB==o){bA.height=bI.height==null?null:bI.height+c;}else if(bB==M){bA.width=bI.width==null?null:bI.width+c;};bE=bC.toUri(bD);return {src:bE,style:bA};};},__kT:function(bJ,bK,bM){var bL=qx.util.ResourceManager.getInstance().getImageHeight(bK[4]);bJ.clip={top:-bK[6],height:bM};bJ.height=bL+c;if(bJ.top!=null){bJ.top=(parseInt(bJ.top,10)+bK[6])+c;}else if(bJ.bottom!=null){bJ.bottom=(parseInt(bJ.bottom,10)+bM-bL-bK[6])+c;};return bJ;},__kU:function(bO,bP,bN){var bQ=qx.util.ResourceManager.getInstance().getImageWidth(bP[4]);bO.clip={left:-bP[5],width:bN};bO.width=bQ+c;if(bO.left!=null){bO.left=(parseInt(bO.left,10)+bP[5])+c;}else if(bO.right!=null){bO.right=(parseInt(bO.right,10)+bN-bQ-bP[5])+c;};return bO;},__kV:function(bR,bS,bV){var bU=qx.util.ResourceManager.getInstance();var bT=bU.getCombinedFormat(bV);var ce=this.__kQ(bV);if(bT&&bS!==b){var cd=bU.getData(bV);var cb=cd[4];if(bT==F){var bX=bU.toDataUri(bV);var bW=0;var bY=0;}else {var bX=bU.toUri(cb);var bW=cd[5];var bY=cd[6];if(bR.paddingTop||bR.paddingLeft||bR.paddingRight||bR.paddingBottom){var top=bR.paddingTop||0;var cf=bR.paddingLeft||0;bW+=bR.paddingLeft||0;bY+=bR.paddingTop||0;bR.clip={left:cf,top:top,width:ce.width,height:ce.height};};};var ca=qx.bom.element.Background.getStyles(bX,bS,bW,bY);for(var cc in ca){bR[cc]=ca[cc];};if(ce.width!=null&&bR.width==null&&(bS==q||bS===j)){bR.width=ce.width+c;};if(ce.height!=null&&bR.height==null&&(bS==I||bS===j)){bR.height=ce.height+c;};return {style:bR};}else {var top=bR.paddingTop||0;var cf=bR.paddingLeft||0;bR.backgroundPosition=cf+g+top+c;{};this.__kP(bR,ce.width,ce.height);this.__kW(bR,bV,bS);return {style:bR};};},__kW:function(cg,cj,ch){var top=null;var cm=null;if(cg.backgroundPosition){var ci=cg.backgroundPosition.split(H);cm=parseInt(ci[0],10);if(isNaN(cm)){cm=ci[0];};top=parseInt(ci[1],10);if(isNaN(top)){top=ci[1];};};var ck=qx.bom.element.Background.getStyles(cj,ch,cm,top);for(var cl in ck){cg[cl]=ck[cl];};if(cg.filter){cg.filter=v;};},__kX:function(cn){if(this.DEBUG&&qx.util.ResourceManager.getInstance().has(cn)&&cn.indexOf(a)==-1){if(!this.__kM[cn]){qx.log.Logger.debug(l+cn);this.__kM[cn]=true;};};}}});})();(function(){var a="')",b="gecko",c="background-image:url(",d="0",e=");",f="",g="px",h="number",i=")",j="background-repeat:",k="engine.version",l="data:",m=" ",n="qx.bom.element.Background",o=";",p="url(",q="background-position:",r="base64",s="url('",t="engine.name",u="'";qx.Class.define(n,{statics:{__kY:[c,null,e,q,null,o,j,null,o],__la:{backgroundImage:null,backgroundPosition:null,backgroundRepeat:null},__lb:function(z,top){var v=qx.core.Environment.get(t);var x=qx.core.Environment.get(k);if(v==b&&x<1.9&&z==top&&typeof z==h){top+=0.01;};if(z){var y=(typeof z==h)?z+g:z;}else {y=d;};if(top){var w=(typeof top==h)?top+g:top;}else {w=d;};return y+m+w;},__lc:function(A){var String=qx.lang.String;var B=A.substr(0,50);return String.startsWith(B,l)&&String.contains(B,r);},compile:function(F,D,H,top){var G=this.__lb(H,top);var E=qx.util.ResourceManager.getInstance().toUri(F);if(this.__lc(E)){E=u+E+u;};var C=this.__kY;C[1]=E;C[4]=G;C[7]=D;return C.join(f);},getStyles:function(L,J,N,top){if(!L){return this.__la;};var M=this.__lb(N,top);var K=qx.util.ResourceManager.getInstance().toUri(L);var O;if(this.__lc(K)){O=s+K+a;}else {O=p+K+i;};var I={backgroundPosition:M,backgroundImage:O};if(J!=null){I.backgroundRepeat=J;};return I;},set:function(T,S,Q,U,top){var P=this.getStyles(S,Q,U,top);for(var R in P){T.style[R]=P[R];};}}});})();(function(){var a="dragdrop-cursor",b="_applyAction",c="alias",d="qx.ui.core.DragDropCursor",e="move",f="singleton",g="copy";qx.Class.define(d,{extend:qx.ui.basic.Image,include:qx.ui.core.MPlacement,type:f,construct:function(){qx.ui.basic.Image.call(this);this.setZIndex(1e8);this.setDomMove(true);var h=this.getApplicationRoot();h.add(this,{left:-1000,top:-1000});},properties:{appearance:{refine:true,init:a},action:{check:[c,g,e],apply:b,nullable:true}},members:{_applyAction:function(j,i){if(i){this.removeState(i);};if(j){this.addState(j);};}}});})();(function(){var a='indexOf',b='slice',c='concat',d='toLocaleLowerCase',e="qx.type.BaseString",f="",g='trim',h='match',j='toLocaleUpperCase',k='search',m='replace',n='toLowerCase',o='charCodeAt',p='split',q='substring',r='lastIndexOf',s='substr',t='toUpperCase',u='charAt';qx.Class.define(e,{extend:Object,construct:function(v){var v=v||f;this.__lg=v;this.length=v.length;},members:{$$isString:true,length:0,__lg:null,toString:function(){return this.__lg;},charAt:null,valueOf:null,charCodeAt:null,concat:null,indexOf:null,lastIndexOf:null,match:null,replace:null,search:null,slice:null,split:null,substr:null,substring:null,toLowerCase:null,toUpperCase:null,toHashCode:function(){return qx.core.ObjectRegistry.toHashCode(this);},toLocaleLowerCase:null,toLocaleUpperCase:null,base:function(x,w){return qx.core.Object.prototype.base.apply(this,arguments);}},defer:function(y,z){{};var A=[u,o,c,a,r,h,m,k,b,p,s,q,n,t,d,j,g];z.valueOf=z.toString;if(new y(f).valueOf()==null){delete z.valueOf;};for(var i=0,l=A.length;i<l;i++ ){z[A[i]]=String.prototype[A[i]];};}});})();(function(){var a="qx.locale.LocalizedString";qx.Class.define(a,{extend:qx.type.BaseString,construct:function(b,d,c){qx.type.BaseString.call(this,b);this.__lh=d;this.__li=c;},members:{__lh:null,__li:null,translate:function(){return qx.locale.Manager.getInstance().translate(this.__lh,this.__li);},getMessageId:function(){return this.__lh;}}});})();(function(){var a="locale",b="_applyLocale",c="",d="changeLocale",e="_",f="C",g="locale.variant",h="qx.locale.Manager",j="String",k="singleton";qx.Class.define(h,{type:k,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__lj=qx.$$translations||{};this.__lk=qx.$$locales||{};var l=qx.core.Environment.get(a);var m=qx.core.Environment.get(g);if(m!==c){l+=e+m;};this.__ll=l;this.setLocale(l||this.__lm);},statics:{tr:function(o,p){var n=qx.lang.Array.fromArguments(arguments);n.splice(0,1);return qx.locale.Manager.getInstance().translate(o,n);},trn:function(r,u,q,t){var s=qx.lang.Array.fromArguments(arguments);s.splice(0,3);if(q!=1){return qx.locale.Manager.getInstance().translate(u,s);}else {return qx.locale.Manager.getInstance().translate(r,s);};},trc:function(y,w,x){var v=qx.lang.Array.fromArguments(arguments);v.splice(0,2);return qx.locale.Manager.getInstance().translate(w,v);},trnc:function(A,B,E,z,D){var C=qx.lang.Array.fromArguments(arguments);C.splice(0,4);if(z!=1){return qx.locale.Manager.getInstance().translate(E,C);}else {return qx.locale.Manager.getInstance().translate(B,C);};},marktr:function(F){return F;}},properties:{locale:{check:j,nullable:true,apply:b,event:d}},members:{__lm:f,__ln:null,__lo:null,__lj:null,__lk:null,__ll:null,getLanguage:function(){return this.__lo;},getTerritory:function(){return this.getLocale().split(e)[1]||c;},getAvailableLocales:function(H){var I=[];for(var G in this.__lk){if(G!=this.__lm){if(this.__lk[G]===null&&!H){continue;};I.push(G);};};return I;},__lp:function(J){var L;if(J==null){return null;};var K=J.indexOf(e);if(K==-1){L=J;}else {L=J.substring(0,K);};return L;},_applyLocale:function(N,M){{};this.__ln=N;this.__lo=this.__lp(N);},addTranslation:function(O,R){var P=this.__lj;if(P[O]){for(var Q in R){P[O][Q]=R[Q];};}else {P[O]=R;};},addLocale:function(V,T){var S=this.__lk;if(S[V]){for(var U in T){S[V][U]=T[U];};}else {S[V]=T;};},translate:function(ba,Y,W){var X=this.__lj;return this.__lq(X,ba,Y,W);},localize:function(be,bd,bb){var bc=this.__lk;return this.__lq(bc,be,bd,bb);},__lq:function(bj,bk,bh,bi){{};var bf;if(!bj){return bk;};if(bi){var bg=this.__lp(bi);}else {bi=this.__ln;bg=this.__lo;};if(!bf&&bj[bi]){bf=bj[bi][bk];};if(!bf&&bj[bg]){bf=bj[bg][bk];};if(!bf&&bj[this.__lm]){bf=bj[this.__lm][bk];};if(!bf){bf=bk;};if(bh.length>0){var bl=[];for(var i=0;i<bh.length;i++ ){var bm=bh[i];if(bm&&bm.translate){bl[i]=bm.translate();}else {bl[i]=bm;};};bf=qx.lang.String.format(bf,bl);};{bf=new qx.locale.LocalizedString(bf,bk,bh);};return bf;}},destruct:function(){this.__lj=this.__lk=null;}});})();(function(){var a="qx.bom.client.Locale",b="-",c="locale",d="",e="android",f="locale.variant";qx.Bootstrap.define(a,{statics:{getLocale:function(){var g=qx.bom.client.Locale.__lr();var h=g.indexOf(b);if(h!=-1){g=g.substr(0,h);};return g;},getVariant:function(){var i=qx.bom.client.Locale.__lr();var k=d;var j=i.indexOf(b);if(j!=-1){k=i.substr(j+1);};return k;},__lr:function(){var l=(navigator.userLanguage||navigator.language||d);if(qx.bom.client.OperatingSystem.getName()==e){var m=/(\w{2})-(\w{2})/i.exec(navigator.userAgent);if(m){l=m[0];};};return l.toLowerCase();}},defer:function(n){qx.core.Environment.add(c,n.getLocale);qx.core.Environment.add(f,n.getVariant);}});})();(function(){var a="qx.ui.core.MChildrenHandling";qx.Mixin.define(a,{members:{getChildren:function(){return this._getChildren();},hasChildren:function(){return this._hasChildren();},indexOf:function(b){return this._indexOf(b);},add:function(d,c){this._add(d,c);},addAt:function(g,e,f){this._addAt(g,e,f);},addBefore:function(h,j,i){this._addBefore(h,j,i);},addAfter:function(m,k,l){this._addAfter(m,k,l);},remove:function(n){this._remove(n);},removeAt:function(o){return this._removeAt(o);},removeAll:function(){return this._removeAll();}},statics:{remap:function(p){p.getChildren=p._getChildren;p.hasChildren=p._hasChildren;p.indexOf=p._indexOf;p.add=p._add;p.addAt=p._addAt;p.addBefore=p._addBefore;p.addAfter=p._addAfter;p.remove=p._remove;p.removeAt=p._removeAt;p.removeAll=p._removeAll;}}});})();(function(){var a="qx.ui.container.Composite",b="addChildWidget",c="removeChildWidget",d="qx.event.type.Data";qx.Class.define(a,{extend:qx.ui.core.Widget,include:[qx.ui.core.MChildrenHandling,qx.ui.core.MLayoutHandling],construct:function(e){qx.ui.core.Widget.call(this);if(e!=null){this._setLayout(e);};},events:{addChildWidget:d,removeChildWidget:d},members:{_afterAddChild:function(f){this.fireNonBubblingEvent(b,qx.event.type.Data,[f]);},_afterRemoveChild:function(g){this.fireNonBubblingEvent(c,qx.event.type.Data,[g]);}},defer:function(h,i){qx.ui.core.MChildrenHandling.remap(i);qx.ui.core.MLayoutHandling.remap(i);}});})();(function(){var a="qx.ui.popup.Popup",b="visible",c="excluded",d="popup",e="Boolean";qx.Class.define(a,{extend:qx.ui.container.Composite,include:qx.ui.core.MPlacement,construct:function(f){qx.ui.container.Composite.call(this,f);this.initVisibility();},properties:{appearance:{refine:true,init:d},visibility:{refine:true,init:c},autoHide:{check:e,init:true}},members:{show:function(){if(this.getLayoutParent()==null){qx.core.Init.getApplication().getRoot().add(this);};qx.ui.container.Composite.prototype.show.call(this);},_applyVisibility:function(i,h){qx.ui.container.Composite.prototype._applyVisibility.call(this,i,h);var g=qx.ui.popup.Manager.getInstance();i===b?g.add(this):g.remove(this);}},destruct:function(){if(!qx.ui.popup.Manager.getInstance().isDisposed()){qx.ui.popup.Manager.getInstance().remove(this);};}});})();(function(){var a="blur",b="pointerdown",c="__ls",d="singleton",f="qx.ui.popup.Manager";qx.Class.define(f,{type:d,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__ls=[];qx.event.Registration.addListener(document.documentElement,b,this.__lu,this,true);qx.bom.Element.addListener(window,a,this.hideAll,this);},members:{__ls:null,add:function(g){{};this.__ls.push(g);this.__lt();},remove:function(h){{};qx.lang.Array.remove(this.__ls,h);this.__lt();},hideAll:function(){var l=this.__ls.length,j={};while(l-- ){j=this.__ls[l];if(j.getAutoHide()){j.exclude();};};},__lt:function(){var k=1e7;for(var i=0;i<this.__ls.length;i++ ){this.__ls[i].setZIndex(k++ );};},__lu:function(e){var n=qx.ui.core.Widget.getWidgetByElement(e.getTarget());var o=this.__ls;for(var i=0;i<o.length;i++ ){var m=o[i];if(!m.getAutoHide()||n==m||qx.ui.core.Widget.contains(m,n)){continue;};m.exclude();};}},destruct:function(){qx.event.Registration.removeListener(document.documentElement,b,this.__lu,this,true);this._disposeArray(c);}});})();(function(){var a="_applyRich",b="qx.ui.tooltip.ToolTip",c="_applyIcon",d="tooltip",f="pointerover",g="qx.ui.core.Widget",h="arrow",i="Boolean",j="_applyArrowPosition",k="left",l="right",m="_applyLabel",n="Integer",o="String",p="atom";qx.Class.define(b,{extend:qx.ui.popup.Popup,construct:function(q,r){qx.ui.popup.Popup.call(this);this.setLayout(new qx.ui.layout.HBox());this._createChildControl(h);this._createChildControl(p);if(q!=null){this.setLabel(q);};if(r!=null){this.setIcon(r);};this.addListener(f,this._onPointerOver,this);},properties:{appearance:{refine:true,init:d},showTimeout:{check:n,init:700,themeable:true},hideTimeout:{check:n,init:4000,themeable:true},label:{check:o,nullable:true,apply:m},icon:{check:o,nullable:true,apply:c,themeable:true},rich:{check:i,init:false,apply:a},opener:{check:g,nullable:true},arrowPosition:{check:[k,l],init:k,themeable:true,apply:j}},members:{_forwardStates:{placementLeft:true},_createChildControlImpl:function(u,t){var s;switch(u){case p:s=new qx.ui.basic.Atom();this._add(s,{flex:1});break;case h:s=new qx.ui.basic.Image();this._add(s);};return s||qx.ui.popup.Popup.prototype._createChildControlImpl.call(this,u);},_onPointerOver:function(e){},_applyIcon:function(w,v){var x=this.getChildControl(p);w==null?x.resetIcon():x.setIcon(w);},_applyLabel:function(z,y){var A=this.getChildControl(p);z==null?A.resetLabel():A.setLabel(z);},_applyRich:function(C,B){var D=this.getChildControl(p);D.setRich(C);},_applyArrowPosition:function(F,E){this._getLayout().setReversed(F==k);}}});})();(function(){var a="Missing renderLayout() implementation!",b="abstract",c="It is not possible to manually set the connected widget.",d="qx.ui.layout.Abstract",e="Missing getHeightForWidth() implementation!";qx.Class.define(d,{type:b,extend:qx.core.Object,members:{__eX:null,_invalidChildrenCache:null,__lf:null,invalidateLayoutCache:function(){this.__eX=null;},renderLayout:function(g,h,f){this.warn(a);},getSizeHint:function(){if(this.__eX){return this.__eX;};return this.__eX=this._computeSizeHint();},hasHeightForWidth:function(){return false;},getHeightForWidth:function(i){this.warn(e);return null;},_computeSizeHint:function(){return null;},invalidateChildrenCache:function(){this._invalidChildrenCache=true;},verifyLayoutProperty:null,_clearSeparators:function(){var j=this.__lf;if(j instanceof qx.ui.core.LayoutItem){j.clearSeparators();};},_renderSeparator:function(k,l){this.__lf.renderSeparator(k,l);},connectToWidget:function(m){if(m&&this.__lf){throw new Error(c);};this.__lf=m;this.invalidateChildrenCache();},_getWidget:function(){return this.__lf;},_applyLayoutChange:function(){if(this.__lf){this.__lf.scheduleLayoutUpdate();};},_getLayoutChildren:function(){return this.__lf.getLayoutChildren();}},destruct:function(){this.__lf=this.__eX=null;}});})();(function(){var a="Decorator",b="middle",c="_applyLayoutChange",d="_applyReversed",e="bottom",f="center",g="Boolean",h="top",j="left",k="right",m="Integer",n="qx.ui.layout.HBox";qx.Class.define(n,{extend:qx.ui.layout.Abstract,construct:function(o,p,q){qx.ui.layout.Abstract.call(this);if(o){this.setSpacing(o);};if(p){this.setAlignX(p);};if(q){this.setSeparator(q);};},properties:{alignX:{check:[j,f,k],init:j,apply:c},alignY:{check:[h,b,e],init:h,apply:c},spacing:{check:m,init:0,apply:c},separator:{check:a,nullable:true,apply:c},reversed:{check:g,init:false,apply:d}},members:{__lv:null,__lw:null,__lx:null,__gO:null,_applyReversed:function(){this._invalidChildrenCache=true;this._applyLayoutChange();},__ly:function(){var w=this._getLayoutChildren();var length=w.length;var t=false;var r=this.__lv&&this.__lv.length!=length&&this.__lw&&this.__lv;var u;var s=r?this.__lv:new Array(length);var v=r?this.__lw:new Array(length);if(this.getReversed()){w=w.concat().reverse();};for(var i=0;i<length;i++ ){u=w[i].getLayoutProperties();if(u.width!=null){s[i]=parseFloat(u.width)/100;};if(u.flex!=null){v[i]=u.flex;t=true;}else {v[i]=0;};};if(!r){this.__lv=s;this.__lw=v;};this.__lx=t;this.__gO=w;delete this._invalidChildrenCache;},verifyLayoutProperty:null,renderLayout:function(N,H,M){if(this._invalidChildrenCache){this.__ly();};var D=this.__gO;var length=D.length;var P=qx.ui.layout.Util;var L=this.getSpacing();var R=this.getSeparator();if(R){var A=P.computeHorizontalSeparatorGaps(D,L,R);}else {var A=P.computeHorizontalGaps(D,L,true);};var i,O,J,I;var Q=[];var E=A;for(i=0;i<length;i+=1){I=this.__lv[i];J=I!=null?Math.floor((N-A)*I):D[i].getSizeHint().width;Q.push(J);E+=J;};if(this.__lx&&E!=N){var G={};var K,y;for(i=0;i<length;i+=1){K=this.__lw[i];if(K>0){F=D[i].getSizeHint();G[i]={min:F.minWidth,value:Q[i],max:F.maxWidth,flex:K};};};var B=P.computeFlexOffsets(G,N,E);for(i in B){y=B[i].offset;Q[i]+=y;E+=y;};};var V=D[0].getMarginLeft();if(E<N&&this.getAlignX()!=j){V=N-E;if(this.getAlignX()===f){V=Math.round(V/2);};};var F,top,z,J,C,T,x;var L=this.getSpacing();this._clearSeparators();if(R){var S=qx.theme.manager.Decoration.getInstance().resolve(R).getInsets();var U=S.left+S.right;};for(i=0;i<length;i+=1){O=D[i];J=Q[i];F=O.getSizeHint();T=O.getMarginTop();x=O.getMarginBottom();z=Math.max(F.minHeight,Math.min(H-T-x,F.maxHeight));top=P.computeVerticalAlignOffset(O.getAlignY()||this.getAlignY(),z,H,T,x);if(i>0){if(R){V+=C+L;this._renderSeparator(R,{left:V+M.left,top:M.top,width:U,height:H});V+=U+L+O.getMarginLeft();}else {V+=P.collapseMargins(L,C,O.getMarginLeft());};};O.renderLayout(V+M.left,top+M.top,J,z);V+=J;C=O.getMarginRight();};},_computeSizeHint:function(){if(this._invalidChildrenCache){this.__ly();};var bl=qx.ui.layout.Util;var X=this.__gO;var bd=0,be=0,W=0;var bb=0,bc=0;var bi,Y,bk;for(var i=0,l=X.length;i<l;i+=1){bi=X[i];Y=bi.getSizeHint();be+=Y.width;var bh=this.__lw[i];var ba=this.__lv[i];if(bh){bd+=Y.minWidth;}else if(ba){W=Math.max(W,Math.round(Y.minWidth/ba));}else {bd+=Y.width;};bk=bi.getMarginTop()+bi.getMarginBottom();if((Y.height+bk)>bc){bc=Y.height+bk;};if((Y.minHeight+bk)>bb){bb=Y.minHeight+bk;};};bd+=W;var bg=this.getSpacing();var bj=this.getSeparator();if(bj){var bf=bl.computeHorizontalSeparatorGaps(X,bg,bj);}else {var bf=bl.computeHorizontalGaps(X,bg,true);};return {minWidth:bd+bf,width:be+bf,minHeight:bb,height:bc};}},destruct:function(){this.__lv=this.__lw=this.__gO=null;}});})();(function(){var a="middle",b="qx.ui.layout.Util",c="left",d="center",e="top",f="bottom",g="right";qx.Class.define(b,{statics:{PERCENT_VALUE:/[0-9]+(?:\.[0-9]+)?%/,computeFlexOffsets:function(j,n,h){var r,q,s,k;var m=n>h;var t=Math.abs(n-h);var u,o;var p={};for(q in j){r=j[q];p[q]={potential:m?r.max-r.value:r.value-r.min,flex:m?r.flex:1/r.flex,offset:0};};while(t!=0){k=Infinity;s=0;for(q in p){r=p[q];if(r.potential>0){s+=r.flex;k=Math.min(k,r.potential/r.flex);};};if(s==0){break;};k=Math.min(t,k*s)/s;u=0;for(q in p){r=p[q];if(r.potential>0){o=Math.min(t,r.potential,Math.ceil(k*r.flex));u+=o-k*r.flex;if(u>=1){u-=1;o-=1;};r.potential-=o;if(m){r.offset+=o;}else {r.offset-=o;};t-=o;};};};return p;},computeHorizontalAlignOffset:function(w,v,y,z,A){if(z==null){z=0;};if(A==null){A=0;};var x=0;switch(w){case c:x=z;break;case g:x=y-v-A;break;case d:x=Math.round((y-v)/2);if(x<z){x=z;}else if(x<A){x=Math.max(z,y-v-A);};break;};return x;},computeVerticalAlignOffset:function(C,F,B,G,D){if(G==null){G=0;};if(D==null){D=0;};var E=0;switch(C){case e:E=G;break;case f:E=B-F-D;break;case a:E=Math.round((B-F)/2);if(E<G){E=G;}else if(E<D){E=Math.max(G,B-F-D);};break;};return E;},collapseMargins:function(K){var I=0,H=0;for(var i=0,l=arguments.length;i<l;i++ ){var J=arguments[i];if(J<0){H=Math.min(H,J);}else if(J>0){I=Math.max(I,J);};};return I+H;},computeHorizontalGaps:function(O,M,L){if(M==null){M=0;};var N=0;if(L){N+=O[0].getMarginLeft();for(var i=1,l=O.length;i<l;i+=1){N+=this.collapseMargins(M,O[i-1].getMarginRight(),O[i].getMarginLeft());};N+=O[l-1].getMarginRight();}else {for(var i=1,l=O.length;i<l;i+=1){N+=O[i].getMarginLeft()+O[i].getMarginRight();};N+=(M*(l-1));};return N;},computeVerticalGaps:function(S,Q,P){if(Q==null){Q=0;};var R=0;if(P){R+=S[0].getMarginTop();for(var i=1,l=S.length;i<l;i+=1){R+=this.collapseMargins(Q,S[i-1].getMarginBottom(),S[i].getMarginTop());};R+=S[l-1].getMarginBottom();}else {for(var i=1,l=S.length;i<l;i+=1){R+=S[i].getMarginTop()+S[i].getMarginBottom();};R+=(Q*(l-1));};return R;},computeHorizontalSeparatorGaps:function(bb,U,Y){var T=qx.theme.manager.Decoration.getInstance().resolve(Y);var V=T.getInsets();var W=V.left+V.right;var X=0;for(var i=0,l=bb.length;i<l;i++ ){var ba=bb[i];X+=ba.getMarginLeft()+ba.getMarginRight();};X+=(U+W+U)*(l-1);return X;},computeVerticalSeparatorGaps:function(bj,bc,bh){var bf=qx.theme.manager.Decoration.getInstance().resolve(bh);var be=bf.getInsets();var bd=be.top+be.bottom;var bg=0;for(var i=0,l=bj.length;i<l;i++ ){var bi=bj[i];bg+=bi.getMarginTop()+bi.getMarginBottom();};bg+=(bc+bd+bc)*(l-1);return bg;},arrangeIdeals:function(bl,bn,bk,bm,bo,bp){if(bn<bl||bo<bm){if(bn<bl&&bo<bm){bn=bl;bo=bm;}else if(bn<bl){bo-=(bl-bn);bn=bl;if(bo<bm){bo=bm;};}else if(bo<bm){bn-=(bm-bo);bo=bm;if(bn<bl){bn=bl;};};};if(bn>bk||bo>bp){if(bn>bk&&bo>bp){bn=bk;bo=bp;}else if(bn>bk){bo+=(bn-bk);bn=bk;if(bo>bp){bo=bp;};}else if(bo>bp){bn+=(bo-bp);bo=bp;if(bn>bk){bn=bk;};};};return {begin:bn,end:bo};}}});})();(function(){var a="Boolean",b="changeGap",c="changeShow",d="bottom",e="bottom-right",f="_applyCenter",g="changeIcon",h="qx.ui.basic.Atom",i="changeLabel",j="both",k="Integer",l="_applyIconPosition",m="bottom-left",n="String",o="icon",p="top-left",q="top",r="top-right",s="right",t="_applyRich",u="_applyIcon",v="label",w="_applyShow",x="left",y="_applyLabel",z="_applyGap",A="atom";qx.Class.define(h,{extend:qx.ui.core.Widget,construct:function(B,C){{};qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.Atom());if(B!=null){this.setLabel(B);};if(C!==undefined){this.setIcon(C);};},properties:{appearance:{refine:true,init:A},label:{apply:y,nullable:true,check:n,event:i},rich:{check:a,init:false,apply:t},icon:{check:n,apply:u,nullable:true,themeable:true,event:g},gap:{check:k,nullable:false,event:b,apply:z,themeable:true,init:4},show:{init:j,check:[j,v,o],themeable:true,inheritable:true,apply:w,event:c},iconPosition:{init:x,check:[q,s,d,x,p,m,r,e],themeable:true,apply:l},center:{init:false,check:a,themeable:true,apply:f}},members:{_createChildControlImpl:function(F,E){var D;switch(F){case v:D=new qx.ui.basic.Label(this.getLabel());D.setAnonymous(true);D.setRich(this.getRich());this._add(D);if(this.getLabel()==null||this.getShow()===o){D.exclude();};break;case o:D=new qx.ui.basic.Image(this.getIcon());D.setAnonymous(true);this._addAt(D,0);if(this.getIcon()==null||this.getShow()===v){D.exclude();};break;};return D||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,F);},_forwardStates:{focused:true,hovered:true},_handleLabel:function(){if(this.getLabel()==null||this.getShow()===o){this._excludeChildControl(v);}else {this._showChildControl(v);};},_handleIcon:function(){if(this.getIcon()==null||this.getShow()===v){this._excludeChildControl(o);}else {this._showChildControl(o);};},_applyLabel:function(H,G){var I=this.getChildControl(v,true);if(I){I.setValue(H);};this._handleLabel();},_applyRich:function(K,J){var L=this.getChildControl(v,true);if(L){L.setRich(K);};},_applyIcon:function(N,M){var O=this.getChildControl(o,true);if(O){O.setSource(N);};this._handleIcon();},_applyGap:function(Q,P){this._getLayout().setGap(Q);},_applyShow:function(S,R){this._handleLabel();this._handleIcon();},_applyIconPosition:function(U,T){this._getLayout().setIconPosition(U);},_applyCenter:function(W,V){this._getLayout().setCenter(W);},_applySelectable:function(Y,X){qx.ui.core.Widget.prototype._applySelectable.call(this,Y,X);var ba=this.getChildControl(v,true);if(ba){this.getChildControl(v).setSelectable(Y);};}}});})();(function(){var a="middle",b="_applyLayoutChange",c="top-right",d="bottom",e="top-left",f="bottom-left",g="center",h="qx.ui.layout.Atom",j="bottom-right",k="top",l="left",m="right",n="Integer",o="Boolean";qx.Class.define(h,{extend:qx.ui.layout.Abstract,properties:{gap:{check:n,init:4,apply:b},iconPosition:{check:[l,k,m,d,e,f,c,j],init:l,apply:b},center:{check:o,init:false,apply:b}},members:{verifyLayoutProperty:null,renderLayout:function(E,y,D){var N=D.left;var top=D.top;var z=qx.ui.layout.Util;var q=this.getIconPosition();var t=this._getLayoutChildren();var length=t.length;var M,r;var G,x;var C=this.getGap();var J=this.getCenter();var L=[d,m,c,j];if(L.indexOf(q)!=-1){var A=length-1;var v=-1;var s=-1;}else {var A=0;var v=length;var s=1;};if(q==k||q==d){if(J){var F=0;for(var i=A;i!=v;i+=s){r=t[i].getSizeHint().height;if(r>0){F+=r;if(i!=A){F+=C;};};};top+=Math.round((y-F)/2);};var u=top;for(var i=A;i!=v;i+=s){G=t[i];x=G.getSizeHint();M=Math.min(x.maxWidth,Math.max(E,x.minWidth));r=x.height;N=z.computeHorizontalAlignOffset(g,M,E)+D.left;G.renderLayout(N,u,M,r);if(r>0){u=top+r+C;};};}else {var w=E;var p=null;var I=0;for(var i=A;i!=v;i+=s){G=t[i];M=G.getSizeHint().width;if(M>0){if(!p&&G instanceof qx.ui.basic.Label){p=G;}else {w-=M;};I++ ;};};if(I>1){var H=(I-1)*C;w-=H;};if(p){var x=p.getSizeHint();var B=Math.max(x.minWidth,Math.min(w,x.maxWidth));w-=B;};if(J&&w>0){N+=Math.round(w/2);};for(var i=A;i!=v;i+=s){G=t[i];x=G.getSizeHint();r=Math.min(x.maxHeight,Math.max(y,x.minHeight));if(G===p){M=B;}else {M=x.width;};var K=a;if(q==e||q==c){K=k;}else if(q==f||q==j){K=d;};var u=top+z.computeVerticalAlignOffset(K,x.height,y);G.renderLayout(N,u,M,r);if(M>0){N+=M+C;};};};},_computeSizeHint:function(){var Y=this._getLayoutChildren();var length=Y.length;var P,W;if(length===1){var P=Y[0].getSizeHint();W={width:P.width,height:P.height,minWidth:P.minWidth,minHeight:P.minHeight};}else {var U=0,V=0;var R=0,T=0;var S=this.getIconPosition();var Q=this.getGap();if(S===k||S===d){var O=0;for(var i=0;i<length;i++ ){P=Y[i].getSizeHint();V=Math.max(V,P.width);U=Math.max(U,P.minWidth);if(P.height>0){T+=P.height;R+=P.minHeight;O++ ;};};if(O>1){var X=(O-1)*Q;T+=X;R+=X;};}else {var O=0;for(var i=0;i<length;i++ ){P=Y[i].getSizeHint();T=Math.max(T,P.height);R=Math.max(R,P.minHeight);if(P.width>0){V+=P.width;U+=P.minWidth;O++ ;};};if(O>1){var X=(O-1)*Q;V+=X;U+=X;};};W={minWidth:U,width:V,minHeight:R,height:T};};return W;}}});})();(function(){var a="qx.event.type.Data",b="qx.ui.form.IStringForm";qx.Interface.define(b,{events:{"changeValue":a},members:{setValue:function(c){return arguments.length==1;},resetValue:function(){},getValue:function(){}}});})();(function(){var a="safari",b="os.name",c="_applyTextAlign",d="Boolean",f="qx.ui.core.Widget",g="nowrap",h="changeStatus",i="changeTextAlign",j="_applyWrap",k="changeValue",l="browser.name",m="color",n="qx.ui.basic.Label",o="osx",p="css.textoverflow",q="html.xul",r="_applyValue",s="center",t="_applyBuddy",u="enabled",v="String",w="toggleValue",x="whiteSpace",y="textAlign",z="function",A="browser.version",B="engine.version",C="right",D="gecko",E="justify",F="changeRich",G="normal",H="_applyRich",I="engine.name",J="label",K="changeLocale",L="left",M="tap",N="A";qx.Class.define(n,{extend:qx.ui.core.Widget,implement:[qx.ui.form.IStringForm],construct:function(O){qx.ui.core.Widget.call(this);if(O!=null){this.setValue(O);};{qx.locale.Manager.getInstance().addListener(K,this._onChangeLocale,this);};},properties:{rich:{check:d,init:false,event:F,apply:H},wrap:{check:d,init:true,apply:j},value:{check:v,apply:r,event:k,nullable:true},buddy:{check:f,apply:t,nullable:true,init:null,dereference:true},textAlign:{check:[L,s,C,E],nullable:true,themeable:true,apply:c,event:i},appearance:{refine:true,init:J},selectable:{refine:true,init:false},allowGrowX:{refine:true,init:false},allowGrowY:{refine:true,init:false},allowShrinkY:{refine:true,init:false}},members:{__lz:null,__lA:null,__lB:null,__lC:null,_getContentHint:function(){if(this.__lA){this.__lD=this.__lE();delete this.__lA;};return {width:this.__lD.width,height:this.__lD.height};},_hasHeightForWidth:function(){return this.getRich()&&this.getWrap();},_applySelectable:function(P){if(!qx.core.Environment.get(p)&&qx.core.Environment.get(q)){if(P&&!this.isRich()){{};return;};};qx.ui.core.Widget.prototype._applySelectable.call(this,P);},_getContentHeightForWidth:function(Q){if(!this.getRich()&&!this.getWrap()){return null;};return this.__lE(Q).height;},_createContentElement:function(){return new qx.html.Label;},_applyTextAlign:function(S,R){this.getContentElement().setStyle(y,S);},_applyTextColor:function(U,T){if(U){this.getContentElement().setStyle(m,qx.theme.manager.Color.getInstance().resolve(U));}else {this.getContentElement().removeStyle(m);};},__lD:{width:0,height:0},_applyFont:function(X,W){if(W&&this.__lz&&this.__lC){this.__lz.removeListenerById(this.__lC);this.__lC=null;};var V;if(X){this.__lz=qx.theme.manager.Font.getInstance().resolve(X);if(this.__lz instanceof qx.bom.webfonts.WebFont){this.__lC=this.__lz.addListener(h,this._onWebFontStatusChange,this);};V=this.__lz.getStyles();}else {this.__lz=null;V=qx.bom.Font.getDefaultStyles();};if(this.getTextColor()!=null){delete V[m];};this.getContentElement().setStyles(V);this.__lA=true;qx.ui.core.queue.Layout.add(this);},__lE:function(bb){var ba=qx.bom.Label;var bd=this.getFont();var Y=bd?this.__lz.getStyles():qx.bom.Font.getDefaultStyles();var content=this.getValue()||N;var bc=this.getRich();if(this.__lC){this.__lF();};return bc?ba.getHtmlSize(content,Y,bb):ba.getTextSize(content,Y);},__lF:function(){if(!this.getContentElement()){return;};if(qx.core.Environment.get(b)==o&&qx.core.Environment.get(I)==D&&parseInt(qx.core.Environment.get(B),10)<16&&parseInt(qx.core.Environment.get(B),10)>9){var be=this.getContentElement().getDomElement();if(be){be.innerHTML=be.innerHTML;};};},_applyBuddy:function(bg,bf){if(bf!=null){this.removeRelatedBindings(bf);this.removeListenerById(this.__lB);this.__lB=null;};if(bg!=null){bg.bind(u,this,u);this.__lB=this.addListener(M,function(){if(bg.isFocusable()){bg.focus.apply(bg);};if(w in bg&&typeof bg.toggleValue===z){bg.toggleValue();};},this);};},_applyRich:function(bh){this.getContentElement().setRich(bh);this.__lA=true;qx.ui.core.queue.Layout.add(this);},_applyWrap:function(bk,bi){if(bk&&!this.isRich()){{};};if(this.isRich()){var bj=bk?G:g;this.getContentElement().setStyle(x,bj);};},_onChangeLocale:function(e){var content=this.getValue();if(content&&content.translate){this.setValue(content.translate());};},_onWebFontStatusChange:function(bl){if(bl.getData().valid===true){if(qx.core.Environment.get(l)==a&&parseFloat(qx.core.Environment.get(A))>=8){window.setTimeout(function(){this.__lA=true;qx.ui.core.queue.Layout.add(this);}.bind(this),0);};this.__lA=true;qx.ui.core.queue.Layout.add(this);};},_applyValue:function(bn,bm){this.getContentElement().setValue(bn);this.__lA=true;qx.ui.core.queue.Layout.add(this);}},destruct:function(){{qx.locale.Manager.getInstance().removeListener(K,this._onChangeLocale,this);};if(this.__lz&&this.__lC){this.__lz.removeListenerById(this.__lC);};this.__lz=null;}});})();(function(){var a="value",b="qx.html.Label",c="The label mode cannot be modified after initial creation",d='hidden';qx.Class.define(b,{extend:qx.html.Element,members:{__lG:null,_applyProperty:function(name,e){qx.html.Element.prototype._applyProperty.call(this,name,e);if(name==a){var f=this.getDomElement();qx.bom.Label.setValue(f,e);};},_createDomElement:function(){var h=this.__lG;var g=qx.bom.Label.create(this._content,h);g.style.overflow=d;return g;},_copyData:function(i){return qx.html.Element.prototype._copyData.call(this,true);},setRich:function(j){var k=this.getDomElement();if(k){throw new Error(c);};j=!!j;if(this.__lG==j){return this;};this.__lG=j;return this;},setValue:function(l){this._setProperty(a,l);return this;},getValue:function(){return this._getProperty(a);}}});})();(function(){var a="text",b="function",c="px",d="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul",e="crop",f="nowrap",g="end",h="div",i="100%",j="auto",k="0",l="css.textoverflow",m="html.xul",n="value",o="visible",p="qx.bom.Label",q="",r="ellipsis",s="normal",t="inherit",u="block",v="label",w="-1000px",x="hidden",y="absolute";qx.Bootstrap.define(p,{statics:{__lH:{fontFamily:1,fontSize:1,fontWeight:1,fontStyle:1,lineHeight:1},__lI:function(){var z=this.__lK(false);document.body.insertBefore(z,document.body.firstChild);return this._textElement=z;},__lJ:function(){var A=this.__lK(true);document.body.insertBefore(A,document.body.firstChild);return this._htmlElement=A;},__lK:function(D){var B=qx.dom.Element.create(h);var C=B.style;C.width=C.height=j;C.left=C.top=w;C.visibility=x;C.position=y;C.overflow=o;C.display=u;if(D){C.whiteSpace=s;}else {C.whiteSpace=f;if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){var E=document.createElementNS(d,v);var C=E.style;C.padding=k;C.margin=k;C.width=j;for(var F in this.__lH){C[F]=t;};B.appendChild(E);};};return B;},__lL:function(H){var G={};if(H){G.whiteSpace=s;}else if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){G.display=u;}else {G.overflow=x;G.whiteSpace=f;G[qx.core.Environment.get(l)]=r;};return G;},create:function(content,L,K){if(!K){K=window;};var I=K.document.createElement(h);if(L){I.useHtml=true;}else if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){var M=K.document.createElementNS(d,v);var J=M.style;J.cursor=t;J.color=t;J.overflow=x;J.maxWidth=i;J.padding=k;J.margin=k;J.width=j;for(var N in this.__lH){M.style[N]=t;};M.setAttribute(e,g);I.appendChild(M);}else {qx.bom.element.Style.setStyles(I,this.__lL(L));};if(content){this.setValue(I,content);};return I;},__lM:null,setSanitizer:function(O){{};qx.bom.Label.__lM=O;},setValue:function(Q,P){P=P||q;if(Q.useHtml){if(qx.bom.Label.__lM&&typeof (qx.bom.Label.__lM)===b){P=qx.bom.Label.__lM(P);};Q.innerHTML=P;}else if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){Q.firstChild.setAttribute(n,P);}else {qx.bom.element.Attribute.set(Q,a,P);};},getValue:function(R){if(R.useHtml){return R.innerHTML;}else if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){return R.firstChild.getAttribute(n)||q;}else {return qx.bom.element.Attribute.get(R,a);};},getHtmlSize:function(content,S,T){var U=this._htmlElement||this.__lJ();U.style.width=T!=undefined?T+c:j;U.innerHTML=content;return this.__lN(U,S);},getTextSize:function(W,V){var X=this._textElement||this.__lI();if(!qx.core.Environment.get(l)&&qx.core.Environment.get(m)){X.firstChild.setAttribute(n,W);}else {qx.bom.element.Attribute.set(X,a,W);};return this.__lN(X,V);},__lN:function(bd,Y){var ba=this.__lH;if(!Y){Y={};};for(var bc in ba){bd.style[bc]=Y[bc]||q;};var bb=qx.bom.element.Dimension.getSize(bd);bb.width++ ;return bb;}}});})();(function(){var a="qx.ui.form.IForm",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeEnabled":b,"changeValid":b,"changeInvalidMessage":b,"changeRequired":b},members:{setEnabled:function(c){return arguments.length==1;},getEnabled:function(){},setRequired:function(d){return arguments.length==1;},getRequired:function(){},setValid:function(e){return arguments.length==1;},getValid:function(){},setInvalidMessage:function(f){return arguments.length==1;},getInvalidMessage:function(){},setRequiredInvalidMessage:function(g){return arguments.length==1;},getRequiredInvalidMessage:function(){}}});})();(function(){var a="qx.application.Standalone";qx.Class.define(a,{extend:qx.application.AbstractGui,members:{_createRootWidget:function(){return new qx.ui.root.Application(document);}}});})();(function(){var a="_applyActiveWindow",b="__gs",c="changeModal",d="windowAdded",f="changeVisibility",g="windowRemoved",h="qx.ui.window.Window",i="__lO",j="changeActive",k="qx.ui.window.MDesktop",l="changeActiveWindow",m="qx.event.type.Data";qx.Mixin.define(k,{properties:{activeWindow:{check:h,apply:a,event:l,init:null,nullable:true}},events:{windowAdded:m,windowRemoved:m},members:{__lO:null,__gs:null,getWindowManager:function(){if(!this.__gs){this.setWindowManager(new qx.ui.window.Window.DEFAULT_MANAGER_CLASS());};return this.__gs;},supportsMaximize:function(){return true;},setWindowManager:function(n){if(this.__gs){this.__gs.setDesktop(null);};n.setDesktop(this);this.__gs=n;},_onChangeActive:function(e){if(e.getData()){this.setActiveWindow(e.getTarget());}else if(this.getActiveWindow()==e.getTarget()){this.setActiveWindow(null);};},_applyActiveWindow:function(p,o){this.getWindowManager().changeActiveWindow(p,o);this.getWindowManager().updateStack();},_onChangeModal:function(e){this.getWindowManager().updateStack();},_onChangeVisibility:function(){this.getWindowManager().updateStack();},_afterAddChild:function(q){if(qx.Class.isDefined(h)&&q instanceof qx.ui.window.Window){this._addWindow(q);};},_addWindow:function(r){if(!qx.lang.Array.contains(this.getWindows(),r)){this.getWindows().push(r);this.fireDataEvent(d,r);r.addListener(j,this._onChangeActive,this);r.addListener(c,this._onChangeModal,this);r.addListener(f,this._onChangeVisibility,this);};if(r.getActive()){this.setActiveWindow(r);};this.getWindowManager().updateStack();},_afterRemoveChild:function(s){if(qx.Class.isDefined(h)&&s instanceof qx.ui.window.Window){this._removeWindow(s);};},_removeWindow:function(t){if(qx.lang.Array.contains(this.getWindows(),t)){qx.lang.Array.remove(this.getWindows(),t);this.fireDataEvent(g,t);t.removeListener(j,this._onChangeActive,this);t.removeListener(c,this._onChangeModal,this);t.removeListener(f,this._onChangeVisibility,this);this.getWindowManager().updateStack();};},getWindows:function(){if(!this.__lO){this.__lO=[];};return this.__lO;}},destruct:function(){this._disposeArray(i);this._disposeObjects(b);}});})();(function(){var a="__lP",b="_applyBlockerColor",c="Number",d="qx.ui.core.MBlocker",e="_applyBlockerOpacity",f="Color";qx.Mixin.define(d,{properties:{blockerColor:{check:f,init:null,nullable:true,apply:b,themeable:true},blockerOpacity:{check:c,init:1,apply:e,themeable:true}},members:{__lP:null,_createBlocker:function(){return new qx.ui.core.Blocker(this);},_applyBlockerColor:function(h,g){this.getBlocker().setColor(h);},_applyBlockerOpacity:function(j,i){this.getBlocker().setOpacity(j);},block:function(){this.getBlocker().block();},isBlocked:function(){return this.__lP&&this.__lP.isBlocked();},unblock:function(){if(this.__lP){this.__lP.unblock();};},forceUnblock:function(){if(this.__lP){this.__lP.forceUnblock();};},blockContent:function(k){this.getBlocker().blockContent(k);},getBlocker:function(){if(!this.__lP){this.__lP=this._createBlocker();};return this.__lP;}},destruct:function(){this._disposeObjects(a);}});})();(function(){var a="qx.dyntheme",b="backgroundColor",c="_applyOpacity",d="Boolean",f="px",g="keydown",h="deactivate",j="changeTheme",k="opacity",l="Tab",m="qx.event.type.Event",n="move",o="Color",p="resize",q="__de",r="zIndex",s="appear",t="qx.ui.root.Abstract",u="__lP",v="keyup",w="keypress",x="Number",y="unblocked",z="qx.ui.core.Blocker",A="disappear",B="blocked",C="_applyColor";qx.Class.define(z,{extend:qx.core.Object,events:{blocked:m,unblocked:m},construct:function(D){qx.core.Object.call(this);this._widget=D;D.addListener(p,this.__lU,this);D.addListener(n,this.__lU,this);D.addListener(A,this.__lW,this);if(qx.Class.isDefined(t)&&D instanceof qx.ui.root.Abstract){this._isRoot=true;this.setKeepBlockerActive(true);};if(qx.core.Environment.get(a)){qx.theme.manager.Meta.getInstance().addListener(j,this._onChangeTheme,this);};this.__lQ=[];this.__lR=[];},properties:{color:{check:o,init:null,nullable:true,apply:C,themeable:true},opacity:{check:x,init:1,apply:c,themeable:true},keepBlockerActive:{check:d,init:false}},members:{__lP:null,__lS:0,__lQ:null,__lR:null,__de:null,_widget:null,_isRoot:false,__lT:null,__lU:function(e){var E=e.getData();if(this.isBlocked()){this._updateBlockerBounds(E);};},__lV:function(){this._updateBlockerBounds(this._widget.getBounds());if(this._widget.isRootWidget()){this._widget.getContentElement().add(this.getBlockerElement());}else {this._widget.getLayoutParent().getContentElement().add(this.getBlockerElement());};},__lW:function(){if(this.isBlocked()){this.getBlockerElement().getParent().remove(this.getBlockerElement());this._widget.addListenerOnce(s,this.__lV,this);};},_updateBlockerBounds:function(F){this.getBlockerElement().setStyles({width:F.width+f,height:F.height+f,left:F.left+f,top:F.top+f});},_applyColor:function(I,H){var G=qx.theme.manager.Color.getInstance().resolve(I);this.__lX(b,G);},_applyOpacity:function(K,J){this.__lX(k,K);},_onChangeTheme:qx.core.Environment.select(a,{"true":function(){this._applyColor(this.getColor());},"false":null}),__lX:function(M,N){var L=[];this.__lP&&L.push(this.__lP);for(var i=0;i<L.length;i++ ){L[i].setStyle(M,N);};},_backupActiveWidget:function(){var O=qx.event.Registration.getManager(window).getHandler(qx.event.handler.Focus);this.__lQ.push(qx.ui.core.Widget.getWidgetByElement(O.getActive()));this.__lR.push(qx.ui.core.Widget.getWidgetByElement(O.getFocus()));if(this._widget.isFocusable()){this._widget.focus();};},_restoreActiveWidget:function(){var Q;var P=this.__lR.length;if(P>0){Q=this.__lR.pop();if(Q&&!Q.isDisposed()&&Q.isFocusable()){Q.focus();};};var R=this.__lQ.length;if(R>0){Q=this.__lQ.pop();if(Q&&!Q.isDisposed()){Q.activate();};};},__lY:function(){return new qx.html.Blocker(this.getColor(),this.getOpacity());},getBlockerElement:function(S){if(!this.__lP){this.__lP=this.__lY();this.__lP.setStyle(r,15);if(!S){if(this._isRoot){S=this._widget;}else {S=this._widget.getLayoutParent();};};S.getContentElement().add(this.__lP);this.__lP.exclude();};return this.__lP;},block:function(){this._block();},_block:function(T,V){if(!this._isRoot&&!this._widget.getLayoutParent()){this.__lT=this._widget.addListenerOnce(s,this._block.bind(this,T));return;};var parent;if(this._isRoot||V){parent=this._widget;}else {parent=this._widget.getLayoutParent();};var U=this.getBlockerElement(parent);if(T!=null){U.setStyle(r,T);};this.__lS++ ;if(this.__lS<2){this._backupActiveWidget();var W=this._widget.getBounds();if(W){this._updateBlockerBounds(W);};U.include();if(!V){U.activate();};U.addListener(h,this.__mc,this);U.addListener(w,this.__mb,this);U.addListener(g,this.__mb,this);U.addListener(v,this.__mb,this);this.fireEvent(B,qx.event.type.Event);};},isBlocked:function(){return this.__lS>0;},unblock:function(){if(this.__lT){this._widget.removeListenerById(this.__lT);};if(!this.isBlocked()){return;};this.__lS-- ;if(this.__lS<1){this.__ma();this.__lS=0;};},forceUnblock:function(){if(!this.isBlocked()){return;};this.__lS=0;this.__ma();},__ma:function(){this._restoreActiveWidget();var X=this.getBlockerElement();X.removeListener(h,this.__mc,this);X.removeListener(w,this.__mb,this);X.removeListener(g,this.__mb,this);X.removeListener(v,this.__mb,this);X.exclude();this.fireEvent(y,qx.event.type.Event);},blockContent:function(Y){this._block(Y,true);},__mb:function(e){if(e.getKeyIdentifier()==l){e.stop();};},__mc:function(){if(this.getKeepBlockerActive()&&!qx.ui.core.FocusHandler.getInstance().isFocusRoot(this._widget)){this.getBlockerElement().activate();};}},destruct:function(){if(qx.core.Environment.get(a)){qx.theme.manager.Meta.getInstance().removeListener(j,this._onChangeTheme,this);};this._widget.removeListener(p,this.__lU,this);this._widget.removeListener(n,this.__lU,this);this._widget.removeListener(s,this.__lV,this);this._widget.removeListener(A,this.__lW,this);if(this.__lT){this._widget.removeListenerById(this.__lT);};this._disposeObjects(u,q);this.__lQ=this.__lR=this._widget=null;}});})();(function(){var a="swipe",b="repeat",c="mousedown",d="url(",f="pointerover",g=")",h="longtap",i="mouseout",j="div",k="roll",l="cursor",m="dblclick",n="mousewheel",o="qx.html.Blocker",p="mousemove",q="dbltap",r="pointerup",s="mouseover",t="appear",u="click",v="pointerdown",w="mshtml",x="engine.name",y="mouseup",z="contextmenu",A="disappear",B="tap",C="pointermove",D="pointerout",E="qx/static/blank.gif",F="absolute";qx.Class.define(o,{extend:qx.html.Element,construct:function(I,G){var I=I?qx.theme.manager.Color.getInstance().resolve(I):null;var H={position:F,opacity:G||0,backgroundColor:I};if((qx.core.Environment.get(x)==w)){H.backgroundImage=d+qx.util.ResourceManager.getInstance().toUri(E)+g;H.backgroundRepeat=b;};qx.html.Element.call(this,j,H);this.addListener(c,this._stopPropagation,this);this.addListener(y,this._stopPropagation,this);this.addListener(u,this._stopPropagation,this);this.addListener(m,this._stopPropagation,this);this.addListener(p,this._stopPropagation,this);this.addListener(s,this._stopPropagation,this);this.addListener(i,this._stopPropagation,this);this.addListener(n,this._stopPropagation,this);this.addListener(k,this._stopPropagation,this);this.addListener(z,this._stopPropagation,this);this.addListener(v,this._stopPropagation,this);this.addListener(r,this._stopPropagation,this);this.addListener(C,this._stopPropagation,this);this.addListener(f,this._stopPropagation,this);this.addListener(D,this._stopPropagation,this);this.addListener(B,this._stopPropagation,this);this.addListener(q,this._stopPropagation,this);this.addListener(a,this._stopPropagation,this);this.addListener(h,this._stopPropagation,this);this.addListener(t,this.__md,this);this.addListener(A,this.__md,this);},members:{_stopPropagation:function(e){e.stopPropagation();},__md:function(){var J=this.getStyle(l);this.setStyle(l,null,true);this.setStyle(l,J,true);}}});})();(function(){var a="keypress",b="__me",c="focusout",d="activate",f="Tab",g="singleton",h="deactivate",j="focusin",k="qx.ui.core.FocusHandler";qx.Class.define(k,{extend:qx.core.Object,type:g,construct:function(){qx.core.Object.call(this);this.__me={};},members:{__me:null,__mf:null,__mg:null,__mh:null,connectTo:function(m){m.addListener(a,this.__hV,this);m.addListener(j,this._onFocusIn,this,true);m.addListener(c,this._onFocusOut,this,true);m.addListener(d,this._onActivate,this,true);m.addListener(h,this._onDeactivate,this,true);},addRoot:function(n){this.__me[n.$$hash]=n;},removeRoot:function(o){delete this.__me[o.$$hash];},getActiveWidget:function(){return this.__mf;},isActive:function(p){return this.__mf==p;},getFocusedWidget:function(){return this.__mg;},isFocused:function(q){return this.__mg==q;},isFocusRoot:function(r){return !!this.__me[r.$$hash];},_onActivate:function(e){var t=e.getTarget();this.__mf=t;var s=this.__mi(t);if(s!=this.__mh){this.__mh=s;};},_onDeactivate:function(e){var u=e.getTarget();if(this.__mf==u){this.__mf=null;};},_onFocusIn:function(e){var v=e.getTarget();if(v!=this.__mg){this.__mg=v;v.visualizeFocus();};},_onFocusOut:function(e){var w=e.getTarget();if(w==this.__mg){this.__mg=null;w.visualizeBlur();};},__hV:function(e){if(e.getKeyIdentifier()!=f){return;};if(!this.__mh){return;};e.stopPropagation();e.preventDefault();var x=this.__mg;if(!e.isShiftPressed()){var y=x?this.__mm(x):this.__mk();}else {var y=x?this.__mn(x):this.__ml();};if(y){y.tabFocus();};},__mi:function(z){var A=this.__me;while(z){if(A[z.$$hash]){return z;};z=z.getLayoutParent();};return null;},__mj:function(I,H){if(I===H){return 0;};var C=I.getTabIndex()||0;var B=H.getTabIndex()||0;if(C!=B){return C-B;};var J=I.getContentElement().getDomElement();var G=H.getContentElement().getDomElement();var F=qx.bom.element.Location;var E=F.get(J);var D=F.get(G);if(E.top!=D.top){return E.top-D.top;};if(E.left!=D.left){return E.left-D.left;};var K=I.getZIndex();var L=H.getZIndex();if(K!=L){return K-L;};return 0;},__mk:function(){return this.__mq(this.__mh,null);},__ml:function(){return this.__mr(this.__mh,null);},__mm:function(M){var N=this.__mh;if(N==M){return this.__mk();};while(M&&M.getAnonymous()){M=M.getLayoutParent();};if(M==null){return [];};var O=[];this.__mo(N,M,O);O.sort(this.__mj);var P=O.length;return P>0?O[0]:this.__mk();},__mn:function(Q){var R=this.__mh;if(R==Q){return this.__ml();};while(Q&&Q.getAnonymous()){Q=Q.getLayoutParent();};if(Q==null){return [];};var S=[];this.__mp(R,Q,S);S.sort(this.__mj);var T=S.length;return T>0?S[T-1]:this.__ml();},__mo:function(parent,U,V){var X=parent.getLayoutChildren();var W;for(var i=0,l=X.length;i<l;i++ ){W=X[i];if(!(W instanceof qx.ui.core.Widget)){continue;};if(!this.isFocusRoot(W)&&W.isEnabled()&&W.isVisible()){if(W.isTabable()&&this.__mj(U,W)<0){V.push(W);};this.__mo(W,U,V);};};},__mp:function(parent,Y,ba){var bc=parent.getLayoutChildren();var bb;for(var i=0,l=bc.length;i<l;i++ ){bb=bc[i];if(!(bb instanceof qx.ui.core.Widget)){continue;};if(!this.isFocusRoot(bb)&&bb.isEnabled()&&bb.isVisible()){if(bb.isTabable()&&this.__mj(Y,bb)>0){ba.push(bb);};this.__mp(bb,Y,ba);};};},__mq:function(parent,bd){var bf=parent.getLayoutChildren();var be;for(var i=0,l=bf.length;i<l;i++ ){be=bf[i];if(!(be instanceof qx.ui.core.Widget)){continue;};if(!this.isFocusRoot(be)&&be.isEnabled()&&be.isVisible()){if(be.isTabable()){if(bd==null||this.__mj(be,bd)<0){bd=be;};};bd=this.__mq(be,bd);};};return bd;},__mr:function(parent,bg){var bi=parent.getLayoutChildren();var bh;for(var i=0,l=bi.length;i<l;i++ ){bh=bi[i];if(!(bh instanceof qx.ui.core.Widget)){continue;};if(!this.isFocusRoot(bh)&&bh.isEnabled()&&bh.isVisible()){if(bh.isTabable()){if(bg==null||this.__mj(bh,bg)>0){bg=bh;};};bg=this.__mr(bh,bg);};};return bg;}},destruct:function(){this._disposeMap(b);this.__mg=this.__mf=this.__mh=null;}});})();(function(){var a="changeGlobalCursor",b="engine.name",c="keypress",d="Boolean",f="root",g="help",h="",i="contextmenu",j=" !important",k="input",l="_applyGlobalCursor",m="Space",n="_applyNativeHelp",o=";",p="event.help",q="qx.ui.root.Abstract",r="abstract",s="textarea",t="String",u="*";qx.Class.define(q,{type:r,extend:qx.ui.core.Widget,include:[qx.ui.core.MChildrenHandling,qx.ui.core.MBlocker,qx.ui.window.MDesktop],construct:function(){qx.ui.core.Widget.call(this);qx.ui.core.FocusHandler.getInstance().addRoot(this);qx.ui.core.queue.Visibility.add(this);this.initNativeHelp();this.addListener(c,this.__mt,this);},properties:{appearance:{refine:true,init:f},enabled:{refine:true,init:true},focusable:{refine:true,init:true},globalCursor:{check:t,nullable:true,themeable:true,apply:l,event:a},nativeContextMenu:{refine:true,init:false},nativeHelp:{check:d,init:false,apply:n}},members:{__ms:null,isRootWidget:function(){return true;},getLayout:function(){return this._getLayout();},_applyGlobalCursor:qx.core.Environment.select(b,{"mshtml":function(w,v){},"default":function(A,z){var y=qx.bom.Stylesheet;var x=this.__ms;if(!x){this.__ms=x=y.createElement();};y.removeAllRules(x);if(A){y.addRule(x,u,qx.bom.element.Cursor.compile(A).replace(o,h)+j);};}}),_applyNativeContextMenu:function(C,B){if(C){this.removeListener(i,this._onNativeContextMenu,this,true);}else {this.addListener(i,this._onNativeContextMenu,this,true);};},_onNativeContextMenu:function(e){if(e.getTarget().getNativeContextMenu()){return;};e.preventDefault();},__mt:function(e){if(e.getKeyIdentifier()!==m){return;};var E=e.getTarget();var D=qx.ui.core.FocusHandler.getInstance();if(!D.isFocused(E)){return;};var F=E.getContentElement().getNodeName();if(F===k||F===s){return;};e.preventDefault();},_applyNativeHelp:function(H,G){if(qx.core.Environment.get(p)){if(G===false){qx.bom.Event.removeNativeListener(document,g,(function(){return false;}));};if(H===false){qx.bom.Event.addNativeListener(document,g,(function(){return false;}));};};}},destruct:function(){this.__ms=null;},defer:function(I,J){qx.ui.core.MChildrenHandling.remap(J);}});})();(function(){var a="touchmove",b="os.name",c="-webkit-overflow-scrolling",d="touch",f="paddingLeft",g="div",h="100%",i="The root widget does not support 'left', or 'top' paddings!",j="0px",k="The application could not be started due to a missing body tag in the HTML file!",l="ios",m="overflowY",n="resize",o="",p="$$widget",q="paddingTop",r="engine.name",s="none",t="webkit",u="-webkit-backface-visibility",v="touch-action",w="qx.ui.root.Application",x="hidden",y="tap",z="overflowX",A="absolute";qx.Class.define(w,{extend:qx.ui.root.Abstract,construct:function(B){this.__cz=qx.dom.Node.getWindow(B);this.__mu=B;qx.ui.root.Abstract.call(this);qx.event.Registration.addListener(this.__cz,n,this._onResize,this);this._setLayout(new qx.ui.layout.Canvas());qx.ui.core.queue.Layout.add(this);qx.ui.core.FocusHandler.getInstance().connectTo(this);this.getContentElement().disableScrolling();this.getContentElement().setStyle(u,x);this.addListener(a,this.__mv,this);if(qx.core.Environment.get(b)==l){this.getContentElement().addListener(y,function(e){var C=qx.ui.core.Widget.getWidgetByElement(e.getTarget());while(C&&!C.isFocusable()){C=C.getLayoutParent();};if(C&&C.isFocusable()){C.getContentElement().focus();};},this,true);};},members:{__cz:null,__mu:null,_createContentElement:function(){var D=this.__mu;if((qx.core.Environment.get(r)==t)){if(!D.body){alert(k);};};var H=D.documentElement.style;var E=D.body.style;H.overflow=E.overflow=x;H.padding=H.margin=E.padding=E.margin=j;H.width=H.height=E.width=E.height=h;var G=D.createElement(g);D.body.appendChild(G);var F=new qx.html.Root(G);F.setStyles({"position":A,"overflowX":x,"overflowY":x});F.setAttribute(p,this.toHashCode());return F;},_onResize:function(e){qx.ui.core.queue.Layout.add(this);if(qx.ui.popup&&qx.ui.popup.Manager){qx.ui.popup.Manager.getInstance().hideAll();};if(qx.ui.menu&&qx.ui.menu.Manager){qx.ui.menu.Manager.getInstance().hideAll();};},_computeSizeHint:function(){var I=qx.bom.Viewport.getWidth(this.__cz);var J=qx.bom.Viewport.getHeight(this.__cz);return {minWidth:I,width:I,maxWidth:I,minHeight:J,height:J,maxHeight:J};},_applyPadding:function(L,K,name){if(L&&(name==q||name==f)){throw new Error(i);};qx.ui.root.Abstract.prototype._applyPadding.call(this,L,K,name);},__mv:function(e){var M=e.getOriginalTarget();while(M&&M.style){var Q=qx.bom.element.Style.get(M,v)!==s&&qx.bom.element.Style.get(M,v)!==o;var P=qx.bom.element.Style.get(M,c)===d;var O=qx.bom.element.Style.get(M,z)!=x;var N=qx.bom.element.Style.get(M,m)!=x;if(Q||P||N||O){return;};M=M.parentNode;};e.preventDefault();}},destruct:function(){this.__cz=this.__mu=null;}});})();(function(){var a="qx.ui.layout.Canvas",b="number",c="Boolean";qx.Class.define(a,{extend:qx.ui.layout.Abstract,properties:{desktop:{check:c,init:false}},members:{verifyLayoutProperty:null,renderLayout:function(g,j,m){var s=this._getLayoutChildren();var d,u,r;var f,top,e,h,n,k;var q,p,t,o;for(var i=0,l=s.length;i<l;i++ ){d=s[i];u=d.getSizeHint();r=d.getLayoutProperties();q=d.getMarginTop();p=d.getMarginRight();t=d.getMarginBottom();o=d.getMarginLeft();f=r.left!=null?r.left:r.edge;if(qx.lang.Type.isString(f)){f=Math.round(parseFloat(f)*g/100);};e=r.right!=null?r.right:r.edge;if(qx.lang.Type.isString(e)){e=Math.round(parseFloat(e)*g/100);};top=r.top!=null?r.top:r.edge;if(qx.lang.Type.isString(top)){top=Math.round(parseFloat(top)*j/100);};h=r.bottom!=null?r.bottom:r.edge;if(qx.lang.Type.isString(h)){h=Math.round(parseFloat(h)*j/100);};if(f!=null&&e!=null){n=g-f-e-o-p;if(n<u.minWidth){n=u.minWidth;}else if(n>u.maxWidth){n=u.maxWidth;};f+=o;}else {n=r.width;if(n==null){n=u.width;}else {n=Math.round(parseFloat(n)*g/100);if(n<u.minWidth){n=u.minWidth;}else if(n>u.maxWidth){n=u.maxWidth;};};if(e!=null){f=g-n-e-p-o;}else if(f==null){f=o;}else {f+=o;};};if(top!=null&&h!=null){k=j-top-h-q-t;if(k<u.minHeight){k=u.minHeight;}else if(k>u.maxHeight){k=u.maxHeight;};top+=q;}else {k=r.height;if(k==null){k=u.height;}else {k=Math.round(parseFloat(k)*j/100);if(k<u.minHeight){k=u.minHeight;}else if(k>u.maxHeight){k=u.maxHeight;};};if(h!=null){top=j-k-h-t-q;}else if(top==null){top=q;}else {top+=q;};};f+=m.left;top+=m.top;d.renderLayout(f,top,n,k);};},_computeSizeHint:function(){var M=0,y=0;var J=0,I=0;var H,v;var E,C;var L=this._getLayoutChildren();var w,B,z;var K=this.isDesktop();var A,top,x,D;for(var i=0,l=L.length;i<l;i++ ){w=L[i];B=w.getLayoutProperties();z=w.getSizeHint();var G=w.getMarginLeft()+w.getMarginRight();var F=w.getMarginTop()+w.getMarginBottom();H=z.width+G;v=z.minWidth+G;A=B.left!=null?B.left:B.edge;if(A&&typeof A===b){H+=A;v+=A;};x=B.right!=null?B.right:B.edge;if(x&&typeof x===b){H+=x;v+=x;};M=Math.max(M,H);y=K?0:Math.max(y,v);E=z.height+F;C=z.minHeight+F;top=B.top!=null?B.top:B.edge;if(top&&typeof top===b){E+=top;C+=top;};D=B.bottom!=null?B.bottom:B.edge;if(D&&typeof D===b){E+=D;C+=D;};J=Math.max(J,E);I=K?0:Math.max(I,C);};return {width:M,minWidth:y,height:J,minHeight:I};}}});})();(function(){var a="qx.html.Root";qx.Class.define(a,{extend:qx.html.Element,construct:function(b){qx.html.Element.call(this);if(b!=null){this.useElement(b);};},members:{useElement:function(c){qx.html.Element.prototype.useElement.call(this,c);this.setRoot(true);qx.html.Element._modified[this.$$hash]=this;}}});})();(function(){var a='center',b='icon/16/status/dialog-information.png',c='icon/16/status/dialog-warning.png',d='icon/32/actions/help-faq.png',e='appear',f='OK',g='$1<br/>\n',h='icon/16/actions/dialog-cancel.png',i='Information',j='icon/32/status/dialog-warning.png',k='Confirm',l='Prompt',m='kucken.ui.MDialog',n='execute',o='icon/16/actions/help-faq.png',p='Cancel',q='Alert',r='icon/32/status/dialog-information.png',s='icon/16/actions/dialog-ok.png',t='Callback is not a function';qx.Mixin.define(m,{members:{inform:function(u,v,y){var x=new qx.ui.form.Button(this.tr(f),s);var window=this.__tg(this.tr(i),u,b,r,[x]);x.addListener(n,function(){this.__cS(window);if(qx.lang.Type.isFunction(v)){v.call(y);};},this);},alert:function(z,A,C){var B=new qx.ui.form.Button(this.tr(f),s);var window=this.__tg(this.tr(q),z,c,j,[B]);B.addListener(n,function(){this.__cS(window);if(qx.lang.Type.isFunction(A)){A.call(C);};},this);},confirm:function(H,D,I,F,G){if(!qx.lang.Type.isFunction(F)){throw new Error(t);};var E=new qx.ui.form.Button(D||this.tr(f),s);var J=new qx.ui.form.Button(I||this.tr(p),h);var K=new qx.ui.container.Composite(new qx.ui.layout.HBox(16));K.add(E);K.add(J);var window=this.__tg(this.tr(k),H,o,d,[K]);E.addListener(n,function(){this.__cS(window);F.call(G,true);},this);J.addListener(n,function(){this.__cS(window);F.call(G,false);},this);},prompt:function(R,L,N,Q,O){if(!qx.lang.Type.isFunction(N)){throw new Error(t);};var M=new qx.ui.form.Button(this.tr(f),s);var S=new qx.ui.form.Button(this.tr(p),h);var P;if(O&&O>1){P=new qx.ui.form.TextArea(L);P.setHeight(O*16);}else {P=new qx.ui.form.TextField(L);};P.setWidth(200);P.addListener(e,P.selectAllText,P);var T=new qx.ui.container.Composite(new qx.ui.layout.HBox(16));T.add(M);T.add(S);var window=this.__tg(this.tr(l),R,o,d,[P,T]);M.addListener(n,function(){N.call(Q,P.getValue());this.__cS(window);},this);S.addListener(n,function(){this.__cS(window);N.call(Q,false);},this);},__tf:function(U){return U.replace(/([^>])\n/g,g);},__cS:function(window){window.close();qx.core.Init.getApplication().getRoot().remove(window);window.dispose();},__tg:function(W,be,Y,bd,bc){var window=new qx.ui.window.Window(W,Y);window.set({'minWidth':300,'minHeight':100,'showMaximize':false,'showMinimize':false,'showClose':false,'modal ':true,'resizable':false,'layout':new qx.ui.layout.VBox()});window.addListener(e,window.center,window);var X=new qx.ui.basic.Image(bd);X.setMarginRight(5);var ba=new qx.ui.basic.Label(this.__tf(be.toString()));ba.setRich(true);ba.setSelectable(true);var bb=new qx.ui.container.Composite(new qx.ui.layout.HBox());bb.setMarginBottom(5);bb.add(X);bb.add(ba);var V=new qx.ui.container.Composite(new qx.ui.layout.VBox(8));V.setAllowGrowX(false);V.setAlignX(a);bc.forEach(function(w){V.add(w,{'flex':1});});window.add(bb);window.add(V,{'flex':1});qx.core.Init.getApplication().getRoot().add(window);window.open();return window;}}});})();(function(){var a="toolTipText",b="icon",c="label",d="qx.ui.core.MExecutable",f="enabled",g="value",h="qx.event.type.Event",j="execute",k="_applyCommand",l="qx.ui.command.Command",m="menu",n="changeCommand";qx.Mixin.define(d,{events:{"execute":h},properties:{command:{check:l,apply:k,event:n,nullable:true}},members:{__ps:null,__pt:false,__pu:null,_bindableProperties:[f,c,b,a,g,m],execute:function(){var o=this.getCommand();if(o){if(this.__pt){this.__pt=false;}else {this.__pt=true;o.execute(this);};};this.fireEvent(j);},__pv:function(e){if(this.__pt){this.__pt=false;return;};if(this.isEnabled()){this.__pt=true;this.execute();};},_applyCommand:function(r,p){if(p!=null){p.removeListenerById(this.__pu);};if(r!=null){this.__pu=r.addListener(j,this.__pv,this);};var q=this.__ps;if(q==null){this.__ps=q={};};var u;for(var i=0;i<this._bindableProperties.length;i++ ){var t=this._bindableProperties[i];if(p!=null&&!p.isDisposed()&&q[t]!=null){p.removeBinding(q[t]);q[t]=null;};if(r!=null&&qx.Class.hasProperty(this.constructor,t)){var s=r.get(t);if(s==null){u=this.get(t);if(u==null){this.syncAppearance();u=qx.util.PropertyUtil.getThemeValue(this,t);};}else {u=null;};q[t]=r.bind(t,this,t);if(u){this.set(t,u);};};};}},destruct:function(){this._applyCommand(null,this.getCommand());this.__ps=null;}});})();(function(){var a="qx.ui.form.IExecutable",b="qx.event.type.Data";qx.Interface.define(a,{events:{"execute":b},members:{setCommand:function(c){return arguments.length==1;},getCommand:function(){},execute:function(){}}});})();(function(){var a="dblclick",b="qx.ui.form.Button",c="pointerup",d="Enter",f="pressed",g="pointerover",h="hovered",i="pointerdown",j="Space",k="keydown",l="abandoned",m="tap",n="button",o="keyup",p="pointerout";qx.Class.define(b,{extend:qx.ui.basic.Atom,include:[qx.ui.core.MExecutable],implement:[qx.ui.form.IExecutable],construct:function(q,s,r){qx.ui.basic.Atom.call(this,q,s);if(r!=null){this.setCommand(r);};this.addListener(g,this._onPointerOver);this.addListener(p,this._onPointerOut);this.addListener(i,this._onPointerDown);this.addListener(c,this._onPointerUp);this.addListener(m,this._onTap);this.addListener(k,this._onKeyDown);this.addListener(o,this._onKeyUp);this.addListener(a,function(e){e.stopPropagation();});},properties:{appearance:{refine:true,init:n},focusable:{refine:true,init:true}},members:{_forwardStates:{focused:true,hovered:true,pressed:true,disabled:true},press:function(){if(this.hasState(l)){return;};this.addState(f);},release:function(){if(this.hasState(f)){this.removeState(f);};},reset:function(){this.removeState(f);this.removeState(l);this.removeState(h);},_onPointerOver:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};if(this.hasState(l)){this.removeState(l);this.addState(f);};this.addState(h);},_onPointerOut:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};this.removeState(h);if(this.hasState(f)){this.removeState(f);this.addState(l);};},_onPointerDown:function(e){if(!e.isLeftPressed()){return;};e.stopPropagation();this.capture();this.removeState(l);this.addState(f);},_onPointerUp:function(e){this.releaseCapture();var t=this.hasState(f);var u=this.hasState(l);if(t){this.removeState(f);};if(u){this.removeState(l);};e.stopPropagation();},_onTap:function(e){this.execute();e.stopPropagation();},_onKeyDown:function(e){switch(e.getKeyIdentifier()){case d:case j:this.removeState(l);this.addState(f);e.stopPropagation();};},_onKeyUp:function(e){switch(e.getKeyIdentifier()){case d:case j:if(this.hasState(f)){this.removeState(l);this.removeState(f);this.execute();e.stopPropagation();};};}}});})();(function(){var a="",b="qx.ui.form.MForm",c="Boolean",d="_applyValid",f="changeLocale",g="changeRequired",h="changeValid",i="changeInvalidMessage",j="String",k="invalid";qx.Mixin.define(b,{construct:function(){{qx.locale.Manager.getInstance().addListener(f,this.__pQ,this);};},properties:{valid:{check:c,init:true,apply:d,event:h},required:{check:c,init:false,event:g},invalidMessage:{check:j,init:a,event:i},requiredInvalidMessage:{check:j,nullable:true,event:i}},members:{_applyValid:function(m,l){m?this.removeState(k):this.addState(k);},__pQ:function(e){var n=this.getInvalidMessage();if(n&&n.translate){this.setInvalidMessage(n.translate());};var o=this.getRequiredInvalidMessage();if(o&&o.translate){this.setRequiredInvalidMessage(o.translate());};}},destruct:function(){{qx.locale.Manager.getInstance().removeListener(f,this.__pQ,this);};}});})();(function(){var a="readOnly",b="text",c='border: none;padding: 0;margin: 0;display : block;background : transparent;outline: none;appearance: none;position: absolute;autoComplete: off;resize: none;border-radius: 0;',d="_applyTextAlign",f="-ms-input-placeholder",g="px",h="RegExp",i="readonly",j=")",k="syncAppearance",l="engine.version",m="Invalid value type: ",n="A",o="input::-moz-placeholder, textarea::-moz-placeholder",p=".qx-abstract-field",q="browser.name",r="color",s="qx.event.type.Data",t="focusin",u="firefox",v="showingPlaceholder",w="center",x="change",y="textarea",z="changeStatus",A="textAlign",B="::",C="input.qx-placeholder-color::-webkit-input-placeholder, textarea.qx-placeholder-color::-webkit-input-placeholder",D="focused",E="qx-placeholder-color",F="visible",G="PositiveInteger",H=":",I=" !important",J="url(",K="hidden",L="_applyReadOnly",M="browser.documentmode",N="input:-moz-placeholder, textarea:-moz-placeholder",O="input.qx-placeholder-color",P="qx.ui.form.AbstractField",Q="disabled",R="",S="-ms-input-placeholder, textarea.qx-placeholder-color",T="visibility",U="_applyMaxLength",V="input",W="color: ",X="qx-abstract-field",Y="appear",bG="browser.version",bH="pointerdown",bI="spellcheck",bC="false",bD="right",bE="maxLength",bF="gecko",bM="normal",bN="mshtml",bO="engine.name",ca="abstract",bJ="focusout",bK="placeholder",bL="edge",bA="css.placeholder",bR="webkit",bB="String",bS="changeLocale",bT="_applyPlaceholder",bX="Boolean",bP="left",bY="changeValue",bQ="qx/static/blank.gif",bU="text-placeholder",bV="changeReadOnly",bW="absolute";qx.Class.define(P,{extend:qx.ui.core.Widget,implement:[qx.ui.form.IStringForm,qx.ui.form.IForm],include:[qx.ui.form.MForm],type:ca,statics:{__ds:null,__pR:function(){var cb=qx.core.Environment.get(bO);var cg=qx.core.Environment.get(q);var cc=qx.theme.manager.Color.getInstance();var cd=cc.resolve(bU);var ce;if(cb==bF){if(parseFloat(qx.core.Environment.get(l))>=19){ce=o;}else {ce=N;};qx.ui.style.Stylesheet.getInstance().addRule(ce,W+cd+I);}else if(cb==bR&&cg!=bL){ce=C;qx.ui.style.Stylesheet.getInstance().addRule(ce,W+cd);}else if(cb==bN||cg==bL){var cf=cg==bL?B:H;ce=[O,S,f].join(cf);qx.ui.style.Stylesheet.getInstance().addRule(ce,W+cd+I);};}},construct:function(ch){qx.ui.core.Widget.call(this);this.__pS=!qx.core.Environment.get(bA);if(ch!=null){this.setValue(ch);};this.getContentElement().addListener(x,this._onChangeContent,this);if(this.__pS){this.addListener(k,this._syncPlaceholder,this);}else {qx.ui.form.AbstractField.__pR();this.getContentElement().addClass(E);};{qx.locale.Manager.getInstance().addListener(bS,this._onChangeLocale,this);};},events:{"input":s,"changeValue":s},properties:{textAlign:{check:[bP,w,bD],nullable:true,themeable:true,apply:d},readOnly:{check:bX,apply:L,event:bV,init:false},selectable:{refine:true,init:true},focusable:{refine:true,init:true},maxLength:{apply:U,check:G,init:Infinity},liveUpdate:{check:bX,init:false},placeholder:{check:bB,nullable:true,apply:bT},filter:{check:h,nullable:true,init:null}},members:{__pT:true,_placeholder:null,__iV:null,__iW:null,__pS:true,__lz:null,__lC:null,getFocusElement:function(){var ci=this.getContentElement();if(ci){return ci;};},_createInputElement:function(){return new qx.html.Input(b);},renderLayout:function(cr,top,cm,ck){var cj=this._updateInsets;var cp=qx.ui.core.Widget.prototype.renderLayout.call(this,cr,top,cm,ck);if(!cp){return;};var cn=cp.size||cj;var cq=g;if(cn||cp.local||cp.margin){var innerWidth=cm;var innerHeight=ck;};var co=this.getContentElement();if(cj&&this.__pS){if(this.__pS){var cl=this.getInsets();this._getPlaceholderElement().setStyles({paddingTop:cl.top+cq,paddingRight:cl.right+cq,paddingBottom:cl.bottom+cq,paddingLeft:cl.left+cq});};};if(cn||cp.margin){if(this.__pS){var cl=this.getInsets();this._getPlaceholderElement().setStyles({"width":(innerWidth-cl.left-cl.right)+cq,"height":(innerHeight-cl.top-cl.bottom)+cq});};co.setStyles({"width":innerWidth+cq,"height":innerHeight+cq});this._renderContentElement(innerHeight,co);};if(cp.position){if(this.__pS){this._getPlaceholderElement().setStyles({"left":cr+cq,"top":top+cq});};};},_renderContentElement:function(innerHeight,cs){},_createContentElement:function(){var ct=this._createInputElement();ct.setSelectable(this.getSelectable());ct.setEnabled(this.getEnabled());ct.addListener(V,this._onHtmlInput,this);ct.setAttribute(bI,bC);ct.addClass(X);if((qx.core.Environment.get(bO)==bN)&&(qx.core.Environment.get(M)==8)){ct.setStyles({backgroundImage:J+qx.util.ResourceManager.getInstance().toUri(bQ)+j});};return ct;},_applyEnabled:function(cw,cv){qx.ui.core.Widget.prototype._applyEnabled.call(this,cw,cv);this.getContentElement().setEnabled(cw);if(this.__pS){if(cw){this._showPlaceholder();}else {this._removePlaceholder();};}else {var cu=this.getContentElement();cu.setAttribute(bK,cw?this.getPlaceholder():R);};},__pU:{width:16,height:16},_getContentHint:function(){return {width:this.__pU.width*10,height:this.__pU.height||16};},_applyFont:function(cz,cy){if(cy&&this.__lz&&this.__lC){this.__lz.removeListenerById(this.__lC);this.__lC=null;};var cx;if(cz){this.__lz=qx.theme.manager.Font.getInstance().resolve(cz);if(this.__lz instanceof qx.bom.webfonts.WebFont){this.__lC=this.__lz.addListener(z,this._onWebFontStatusChange,this);};cx=this.__lz.getStyles();}else {cx=qx.bom.Font.getDefaultStyles();};if(this.getTextColor()!=null){delete cx[r];};if(qx.core.Environment.get(bO)==bN&&qx.core.Environment.get(M)<11){qx.html.Element.flush();this.getContentElement().setStyles(cx,true);}else {this.getContentElement().setStyles(cx);};if(this.__pS){delete cx[r];this._getPlaceholderElement().setStyles(cx);};if(cz){this.__pU=qx.bom.Label.getTextSize(n,cx);}else {delete this.__pU;};qx.ui.core.queue.Layout.add(this);},_applyTextColor:function(cB,cA){if(cB){this.getContentElement().setStyle(r,qx.theme.manager.Color.getInstance().resolve(cB));}else {this.getContentElement().removeStyle(r);};},_applyMaxLength:function(cD,cC){if(cD){this.getContentElement().setAttribute(bE,cD);}else {this.getContentElement().removeAttribute(bE);};},tabFocus:function(){qx.ui.core.Widget.prototype.tabFocus.call(this);this.selectAllText();},_getTextSize:function(){return this.__pU;},_onHtmlInput:function(e){var cF=e.getData();var cE=true;this.__pT=false;if(this.__iW&&this.__iW===cF){cE=false;};if(this.getFilter()!=null){var cG=this._validateInput(cF);if(cG!=cF){cE=false;cF=cG;this.getContentElement().setValue(cF);};};if(cE){this.fireDataEvent(V,cF,this.__iW);this.__iW=cF;if(this.getLiveUpdate()){this.__pV(cF);};};},_onWebFontStatusChange:function(cI){if(cI.getData().valid===true){var cH=this.__lz.getStyles();this.__pU=qx.bom.Label.getTextSize(n,cH);qx.ui.core.queue.Layout.add(this);};},__pV:function(cK){var cJ=this.__iV;this.__iV=cK;if(cJ!=cK){this.fireNonBubblingEvent(bY,qx.event.type.Data,[cK,cJ]);};},setValue:function(cO){if(cO===null){if(this.__pT){return cO;};cO=R;this.__pT=true;}else {this.__pT=false;if(this.__pS){this._removePlaceholder();};};if(qx.lang.Type.isString(cO)){var cN=this.getContentElement();if(cN.getValue()!=cO){var cL=cN.getValue();cN.setValue(cO);var cM=this.__pT?null:cO;this.__iV=cL;this.__pV(cM);this.__iW=this.__iV;};if(this.__pS){this._showPlaceholder();};return cO;};throw new Error(m+cO);},getValue:function(){var cP=this.getContentElement().getValue();return this.__pT?null:cP;},resetValue:function(){this.setValue(null);},_onChangeContent:function(e){this.__pT=e.getData()===null;this.__pV(e.getData());},getTextSelection:function(){return this.getContentElement().getTextSelection();},getTextSelectionLength:function(){return this.getContentElement().getTextSelectionLength();},getTextSelectionStart:function(){return this.getContentElement().getTextSelectionStart();},getTextSelectionEnd:function(){return this.getContentElement().getTextSelectionEnd();},setTextSelection:function(cQ,cR){this.getContentElement().setTextSelection(cQ,cR);},clearTextSelection:function(){this.getContentElement().clearTextSelection();},selectAllText:function(){this.setTextSelection(0);},setLayoutParent:function(parent){qx.ui.core.Widget.prototype.setLayoutParent.call(this,parent);if(this.__pS){if(parent){this.getLayoutParent().getContentElement().add(this._getPlaceholderElement());}else {var cS=this._getPlaceholderElement();cS.getParent().remove(cS);};};},_showPlaceholder:function(){var cU=this.getValue()||R;var cT=this.getPlaceholder();if(cT!=null&&cU==R&&!this.hasState(D)&&!this.hasState(Q)){if(this.hasState(v)){this._syncPlaceholder();}else {this.addState(v);};};},_onPointerDownPlaceholder:function(){window.setTimeout(function(){this.focus();}.bind(this),0);},_removePlaceholder:function(){if(this.hasState(v)){if(this.__pS){this._getPlaceholderElement().setStyle(T,K);};this.removeState(v);};},_syncPlaceholder:function(){if(this.hasState(v)&&this.__pS){this._getPlaceholderElement().setStyle(T,F);};},_getPlaceholderElement:function(){if(this._placeholder==null){this._placeholder=new qx.html.Label();var cV=qx.theme.manager.Color.getInstance();this._placeholder.setStyles({"zIndex":11,"position":bW,"color":cV.resolve(bU),"whiteSpace":bM,"cursor":b,"visibility":K});this._placeholder.addListener(bH,this._onPointerDownPlaceholder,this);};return this._placeholder;},_onChangeLocale:function(e){var content=this.getPlaceholder();if(content&&content.translate){this.setPlaceholder(content.translate());};},_onChangeTheme:function(){qx.ui.core.Widget.prototype._onChangeTheme.call(this);if(this._placeholder){this._placeholder.dispose();this._placeholder=null;};if(!this.__pS&&qx.ui.form.AbstractField.__ds){qx.bom.Stylesheet.removeSheet(qx.ui.form.AbstractField.__ds);qx.ui.form.AbstractField.__ds=null;qx.ui.form.AbstractField.__pR();};},_validateInput:function(da){var cY=da;var cW=this.getFilter();if(cW!=null){cY=R;var cX=da.search(cW);var db=da;while((cX>=0)&&(db.length>0)){cY=cY+(db.charAt(cX));db=db.substring(cX+1,db.length);cX=db.search(cW);};};return cY;},_applyPlaceholder:function(dd,dc){if(this.__pS){this._getPlaceholderElement().setValue(dd);if(dd!=null){this.addListener(t,this._removePlaceholder,this);this.addListener(bJ,this._showPlaceholder,this);this._showPlaceholder();}else {this.removeListener(t,this._removePlaceholder,this);this.removeListener(bJ,this._showPlaceholder,this);this._removePlaceholder();};}else {if(this.getEnabled()){this.getContentElement().setAttribute(bK,dd);if(qx.core.Environment.get(q)===u&&parseFloat(qx.core.Environment.get(bG))<36&&this.getContentElement().getNodeName()===y&&!this.getContentElement().getDomElement()){this.addListenerOnce(Y,function(){this.getContentElement().getDomElement().removeAttribute(bK);this.getContentElement().getDomElement().setAttribute(bK,dd);},this);};};};},_applyTextAlign:function(df,de){this.getContentElement().setStyle(A,df);},_applyReadOnly:function(dh,dg){var di=this.getContentElement();di.setAttribute(a,dh);if(dh){this.addState(i);this.setFocusable(false);}else {this.removeState(i);this.setFocusable(true);};}},defer:function(dj){var dk=c;qx.ui.style.Stylesheet.getInstance().addRule(p,dk);},destruct:function(){if(this._placeholder){this._placeholder.removeListener(bH,this._onPointerDownPlaceholder,this);var parent=this._placeholder.getParent();if(parent){parent.remove(this._placeholder);};this._placeholder.dispose();};this._placeholder=this.__lz=null;{qx.locale.Manager.getInstance().removeListener(bS,this._onChangeLocale,this);};if(this.__lz&&this.__lC){this.__lz.removeListenerById(this.__lC);};this.getContentElement().removeListener(V,this._onHtmlInput,this);}});})();(function(){var a="engine.name",b="",c="wrap",d="none",e="Text wrapping is only support by textareas!",f="overflow",g="webkit",h="input",i="qx.html.Input",j="value",k="select",l="disabled",m="read-only",n="textarea",o="overflowX",p="overflowY";qx.Class.define(i,{extend:qx.html.Element,construct:function(s,q,r){if(s===k||s===n){var t=s;}else {t=h;};qx.html.Element.call(this,t,q,r);this.__pW=s;},members:{__pW:null,__pX:null,__pY:null,_createDomElement:function(){return qx.bom.Input.create(this.__pW);},_applyProperty:function(name,u){qx.html.Element.prototype._applyProperty.call(this,name,u);var v=this.getDomElement();if(name===j){qx.bom.Input.setValue(v,u);}else if(name===c){qx.bom.Input.setWrap(v,u);this.setStyle(f,v.style.overflow,true);this.setStyle(o,v.style.overflowX,true);this.setStyle(p,v.style.overflowY,true);};},setEnabled:function(w){this.__pY=w;this.setAttribute(l,w===false);if(qx.core.Environment.get(a)==g){if(!w){this.setStyles({"userModify":m,"userSelect":d});}else {this.setStyles({"userModify":null,"userSelect":this.__pX?null:d});};};},setSelectable:qx.core.Environment.select(a,{"webkit":function(x){this.__pX=x;qx.html.Element.prototype.setSelectable.call(this,this.__pY&&x);},"default":function(y){qx.html.Element.prototype.setSelectable.call(this,y);}}),setValue:function(z){var A=this.getDomElement();if(A){if(A.value!=z){qx.bom.Input.setValue(A,z);};}else {this._setProperty(j,z);};return this;},getValue:function(){var B=this.getDomElement();if(B){return qx.bom.Input.getValue(B);};return this._getProperty(j)||b;},setWrap:function(C,D){if(this.__pW===n){this._setProperty(c,C,D);}else {throw new Error(e);};return this;},getWrap:function(){if(this.__pW===n){return this._getProperty(c);}else {throw new Error(e);};}}});})();(function(){var a="wrap",b="text",c="engine.name",d="soft",e="",f="mshtml",g="number",h="checkbox",j="select-one",k="input",m="option",n="value",o="off",p="select",q="radio",r="qx.bom.Input",s="nowrap",t="textarea",u="auto",v="normal";qx.Bootstrap.define(r,{statics:{__jH:{text:1,textarea:1,select:1,checkbox:1,radio:1,password:1,hidden:1,submit:1,image:1,file:1,search:1,reset:1,button:1},create:function(y,w,z){{};var w=w?qx.lang.Object.clone(w):{};var x;if(y===t||y===p){x=y;}else {x=k;w.type=y;};return qx.dom.Element.create(x,w,z);},setValue:function(F,E){var G=F.nodeName.toLowerCase();var B=F.type;var Array=qx.lang.Array;var H=qx.lang.Type;if(typeof E===g){E+=e;};if((B===h||B===q)){if(H.isArray(E)){F.checked=Array.contains(E,F.value);}else {F.checked=F.value==E;};}else if(G===p){var A=H.isArray(E);var I=F.options;var C,D;for(var i=0,l=I.length;i<l;i++ ){C=I[i];D=C.getAttribute(n);if(D==null){D=C.text;};C.selected=A?Array.contains(E,D):E==D;};if(A&&E.length==0){F.selectedIndex=-1;};}else if((B===b||B===t)&&(qx.core.Environment.get(c)==f)){F.$$inValueSet=true;F.value=E;F.$$inValueSet=null;}else {F.value=E;};},getValue:function(Q){var O=Q.nodeName.toLowerCase();if(O===m){return (Q.attributes.value||{}).specified?Q.value:Q.text;};if(O===p){var J=Q.selectedIndex;if(J<0){return null;};var P=[];var S=Q.options;var N=Q.type==j;var R=qx.bom.Input;var M;for(var i=N?J:0,L=N?J+1:S.length;i<L;i++ ){var K=S[i];if(K.selected){M=R.getValue(K);if(N){return M;};P.push(M);};};return P;}else {return (Q.value||e).replace(/\r/g,e);};},setWrap:qx.core.Environment.select(c,{"mshtml":function(W,T){var V=T?d:o;var U=T?u:e;W.wrap=V;W.style.overflowY=U;},"gecko":function(bb,X){var ba=X?d:o;var Y=X?e:u;bb.setAttribute(a,ba);bb.style.overflow=Y;},"webkit":function(bf,bc){var be=bc?d:o;var bd=bc?e:u;bf.setAttribute(a,be);bf.style.overflow=bd;},"default":function(bh,bg){bh.style.whiteSpace=bg?v:s;}})}});})();(function(){var a="input",b="Boolean",c="px",d="nowrap",f="_applyWrap",g="-1",h="_applyMinimalLineHeight",i="Integer",j="textarea",k="auto",l="0",m="-9999px",n="roll",o="whiteSpace",p="visible",q="browser.documentmode",r="resize",s="",t="width",u="_applyAutoSize",v="appear",w="tabIndex",x='name',y='autoSize is ignored when the height property is set. If you want to set an initial height, use the minHeight property instead.',z="normal",A="mshtml",B="engine.name",C="qx.ui.form.TextArea",D="webkit",E="wheel",F='id',G="hidden",H="overflowY",I="absolute";qx.Class.define(C,{extend:qx.ui.form.AbstractField,construct:function(J){qx.ui.form.AbstractField.call(this,J);this.initWrap();this.addListener(n,this._onRoll,this);this.addListener(r,this._onResize,this);},properties:{wrap:{check:b,init:true,apply:f},appearance:{refine:true,init:j},singleStep:{check:i,init:20},minimalLineHeight:{check:i,apply:h,init:4},autoSize:{check:b,apply:u,init:false}},members:{__th:null,__ti:null,__tj:null,setValue:function(K){K=qx.ui.form.AbstractField.prototype.setValue.call(this,K);this.__tk();return K;},_onRoll:function(e){if(e.getPointerType()!=E){return;};var L=this.getContentElement();var scrollY=L.getScrollY();L.scrollToY(scrollY+(e.getDelta().y/30)*this.getSingleStep());var M=L.getScrollY();if(M!=scrollY){e.stop();};},_onResize:function(e){if(this.__th){this.__th.dispose();this.__th=null;this.__tk();};},__tk:function(){if(this.isAutoSize()){var P=this.__tl();if(P&&this.getBounds()){this.__tj=this.__tj||this._getAreaHeight();var R=this._getScrolledAreaHeight();if(this.getMaxHeight()){var N=this.getInsets();var O=-N.top+this.getMaxHeight()-N.bottom;if(R>O){this.getContentElement().setStyle(H,k);}else {this.getContentElement().setStyle(H,G);};};var Q=Math.max(R,this.__tj);this._setAreaHeight(Q);}else {this.getContentElement().addListenerOnce(v,function(){this.__tk();},this);};};},_getAreaHeight:function(){return this.getInnerSize().height;},_setAreaHeight:function(S){if(this._getAreaHeight()!==S){this.__ti=S;qx.ui.core.queue.Layout.add(this);qx.ui.core.queue.Manager.flush();this.__to();};},_getScrolledAreaHeight:function(){var U=this.__tl();var T=U.getDomElement();if(T){if(!T.parentNode){qx.html.Element.flush();return this._getScrolledAreaHeight();};if(qx.core.Environment.get(B)===D||(qx.core.Environment.get(B)==A)){U.setWrap(!this.getWrap(),true);};U.setWrap(this.getWrap(),true);if(qx.core.Environment.get(B)===D||(qx.core.Environment.get(B)==A)){T.style.overflow=G;};if(qx.core.Environment.get(B)==A&&qx.core.Environment.get(q)>=8){T.style.overflow=p;T.style.overflowX=G;};U.setValue(this.getValue()||s);if(qx.core.Environment.get(B)==A){T.style.height=k;qx.html.Element.flush();T.style.height=l;};this.__tn(U);if(qx.core.Environment.get(B)==A&&qx.core.Environment.get(q)==8){if(!T.scrollTop){qx.html.Element.flush();};};return T.scrollTop;};},__tl:function(){this.__th=this.__th||this.__tm();return this.__th;},__tm:function(){var X,W,Y,V;X=this.getContentElement();if(!X.getDomElement()){return null;};Y=qx.bom.Element.clone(X.getDomElement());V=new qx.html.Input(j);V.useElement(Y);W=V;W.setStyles({position:I,top:0,left:m,height:0,overflow:G},true);W.removeAttribute(F);W.removeAttribute(x);W.setAttribute(w,g);W.setValue(X.getValue()||s);W.insertBefore(X);this.__tn(W);return W;},__tn:function(ba){ba=ba.getDomElement();if(ba){ba.scrollTop=10000;};},_createInputElement:function(){return new qx.html.Input(j,{overflowX:k,overflowY:k});},_applyWrap:function(bd,bb){this.getContentElement().setWrap(bd);if(this._placeholder){var bc=bd?z:d;this._placeholder.setStyle(o,bc);};this.__tk();},_applyMinimalLineHeight:function(){qx.ui.core.queue.Layout.add(this);},_applyAutoSize:function(bf,be){{};if(bf){this.__tk();this.addListener(a,this.__tk,this);if(!this.getBounds()){this.addListenerOnce(v,function(){this.getContentElement().setStyle(H,G);});}else {this.getContentElement().setStyle(H,G);};}else {this.removeListener(a,this.__tk);this.getContentElement().setStyle(H,k);};},_applyDimension:function(bg){qx.ui.form.AbstractField.prototype._applyDimension.call(this);{};if(bg===this.getMaxHeight()){this.__tk();};},__to:function(){var content=this.getContentElement();var bi=content.getDomElement();var bh=content.getStyle(t);content.setStyle(t,parseInt(bh,10)+1000+c,true);if(bi){qx.bom.element.Dimension.getWidth(bi);};content.setStyle(t,bh,true);},__tp:function(){if(this.isAutoSize()&&this.getHeight()){this.warn(y);};},_getContentHint:function(){var bj=qx.ui.form.AbstractField.prototype._getContentHint.call(this);bj.height=bj.height*this.getMinimalLineHeight();bj.width=this._getTextSize().width*20;if(this.isAutoSize()){bj.height=this.__ti||bj.height;};return bj;}},destruct:function(){this.setAutoSize(false);if(this.__th){this.__th.dispose();};}});})();(function(){var a="mshtml",b="engine.name",c="qx.ui.form.TextField",d="Enter",e='px',f="mobile",g="tablet",h="device.type",i="textfield",j="engine.version",k="keypress",l="browser.documentmode";qx.Class.define(c,{extend:qx.ui.form.AbstractField,properties:{appearance:{refine:true,init:i},allowGrowY:{refine:true,init:false},allowShrinkY:{refine:true,init:false}},members:{_renderContentElement:function(innerHeight,m){if((qx.core.Environment.get(b)==a)&&(parseInt(qx.core.Environment.get(j),10)<9||qx.core.Environment.get(l)<9)){m.setStyles({"line-height":innerHeight+e});};},_createContentElement:function(){var n=qx.ui.form.AbstractField.prototype._createContentElement.call(this);var o=qx.core.Environment.get(h);if(o==g||o==f){n.addListener(k,this._onKeyPress,this);};return n;},_onKeyPress:function(p){if(p.getKeyIdentifier()==d){this.blur();};}},destruct:function(){this.getContentElement().removeListener(k,this._onKeyPress,this);}});})();(function(){var a="qx.ui.window.IWindowManager";qx.Interface.define(a,{members:{setDesktop:function(b){this.assertInterface(b,qx.ui.window.IDesktop);},changeActiveWindow:function(c,d){},updateStack:function(){},bringToFront:function(e){this.assertInstance(e,qx.ui.window.Window);},sendToBack:function(f){this.assertInstance(f,qx.ui.window.Window);}}});})();(function(){var a="qx.ui.window.IDesktop";qx.Interface.define(a,{members:{setWindowManager:function(b){this.assertInterface(b,qx.ui.window.IWindowManager);},getWindows:function(){},supportsMaximize:function(){},blockContent:function(c){this.assertInteger(c);},unblock:function(){},isBlocked:function(){}}});})();(function(){var a="qx.ui.window.Manager",b="__tq";qx.Class.define(a,{extend:qx.core.Object,implement:qx.ui.window.IWindowManager,members:{__tq:null,setDesktop:function(c){this.__tq=c;if(c){this.updateStack();}else {qx.ui.core.queue.Widget.remove(this);};},getDesktop:function(){return this.__tq;},changeActiveWindow:function(d,e){if(d){this.bringToFront(d);d.setActive(true);};if(e){e.resetActive();};},_minZIndex:1e5,updateStack:function(){qx.ui.core.queue.Widget.add(this);},syncWidget:function(){this.__tq.forceUnblock();var h=this.__tq.getWindows();var g=this._minZIndex;var m=g+h.length*2;var j=g+h.length*4;var k=null;for(var i=0,l=h.length;i<l;i++ ){var f=h[i];if(!f.isVisible()){continue;};k=k||f;if(f.isModal()){f.setZIndex(j);this.__tq.blockContent(j-1);j+=2;k=f;}else if(f.isAlwaysOnTop()){f.setZIndex(m);m+=2;}else {f.setZIndex(g);g+=2;};if(!k.isModal()&&f.isActive()||f.getZIndex()>k.getZIndex()){k=f;};};this.__tq.setActiveWindow(k);},bringToFront:function(o){var n=this.__tq.getWindows();var p=qx.lang.Array.remove(n,o);if(p){n.push(o);this.updateStack();};},sendToBack:function(r){var q=this.__tq.getWindows();var s=qx.lang.Array.remove(q,r);if(s){q.unshift(r);this.updateStack();};}},destruct:function(){this._disposeObjects(b);}});})();(function(){var a="indexOf",b="addAfter",c="add",d="addBefore",e="_",f="addAt",g="hasChildren",h="removeAt",i="removeAll",j="getChildren",k="remove",l="qx.ui.core.MRemoteChildrenHandling";qx.Mixin.define(l,{members:{__pD:function(q,m,o,n){var p=this.getChildrenContainer();if(p===this){q=e+q;};return (p[q])(m,o,n);},getChildren:function(){return this.__pD(j);},hasChildren:function(){return this.__pD(g);},add:function(s,r){return this.__pD(c,s,r);},remove:function(t){return this.__pD(k,t);},removeAll:function(){return this.__pD(i);},indexOf:function(u){return this.__pD(a,u);},addAt:function(x,v,w){this.__pD(f,x,v,w);},addBefore:function(y,A,z){this.__pD(d,y,A,z);},addAfter:function(D,B,C){this.__pD(b,D,B,C);},removeAt:function(E){return this.__pD(h,E);}}});})();(function(){var a="qx.ui.core.MRemoteLayoutHandling";qx.Mixin.define(a,{members:{setLayout:function(b){this.getChildrenContainer().setLayout(b);},getLayout:function(){return this.getChildrenContainer().getLayout();}}});})();(function(){var a="pointerup",b="Boolean",c="losecapture",d="__ts",f="move",g="qx.ui.core.MMovable",h="The move handle could not be redefined!",i="pointerdown",j="maximized",k="pointermove",l="__tr",m="roll",n="move-frame";qx.Mixin.define(g,{properties:{movable:{check:b,init:true},useMoveFrame:{check:b,init:false}},members:{__tr:null,__ts:null,__tt:null,__tu:null,__tv:null,__tw:null,__tx:null,__ty:false,__tz:null,__tA:0,_activateMoveHandle:function(o){if(this.__tr){throw new Error(h);};this.__tr=o;o.addListener(i,this._onMovePointerDown,this);o.addListener(a,this._onMovePointerUp,this);o.addListener(k,this._onMovePointerMove,this);o.addListener(c,this.__tE,this);},__tB:function(){var p=this.__ts;if(!p){p=this.__ts=new qx.ui.core.Widget();p.setAppearance(n);p.exclude();qx.core.Init.getApplication().getRoot().add(p);};return p;},__tC:function(){var location=this.getContentLocation();var r=this.getBounds();var q=this.__tB();q.setUserBounds(location.left,location.top,r.width,r.height);q.show();q.setZIndex(this.getZIndex()+1);},__tD:function(e){var t=this.__tt;var s=Math.max(t.left,Math.min(t.right,e.getDocumentLeft()));var v=Math.max(t.top,Math.min(t.bottom,e.getDocumentTop()));var u=this.__tu+s;var w=this.__tv+v;return {viewportLeft:parseInt(u,10),viewportTop:parseInt(w,10),parentLeft:parseInt(u-this.__tw,10),parentTop:parseInt(w-this.__tx,10)};},_onMoveRoll:function(e){e.stop();},_onMovePointerDown:function(e){if(!this.getMovable()||this.hasState(j)){return;};this.addListener(m,this._onMoveRoll,this);var parent=this.getLayoutParent();var x=parent.getContentLocation();var z=parent.getBounds();if(qx.Class.implementsInterface(parent,qx.ui.window.IDesktop)){if(!parent.isBlocked()){this.__tz=parent.getBlockerColor();this.__tA=parent.getBlockerOpacity();parent.setBlockerColor(null);parent.setBlockerOpacity(1);parent.blockContent(this.getZIndex()-1);this.__ty=true;};};this.__tt={left:x.left,top:x.top,right:x.left+z.width,bottom:x.top+z.height};var y=this.getContentLocation();this.__tw=x.left;this.__tx=x.top;this.__tu=y.left-e.getDocumentLeft();this.__tv=y.top-e.getDocumentTop();this.addState(f);this.__tr.capture();if(this.getUseMoveFrame()){this.__tC();};e.stop();},_onMovePointerMove:function(e){if(!this.hasState(f)){return;};var B=this.__tD(e);if(this.getUseMoveFrame()){this.__tB().setDomPosition(B.viewportLeft,B.viewportTop);}else {var A=this.getLayoutParent().getInsets();this.setDomPosition(B.parentLeft-(A.left||0),B.parentTop-(A.top||0));};e.stopPropagation();},_onMovePointerUp:function(e){if(this.hasListener(m)){this.removeListener(m,this._onMoveRoll,this);};if(!this.hasState(f)){return;};this.removeState(f);var parent=this.getLayoutParent();if(qx.Class.implementsInterface(parent,qx.ui.window.IDesktop)){if(this.__ty){parent.unblock();parent.setBlockerColor(this.__tz);parent.setBlockerOpacity(this.__tA);this.__tz=null;this.__tA=0;this.__ty=false;};};this.__tr.releaseCapture();var D=this.__tD(e);var C=this.getLayoutParent().getInsets();this.setLayoutProperties({left:D.parentLeft-(C.left||0),top:D.parentTop-(C.top||0)});if(this.getUseMoveFrame()){this.__tB().exclude();};e.stopPropagation();},__tE:function(e){if(!this.hasState(f)){return;};this.removeState(f);if(this.getUseMoveFrame()){this.__tB().exclude();};}},destruct:function(){this._disposeObjects(d,l);this.__tt=null;}});})();(function(){var a="resetPaddingRight",b="setPaddingTop",c="_applyContentPadding",d="setPaddingBottom",e="resetThemed",f="contentPaddingRight",g="Integer",h="contentPaddingLeft",i="setThemedPaddingLeft",j="resetPaddingTop",k="shorthand",l="setThemedPaddingRight",m="setThemed",n="setPaddingRight",o="contentPaddingBottom",p="resetPaddingBottom",q="qx.ui.core.MContentPadding",r="resetPaddingLeft",s="setThemedPaddingTop",t="setPaddingLeft",u="setThemedPaddingBottom",v="contentPaddingTop";qx.Mixin.define(q,{properties:{contentPaddingTop:{check:g,init:0,apply:c,themeable:true},contentPaddingRight:{check:g,init:0,apply:c,themeable:true},contentPaddingBottom:{check:g,init:0,apply:c,themeable:true},contentPaddingLeft:{check:g,init:0,apply:c,themeable:true},contentPadding:{group:[v,f,o,h],mode:k,themeable:true}},members:{__rR:{contentPaddingTop:b,contentPaddingRight:n,contentPaddingBottom:d,contentPaddingLeft:t},__rS:{contentPaddingTop:s,contentPaddingRight:l,contentPaddingBottom:u,contentPaddingLeft:i},__rT:{contentPaddingTop:j,contentPaddingRight:a,contentPaddingBottom:p,contentPaddingLeft:r},_applyContentPadding:function(z,w,name,y){var A=this._getContentPaddingTarget();if(z==null){var x=this.__rT[name];A[x]();}else {if(y==m||y==e){var B=this.__rS[name];A[B](z);}else {var B=this.__rR[name];A[B](z);};};}}});})();(function(){var a="Boolean",b="w-resize",c="touch",d="sw-resize",f="n-resize",g="resizableRight",h="ne-resize",i="se-resize",j="Integer",k="e-resize",l="resizableLeft",m="move",n="shorthand",o="maximized",p="resize",q="nw-resize",r="pointerup",s="pointerdown",t="qx.ui.core.MResizable",u="losecapture",v="resize-frame",w="resizableBottom",x="s-resize",y="pointermove",z="resizableTop",A="pointerout";qx.Mixin.define(t,{construct:function(){var content=this.getContentElement();content.addListener(s,this.__tR,this,true);content.addListener(r,this.__tS,this);content.addListener(y,this.__tU,this);content.addListener(A,this.__tV,this);content.addListener(u,this.__tT,this);var B=content.getDomElement();if(B==null){B=window;};this.__tF=qx.event.Registration.getManager(B).getHandler(qx.event.handler.DragDrop);},properties:{resizableTop:{check:a,init:true},resizableRight:{check:a,init:true},resizableBottom:{check:a,init:true},resizableLeft:{check:a,init:true},resizable:{group:[z,g,w,l],mode:n},resizeSensitivity:{check:j,init:5},useResizeFrame:{check:a,init:true}},members:{__tF:null,__tG:null,__tH:null,__tI:null,__tJ:null,__tK:null,__tL:null,RESIZE_TOP:1,RESIZE_BOTTOM:2,RESIZE_LEFT:4,RESIZE_RIGHT:8,_getResizeFrame:function(){var C=this.__tG;if(!C){C=this.__tG=new qx.ui.core.Widget();C.setAppearance(v);C.exclude();qx.core.Init.getApplication().getRoot().add(C);};return C;},__tM:function(){var location=this.getContentLocation();var D=this._getResizeFrame();D.setUserBounds(location.left,location.top,location.right-location.left,location.bottom-location.top);D.show();D.setZIndex(this.getZIndex()+1);},__tN:function(e){var F=this.__tH;var E=this.getSizeHint();var I=this.__tL;var H=this.__tK;var J=H.width;var G=H.height;var L=H.left;var top=H.top;var K;if((F&this.RESIZE_TOP)||(F&this.RESIZE_BOTTOM)){K=Math.max(I.top,Math.min(I.bottom,e.getDocumentTop()))-this.__tJ;if(F&this.RESIZE_TOP){G-=K;}else {G+=K;};if(G<E.minHeight){G=E.minHeight;}else if(G>E.maxHeight){G=E.maxHeight;};if(F&this.RESIZE_TOP){top+=H.height-G;};};if((F&this.RESIZE_LEFT)||(F&this.RESIZE_RIGHT)){K=Math.max(I.left,Math.min(I.right,e.getDocumentLeft()))-this.__tI;if(F&this.RESIZE_LEFT){J-=K;}else {J+=K;};if(J<E.minWidth){J=E.minWidth;}else if(J>E.maxWidth){J=E.maxWidth;};if(F&this.RESIZE_LEFT){L+=H.width-J;};};return {viewportLeft:L,viewportTop:top,parentLeft:H.bounds.left+L-H.left,parentTop:H.bounds.top+top-H.top,width:J,height:G};},__tO:{'1':f,'2':x,'4':b,'8':k,'5':q,'6':d,'9':h,'10':i},__tP:function(e){var location=this.getContentLocation();var O=this.getResizeSensitivity();var N=e.getDocumentLeft();var P=e.getDocumentTop();var M=this.__tQ(location,N,P,O);if(M>0){M=M|this.__tQ(location,N,P,O*2);};this.__tH=M;},__tQ:function(location,T,R,S){var Q=0;if(this.getResizableTop()&&Math.abs(location.top-R)<S&&T>location.left-S&&T<location.right+S){Q+=this.RESIZE_TOP;}else if(this.getResizableBottom()&&Math.abs(location.bottom-R)<S&&T>location.left-S&&T<location.right+S){Q+=this.RESIZE_BOTTOM;};if(this.getResizableLeft()&&Math.abs(location.left-T)<S&&R>location.top-S&&R<location.bottom+S){Q+=this.RESIZE_LEFT;}else if(this.getResizableRight()&&Math.abs(location.right-T)<S&&R>location.top-S&&R<location.bottom+S){Q+=this.RESIZE_RIGHT;};return Q;},__tR:function(e){if(!this.__tH||!this.getEnabled()||e.getPointerType()==c){return;};this.addState(p);this.__tI=e.getDocumentLeft();this.__tJ=e.getDocumentTop();var location=this.getContentLocation();var V=this.getBounds();this.__tK={top:location.top,left:location.left,width:location.right-location.left,height:location.bottom-location.top,bounds:qx.lang.Object.clone(V)};var parent=this.getLayoutParent();var W=parent.getContentLocation();var U=parent.getBounds();this.__tL={left:W.left,top:W.top,right:W.left+U.width,bottom:W.top+U.height};if(this.getUseResizeFrame()){this.__tM();};this.capture();e.stop();},__tS:function(e){if(!this.hasState(p)||!this.getEnabled()||e.getPointerType()==c){return;};if(this.getUseResizeFrame()){this._getResizeFrame().exclude();};var X=this.__tN(e);this.setWidth(X.width);this.setHeight(X.height);if(this.getResizableLeft()||this.getResizableTop()){this.setLayoutProperties({left:X.parentLeft,top:X.parentTop});};this.__tH=0;this.removeState(p);this.resetCursor();this.getApplicationRoot().resetGlobalCursor();this.releaseCapture();e.stopPropagation();},__tT:function(e){if(!this.__tH){return;};this.resetCursor();this.getApplicationRoot().resetGlobalCursor();this.removeState(m);if(this.getUseResizeFrame()){this._getResizeFrame().exclude();};},__tU:function(e){if(!this.getEnabled()||e.getPointerType()==c){return;};if(this.hasState(p)){var ba=this.__tN(e);if(this.getUseResizeFrame()){var Y=this._getResizeFrame();Y.setUserBounds(ba.viewportLeft,ba.viewportTop,ba.width,ba.height);}else {this.setWidth(ba.width);this.setHeight(ba.height);if(this.getResizableLeft()||this.getResizableTop()){this.setLayoutProperties({left:ba.parentLeft,top:ba.parentTop});};};e.stopPropagation();}else if(!this.hasState(o)&&!this.__tF.isSessionActive()){this.__tP(e);var bd=this.__tH;var bc=this.getApplicationRoot();if(bd){var bb=this.__tO[bd];this.setCursor(bb);bc.setGlobalCursor(bb);}else if(this.getCursor()){this.resetCursor();bc.resetGlobalCursor();};};},__tV:function(e){if(e.getPointerType()==c){return;};if(this.getCursor()&&!this.hasState(p)){this.resetCursor();this.getApplicationRoot().resetGlobalCursor();};}},destruct:function(){if(this.__tG!=null&&!qx.core.ObjectRegistry.inShutDown){this.__tG.destroy();this.__tG=null;};this.__tF=null;}});})();(function(){var a="beforeClose",b="beforeMinimize",c="Boolean",d="window-resize-frame",f="changeStatus",g="changeIcon",h="excluded",i="_applyModal",j="execute",k="restore-button",l="_applyActive",m="minimize-button",n="qx.event.type.Event",o="close-button",p="beforeRestore",q="statusbar",r="captionbar",s="String",t="minimize",u="dbltap",v="modal",w="changeModal",x="title",y="icon",z="showStatusbar",A="changeAlwaysOnTop",B="_applyShowStatusbar",C="pointerdown",D="maximized",E="_applyStatus",F="qx.ui.window.Window",G="normal",H="changeCaption",I="engine.name",J="statusbar-text",K="focusout",L="beforeMaximize",M="maximize",N="maximize-button",O="restore",P="window",Q="pane",R="close",S="changeActive",T="mshtml",U="_applyCaptionBarChange",V="active",W="minimized";qx.Class.define(F,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.core.MRemoteLayoutHandling,qx.ui.core.MResizable,qx.ui.core.MMovable,qx.ui.core.MContentPadding],construct:function(X,Y){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.VBox());this._createChildControl(r);this._createChildControl(Q);if(Y!=null){this.setIcon(Y);};if(X!=null){this.setCaption(X);};this._updateCaptionBar();this.addListener(C,this._onWindowPointerDown,this,true);this.addListener(K,this._onWindowFocusOut,this);qx.core.Init.getApplication().getRoot().add(this);this.initVisibility();qx.ui.core.FocusHandler.getInstance().addRoot(this);this._getResizeFrame().setAppearance(d);},statics:{DEFAULT_MANAGER_CLASS:qx.ui.window.Manager},events:{"beforeClose":n,"close":n,"beforeMinimize":n,"minimize":n,"beforeMaximize":n,"maximize":n,"beforeRestore":n,"restore":n},properties:{appearance:{refine:true,init:P},visibility:{refine:true,init:h},focusable:{refine:true,init:true},active:{check:c,init:false,apply:l,event:S},alwaysOnTop:{check:c,init:false,event:A},modal:{check:c,init:false,event:w,apply:i},caption:{apply:U,event:H,nullable:true},icon:{check:s,nullable:true,apply:U,event:g,themeable:true},status:{check:s,nullable:true,apply:E,event:f},showClose:{check:c,init:true,apply:U,themeable:true},showMaximize:{check:c,init:true,apply:U,themeable:true},showMinimize:{check:c,init:true,apply:U,themeable:true},allowClose:{check:c,init:true,apply:U},allowMaximize:{check:c,init:true,apply:U},allowMinimize:{check:c,init:true,apply:U},showStatusbar:{check:c,init:false,apply:B}},members:{__tW:null,__tX:null,getChildrenContainer:function(){return this.getChildControl(Q);},_forwardStates:{active:true,maximized:true,showStatusbar:true,modal:true},setLayoutParent:function(parent){{};qx.ui.core.Widget.prototype.setLayoutParent.call(this,parent);},_createChildControlImpl:function(be,bd){var ba;switch(be){case q:ba=new qx.ui.container.Composite(new qx.ui.layout.HBox());this._add(ba);ba.add(this.getChildControl(J));break;case J:ba=new qx.ui.basic.Label();ba.setValue(this.getStatus());break;case Q:ba=new qx.ui.container.Composite();this._add(ba,{flex:1});break;case r:var bb=new qx.ui.layout.Grid();bb.setRowFlex(0,1);bb.setColumnFlex(1,1);ba=new qx.ui.container.Composite(bb);this._add(ba);ba.addListener(u,this._onCaptionPointerDblTap,this);this._activateMoveHandle(ba);break;case y:ba=new qx.ui.basic.Image(this.getIcon());this.getChildControl(r).add(ba,{row:0,column:0});break;case x:ba=new qx.ui.basic.Label(this.getCaption());ba.setWidth(0);ba.setAllowGrowX(true);var bc=this.getChildControl(r);bc.add(ba,{row:0,column:1});break;case m:ba=new qx.ui.form.Button();ba.setFocusable(false);ba.addListener(j,this._onMinimizeButtonTap,this);this.getChildControl(r).add(ba,{row:0,column:2});break;case k:ba=new qx.ui.form.Button();ba.setFocusable(false);ba.addListener(j,this._onRestoreButtonTap,this);this.getChildControl(r).add(ba,{row:0,column:3});break;case N:ba=new qx.ui.form.Button();ba.setFocusable(false);ba.addListener(j,this._onMaximizeButtonTap,this);this.getChildControl(r).add(ba,{row:0,column:4});break;case o:ba=new qx.ui.form.Button();ba.setFocusable(false);ba.addListener(j,this._onCloseButtonTap,this);this.getChildControl(r).add(ba,{row:0,column:6});break;};return ba||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,be);},_updateCaptionBar:function(){var bg;var bh=this.getIcon();if(bh){this.getChildControl(y).setSource(bh);this._showChildControl(y);}else {this._excludeChildControl(y);};var bf=this.getCaption();if(bf){this.getChildControl(x).setValue(bf);this._showChildControl(x);}else {this._excludeChildControl(x);};if(this.getShowMinimize()){this._showChildControl(m);bg=this.getChildControl(m);this.getAllowMinimize()?bg.resetEnabled():bg.setEnabled(false);}else {this._excludeChildControl(m);};if(this.getShowMaximize()){if(this.isMaximized()){this._showChildControl(k);this._excludeChildControl(N);}else {this._showChildControl(N);this._excludeChildControl(k);};bg=this.getChildControl(N);this.getAllowMaximize()?bg.resetEnabled():bg.setEnabled(false);}else {this._excludeChildControl(N);this._excludeChildControl(k);};if(this.getShowClose()){this._showChildControl(o);bg=this.getChildControl(o);this.getAllowClose()?bg.resetEnabled():bg.setEnabled(false);}else {this._excludeChildControl(o);};},close:function(){if(!this.isVisible()){return;};if(this.fireNonBubblingEvent(a,qx.event.type.Event,[false,true])){this.hide();this.fireEvent(R);};},open:function(){this.show();this.setActive(true);this.focus();},center:function(){var parent=this.getLayoutParent();if(parent){var bj=parent.getBounds();if(bj){var bk=this.getSizeHint();var bi=Math.round((bj.width-bk.width)/2);var top=Math.round((bj.height-bk.height)/2);if(top<0){top=0;};this.moveTo(bi,top);return;};};{};},maximize:function(){if(this.isMaximized()){return;};var parent=this.getLayoutParent();if(parent!=null&&parent.supportsMaximize()){if(this.fireNonBubblingEvent(L,qx.event.type.Event,[false,true])){if(!this.isVisible()){this.open();};var bl=this.getLayoutProperties();this.__tX=bl.left===undefined?0:bl.left;this.__tW=bl.top===undefined?0:bl.top;this.setLayoutProperties({left:null,top:null,edge:0});this.addState(D);this._updateCaptionBar();this.fireEvent(M);};};},minimize:function(){if(!this.isVisible()){return;};if(this.fireNonBubblingEvent(b,qx.event.type.Event,[false,true])){var bm=this.getLayoutProperties();this.__tX=bm.left===undefined?0:bm.left;this.__tW=bm.top===undefined?0:bm.top;this.removeState(D);this.hide();this.fireEvent(t);};},restore:function(){if(this.getMode()===G){return;};if(this.fireNonBubblingEvent(p,qx.event.type.Event,[false,true])){if(!this.isVisible()){this.open();};var bn=this.__tX;var top=this.__tW;this.setLayoutProperties({edge:null,left:bn,top:top});this.removeState(D);this._updateCaptionBar();this.fireEvent(O);};},moveTo:function(bo,top){if(this.isMaximized()){return;};this.setLayoutProperties({left:bo,top:top});},isMaximized:function(){return this.hasState(D);},getMode:function(){if(!this.isVisible()){return W;}else {if(this.isMaximized()){return D;}else {return G;};};},_applyActive:function(bq,bp){if(bp){this.removeState(V);}else {this.addState(V);};},_applyModal:function(bs,br){if(br){this.removeState(v);}else {this.addState(v);};},_getContentPaddingTarget:function(){return this.getChildControl(Q);},_applyShowStatusbar:function(bv,bt){var bu=this._getResizeFrame();if(bv){this.addState(z);bu.addState(z);}else {this.removeState(z);bu.removeState(z);};if(bv){this._showChildControl(q);}else {this._excludeChildControl(q);};},_applyCaptionBarChange:function(bx,bw){this._updateCaptionBar();},_applyStatus:function(bz,by){var bA=this.getChildControl(J,true);if(bA){bA.setValue(bz);};},_applyFocusable:function(bC,bB){if(qx.core.Environment.get(I)!==T){qx.ui.core.Widget.prototype._applyFocusable.call(this,bC,bB);};},_onWindowEventStop:function(e){e.stopPropagation();},_onWindowPointerDown:function(e){this.setActive(true);},_onWindowFocusOut:function(e){if(this.getModal()){return;};var bD=e.getRelatedTarget();if(bD!=null&&!qx.ui.core.Widget.contains(this,bD)){this.setActive(false);};},_onCaptionPointerDblTap:function(e){if(this.getAllowMaximize()){this.isMaximized()?this.restore():this.maximize();};},_onMinimizeButtonTap:function(e){this.minimize();this.getChildControl(m).reset();},_onRestoreButtonTap:function(e){this.restore();this.getChildControl(k).reset();},_onMaximizeButtonTap:function(e){this.maximize();this.getChildControl(N).reset();},_onCloseButtonTap:function(e){this.close();this.getChildControl(o).reset();}}});})();(function(){var a="Decorator",b="_applyLayoutChange",c="center",d="_applyReversed",e="bottom",f="qx.ui.layout.VBox",g="top",h="left",j="middle",k="Integer",m="right",n="Boolean";qx.Class.define(f,{extend:qx.ui.layout.Abstract,construct:function(o,p,q){qx.ui.layout.Abstract.call(this);if(o){this.setSpacing(o);};if(p){this.setAlignY(p);};if(q){this.setSeparator(q);};},properties:{alignY:{check:[g,j,e],init:g,apply:b},alignX:{check:[h,c,m],init:h,apply:b},spacing:{check:k,init:0,apply:b},separator:{check:a,nullable:true,apply:b},reversed:{check:n,init:false,apply:d}},members:{__pb:null,__lw:null,__lx:null,__gO:null,_applyReversed:function(){this._invalidChildrenCache=true;this._applyLayoutChange();},__ly:function(){var w=this._getLayoutChildren();var length=w.length;var s=false;var r=this.__pb&&this.__pb.length!=length&&this.__lw&&this.__pb;var u;var t=r?this.__pb:new Array(length);var v=r?this.__lw:new Array(length);if(this.getReversed()){w=w.concat().reverse();};for(var i=0;i<length;i++ ){u=w[i].getLayoutProperties();if(u.height!=null){t[i]=parseFloat(u.height)/100;};if(u.flex!=null){v[i]=u.flex;s=true;}else {v[i]=0;};};if(!r){this.__pb=t;this.__lw=v;};this.__lx=s;this.__gO=w;delete this._invalidChildrenCache;},verifyLayoutProperty:null,renderLayout:function(O,G,R){if(this._invalidChildrenCache){this.__ly();};var D=this.__gO;var length=D.length;var N=qx.ui.layout.Util;var M=this.getSpacing();var T=this.getSeparator();if(T){var A=N.computeVerticalSeparatorGaps(D,M,T);}else {var A=N.computeVerticalGaps(D,M,true);};var i,S,z,H;var I=[];var P=A;for(i=0;i<length;i+=1){H=this.__pb[i];z=H!=null?Math.floor((G-A)*H):D[i].getSizeHint().height;I.push(z);P+=z;};if(this.__lx&&P!=G){var F={};var L,y;for(i=0;i<length;i+=1){L=this.__lw[i];if(L>0){E=D[i].getSizeHint();F[i]={min:E.minHeight,value:I[i],max:E.maxHeight,flex:L};};};var B=N.computeFlexOffsets(F,G,P);for(i in B){y=B[i].offset;I[i]+=y;P+=y;};};var top=D[0].getMarginTop();if(P<G&&this.getAlignY()!=g){top=G-P;if(this.getAlignY()===j){top=Math.round(top/2);};};var E,V,J,z,x,K,C;this._clearSeparators();if(T){var U=qx.theme.manager.Decoration.getInstance().resolve(T).getInsets();var Q=U.top+U.bottom;};for(i=0;i<length;i+=1){S=D[i];z=I[i];E=S.getSizeHint();K=S.getMarginLeft();C=S.getMarginRight();J=Math.max(E.minWidth,Math.min(O-K-C,E.maxWidth));V=N.computeHorizontalAlignOffset(S.getAlignX()||this.getAlignX(),J,O,K,C);if(i>0){if(T){top+=x+M;this._renderSeparator(T,{top:top+R.top,left:R.left,height:Q,width:O});top+=Q+M+S.getMarginTop();}else {top+=N.collapseMargins(M,x,S.getMarginTop());};};S.renderLayout(V+R.left,top+R.top,J,z);top+=z;x=S.getMarginBottom();};},_computeSizeHint:function(){if(this._invalidChildrenCache){this.__ly();};var W=qx.ui.layout.Util;var bl=this.__gO;var ba=0,bb=0,bj=0;var bc=0,bd=0;var bh,X,bk;for(var i=0,l=bl.length;i<l;i+=1){bh=bl[i];X=bh.getSizeHint();bb+=X.height;var bg=this.__lw[i];var Y=this.__pb[i];if(bg){ba+=X.minHeight;}else if(Y){bj=Math.max(bj,Math.round(X.minHeight/Y));}else {ba+=X.height;};bk=bh.getMarginLeft()+bh.getMarginRight();if((X.width+bk)>bd){bd=X.width+bk;};if((X.minWidth+bk)>bc){bc=X.minWidth+bk;};};ba+=bj;var bf=this.getSpacing();var bi=this.getSeparator();if(bi){var be=W.computeVerticalSeparatorGaps(bl,bf,bi);}else {var be=W.computeVerticalGaps(bl,bf,true);};return {minHeight:ba+be,height:bb+be,minWidth:bc,width:bd};}},destruct:function(){this.__pb=this.__lw=this.__gO=null;}});})();(function(){var a="' must be defined!",b="height",c="hAlign",d="vAlign",e="Integer",f="'",g="_applyLayoutChange",h="qx.ui.layout.Grid",m="maxHeight",n="Cannot add widget '",o="width",p=") for '",q="'!. ",r="top",s="minHeight",t="' in this cell (",u=", ",v="The layout properties 'row' and 'column' of the child widget '",w="minWidth",z="flex",A="left",B="maxWidth",C="There is already a widget '";qx.Class.define(h,{extend:qx.ui.layout.Abstract,construct:function(E,D){qx.ui.layout.Abstract.call(this);this.__qL=[];this.__qM=[];if(E){this.setSpacingX(E);};if(D){this.setSpacingY(D);};},properties:{spacingX:{check:e,init:0,apply:g},spacingY:{check:e,init:0,apply:g}},members:{__qN:null,__qL:null,__qM:null,__qO:null,__qP:null,__qQ:null,__qR:null,__qS:null,__qT:null,verifyLayoutProperty:null,__qU:function(){var L=[];var G=[];var J=[];var I=-1;var F=-1;var K=this._getLayoutChildren();for(var i=0,l=K.length;i<l;i++ ){var M=K[i];var N=M.getLayoutProperties();var O=N.row;var H=N.column;N.colSpan=N.colSpan||1;N.rowSpan=N.rowSpan||1;if(O==null||H==null){throw new Error(v+M+a);};if(L[O]&&L[O][H]){throw new Error(n+M+q+C+L[O][H]+t+O+u+H+p+this+f);};for(var x=H;x<H+N.colSpan;x++ ){for(var y=O;y<O+N.rowSpan;y++ ){if(L[y]==undefined){L[y]=[];};L[y][x]=M;F=Math.max(F,x);I=Math.max(I,y);};};if(N.rowSpan>1){J.push(M);};if(N.colSpan>1){G.push(M);};};for(var y=0;y<=I;y++ ){if(L[y]==undefined){L[y]=[];};};this.__qN=L;this.__qO=G;this.__qP=J;this.__qQ=I;this.__qR=F;this.__qS=null;this.__qT=null;delete this._invalidChildrenCache;},_setRowData:function(S,Q,R){var P=this.__qL[S];if(!P){this.__qL[S]={};this.__qL[S][Q]=R;}else {P[Q]=R;};},_setColumnData:function(T,V,W){var U=this.__qM[T];if(!U){this.__qM[T]={};this.__qM[T][V]=W;}else {U[V]=W;};},setSpacing:function(X){this.setSpacingY(X);this.setSpacingX(X);return this;},setColumnAlign:function(Y,ba,bb){{};this._setColumnData(Y,c,ba);this._setColumnData(Y,d,bb);this._applyLayoutChange();return this;},getColumnAlign:function(bc){var bd=this.__qM[bc]||{};return {vAlign:bd.vAlign||r,hAlign:bd.hAlign||A};},setRowAlign:function(bf,be,bg){{};this._setRowData(bf,c,be);this._setRowData(bf,d,bg);this._applyLayoutChange();return this;},getRowAlign:function(bi){var bh=this.__qL[bi]||{};return {vAlign:bh.vAlign||r,hAlign:bh.hAlign||A};},getCellWidget:function(bk,bj){if(this._invalidChildrenCache){this.__qU();};var bk=this.__qN[bk]||{};return bk[bj]||null;},getRowCount:function(){if(this._invalidChildrenCache){this.__qU();};return this.__qQ+1;},getColumnCount:function(){if(this._invalidChildrenCache){this.__qU();};return this.__qR+1;},getCellAlign:function(bs,bm){var br=r;var bp=A;var bq=this.__qL[bs];var bn=this.__qM[bm];var bl=this.__qN[bs][bm];if(bl){var bo={vAlign:bl.getAlignY(),hAlign:bl.getAlignX()};}else {bo={};};if(bo.vAlign){br=bo.vAlign;}else if(bq&&bq.vAlign){br=bq.vAlign;}else if(bn&&bn.vAlign){br=bn.vAlign;};if(bo.hAlign){bp=bo.hAlign;}else if(bn&&bn.hAlign){bp=bn.hAlign;}else if(bq&&bq.hAlign){bp=bq.hAlign;};return {vAlign:br,hAlign:bp};},setColumnFlex:function(bt,bu){this._setColumnData(bt,z,bu);this._applyLayoutChange();return this;},getColumnFlex:function(bv){var bw=this.__qM[bv]||{};return bw.flex!==undefined?bw.flex:0;},setRowFlex:function(by,bx){this._setRowData(by,z,bx);this._applyLayoutChange();return this;},getRowFlex:function(bB){var bz=this.__qL[bB]||{};var bA=bz.flex!==undefined?bz.flex:0;return bA;},setColumnMaxWidth:function(bC,bD){this._setColumnData(bC,B,bD);this._applyLayoutChange();return this;},getColumnMaxWidth:function(bE){var bF=this.__qM[bE]||{};return bF.maxWidth!==undefined?bF.maxWidth:Infinity;},setColumnWidth:function(bG,bH){this._setColumnData(bG,o,bH);this._applyLayoutChange();return this;},getColumnWidth:function(bI){var bJ=this.__qM[bI]||{};return bJ.width!==undefined?bJ.width:null;},setColumnMinWidth:function(bK,bL){this._setColumnData(bK,w,bL);this._applyLayoutChange();return this;},getColumnMinWidth:function(bM){var bN=this.__qM[bM]||{};return bN.minWidth||0;},setRowMaxHeight:function(bP,bO){this._setRowData(bP,m,bO);this._applyLayoutChange();return this;},getRowMaxHeight:function(bR){var bQ=this.__qL[bR]||{};return bQ.maxHeight||Infinity;},setRowHeight:function(bS,bT){this._setRowData(bS,b,bT);this._applyLayoutChange();return this;},getRowHeight:function(bV){var bU=this.__qL[bV]||{};return bU.height!==undefined?bU.height:null;},setRowMinHeight:function(bX,bW){this._setRowData(bX,s,bW);this._applyLayoutChange();return this;},getRowMinHeight:function(ca){var bY=this.__qL[ca]||{};return bY.minHeight||0;},__qV:function(cc){var cb=cc.getSizeHint();var ce=cc.getMarginLeft()+cc.getMarginRight();var cd=cc.getMarginTop()+cc.getMarginBottom();var cf={height:cb.height+cd,width:cb.width+ce,minHeight:cb.minHeight+cd,minWidth:cb.minWidth+ce,maxHeight:cb.maxHeight+cd,maxWidth:cb.maxWidth+ce};return cf;},_fixHeightsRowSpan:function(cA){var cm=this.getSpacingY();for(var i=0,l=this.__qP.length;i<l;i++ ){var cs=this.__qP[i];var cp=this.__qV(cs);var ci=cs.getLayoutProperties();var co=ci.row;var cx=cm*(ci.rowSpan-1);var cg=cx;var cj={};for(var j=0;j<ci.rowSpan;j++ ){var cn=ci.row+j;var cw=cA[cn];var cy=this.getRowFlex(cn);if(cy>0){cj[cn]={min:cw.minHeight,value:cw.height,max:cw.maxHeight,flex:cy};};cx+=cw.height;cg+=cw.minHeight;};if(cx<cp.height){if(!qx.lang.Object.isEmpty(cj)){var cz=qx.ui.layout.Util.computeFlexOffsets(cj,cp.height,cx);for(var k=0;k<ci.rowSpan;k++ ){var cu=cz[co+k]?cz[co+k].offset:0;cA[co+k].height+=cu;};}else {var cr=cm*(ci.rowSpan-1);var cq=cp.height-cr;var cv=Math.floor(cq/ci.rowSpan);var ct=0;var ch=0;for(var k=0;k<ci.rowSpan;k++ ){var cl=cA[co+k].height;ct+=cl;if(cl<cv){ch++ ;};};var ck=Math.floor((cq-ct)/ch);for(var k=0;k<ci.rowSpan;k++ ){if(cA[co+k].height<cv){cA[co+k].height+=ck;};};};};if(cg<cp.minHeight){var cz=qx.ui.layout.Util.computeFlexOffsets(cj,cp.minHeight,cg);for(var j=0;j<ci.rowSpan;j++ ){var cu=cz[co+j]?cz[co+j].offset:0;cA[co+j].minHeight+=cu;};};};},_fixWidthsColSpan:function(cE){var cF=this.getSpacingX();for(var i=0,l=this.__qO.length;i<l;i++ ){var cB=this.__qO[i];var cD=this.__qV(cB);var cH=cB.getLayoutProperties();var cC=cH.column;var cN=cF*(cH.colSpan-1);var cG=cN;var cI={};var cK;for(var j=0;j<cH.colSpan;j++ ){var cJ=cH.column+j;var cM=cE[cJ];var cL=this.getColumnFlex(cJ);if(cL>0){cI[cJ]={min:cM.minWidth,value:cM.width,max:cM.maxWidth,flex:cL};};cN+=cM.width;cG+=cM.minWidth;};if(cN<cD.width){var cO=qx.ui.layout.Util.computeFlexOffsets(cI,cD.width,cN);for(var j=0;j<cH.colSpan;j++ ){cK=cO[cC+j]?cO[cC+j].offset:0;cE[cC+j].width+=cK;};};if(cG<cD.minWidth){var cO=qx.ui.layout.Util.computeFlexOffsets(cI,cD.minWidth,cG);for(var j=0;j<cH.colSpan;j++ ){cK=cO[cC+j]?cO[cC+j].offset:0;cE[cC+j].minWidth+=cK;};};};},_getRowHeights:function(){if(this.__qS!=null){return this.__qS;};var cY=[];var cR=this.__qQ;var cQ=this.__qR;for(var da=0;da<=cR;da++ ){var cS=0;var cU=0;var cT=0;for(var cX=0;cX<=cQ;cX++ ){var cP=this.__qN[da][cX];if(!cP){continue;};var cV=cP.getLayoutProperties().rowSpan||0;if(cV>1){continue;};var cW=this.__qV(cP);if(this.getRowFlex(da)>0){cS=Math.max(cS,cW.minHeight);}else {cS=Math.max(cS,cW.height);};cU=Math.max(cU,cW.height);};var cS=Math.max(cS,this.getRowMinHeight(da));var cT=this.getRowMaxHeight(da);if(this.getRowHeight(da)!==null){var cU=this.getRowHeight(da);}else {var cU=Math.max(cS,Math.min(cU,cT));};cY[da]={minHeight:cS,height:cU,maxHeight:cT};};if(this.__qP.length>0){this._fixHeightsRowSpan(cY);};this.__qS=cY;return cY;},_getColWidths:function(){if(this.__qT!=null){return this.__qT;};var df=[];var dc=this.__qR;var de=this.__qQ;for(var dk=0;dk<=dc;dk++ ){var di=0;var dh=0;var dd=Infinity;for(var dl=0;dl<=de;dl++ ){var db=this.__qN[dl][dk];if(!db){continue;};var dg=db.getLayoutProperties().colSpan||0;if(dg>1){continue;};var dj=this.__qV(db);if(this.getColumnFlex(dk)>0){dh=Math.max(dh,dj.minWidth);}else {dh=Math.max(dh,dj.width);};di=Math.max(di,dj.width);};dh=Math.max(dh,this.getColumnMinWidth(dk));dd=this.getColumnMaxWidth(dk);if(this.getColumnWidth(dk)!==null){var di=this.getColumnWidth(dk);}else {var di=Math.max(dh,Math.min(di,dd));};df[dk]={minWidth:dh,width:di,maxWidth:dd};};if(this.__qO.length>0){this._fixWidthsColSpan(df);};this.__qT=df;return df;},_getColumnFlexOffsets:function(dq){var dm=this.getSizeHint();var ds=dq-dm.width;if(ds==0){return {};};var dp=this._getColWidths();var dn={};for(var i=0,l=dp.length;i<l;i++ ){var dt=dp[i];var dr=this.getColumnFlex(i);if((dr<=0)||(dt.width==dt.maxWidth&&ds>0)||(dt.width==dt.minWidth&&ds<0)){continue;};dn[i]={min:dt.minWidth,value:dt.width,max:dt.maxWidth,flex:dr};};return qx.ui.layout.Util.computeFlexOffsets(dn,dq,dm.width);},_getRowFlexOffsets:function(dw){var du=this.getSizeHint();var dy=dw-du.height;if(dy==0){return {};};var dx=this._getRowHeights();var dv={};for(var i=0,l=dx.length;i<l;i++ ){var dA=dx[i];var dz=this.getRowFlex(i);if((dz<=0)||(dA.height==dA.maxHeight&&dy>0)||(dA.height==dA.minHeight&&dy<0)){continue;};dv[i]={min:dA.minHeight,value:dA.height,max:dA.maxHeight,flex:dz};};return qx.ui.layout.Util.computeFlexOffsets(dv,dw,du.height);},renderLayout:function(dV,dB,dU){if(this._invalidChildrenCache){this.__qU();};var dP=qx.ui.layout.Util;var dD=this.getSpacingX();var dJ=this.getSpacingY();var dT=this._getColWidths();var dW=this._getColumnFlexOffsets(dV);var dE=[];var dY=this.__qR;var dC=this.__qQ;var dX;for(var ea=0;ea<=dY;ea++ ){dX=dW[ea]?dW[ea].offset:0;dE[ea]=dT[ea].width+dX;};var dM=this._getRowHeights();var dO=this._getRowFlexOffsets(dB);var eg=[];for(var dK=0;dK<=dC;dK++ ){dX=dO[dK]?dO[dK].offset:0;eg[dK]=dM[dK].height+dX;};var ee=0;for(var ea=0;ea<=dY;ea++ ){var top=0;for(var dK=0;dK<=dC;dK++ ){var dR=this.__qN[dK][ea];if(!dR){top+=eg[dK]+dJ;continue;};var dF=dR.getLayoutProperties();if(dF.row!==dK||dF.column!==ea){top+=eg[dK]+dJ;continue;};var ef=dD*(dF.colSpan-1);for(var i=0;i<dF.colSpan;i++ ){ef+=dE[ea+i];};var dS=dJ*(dF.rowSpan-1);for(var i=0;i<dF.rowSpan;i++ ){dS+=eg[dK+i];};var dG=dR.getSizeHint();var ed=dR.getMarginTop();var dQ=dR.getMarginLeft();var dN=dR.getMarginBottom();var dI=dR.getMarginRight();var dL=Math.max(dG.minWidth,Math.min(ef-dQ-dI,dG.maxWidth));var eh=Math.max(dG.minHeight,Math.min(dS-ed-dN,dG.maxHeight));var eb=this.getCellAlign(dK,ea);var ec=ee+dP.computeHorizontalAlignOffset(eb.hAlign,dL,ef,dQ,dI);var dH=top+dP.computeVerticalAlignOffset(eb.vAlign,eh,dS,ed,dN);dR.renderLayout(ec+dU.left,dH+dU.top,dL,eh);top+=eg[dK]+dJ;};ee+=dE[ea]+dD;};},invalidateLayoutCache:function(){qx.ui.layout.Abstract.prototype.invalidateLayoutCache.call(this);this.__qT=null;this.__qS=null;},_computeSizeHint:function(){if(this._invalidChildrenCache){this.__qU();};var ek=this._getColWidths();var ei=0,eq=0;for(var i=0,l=ek.length;i<l;i++ ){var ep=ek[i];if(this.getColumnFlex(i)>0){ei+=ep.minWidth;}else {ei+=ep.width;};eq+=ep.width;};var er=this._getRowHeights();var el=0,em=0;for(var i=0,l=er.length;i<l;i++ ){var es=er[i];if(this.getRowFlex(i)>0){el+=es.minHeight;}else {el+=es.height;};em+=es.height;};var eo=this.getSpacingX()*(ek.length-1);var en=this.getSpacingY()*(er.length-1);var ej={minWidth:ei+eo,width:eq+eo,minHeight:el+en,height:em+en};return ej;}},destruct:function(){this.__qN=this.__qL=this.__qM=this.__qO=this.__qP=this.__qT=this.__qS=null;}});})();(function(){var a='clui.Application',b='0.3.1',c='Cronologer UI',d='loading-indicator';qx.Class.define(a,{extend:qx.application.Standalone,members:{_createLayout:function(){var document=this.getRoot().getContentElement().getDomElement().ownerDocument;document.getElementById(d).remove();var f=this.tr(c);document.title=f;var e=new clui.view.Layout();e.setVersion(b);e.setTitle(f);e.setController(new clui.controller.Overview());qx.core.Init.getApplication().getRoot().add(e,{'edge':0});},main:function(){qx.application.Standalone.prototype.main.call(this);{};this._createLayout();}},defer:function(){qx.Class.include(qx.application.Standalone,kucken.ui.MDialog);}});})();(function(){var a="qx.data.marshal.MEventBubbling",b="",c="]",d="idBubble-",f="[",g="changeBubble",h=".",j="qx.event.type.Data";qx.Mixin.define(a,{events:{"changeBubble":j},members:{_applyEventPropagation:function(l,k,name){this.fireDataEvent(g,{value:l,name:name,old:k,item:this});this._registerEventChaining(l,k,name);},_registerEventChaining:function(n,m,name){if(m!=null&&m.getUserData&&m.getUserData(d+this.$$hash)!=null){var p=m.getUserData(d+this.$$hash);for(var i=0;i<p.length;i++ ){m.removeListenerById(p[i]);};m.setUserData(d+this.$$hash,null);};if((n instanceof qx.core.Object)&&qx.Class.hasMixin(n.constructor,qx.data.marshal.MEventBubbling)){var o=qx.lang.Function.bind(this.__na,this,name);var q=n.addListener(g,o,this);var p=n.getUserData(d+this.$$hash);if(p==null){p=[];n.setUserData(d+this.$$hash,p);};p.push(q);};},__na:function(name,e){var y=e.getData();var u=y.value;var s=y.old;if(qx.Class.hasInterface(e.getTarget().constructor,qx.data.IListData)){if(y.name.indexOf){var x=y.name.indexOf(h)!=-1?y.name.indexOf(h):y.name.length;var v=y.name.indexOf(f)!=-1?y.name.indexOf(f):y.name.length;if(v==0){var t=name+y.name;}else if(x<v){var r=y.name.substring(0,x);var w=y.name.substring(x+1,y.name.length);if(w[0]!=f){w=h+w;};var t=name+f+r+c+w;}else if(v<x){var r=y.name.substring(0,v);var w=y.name.substring(v,y.name.length);var t=name+f+r+c+w;}else {var t=name+f+y.name+c;};}else {var t=name+f+y.name+c;};}else {if(parseInt(name)==name&&name!==b){name=f+name+c;};var t=name+h+y.name;};this.fireDataEvent(g,{value:u,name:t,old:s,item:y.item||e.getTarget()});}}});})();(function(){var a="-",b="add",c="order",d="add/remove",e="Boolean",f="",g="change",h="qx.data.Array",j="Type of the parameter not supported!",k="0-",l="remove",m="0",n="number",o="changeBubble",p="changeLength",q="qx.event.type.Data";qx.Class.define(h,{extend:qx.core.Object,include:qx.data.marshal.MEventBubbling,implement:[qx.data.IListData],construct:function(r){qx.core.Object.call(this);if(r==undefined){this.__nb=[];}else if(arguments.length>1){this.__nb=[];for(var i=0;i<arguments.length;i++ ){this.__nb.push(arguments[i]);};}else if(typeof r==n){this.__nb=new Array(r);}else if(r instanceof Array){this.__nb=qx.lang.Array.clone(r);}else {this.__nb=[];this.dispose();throw new Error(j);};for(var i=0;i<this.__nb.length;i++ ){this._applyEventPropagation(this.__nb[i],null,i);};this.__nc();{};},properties:{autoDisposeItems:{check:e,init:false}},events:{"change":q,"changeLength":q},members:{__nb:null,concat:function(s){if(s){var t=this.__nb.concat(s);}else {var t=this.__nb.concat();};return new qx.data.Array(t);},join:function(u){return this.__nb.join(u);},pop:function(){var v=this.__nb.pop();this.__nc();this._registerEventChaining(null,v,this.length-1);this.fireDataEvent(o,{value:[],name:this.length+f,old:[v],item:this});this.fireDataEvent(g,{start:this.length-1,end:this.length-1,type:l,removed:[v],added:[]},null);return v;},push:function(w){for(var i=0;i<arguments.length;i++ ){this.__nb.push(arguments[i]);this.__nc();this._registerEventChaining(arguments[i],null,this.length-1);this.fireDataEvent(o,{value:[arguments[i]],name:(this.length-1)+f,old:[],item:this});this.fireDataEvent(g,{start:this.length-1,end:this.length-1,type:b,added:[arguments[i]],removed:[]},null);};return this.length;},reverse:function(){if(this.length==0){return;};var x=this.__nb.concat();this.__nb.reverse();this.__nd(0,this.length);this.fireDataEvent(g,{start:0,end:this.length-1,type:c,added:[],removed:[]},null);this.fireDataEvent(o,{value:this.__nb,name:k+(this.__nb.length-1),old:x,item:this});},shift:function(){if(this.length==0){return;};var y=this.__nb.shift();this.__nc();this._registerEventChaining(null,y,this.length-1);this.__nd(0,this.length);this.fireDataEvent(o,{value:[],name:m,old:[y],item:this});this.fireDataEvent(g,{start:0,end:this.length-1,type:l,removed:[y],added:[]},null);return y;},slice:function(A,z){return new qx.data.Array(this.__nb.slice(A,z));},splice:function(F,H,J){var N=this.__nb.length;var I=this.__nb.splice.apply(this.__nb,arguments);if(this.__nb.length!=N){this.__nc();}else if(H==arguments.length-2){var B=qx.lang.Array.fromArguments(arguments,2);for(var i=0;i<B.length;i++ ){if(B[i]!==I[i]){break;};if(i==B.length-1){return new qx.data.Array();};};};var L=H>0;var D=arguments.length>2;if(L||D){var B=qx.lang.Array.fromArguments(arguments,2);if(I.length==0){var M=b;var E=F+B.length;}else if(B.length==0){var M=l;var E=this.length-1;}else {var M=d;var E=F+Math.max(B.length,I.length)-1;};this.fireDataEvent(g,{start:F,end:E,type:M,added:B,removed:I},null);};for(var i=0;i<I.length;i++ ){this._registerEventChaining(null,I[i],i);};for(var i=2;i<arguments.length;i++ ){this._registerEventChaining(arguments[i],null,F+(i-2));};this.__nd(F+(arguments.length-2)-H,this.length);if(L||D){var G=[];for(var i=2;i<arguments.length;i++ ){G[i-2]=arguments[i];};var C=(F+Math.max(arguments.length-3,H-1));var name=F==C?C:F+a+C;var K={value:G,name:name+f,old:I,item:this};this.fireDataEvent(o,K);};return (new qx.data.Array(I));},sort:function(P){if(this.length==0){return;};var O=this.__nb.concat();this.__nb.sort.apply(this.__nb,arguments);if(qx.lang.Array.equals(this.__nb,O)===true){return;};this.__nd(0,this.length);this.fireDataEvent(g,{start:0,end:this.length-1,type:c,added:[],removed:[]},null);this.fireDataEvent(o,{value:this.__nb,name:k+(this.length-1),old:O,item:this});},unshift:function(Q){for(var i=arguments.length-1;i>=0;i-- ){this.__nb.unshift(arguments[i]);this.__nc();this.__nd(0,this.length);this.fireDataEvent(o,{value:[this.__nb[0]],name:m,old:[this.__nb[1]],item:this});this.fireDataEvent(g,{start:0,end:this.length-1,type:b,added:[arguments[i]],removed:[]},null);};return this.length;},toArray:function(){return this.__nb;},getItem:function(R){return this.__nb[R];},setItem:function(S,U){var T=this.__nb[S];if(T===U){return;};this.__nb[S]=U;this._registerEventChaining(U,T,S);if(this.length!=this.__nb.length){this.__nc();};this.fireDataEvent(o,{value:[U],name:S+f,old:[T],item:this});this.fireDataEvent(g,{start:S,end:S,type:d,added:[U],removed:[T]},null);},getLength:function(){return this.length;},indexOf:function(V){return this.__nb.indexOf(V);},lastIndexOf:function(W){return this.__nb.lastIndexOf(W);},toString:function(){if(this.__nb!=null){return this.__nb.toString();};return f;},contains:function(X){return this.__nb.indexOf(X)!==-1;},copy:function(){return this.concat();},insertAt:function(Y,ba){this.splice(Y,0,ba).dispose();},insertBefore:function(bc,bb){var bd=this.indexOf(bc);if(bd==-1){this.push(bb);}else {this.splice(bd,0,bb).dispose();};},insertAfter:function(bf,be){var bg=this.indexOf(bf);if(bg==-1||bg==(this.length-1)){this.push(be);}else {this.splice(bg+1,0,be).dispose();};},removeAt:function(bh){var bi=this.splice(bh,1);var bj=bi.getItem(0);bi.dispose();return bj;},removeAll:function(){for(var i=0;i<this.__nb.length;i++ ){this._registerEventChaining(null,this.__nb[i],i);};if(this.getLength()==0){return [];};var bl=this.getLength();var bk=this.__nb.concat();this.__nb.length=0;this.__nc();this.fireDataEvent(o,{value:[],name:k+(bl-1),old:bk,item:this});this.fireDataEvent(g,{start:0,end:bl-1,type:l,removed:bk,added:[]},null);return bk;},append:function(bm){if(bm instanceof qx.data.Array){bm=bm.toArray();};{};var bn=this.__nb.length;Array.prototype.push.apply(this.__nb,bm);for(var i=0;i<bm.length;i++ ){this._registerEventChaining(bm[i],null,bn+i);};var bn=this.length;this.__nc();var name=bn==(this.length-1)?bn:bn+a+(this.length-1);this.fireDataEvent(o,{value:bm,name:name+f,old:[],item:this});this.fireDataEvent(g,{start:bn,end:this.length-1,type:b,added:bm,removed:[]},null);},remove:function(bo){var bp=this.indexOf(bo);if(bp!=-1){this.splice(bp,1).dispose();return bo;};},equals:function(bq){if(this.length!==bq.length){return false;};for(var i=0;i<this.length;i++ ){if(this.getItem(i)!==bq.getItem(i)){return false;};};return true;},sum:function(){var br=0;for(var i=0;i<this.length;i++ ){br+=this.getItem(i);};return br;},max:function(){var bs=this.getItem(0);for(var i=1;i<this.length;i++ ){if(this.getItem(i)>bs){bs=this.getItem(i);};};return bs===undefined?null:bs;},min:function(){var bt=this.getItem(0);for(var i=1;i<this.length;i++ ){if(this.getItem(i)<bt){bt=this.getItem(i);};};return bt===undefined?null:bt;},forEach:function(bu,bv){for(var i=0;i<this.__nb.length;i++ ){bu.call(bv,this.__nb[i],i,this);};},filter:function(bw,self){return new qx.data.Array(this.__nb.filter(bw,self));},map:function(bx,self){return new qx.data.Array(this.__nb.map(bx,self));},some:function(by,self){return this.__nb.some(by,self);},every:function(bz,self){return this.__nb.every(bz,self);},reduce:function(bB,bA){return this.__nb.reduce(bB,bA);},reduceRight:function(bD,bC){return this.__nb.reduceRight(bD,bC);},__nc:function(){var bE=this.length;this.length=this.__nb.length;this.fireDataEvent(p,this.length,bE);},__nd:function(bG,bF){for(var i=bG;i<bF;i++ ){this._registerEventChaining(this.__nb[i],this.__nb[i],i);};}},destruct:function(){for(var i=0;i<this.__nb.length;i++ ){var bH=this.__nb[i];this._applyEventPropagation(null,bH,i);if(this.isAutoDisposeItems()&&bH&&bH instanceof qx.core.Object){bH.dispose();};};this.__nb=null;}});})();(function(){var a='gecko',b='engine.name',c='kucken.Fix',d='change',e='',f='remove',g='changeLength',h=":",i='locale.variant',j='changeBubble';qx.Class.define(c,{statics:{fix5443:function(k){for(var l in k){if(k[l]&&k[l].translate){k[l]=k[l].translate();};};},__tY:function(){var m=this.toArray().pop();var n=this.length;this.length=this.toArray().length;this.fireDataEvent(g,this.length,n);this._registerEventChaining(null,m,this.length-1);this.fireDataEvent(j,{'value':[],'name':this.length+e,'old':[m],'item':this});this.fireDataEvent(d,{'start':this.length,'end':this.length,'type':f,'removed':[m],'added':[]},null);return m;},__ua:function(o){return function(){return o().toUpperCase();};},__xV:function(v){var r=[];if(!v.stack){return r;};var q,u,t,p,s;var w=/@(.+):(\d+):(\d+)$/gm;while((q=w.exec(v.stack))!=null){s=q[1];t=q[2];p=q[3];u=this.__fileNameToClassName(s);r.push(u+h+t+h+p);};return this.__formatStackTrace(r);}},defer:function(x){qx.data.Array.prototype.pop=x.__tY;qx.bom.client.Locale.getVariant=x.__ua(qx.bom.client.Locale.getVariant);delete qx.core.Environment.getChecks()[i];qx.core.Environment.add(i,qx.bom.client.Locale.getVariant);if(qx.core.Environment.get(b)==a){qx.dev.StackTrace.getStackTraceFromError=x.__xV;};}});})();(function(){var a='_applyController',b='clui.view.Layout',c='clui.controller.Overview',d='_applyTitle',e='clui/image/logo/logo64.png',f='',g='_applyVersion',h='app-header';qx.Class.define(b,{extend:qx.ui.container.Composite,construct:function(){qx.ui.container.Composite.call(this);this.setLayout(new qx.ui.layout.VBox());this._createHeader();this._createPanel();},properties:{title:{apply:d},version:{apply:g},controller:{check:c,apply:a}},members:{_left:null,_right:null,_panel:null,_applyTitle:function(i){this._left.setValue(i);},_applyVersion:function(j){this._right.setValue(j);},_applyController:function(k){this._panel.removeAll();this._panel.add(k.createWidget());},_createHeader:function(){var m=new qx.ui.container.Composite();m.setLayout(new qx.ui.layout.HBox(8));m.setAppearance(h);var l=new qx.ui.basic.Image(e);l.setScale(true);l.setWidth(29);l.setHeight(29);m.add(l);this._left=new qx.ui.basic.Label(f);m.add(this._left);m.add(new qx.ui.core.Spacer,{flex:1});this._right=new qx.ui.basic.Label(f);m.add(this._right);this.add(m);},_createPanel:function(){this._panel=new qx.ui.container.Composite(new qx.ui.layout.Grow());this.add(this._panel,{'flex':1});}}});})();(function(){var a="qx.ui.core.Spacer";qx.Class.define(a,{extend:qx.ui.core.LayoutItem,construct:function(b,c){qx.ui.core.LayoutItem.call(this);this.setWidth(b!=null?b:0);this.setHeight(c!=null?c:0);},members:{checkAppearanceNeeds:function(){},addChildrenToQueue:function(d){},destroy:function(){if(this.$$disposed){return;};var parent=this.$$parent;if(parent){parent._remove(this);};qx.ui.core.queue.Dispose.add(this);}}});})();(function(){var a="qx.ui.layout.Grow";qx.Class.define(a,{extend:qx.ui.layout.Abstract,members:{verifyLayoutProperty:null,renderLayout:function(b,c,e){var h=this._getLayoutChildren();var g,j,f,d;for(var i=0,l=h.length;i<l;i++ ){g=h[i];j=g.getSizeHint();f=b;if(f<j.minWidth){f=j.minWidth;}else if(f>j.maxWidth){f=j.maxWidth;};d=c;if(d<j.minHeight){d=j.minHeight;}else if(d>j.maxHeight){d=j.maxHeight;};g.renderLayout(e.left,e.top,f,d);};},_computeSizeHint:function(){var r=this._getLayoutChildren();var p,t;var s=0,q=0;var o=0,m=0;var k=Infinity,n=Infinity;for(var i=0,l=r.length;i<l;i++ ){p=r[i];t=p.getSizeHint();s=Math.max(s,t.width);q=Math.max(q,t.height);o=Math.max(o,t.minWidth);m=Math.max(m,t.minHeight);k=Math.min(k,t.maxWidth);n=Math.min(n,t.maxHeight);};return {width:s,height:q,minWidth:o,minHeight:m,maxWidth:k,maxHeight:n};}}});})();(function(){var a="The context object '",b="' of the debounced call is already disposed.",c="qx.util.Function",d="undefined";qx.Bootstrap.define(c,{statics:{debounce:function(i,h,g){var e=false;var j=null;var f=null;var k=function(){f=qx.lang.Array.fromArguments(arguments);var l=this;if(j===null){j=window.setInterval(function(){if(!e){window.clearInterval(j);j=null;if(l&&l.isDisposed&&l.isDisposed()){qx.log.Logger.warn(a+l+b);}else {i.apply(l,f);};};e=false;},h);if(g){i.apply(l,f);};};e=true;};return k;},throttle:function(q,p,t){if(typeof t===d){t={};};var n,o,r;var s=null;var u=0;var m=function(){u=t.leading===false?0:new Date();s=null;r=q.apply(n,o);};return function(){var v=new Date();if(!u&&t.leading===false){u=v;};var w=p-(v-u);n=this;o=arguments;if(w<=0){window.clearTimeout(s);s=null;u=v;r=q.apply(n,o);}else if(!s&&t.trailing!==false){s=window.setTimeout(m,w);};return r;};}}});})();(function(){var a='openTablePage',b='clui.controller.Overview',c='group',d='loaded',e='Overview model bubble change',f='refreshTimeline',g='Overview model is loading counts',h='changeBubble';qx.Class.define(b,{extend:qx.core.Object,include:qx.locale.MTranslation,construct:function(){qx.core.Object.call(this);this._recordLoader=new clui.io.Record();this._formController=new qx.data.controller.Form();this._overviewModel=new clui.model.form.Overview();this._overviewModel.addListenerOnce(d,this._onOverviewModelLoaded,this);this._overviewModel.load();},members:{_recordLoader:null,_overviewModel:null,_formController:null,_onOverviewFormModelChangeBubble:function(event){this.debug(e,event.getData());this._loadTimline(this._overviewModel.save());},_onOverviewModelLoaded:function(){var i=this._overviewModel.getFormModel();i.addListener(h,this._onOverviewFormModelChangeBubble,this);this._formController.setModel(i);this._loadTimline(this._overviewModel.save());},_loadTimline:qx.util.Function.debounce(function(k){this.debug(g);var j=k[c];delete k[c];this._recordLoader.loadCount(j,clui.bom.Timezone.get(),k);},10),createWidget:function(){var l=new clui.view.TabView();l.setOverviewPage(new clui.view.OverviewPage(this._formController,this._recordLoader));l.addListener(a,function(){var m=new clui.model.form.TableQuery();m.load(this._overviewModel.save());var n=new clui.controller.RecordTable(m,l);l.addTablePage(new clui.view.TablePage(n));},this);l.addListener(f,function(){this._loadTimline(this._overviewModel.save());},this);return l;}}});})();(function(){var a="changeModel",b="modelSelection[0]",c="qx.core.Object",d="_applyTarget",e="qx.data.controller.Form",f="changeTarget",g="value",h=".",j="No target is set.",k="qx.ui.form.Form",l="_applyModel";qx.Class.define(e,{extend:qx.core.Object,construct:function(m,o,n){qx.core.Object.call(this);this._selfUpdate=!!n;this.__ub={};if(m!=null){this.setModel(m);};if(o!=null){this.setTarget(o);};},properties:{model:{check:c,apply:l,event:a,nullable:true,dereference:true},target:{check:k,apply:d,event:f,nullable:true,init:null,dereference:true}},members:{__uc:null,__ub:null,addBindingOptions:function(name,r,s){this.__ub[name]=[r,s];if(this.getModel()==null||this.getTarget()==null){return;};var p=this.getTarget().getItems()[name];var q=this.__uf(p)?b:g;this.__uc.removeTarget(p,q,name);this.__uc.addTarget(p,q,name,!this._selfUpdate,r,s);},createModel:function(y){var t=this.getTarget();if(t==null){throw new Error(j);};var u=t.getItems();var v={};for(var name in u){var B=name.split(h);var A=v;for(var i=0;i<B.length;i++ ){if(i+1==B.length){var w=u[name].constructor;var x=null;if(qx.Class.hasInterface(w,qx.ui.core.ISingleSelection)){x=u[name].getModelSelection().getItem(0)||null;}else {x=u[name].getValue();};if(this.__ub[name]&&this.__ub[name][1]){x=this.__ub[name][1].converter(x);};A[B[i]]=x;}else {if(!A[B[i]]){A[B[i]]={};};A=A[B[i]];};};};var z=qx.data.marshal.Json.createModel(v,y);this.setModel(z);return z;},updateModel:function(){if(!this._selfUpdate||!this.getModel()||!this.getTarget()){return;};var C=this.getTarget().getItems();for(var name in C){var F=C[name];var E=this.__uf(F)?b:g;var D=this.__ub[name];D=D&&this.__ub[name][1];qx.data.SingleValueBinding.updateTarget(F,E,this.getModel(),name,D);};},_applyTarget:function(H,G){if(G!=null){this.__ue(G);};if(this.getModel()==null){return;};if(H!=null){this.__ud();};},_applyModel:function(K,I){if(this.__uc!=null&&K==null){this.__uc.setModel(null);};if(this.__uc!=null){var J=this.getTarget().getItems();for(var name in J){var L=J[name];var M=this.__uf(L)?b:g;this.__uc.removeTarget(L,M,name);};};if(this.__uc!=null){this.__uc.setModel(K);};if(this.getTarget()==null){return;};if(K!=null){this.__ud();};},__ud:function(){if(this.__uc==null){this.__uc=new qx.data.controller.Object(this.getModel());};var Q=this.getTarget().getItems();for(var name in Q){var N=Q[name];var O=this.__uf(N)?b:g;var P=this.__ub[name];try{if(P==null){this.__uc.addTarget(N,O,name,!this._selfUpdate);}else {this.__uc.addTarget(N,O,name,!this._selfUpdate,P[0],P[1]);};}catch(R){{};};};this.getTarget().redefineResetter();},__ue:function(S){if(this.__uc==null){return;};var V=S.getItems();for(var name in V){var U=V[name];var T=this.__uf(U)?b:g;this.__uc.removeTarget(U,T,name);};},__uf:function(W){return qx.Class.hasInterface(W.constructor,qx.ui.core.ISingleSelection)&&qx.Class.hasInterface(W.constructor,qx.ui.form.IModelSelection);}},destruct:function(){if(this.__uc){this.__uc.dispose();};}});})();(function(){var a="qx.ui.core.ISingleSelection",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeSelection":b},members:{getSelection:function(){return true;},setSelection:function(c){return arguments.length==1;},resetSelection:function(){return true;},isSelected:function(d){return arguments.length==1;},isSelectionEmpty:function(){return true;},getSelectables:function(e){return arguments.length==1;}}});})();(function(){var a="qx.data.marshal.IMarshaler";qx.Interface.define(a,{members:{toClass:function(b,c){},toModel:function(d){}}});})();(function(){var a='"',b="Class '",c="",d="Unsupported type!",e="change",f="qx.data.marshal.Json",g="Array",h="_validate",j="' could not be found.",k="]",l="[",m="set",n="_applyEventPropagation",o="qx.data.model.";qx.Class.define(f,{extend:qx.core.Object,implement:[qx.data.marshal.IMarshaler],construct:function(p){qx.core.Object.call(this);this.__mR=p;},statics:{$$instance:null,createModel:function(q,r){if(this.$$instance===null){this.$$instance=new qx.data.marshal.Json();};this.$$instance.toClass(q,r);return this.$$instance.toModel(q);}},members:{__mR:null,__mS:function(s){return Object.keys(s).sort().join(a);},toClass:function(t,u){this.__mT(t,u,null,0);},__mT:function(G,B,v,D){if(!qx.lang.Type.isObject(G)||!!G.$$isString||G instanceof qx.core.Object){if(G instanceof Array||qx.Bootstrap.getClass(G)==g){for(var i=0;i<G.length;i++ ){this.__mT(G[i],B,v+l+i+k,D+1);};};return;};var x=this.__mS(G);if(this.__mX(x,v,D)){return;};for(var F in G){this.__mT(G[F],B,F,D+1);};if(qx.Class.isDefined(o+x)){return;};if(this.__mR&&this.__mR.getModelClass&&this.__mR.getModelClass(x,G,v,D)!=null){return;};var H={};var y={__mU:this.__mU};for(var F in G){if(this.__mR&&this.__mR.getPropertyMapping){F=this.__mR.getPropertyMapping(F,x);};F=F.replace(/-|\.|\s+/g,c);{};H[F]={};H[F].nullable=true;H[F].event=e+qx.lang.String.firstUp(F);if(B){H[F].apply=n;};if(this.__mR&&this.__mR.getValidationRule){var A=this.__mR.getValidationRule(x,F);if(A){H[F].validate=h+F;y[h+F]=A;};};};if(this.__mR&&this.__mR.getModelSuperClass){var E=this.__mR.getModelSuperClass(x,v,D)||qx.core.Object;}else {var E=qx.core.Object;};var z=[];if(this.__mR&&this.__mR.getModelMixins){var C=this.__mR.getModelMixins(x,v,D);if(!qx.lang.Type.isArray(C)){if(C!=null){z=[C];};}else {z=C;};};if(B){z.push(qx.data.marshal.MEventBubbling);};var w={extend:E,include:z,properties:H,members:y,destruct:this.__mV};qx.Class.define(o+x,w);},__mV:function(){var I=qx.util.PropertyUtil.getAllProperties(this.constructor);for(var J in I){this.__mU(this.get(I[J].name));};},__mU:function(K){if(!(K instanceof qx.core.Object)){return;};if(K.isDisposed()){return;};K.dispose();},__mW:function(L,P,Q,O){var R;if(this.__mR&&this.__mR.getModelClass){R=this.__mR.getModelClass(L,P,Q,O);};if(R!=null){return (new R());}else {var N=o+L;var M=qx.Class.getByName(N);if(!M){throw new Error(b+N+j);};return (new M());};},__mX:function(S,V,T){var U=this.__mR;return U&&U.ignore&&U.ignore(S,V,T);},toModel:function(W){return this.__mY(W,null,0);},__mY:function(bj,Y,bf){var bd=qx.lang.Type.isObject(bj);var X=bj instanceof Array||qx.Bootstrap.getClass(bj)==g;if((!bd&&!X)||!!bj.$$isString||bj instanceof qx.core.Object){return bj;}else if(this.__mX(this.__mS(bj),Y,bf)){return bj;}else if(X){var bh=qx.data.Array;if(this.__mR&&this.__mR.getArrayClass){var be=this.__mR.getArrayClass(Y,bf);bh=be||bh;};var bk=new bh();bk.setAutoDisposeItems(true);for(var i=0;i<bj.length;i++ ){bk.push(this.__mY(bj[i],Y+l+i+k,bf+1));};return bk;}else if(bd){var ba=this.__mS(bj);var bi=this.__mW(ba,bj,Y,bf);for(var bg in bj){var bb=bg;if(this.__mR&&this.__mR.getPropertyMapping){bb=this.__mR.getPropertyMapping(bg,ba);};var bl=bb.replace(/-|\.|\s+/g,c);{};bb=bl;var bc=m+qx.lang.String.firstUp(bb);if(bi[bc]){bi[bc](this.__mY(bj[bg],bg,bf+1));};};return bi;};throw new Error(d);}},destruct:function(){this.__mR=null;}});})();(function(){var a="changeModel",b="qx.core.Object",c="qx.data.controller.Object",d="get",e="[",f="reset",g="_applyModel",h="last";qx.Class.define(c,{extend:qx.core.Object,construct:function(j){qx.core.Object.call(this);this.__bK={};this.__hb=[];if(j!=null){this.setModel(j);};},properties:{model:{check:b,event:a,apply:g,nullable:true,dereference:true}},members:{__hb:null,__bK:null,_applyModel:function(o,l){for(var i=0;i<this.__hb.length;i++ ){var t=this.__hb[i][0];var q=this.__hb[i][1];var n=this.__hb[i][2];var r=this.__hb[i][3];var p=this.__hb[i][4];var m=this.__hb[i][5];if(l!=undefined&&!l.isDisposed()){this.__uh(t,q,n,l);};if(o!=undefined){this.__ug(t,q,n,r,p,m);}else {if(t.isDisposed()||qx.core.ObjectRegistry.inShutDown){continue;};if(q.indexOf(e)==-1){t[f+qx.lang.String.firstUp(q)]();}else {var open=q.indexOf(e);var k=parseInt(q.substring(open+1,q.length-1),10);q=q.substring(0,open);var s=t[d+qx.lang.String.firstUp(q)]();if(k==h){k=s.length;};if(s){s.setItem(k,null);};};};};},addTarget:function(z,w,u,x,y,v){this.__hb.push([z,w,u,x,y,v]);this.__ug(z,w,u,x,y,v);},__ug:function(F,D,B,G,E,A){if(this.getModel()==null){return;};var C=this.getModel().bind(B,F,D,E);var I=null;if(G){I=F.bind(D,this.getModel(),B,A);};var H=F.toHashCode();if(this.__bK[H]==undefined){this.__bK[H]=[];};this.__bK[H].push([C,I,D,B,E,A]);},removeTarget:function(K,J,L){this.__uh(K,J,L,this.getModel());for(var i=0;i<this.__hb.length;i++ ){if(this.__hb[i][0]==K&&this.__hb[i][1]==J&&this.__hb[i][2]==L){this.__hb.splice(i,1);};};},__uh:function(R,O,N,M){if(!(R instanceof qx.core.Object)){return;};var P=this.__bK[R.toHashCode()];if(P==undefined||P.length==0){return;};for(var i=0;i<P.length;i++ ){if(P[i][2]==O&&P[i][3]==N){var Q=P[i][0];M.removeBinding(Q);if(P[i][1]!=null){R.removeBinding(P[i][1]);};P.splice(i,1);return;};};}},destruct:function(){if(this.getModel()!=null&&!this.getModel().isDisposed()){this.setModel(null);};}});})();(function(){var a="qx.ui.form.IModelSelection";qx.Interface.define(a,{members:{setModelSelection:function(b){},getModelSelection:function(){}}});})();(function(){var c='hour',d='',e='before',f='qx.event.type.Data',g='after',h='{0}/{id}',i='success',j='HEAD',k='rangeSuccess',l=',',m='query',n='level',o='Array',p='date',q='clui.io.Record',s='group',t='day',u='/api/v1/record',w='countSuccess',x='name',y='changeRecordRange',z='recordSuccess',A='qx.event.type.Event',B='error',C='GET',D='changeCount',E='changeTimeSeries',F='X-Record-Count',G='Number',H='X-Record-Group',I='ts',J='changeGroup';qx.Class.define(q,{extend:qx.core.Object,properties:{timeSeries:{check:o,init:[],event:E},count:{check:G,init:0,event:D},group:{check:[t,c],nullable:true,event:J},recordRange:{check:o,init:[],event:y}},events:{success:A,error:f},construct:function(){qx.core.Object.call(this);var K=u;this._resource=new clui.io.Resource({'count':{'method':j,'url':K},'range':{'method':C,'url':K},'record':{'method':C,'url':h.format(K)}});this._resource.addListener(w,this._onCountSuccess,this);this._resource.addListener(k,this._onRangeSuccess,this);this._resource.addListener(z,this._onRecordSuccess,this);this._resource.addListener(B,this._onError,this);},members:{_resource:null,_onError:function(event){this.fireDataEvent(B,event);},_extendAbsentAsZero:function(M,N,Q,L){var P=M.reduce(function(r,v){r[v[p].toISOString()]=true;return r;},{});var O=kucken.lib.D3.get().time[L].range(N,Q);O.forEach(function(R){if(!(R.toISOString() in P)){M.push({'date':R,'count':0});};});return M.sort(function(a,b){return a[p]-b[p];});},_onCountSuccess:function(event){var V=event.getRequest();var W=V.getRequestData();var U=new Date(W[g]);var ba=new Date(W[e]);var S=W[s];var Y=event.getRequest().getResponseHeader(F);if(!S){this.setCount(Number(Y));this.resetTimeSeries();}else {var X=event.getRequest().getResponseHeader(H);var T=[];if(X){T=kucken.lang.Array.zip(Y.split(l),X.split(l)).map(function(bb){return {'date':new Date(Number(bb[1])*1000),'count':Number(bb[0])};});};this.setCount(qx.lang.Array.sum(Y.split(l).map(Number)));this.setTimeSeries(this._extendAbsentAsZero(T,U,ba,S));};this.fireEvent(i);},_onRangeSuccess:function(event){var bc=event.getRequest().getResponse().map(function(bd){bd[I]=new Date(bd[I]);return bd;});this.setRecordRange(bc);this.setCount(bc.length);this.fireEvent(i);},_onRecordSuccess:function(event){var be=event.getRequest().getResponse();be[I]=new Date(be[I]);this.setRecordRange([be]);this.setCount(1);this.fireEvent(i);},_getCommonRequestParams:function(bf){return {'level':bf[n]||d,'name':bf[x]||d,'after':bf[g]?bf[g].toDate().toISOString():d,'before':bf[e]?bf[e].toDate().toISOString():d,'query':bf[m]||d};},loadCount:function(bi,bg,bj){var bk=this._getCommonRequestParams(bj);var bh=kucken.lang.Object.merge(bk,{'group':bi||d,'timezone':bg||d});this._resource.count(null,bh);this.setGroup(bi);},loadRange:function(bn,bl,bo){var bp=this._getCommonRequestParams(bo);var bm=kucken.lang.Object.merge(bp,{'left':bn,'right':bl});this._resource.range(null,bm);},loadRecord:function(bq){this._resource.record({'id':bq});}}});})();(function(){var a='}',b='{',c='kucken.lang.String';qx.Class.define(c,{statics:{_stringFormat:function(e){var d=this;for(var i=0;i<arguments.length;i+=1){d=d.split(b+i+a).join(String(arguments[i]));};return d;}},defer:function(f){String.prototype.format=f._stringFormat;}});})();(function(){var a=") already exists",b="Error",c="qx.io.rest.Resource",d="interval",f="qx.event.type.Rest",g="get",h="Method with name of action (",i="Success",j="undefined",k="success",l="error";qx.Class.define(c,{extend:qx.core.Object,construct:function(m){qx.core.Object.call(this);this.__ui={};this.__uj={};this.__uk={};this._resource=this._tailorResource(this._getResource());try{if(typeof m!==j){{};this.__um(m);};}catch(e){this.dispose();throw e;};},events:{"success":f,"actionSuccess":f,"error":f,"actionError":f},statics:{POLL_THROTTLE_LIMIT:100,POLL_THROTTLE_COUNT:30,REQUIRED:true,placeholdersFromUrl:function(n){return qx.bom.rest.Resource.placeholdersFromUrl(n);}},members:{_resource:null,__ui:null,__uj:null,__uk:null,_getResource:function(o){return new qx.bom.rest.Resource(o);},_tailorResource:function(p){p.setRequestFactory(this._getRequest);p.setRequestHandler({onsuccess:{callback:function(r,q){return function(){var s=[r.getResponse(),null,false,r,q,r.getPhase()];this.fireEvent(q+i,qx.event.type.Rest,s);this.fireEvent(k,qx.event.type.Rest,s);};},context:this},onfail:{callback:function(u,t){return function(){var v=[u.getResponse(),null,false,u,t,u.getPhase()];this.fireEvent(t+b,qx.event.type.Rest,v);this.fireEvent(l,qx.event.type.Rest,v);};},context:this},onloadend:{callback:function(x,w){return function(){x.dispose();};},context:this}});return p;},configureRequest:function(y){this._resource.configureRequest(y);},_getRequest:function(){return new qx.io.request.Xhr();},map:function(z,B,A,C){this.__ul(z,B,A,C);this._resource.map(z,B,A,C);},__ul:function(E,G,D,F){this.__uk[E]=[G,D,F];if(E==g){this[E]=undefined;};if(typeof this[E]!==j&&this[E]!==null&&this[E].action!==true){throw new Error(h+E+a);};this.__un(E+i);this.__un(E+b);this[E]=qx.lang.Function.bind(function(){Array.prototype.unshift.call(arguments,E);return this.invoke.apply(this,arguments);},this);this[E].action=true;},invoke:function(H,I,J){var I=(I==null)?{}:I;this.__uk[H].params=I;return this._resource.invoke(H,I,J);},setBaseUrl:function(K){this._resource.setBaseUrl(K);},abort:function(L){this._resource.abort(L);},refresh:function(M){this._resource.refresh(M);},poll:function(R,N,Q,S){if(this.__uj[R]){this.__uj[R].dispose();};if(typeof Q==j){Q=this.__uk[R].params;};if(S){this.invoke(R,Q);};var P=function(){var U=this.getRequestsByAction(R),T=(U)?U[0]:null;if(!S&&!T){this.invoke(R,Q);return;};if(T&&(T.isDone()||T.isDisposed())){this.refresh(R);};};var O=this.__uj[R]=new qx.event.Timer(N);O.addListener(d,P,this._resource);O.start();return O;},longPoll:function(ba){var W=this,Y,bb=0;function V(){var bc=Y&&((new Date())-Y)<W._getThrottleLimit();if(bc){bb+=1;if(bb>W._getThrottleCount()){{};return true;};};if(!bc){bb=0;};return false;};var X=this.__ui[ba]=this.addListener(ba+i,function bd(){if(W.isDisposed()){return;};if(!V()){Y=new Date();W.refresh(ba);};});this.invoke(ba);return X;},_getRequestConfig:function(be,bf){return this._resource._getRequestConfig(be,bf);},_getThrottleLimit:function(){return qx.io.rest.Resource.POLL_THROTTLE_LIMIT;},_getThrottleCount:function(){return qx.io.rest.Resource.POLL_THROTTLE_COUNT;},__um:function(bg){Object.keys(bg).forEach(function(bi){var bj=bg[bi],bl=bj.method,bh=bj.url,bk=bj.check;{};this.map(bi,bl,bh,bk);},this);},__un:function(bm){if(!this.constructor.$$events){this.constructor.$$events={};};if(!this.constructor.$$events[bm]){this.constructor.$$events[bm]=f;};}},destruct:function(){var bn;if(this.__uj){for(bn in this.__uj){var bp=this.__uj[bn];bp.stop();bp.dispose();};};if(this.__ui){for(bn in this.__ui){var bo=this.__ui[bn];this.removeListenerById(bo);};};this._resource.destruct();this._resource=this.__uk=this.__uj=this.__ui=null;}});})();(function(){var a="function",b="=?(\\w+)?}",c="' is invalid",d="loadEnd",f="Started",g="Parameter '",h="GET",i="sent",j="Method with name of action (",k="'",l="error",m="Content-Type",n="onreadystatechange",o="get",p="{",q="Sent",r="success",s=") doesn't support other HTTP methods than 'GET'",t=") already exists",u="Error",v="",w="qx.bom.rest.Resource",x="Request (",y="Missing parameter '",z="Success",A="readystatechange",B="started",C="fail",D="undefined",E="No route for action ";qx.Bootstrap.define(w,{extend:qx.event.Emitter,construct:function(F){this.__uo={};this.__uk={};this.__uj={};this.__ui={};try{if(typeof F!==D){{};this.__um(F);};}catch(e){this.dispose();throw e;};},events:{"success":w,"actionSuccess":w,"error":w,"actionError":w,"sent":w,"actionSent":w,"started":w,"actionStarted":w},statics:{POLL_THROTTLE_LIMIT:100,POLL_THROTTLE_COUNT:30,REQUIRED:true,placeholdersFromUrl:function(G){var I=/\{(\w+)(=\w+)?\}/g,J,H=[];while((J=I.exec(G))){H.push(J[1]);};return H;}},members:{__uo:null,__uk:null,__up:null,__uj:null,__ui:null,__uq:null,__ur:null,__us:null,setRequestFactory:function(K){this.__us=K;},setRequestHandler:function(L){this.__ur=L;},_getRequestHandler:function(){return (this.__ur===null)?{onsuccess:{callback:function(N,M){return function(){var O={"id":parseInt(N.toHashCode(),10),"response":N.getResponse(),"request":N,"action":M};this.emit(M+z,O);this.emit(r,O);};},context:this},onfail:{callback:function(Q,P){return function(){var R={"id":parseInt(Q.toHashCode(),10),"response":Q.getResponse(),"request":Q,"action":P};this.emit(P+u,R);this.emit(l,R);};},context:this},onloadend:{callback:function(T,S){return function(){window.setTimeout(function(){T.dispose();},0);};},context:this},onreadystatechange:{callback:function(V,U){return function(){if(V.getTransport().readyState===qx.bom.request.Xhr.HEADERS_RECEIVED){var W={"id":parseInt(V.toHashCode(),10),"request":V,"action":U};this.emit(U+q,W);this.emit(i,W);};if(V.getTransport().readyState===qx.bom.request.Xhr.OPENED){var X={"id":parseInt(V.toHashCode(),10),"request":V,"action":U};this.emit(U+f,X);this.emit(B,X);};};},context:this}}:this.__ur;},getRequestsByAction:function(Y){var ba=(this.__uo!==null&&Y in this.__uo);return ba?this.__uo[Y]:null;},configureRequest:function(bb){this.__uq=bb;},_getRequest:function(){return (this.__us===null)?new qx.bom.request.SimpleXhr():this.__us();},__ut:function(bc){var bd=this._getRequest();if(!qx.lang.Type.isArray(this.__uo[bc])){this.__uo[bc]=[];};this.__uo[bc].push(bd);return bd;},map:function(bf,bh,be,bg){this.__uk[bf]=[bh,be,bg];this.__uo[bf]=[];if(bf==o){this[bf]=undefined;};if(typeof this[bf]!==D&&this[bf]!==null&&this[bf].action!==true){throw new Error(j+bf+t);};this.__un(bf+z);this.__un(bf+u);this[bf]=qx.lang.Function.bind(function(){Array.prototype.unshift.call(arguments,bf);return this.invoke.apply(this,arguments);},this);this[bf].action=true;},invoke:function(bm,bk,bi){var bj=this.__ut(bm),bk=bk==null?{}:bk,bn=this._getRequestConfig(bm,bk);this.__uk[bm].params=bk;this.__uu(bk,bn.check);this.__uv(bj,bn,bi);if(this.__uq){this.__uq.call(this,bj,bm,bk,bi);};this.__uw(bj,bn,bi);var bl=this._getRequestHandler();bj.addListenerOnce(r,bl.onsuccess.callback(bj,bm),bl.onsuccess.context);bj.addListenerOnce(C,bl.onfail.callback(bj,bm),bl.onfail.context);bj.addListenerOnce(d,bl.onloadend.callback(bj,bm),bl.onloadend.context);if(bl.hasOwnProperty(n)){bj.addListener(A,bl.onreadystatechange.callback(bj,bm),bl.onreadystatechange.context);};bj.send();return parseInt(bj.toHashCode(),10);},setBaseUrl:function(bo){this.__up=bo;},__uu:function(bp,bq){if(typeof bq!==D){{};Object.keys(bq).forEach(function(br){{};if(bq[br]===qx.bom.rest.Resource.REQUIRED&&typeof bp[br]===D){throw new Error(y+br+k);};if(!(bq[br]&&typeof bq[br].test==a)){return;};if(!bq[br].test(bp[br])){throw new Error(g+br+c);};});};},__uv:function(bt,bs,bu){bt.setUrl(bs.url);if(!bt.setMethod&&bs.method!==h){throw new Error(x+bt.classname+s);};if(bt.setMethod){bt.setMethod(bs.method);};if(bu){bt.setRequestData(bu);};},__uw:function(bx,bv,bw){if(bw){var by=bx.getRequestHeader(m);if(bx.getMethod&&qx.util.Request.methodAllowsRequestBody(bx.getMethod())){if(/application\/.*\+?json/.test(by)){bw=qx.lang.Json.stringify(bw);bx.setRequestData(bw);};};};},abort:function(bB){if(qx.lang.Type.isNumber(bB)){var bE=bB;var bD=qx.core.ObjectRegistry.getPostId();var bz=qx.core.ObjectRegistry.fromHashCode(bE+bD);if(bz){bz.abort();};}else {var bC=bB;var bA=this.__uo[bC];if(this.__uo[bC]){bA.forEach(function(bF){bF.abort();});};};},refresh:function(bG){this.invoke(bG,this.__uk[bG].params);},poll:function(bH,bJ,bK,bI){if(this.__uj[bH]){this.stopPollByAction(bH);};if(typeof bK==D){bK=this.__uk[bH].params;};if(bI){this.invoke(bH,bK);};var bL=(function(bM){return function(){var bN=bM.__uo[bH][0];if(!bI&&!bN){bM.invoke(bH,bK);return;};if(bN.isDone()||bN.isDisposed()){bM.refresh(bH);};};})(this);this._startPoll(bH,bL,bJ);},_startPoll:function(bO,bP,bQ){this.__uj[bO]={"id":window.setInterval(bP,bQ),"interval":bQ,"listener":bP};},stopPollByAction:function(bR){if(bR in this.__uj){var bS=this.__uj[bR].id;window.clearInterval(bS);};},restartPollByAction:function(bT){if(bT in this.__uj){var bU=this.__uj[bT];this.stopPollByAction(bT);this._startPoll(bT,bU.listener,bU.interval);};},longPoll:function(ca){var bW=this,bY,cb=0;function bV(){var cc=bY&&((new Date())-bY)<bW._getThrottleLimit();if(cc){cb+=1;if(cb>bW._getThrottleCount()){{};return true;};};if(!cc){cb=0;};return false;};var bX=this.__ui[ca]=this.addListener(ca+z,function cd(){if(bW.isDisposed()){return;};if(!bV()){bY=new Date();bW.refresh(ca);};});this.invoke(ca);return bX;},_getRequestConfig:function(ci,ch){var cf=this.__uk[ci];var ch=qx.lang.Object.clone(ch);if(!qx.lang.Type.isArray(cf)){throw new Error(E+ci);};var cg=cf[0],ce=this.__up!==null?this.__up+cf[1]:cf[1],ck=cf[2],cj=qx.bom.rest.Resource.placeholdersFromUrl(ce);ch=ch||{};cj.forEach(function(cn){var cl=new RegExp(p+cn+b),cm=ce.match(cl)[1];if(typeof ch[cn]===D){if(cm){ch[cn]=cm;}else {ch[cn]=v;};};ce=ce.replace(cl,ch[cn]);});return {method:cg,url:ce,check:ck};},_getThrottleLimit:function(){return qx.bom.rest.Resource.POLL_THROTTLE_LIMIT;},_getThrottleCount:function(){return qx.bom.rest.Resource.POLL_THROTTLE_COUNT;},__um:function(co){Object.keys(co).forEach(function(cq){var cr=co[cq],ct=cr.method,cp=cr.url,cs=cr.check;{};this.map(cq,ct,cp,cs);},this);},__un:function(cu){if(!this.constructor.$$events){this.constructor.$$events={};};if(!this.constructor.$$events[cu]){this.constructor.$$events[cu]=w;};},isDisposed:function(){return this.$$disposed||false;},dispose:function(){if(this.$$disposed){return;};this.$$disposed=true;{};this.destruct();{var cw,cx,cv,cy;};},destruct:function(){var cz;for(cz in this.__uo){if(this.__uo[cz]){this.__uo[cz].forEach(function(cB){cB.dispose();});};};if(this.__uj){for(cz in this.__uj){this.stopPollByAction(cz);};};if(this.__ui){for(cz in this.__ui){var cA=this.__ui[cz];this.removeListenerById(cA);};};this.__uo=this.__uk=this.__uj=null;}}});})();(function(){var a="activex",b="No XHR support available.",c="If-None-Match",d="xhr",f="If-Modified-Since",g="engine.version",h="onunload",i="GET",j="-1",k="qx.debug.io",l="HTMLDocument",m="error",n="loadend",o="Blob",p="load",q="abort",r="String",s="browser.documentmode",t="",u="engine.name",v="Microsoft.XMLHTTP",w="Already disposed",x="browser.version",y="opera",z="qx.bom.request.Xhr",A="Not enough arguments",B="timeout",C="gecko",D="If-Match",E="mshtml",F="readystatechange",G="Microsoft.XMLDOM",H="file:",I="FormData",J="If-Range",K="Content-Type",L="io.xhr",M="on",N="ArrayBuffer",O="undefined",P="Native XHR object doesn't support overrideMimeType.";qx.Bootstrap.define(z,{extend:Object,construct:function(){var Q=qx.Bootstrap.bind(this.__nU,this);if(qx.event&&qx.event.GlobalError&&qx.event.GlobalError.observeMethod){this.__nI=qx.event.GlobalError.observeMethod(Q);}else {this.__nI=Q;};this.__nJ=qx.Bootstrap.bind(this.__nT,this);this.__ng=qx.Bootstrap.bind(this.__nY,this);this.__nS();this._emitter=new qx.event.Emitter();if(window.attachEvent){this.__nK=qx.Bootstrap.bind(this.__oc,this);window.attachEvent(h,this.__nK);};},statics:{UNSENT:0,OPENED:1,HEADERS_RECEIVED:2,LOADING:3,DONE:4},events:{"readystatechange":z,"error":z,"loadend":z,"timeout":z,"abort":z,"load":z},members:{readyState:0,responseText:t,responseXML:null,status:0,statusText:t,timeout:0,open:function(V,R,S,U,T){this.__oe();if(typeof R===O){throw new Error(A);}else if(typeof V===O){V=i;};this.__nj=false;this.__nL=false;this.__nM=false;this.__nk=R;if(typeof S==O){S=true;};this.__nN=S;if(!this.__od()&&this.readyState>qx.bom.request.Xhr.UNSENT){this.dispose();this.__nS();};this.__nP.onreadystatechange=this.__nI;try{{};this.__nP.open(V,R,S,U,T);}catch(W){if(!qx.util.Request.isCrossDomain(R)){throw W;};if(!this.__nN){this.__nO=W;};if(this.__nN){if(window.XDomainRequest){this.readyState=4;this.__nP=new XDomainRequest();this.__nP.onerror=qx.Bootstrap.bind(function(){this._emit(F);this._emit(m);this._emit(n);},this);{};this.__nP.open(V,R,S,U,T);return;};window.setTimeout(qx.Bootstrap.bind(function(){if(this.__nl){return;};this.readyState=4;this._emit(F);this._emit(m);this._emit(n);},this));};};if(qx.core.Environment.get(u)===E&&qx.core.Environment.get(s)<9&&this.__nP.readyState>0){this.__nP.setRequestHeader(f,j);};if(qx.core.Environment.get(u)===C&&parseInt(qx.core.Environment.get(g),10)<2&&!this.__nN){this.readyState=qx.bom.request.Xhr.OPENED;this._emit(F);};},setRequestHeader:function(X,Y){this.__oe();if(X==D||X==f||X==c||X==J){this.__nM=true;};this.__nP.setRequestHeader(X,Y);return this;},send:function(bb){this.__oe();if(!this.__nN&&this.__nO){throw this.__nO;};if(qx.core.Environment.get(u)===y&&this.timeout===0){this.timeout=10000;};if(this.timeout>0){this.__nQ=window.setTimeout(this.__ng,this.timeout);};bb=typeof bb==O?null:bb;var ba=qx.Bootstrap.getClass(bb);bb=(bb!==null&&this.__nR.indexOf(ba)===-1)?bb.toString():bb;try{{};this.__nP.send(bb);}catch(bd){if(!this.__nN){throw bd;};if(this._getProtocol()===H){this.readyState=2;this.__nV();var bc=this;window.setTimeout(function(){if(bc.__nl){return;};bc.readyState=3;bc.__nV();bc.readyState=4;bc.__nV();});};};if(qx.core.Environment.get(u)===C&&!this.__nN){this.__nU();};this.__nL=true;return this;},abort:function(){this.__oe();this.__nj=true;this.__nP.abort();if(this.__nP){this.readyState=this.__nP.readyState;};return this;},_emit:function(event){if(this[M+event]){this[M+event]();};this._emitter.emit(event,this);},onreadystatechange:function(){},onload:function(){},onloadend:function(){},onerror:function(){},onabort:function(){},ontimeout:function(){},on:function(name,be,bf){this._emitter.on(name,be,bf);return this;},getResponseHeader:function(bg){this.__oe();if(qx.core.Environment.get(s)===9&&this.__nP.aborted){return t;};return this.__nP.getResponseHeader(bg);},getAllResponseHeaders:function(){this.__oe();if(qx.core.Environment.get(s)===9&&this.__nP.aborted){return t;};return this.__nP.getAllResponseHeaders();},overrideMimeType:function(bh){this.__oe();if(this.__nP.overrideMimeType){this.__nP.overrideMimeType(bh);}else {throw new Error(P);};return this;},getRequest:function(){return this.__nP;},dispose:function(){if(this.__nl){return false;};window.clearTimeout(this.__nQ);if(window.detachEvent){window.detachEvent(h,this.__nK);};try{this.__nP.onreadystatechange;}catch(bj){return false;};var bi=function(){};this.__nP.onreadystatechange=bi;this.__nP.onload=bi;this.__nP.onerror=bi;this.abort();this.__nP=null;this.__nl=true;return true;},isDisposed:function(){return !!this.__nl;},_createNativeXhr:function(){var bk=qx.core.Environment.get(L);if(bk===d){return new XMLHttpRequest();};if(bk==a){return new window.ActiveXObject(v);};qx.Bootstrap.error(this,b);},_getProtocol:function(){var bl=this.__nk;var bm=/^(\w+:)\/\//;if(bl!==null&&bl.match){var bn=bl.match(bm);if(bn&&bn[1]){return bn[1];};};return window.location.protocol;},__nP:null,__nN:null,__nI:null,__nJ:null,__nK:null,__ng:null,__nL:null,__nk:null,__nj:null,__gr:null,__nl:null,__nQ:null,__nO:null,__nM:null,__nR:null,__nS:function(){this.__nP=this._createNativeXhr();this.__nP.onreadystatechange=this.__nI;if(this.__nP.onabort){this.__nP.onabort=this.__nJ;};this.__nl=this.__nL=this.__nj=false;this.__nR=[N,o,l,r,I];},__nT:function(){if(!this.__nj){this.abort();};},__nU:function(){var bo=this.__nP,bp=true;{};if(this.readyState==bo.readyState){return;};this.readyState=bo.readyState;if(this.readyState===qx.bom.request.Xhr.DONE&&this.__nj&&!this.__nL){return;};if(!this.__nN&&(bo.readyState==2||bo.readyState==3)){return;};this.status=0;this.statusText=this.responseText=t;this.responseXML=null;if(this.readyState>=qx.bom.request.Xhr.HEADERS_RECEIVED){try{this.status=bo.status;this.statusText=bo.statusText;this.responseText=bo.responseText;this.responseXML=bo.responseXML;}catch(bq){bp=false;};if(bp){this.__oa();this.__ob();};};this.__nV();if(this.readyState==qx.bom.request.Xhr.DONE){if(bo){bo.onreadystatechange=function(){};};};},__nV:function(){if(this.readyState===qx.bom.request.Xhr.DONE){window.clearTimeout(this.__nQ);};this._emit(F);if(this.readyState===qx.bom.request.Xhr.DONE){this.__nW();};},__nW:function(){if(this.__gr){this._emit(B);if(qx.core.Environment.get(u)===y){this._emit(m);};this.__gr=false;}else {if(this.__nj){this._emit(q);}else {if(this.__nX()){this._emit(m);}else {this._emit(p);};};};this._emit(n);},__nX:function(){var br;if(this._getProtocol()===H){br=!this.responseText;}else {br=this.status===0;};return br;},__nY:function(){var bs=this.__nP;this.readyState=qx.bom.request.Xhr.DONE;this.__gr=true;bs.aborted=true;bs.abort();this.responseText=t;this.responseXML=null;this.__nV();},__oa:function(){var bt=this.readyState===qx.bom.request.Xhr.DONE;if(this._getProtocol()===H&&this.status===0&&bt){if(!this.__nX()){this.status=200;};};if(this.status===1223){this.status=204;};if(qx.core.Environment.get(u)===y){if(bt&&this.__nM&&!this.__nj&&this.status===0){this.status=304;};};},__ob:function(){if(qx.core.Environment.get(u)==E&&(this.getResponseHeader(K)||t).match(/[^\/]+\/[^\+]+\+xml/)&&this.responseXML&&!this.responseXML.documentElement){var bu=new window.ActiveXObject(G);bu.async=false;bu.validateOnParse=false;bu.loadXML(this.responseText);this.responseXML=bu;};},__oc:function(){try{if(this){this.dispose();};}catch(e){};},__od:function(){var name=qx.core.Environment.get(u);var bv=qx.core.Environment.get(x);return !(name==E&&bv<9||name==C&&bv<3.5);},__oe:function(){if(this.__nl){throw new Error(w);};}},defer:function(){qx.core.Environment.add(k,false);}});})();(function(){var a="HEAD",b="CONNECT",c="OPTIONS",d="PUT",e="GET",f="PATCH",g="//",h="DELETE",i="POST",j="TRACE",k="qx.util.Request";qx.Bootstrap.define(k,{statics:{isCrossDomain:function(l){var n=qx.util.Uri.parseUri(l),location=window.location;if(!location){return false;};var m=location.protocol;if(!(l.indexOf(g)!==-1)){return false;};if(m.substr(0,m.length-1)==n.protocol&&location.host===n.host&&location.port===n.port){return false;};return true;},isSuccessful:function(status){return (status>=200&&status<300||status===304);},isMethod:function(p){var o=[e,i,d,h,a,c,j,b,f];return (o.indexOf(p)!==-1)?true:false;},methodAllowsRequestBody:function(q){return !((/^(GET|HEAD)$/).test(q));}}});})();(function(){var a="error",b="",c="loadEnd",d="application/x-www-form-urlencoded",f="Cache-Control",g="Content-Type",h="fail",i="GET",j="success",k="undefined",l="POST",m="timeout",n="qx.bom.request.SimpleXhr",o="abort";qx.Bootstrap.define(n,{extend:qx.event.Emitter,construct:function(p,q){if(p!==undefined){this.setUrl(p);};this.useCaching(true);this.setMethod((q!==undefined)?q:i);this._transport=this._registerTransportListener(this._createTransport());qx.core.ObjectRegistry.register(this);this.__og={};this.__os=this._createResponseParser();},members:{setRequestHeader:function(r,s){this.__og[r]=s;return this;},getRequestHeader:function(t){return this.__og[t];},getResponseHeader:function(u){return this._transport.getResponseHeader(u);},getAllResponseHeaders:function(){return this._transport.getAllResponseHeaders();},setUrl:function(v){if(qx.lang.Type.isString(v)){this.__nk=v;};return this;},getUrl:function(){return this.__nk;},setMethod:function(w){if(qx.util.Request.isMethod(w)){this.__ux=w;};return this;},getMethod:function(){return this.__ux;},setRequestData:function(x){if(qx.lang.Type.isString(x)||qx.lang.Type.isObject(x)){this.__uy=x;};return this;},getRequestData:function(){return this.__uy;},getResponse:function(){if(this.__om!==null){return this.__om;}else {return (this._transport.responseXML!==null)?this._transport.responseXML:this._transport.responseText;};return null;},getTransport:function(){return this._transport;},setParser:function(y){return this.__os.setParser(y);},setTimeout:function(z){if(qx.lang.Type.isNumber(z)){this.__gr=z;};return this;},getTimeout:function(){return this.__gr;},useCaching:function(A){if(qx.lang.Type.isBoolean(A)){this.__c=A;};return this;},isCaching:function(){return this.__c;},isDone:function(){return (this._transport.readyState===qx.bom.request.Xhr.DONE);},toHashCode:function(){return this.$$hash;},isDisposed:function(){return !!this.__nl;},send:function(){var G=this.getTimeout(),D=(this.getRequestData()!==null),E=this.__og.hasOwnProperty(f),B=qx.util.Request.methodAllowsRequestBody(this.getMethod()),H=this.getRequestHeader(g),C=this._serializeData(this.getRequestData(),H);if(this.getMethod()===i&&D){this.setUrl(qx.util.Uri.appendParamsToUrl(this.getUrl(),C));};if(this.isCaching()===false&&!E){this.setUrl(qx.util.Uri.appendParamsToUrl(this.getUrl(),{nocache:new Date().valueOf()}));};if(G){this._transport.timeout=G;};this._transport.open(this.getMethod(),this.getUrl(),true);for(var F in this.__og){this._transport.setRequestHeader(F,this.__og[F]);};if(!B){this._transport.send();}else {if(typeof H===k){this._transport.setRequestHeader(g,d);};this._transport.send(C);};},abort:function(){this._transport.abort();return this;},dispose:function(){if(this._transport.dispose()){this.__os=null;this.__nl=true;return true;};return false;},_transport:null,_createTransport:function(){return new qx.bom.request.Xhr();},_registerTransportListener:function(I){I.onreadystatechange=qx.lang.Function.bind(this._onReadyStateChange,this);I.onloadend=qx.lang.Function.bind(this._onLoadEnd,this);I.ontimeout=qx.lang.Function.bind(this._onTimeout,this);I.onerror=qx.lang.Function.bind(this._onError,this);I.onabort=qx.lang.Function.bind(this._onAbort,this);return I;},_createResponseParser:function(){return new qx.util.ResponseParser();},_setResponse:function(J){this.__om=J;},_serializeData:function(N,M){var K=this.getMethod()===l,L=/application\/.*\+?json/.test(M);if(!N){return null;};if(qx.lang.Type.isString(N)){return N;};if(L&&(qx.lang.Type.isObject(N)||qx.lang.Type.isArray(N))){return qx.lang.Json.stringify(N);};if(qx.lang.Type.isObject(N)){return qx.util.Uri.toParameter(N,K);};return null;},__og:null,__uy:null,__ux:b,__nk:b,__om:null,__os:null,__c:null,__gr:null,__nl:null,addListenerOnce:function(name,O,P){this.once(name,O,P);return this;},addListener:function(name,Q,R){this._transport._emitter.on(name,Q,R);return this;},_onReadyStateChange:function(){{};if(this.isDone()){this.__oq();};},__oq:function(){{};var T=this._transport.responseText;var S=this._transport.getResponseHeader(g);if(qx.util.Request.isSuccessful(this._transport.status)){{};this._setResponse(this.__os.parse(T,S));this.emit(j);}else {try{this._setResponse(this.__os.parse(T,S));}catch(e){};if(this._transport.status!==0){this.emit(h);};};},_onLoadEnd:function(){this.emit(c);},_onAbort:function(){this.emit(o);},_onTimeout:function(){this.emit(m);this.emit(h);},_onError:function(){this.emit(a);this.emit(h);}}});})();(function(){var a="function",b="qx.util.ResponseParser",c="";qx.Bootstrap.define(b,{construct:function(d){if(d!==undefined){this.setParser(d);};},statics:{PARSER:{json:qx.lang.Json.parse,xml:qx.xml.Document.fromString}},members:{__os:null,parse:function(g,f){var e=this._getParser(f);if(typeof e===a){if(g!==c){return e.call(this,g);};};return g;},setParser:function(h){if(typeof qx.util.ResponseParser.PARSER[h]===a){return this.__os=qx.util.ResponseParser.PARSER[h];};{};return this.__os=h;},_getParser:function(j){var i=this.__os,l=c,k=c;if(i){return i;};l=j||c;k=l.replace(/;.*$/,c);if(/^application\/(\w|\.)*\+?json$/.test(k)){i=qx.util.ResponseParser.PARSER.json;};if(/^application\/xml$/.test(k)){i=qx.util.ResponseParser.PARSER.xml;};if(/[^\/]+\/[^\+]+\+xml$/.test(l)){i=qx.util.ResponseParser.PARSER.xml;};return i;}}});})();(function(){var a="Number",b="qx.io.request.AbstractRequest",c="qx.event.type.Rest",d="String";qx.Class.define(c,{extend:qx.event.type.Data,properties:{request:{check:b},action:{check:d},phase:{check:d},id:{check:a}},members:{init:function(j,e,g,f,h,i){qx.event.type.Data.prototype.init.call(this,j,e,g);this.setRequest(f);this.setAction(h);this.setPhase(i);this.setId(parseInt(f.toHashCode(),10));return this;},clone:function(k){var l=qx.event.type.Data.prototype.clone.call(this,k);l.setAction(this.getAction());l.setPhase(this.getPhase());l.setRequest(this.getRequest());return l;}}});})();(function(){var a="loadEnd",b="qx.io.request.AbstractRequest",c="changePhase",d="GET",f="sent",g="qx.event.type.Data",h="qx.io.request.authentication.IAuthentication",i="error",j="Blob",k="fail",l="loading",m="load",n="qx.event.type.Event",o="abort",p="success",q="String",r="",s="opened",t="POST",u="timeout",v="statusError",w="readyStateChange",x="Abstract method call",y="abstract",z="unsent",A="changeResponse",B="Number",C="FormData",D="Content-Type",E="ArrayBuffer",F="undefined";qx.Class.define(b,{type:y,extend:qx.core.Object,construct:function(G){qx.core.Object.call(this);if(G!==undefined){this.setUrl(G);};this.__og={};var H=this._transport=this._createTransport();this._setPhase(z);this.__oh=qx.lang.Function.bind(this._onReadyStateChange,this);this.__oi=qx.lang.Function.bind(this._onLoad,this);this.__oj=qx.lang.Function.bind(this._onLoadEnd,this);this.__ok=qx.lang.Function.bind(this._onAbort,this);this.__ng=qx.lang.Function.bind(this._onTimeout,this);this.__ol=qx.lang.Function.bind(this._onError,this);H.onreadystatechange=this.__oh;H.onload=this.__oi;H.onloadend=this.__oj;H.onabort=this.__ok;H.ontimeout=this.__ng;H.onerror=this.__ol;},events:{"readyStateChange":n,"success":n,"load":n,"loadEnd":n,"abort":n,"timeout":n,"error":n,"statusError":n,"fail":n,"changeResponse":g,"changePhase":g},properties:{url:{check:q},timeout:{check:B,nullable:true,init:0},requestData:{check:function(I){return qx.lang.Type.isString(I)||qx.Class.isSubClassOf(I.constructor,qx.core.Object)||qx.lang.Type.isObject(I)||qx.lang.Type.isArray(I)||qx.Bootstrap.getClass(I)==j||qx.Bootstrap.getClass(I)==E||qx.Bootstrap.getClass(I)==C;},nullable:true},authentication:{check:h,nullable:true}},members:{__oh:null,__oi:null,__oj:null,__ok:null,__ng:null,__ol:null,__om:null,__nj:null,__on:null,__og:null,__oo:null,_transport:null,_createTransport:function(){throw new Error(x);},_getConfiguredUrl:function(){},_getConfiguredRequestHeaders:function(){},_getParsedResponse:function(){throw new Error(x);},_getMethod:function(){return d;},_isAsync:function(){return true;},send:function(){var M=this._transport,K,L,N,J;K=this._getConfiguredUrl();if(/\#/.test(K)){K=K.replace(/\#.*/,r);};M.timeout=this.getTimeout();L=this._getMethod();N=this._isAsync();{};M.open(L,K,N);this._setPhase(s);J=this.getRequestData();if([E,j,C].indexOf(qx.Bootstrap.getClass(J))==-1){J=this._serializeData(J);};this._setRequestHeaders();{};L==d?M.send():M.send(J);this._setPhase(f);},abort:function(){{};this.__nj=true;this.__on=o;this._transport.abort();},_setRequestHeaders:function(){var P=this._transport,O=this._getAllRequestHeaders();for(var Q in O){P.setRequestHeader(Q,O[Q]);};},_getAllRequestHeaders:function(){var R={};qx.lang.Object.mergeWith(R,this._getConfiguredRequestHeaders());qx.lang.Object.mergeWith(R,this.__op());qx.lang.Object.mergeWith(R,this.__oo);qx.lang.Object.mergeWith(R,this.__og);return R;},__op:function(){var T=this.getAuthentication(),S={};if(T){T.getAuthHeaders().forEach(function(U){S[U.key]=U.value;});return S;};},setRequestHeader:function(V,W){this.__og[V]=W;},getRequestHeader:function(X){return this.__og[X];},removeRequestHeader:function(Y){if(this.__og[Y]){delete this.__og[Y];};},getTransport:function(){return this._transport;},getReadyState:function(){return this._transport.readyState;},getPhase:function(){return this.__on;},getStatus:function(){return this._transport.status;},getStatusText:function(){return this._transport.statusText;},getResponseText:function(){return this._transport.responseText;},getAllResponseHeaders:function(){return this._transport.getAllResponseHeaders();},getResponseHeader:function(ba){return this._transport.getResponseHeader(ba);},overrideResponseContentType:function(bb){return this._transport.overrideMimeType(bb);},getResponseContentType:function(){return this.getResponseHeader(D);},isDone:function(){return this.getReadyState()===4;},getResponse:function(){return this.__om;},_setResponse:function(bd){var bc=bd;if(this.__om!==bd){this.__om=bd;this.fireEvent(A,qx.event.type.Data,[this.__om,bc]);};},_onReadyStateChange:function(){var be=this.getReadyState();{};this.fireEvent(w);if(this.__nj){return;};if(be===3){this._setPhase(l);};if(this.isDone()){this.__oq();};},__oq:function(){{};this._setPhase(m);if(qx.util.Request.isSuccessful(this.getStatus())){{};this._setResponse(this._getParsedResponse());this._fireStatefulEvent(p);}else {try{this._setResponse(this._getParsedResponse());}catch(e){};if(this.getStatus()!==0){this._fireStatefulEvent(v);this.fireEvent(k);};};},_onLoad:function(){this.fireEvent(m);},_onLoadEnd:function(){this.fireEvent(a);},_onAbort:function(){this._fireStatefulEvent(o);},_onTimeout:function(){this._fireStatefulEvent(u);this.fireEvent(k);},_onError:function(){this.fireEvent(i);this.fireEvent(k);},_fireStatefulEvent:function(bf){{};this._setPhase(bf);this.fireEvent(bf);},_setPhase:function(bg){var bh=this.__on;{};this.__on=bg;this.fireDataEvent(c,bg,bh);},_serializeData:function(bk){var bi=typeof this.getMethod!==F&&this.getMethod()==t,bj=/application\/.*\+?json/.test(this.getRequestHeader(D));if(!bk){return null;};if(qx.lang.Type.isString(bk)){return bk;};if(qx.Class.isSubClassOf(bk.constructor,qx.core.Object)){return qx.util.Serializer.toUriParameter(bk);};if(bj&&(qx.lang.Type.isObject(bk)||qx.lang.Type.isArray(bk))){return qx.lang.Json.stringify(bk);};if(qx.lang.Type.isObject(bk)){return qx.util.Uri.toParameter(bk,bi);};return null;}},environment:{"qx.debug.io":false},destruct:function(){var bm=this._transport,bl=function(){};if(this._transport){bm.onreadystatechange=bm.onload=bm.onloadend=bm.onabort=bm.ontimeout=bm.onerror=bl;window.setTimeout(function(){bm.dispose();},0);};}});})();(function(){var a="qx.util.Serializer",b='\\\\',c='\\f',d='"',e="null",f='\\"',g="}",h="get",j="{",k='\\r',l="",m='\\t',n="]",o="Class",p="Interface",q="[",r="Mixin",s='":',t="&",u='\\b',v="=",w='\\n',x=",";qx.Class.define(a,{statics:{toUriParameter:function(z,C,y){var E=l;var B=qx.util.PropertyUtil.getAllProperties(z.constructor);for(var name in B){if(B[name].group!=undefined){continue;};var A=z[h+qx.lang.String.firstUp(name)]();if(qx.lang.Type.isArray(A)){var D=qx.data&&qx.data.IListData&&qx.Class.hasInterface(A&&A.constructor,qx.data.IListData);for(var i=0;i<A.length;i++ ){var F=D?A.getItem(i):A[i];E+=this.__or(name,F,C);};}else if(qx.lang.Type.isDate(A)&&y!=null){E+=this.__or(name,y.format(A),C);}else {E+=this.__or(name,A,C);};};return E.substring(0,E.length-1);},__or:function(name,I,G){if(I&&I.$$type==o){I=I.classname;};if(I&&(I.$$type==p||I.$$type==r)){I=I.name;};if(I instanceof qx.core.Object&&G!=null){var H=encodeURIComponent(G(I));if(H===undefined){var H=encodeURIComponent(I);};}else {var H=encodeURIComponent(I);};return encodeURIComponent(name)+v+H+t;},toNativeObject:function(L,N,K){var O;if(L==null){return null;};if(qx.data&&qx.data.IListData&&qx.Class.hasInterface(L.constructor,qx.data.IListData)){O=[];for(var i=0;i<L.getLength();i++ ){O.push(qx.util.Serializer.toNativeObject(L.getItem(i),N,K));};return O;};if(qx.lang.Type.isArray(L)){O=[];for(var i=0;i<L.length;i++ ){O.push(qx.util.Serializer.toNativeObject(L[i],N,K));};return O;};if(L.$$type==o){return L.classname;};if(L.$$type==p||L.$$type==r){return L.name;};if(L instanceof qx.core.Object){if(N!=null){var J=N(L);if(J!=undefined){return J;};};O={};var Q=qx.util.PropertyUtil.getAllProperties(L.constructor);for(var name in Q){if(Q[name].group!=undefined){continue;};var M=L[h+qx.lang.String.firstUp(name)]();O[name]=qx.util.Serializer.toNativeObject(M,N,K);};return O;};if(qx.lang.Type.isDate(L)&&K!=null){return K.format(L);};if(qx.locale&&qx.locale.LocalizedString&&L instanceof qx.locale.LocalizedString){return L.toString();};if(qx.lang.Type.isObject(L)){O={};for(var P in L){O[P]=qx.util.Serializer.toNativeObject(L[P],N,K);};return O;};return L;},toJson:function(T,V,S){var W=l;if(T==null){return e;};if(qx.data&&qx.data.IListData&&qx.Class.hasInterface(T.constructor,qx.data.IListData)){W+=q;for(var i=0;i<T.getLength();i++ ){W+=qx.util.Serializer.toJson(T.getItem(i),V,S)+x;};if(W!=q){W=W.substring(0,W.length-1);};return W+n;};if(qx.lang.Type.isArray(T)){W+=q;for(var i=0;i<T.length;i++ ){W+=qx.util.Serializer.toJson(T[i],V,S)+x;};if(W!=q){W=W.substring(0,W.length-1);};return W+n;};if(T.$$type==o){return d+T.classname+d;};if(T.$$type==p||T.$$type==r){return d+T.name+d;};if(T instanceof qx.core.Object){if(V!=null){var R=V(T);if(R!=undefined){return d+R+d;};};W+=j;var Y=qx.util.PropertyUtil.getAllProperties(T.constructor);for(var name in Y){if(Y[name].group!=undefined){continue;};var U=T[h+qx.lang.String.firstUp(name)]();W+=d+name+s+qx.util.Serializer.toJson(U,V,S)+x;};if(W!=j){W=W.substring(0,W.length-1);};return W+g;};if(qx.locale&&qx.locale.LocalizedString&&T instanceof qx.locale.LocalizedString){T=T.toString();};if(qx.lang.Type.isDate(T)&&S!=null){return d+S.format(T)+d;};if(qx.lang.Type.isObject(T)){W+=j;for(var X in T){W+=d+X+s+qx.util.Serializer.toJson(T[X],V,S)+x;};if(W!=j){W=W.substring(0,W.length-1);};return W+g;};if(qx.lang.Type.isString(T)){T=T.replace(/([\\])/g,b);T=T.replace(/(["])/g,f);T=T.replace(/([\r])/g,k);T=T.replace(/([\f])/g,c);T=T.replace(/([\n])/g,w);T=T.replace(/([\t])/g,m);T=T.replace(/([\b])/g,u);return d+T+d;};if(qx.lang.Type.isDate(T)||qx.lang.Type.isRegExp(T)){return d+T+d;};return T+l;}}});})();(function(){var a="null",b="XMLHttpRequest",c="Boolean",d="X-Requested-With",e="",f="application/x-www-form-urlencoded",g="Cache-Control",h="Content-Type",i="qx.event.type.Event",j="GET",k="qx.io.request.Xhr",l="Accept",m="String";qx.Class.define(k,{extend:qx.io.request.AbstractRequest,construct:function(n,o){if(o!==undefined){this.setMethod(o);};qx.io.request.AbstractRequest.call(this,n);this._parser=this._createResponseParser();},events:{"readyStateChange":i,"success":i,"load":i,"statusError":i},properties:{method:{init:j},async:{check:c,init:true},accept:{check:m,nullable:true},cache:{check:function(p){return qx.lang.Type.isBoolean(p)||qx.lang.Type.isString(p);},init:true}},members:{_parser:null,_createTransport:function(){return new qx.bom.request.Xhr();},_getConfiguredUrl:function(){var q=this.getUrl(),r;if(this.getMethod()===j&&this.getRequestData()){r=this._serializeData(this.getRequestData());q=qx.util.Uri.appendParamsToUrl(q,r);};if(this.getCache()===false){q=qx.util.Uri.appendParamsToUrl(q,{nocache:new Date().valueOf()});};return q;},_getConfiguredRequestHeaders:function(){var s={},t=qx.util.Request.methodAllowsRequestBody(this.getMethod());if(!qx.util.Request.isCrossDomain(this.getUrl())){s[d]=b;};if(qx.lang.Type.isString(this.getCache())){s[g]=this.getCache();};if(this.getRequestData()!==a&&t){s[h]=f;};if(this.getAccept()){{};s[l]=this.getAccept();};return s;},_getMethod:function(){return this.getMethod();},_isAsync:function(){return this.isAsync();},_createResponseParser:function(){return new qx.util.ResponseParser();},_getParsedResponse:function(){var v=this._transport.responseText,u=this.getResponseContentType()||e;return this._parser.parse(v,u);},setParser:function(w){return this._parser.setParser(w);}}});})();(function(){var a='clui.io.Resource';qx.Class.define(a,{extend:qx.io.rest.Resource,members:{_getRequest:function(){return new clui.io.Xhr();}}});})();(function(){var a='clui.io.Xhr';qx.Class.define(a,{extend:qx.io.request.Xhr,members:{_getConfiguredUrl:function(){var b=this.getUrl(),c;if(this.getMethod() in {'GET':0,'HEAD':0}&&this.getRequestData()){c=this._serializeData(this.getRequestData());b=qx.util.Uri.appendParamsToUrl(b,c);};if(this.getCache()===false){b=qx.util.Uri.appendParamsToUrl(b,{'nocache':new Date().valueOf()});};return b;}}});})();(function(){var E="-",J=".extent,.n>rect,.s>rect",K="Q 0,0 ",M="text/csv",O="height",P="2000-01-01T00:00:00.000Z",Q="end.transition",R="G",T="C",U="beforesend",V="background",W="ne",bd='LLLL',be="Z",bf="brushstart",bj="http://www.w3.org/2000/svg",bk='["',bn="dy",bo="xmlns",bp='abbreviated',bq="opacity",bt="important",bu="range",bw=":%S",bz="%",bA="brushend",bB="saturday",bC="slice-dice",bD="<",bE="load",bF="MultiLineString",bG="hidden",bH="DIV",bI="withCredentials",bJ=".0e",bK="m0,",bL="drag.force",bM=")skewX(",bN="start.zoom",bO='Ed',bP="3.5.16",bQ="touchend.brush",bR="start",bS="dragstart",bT="mousemove.zoom",bU="number",bV="crosshair",bW="i",bX="mouseover",bY="__uB",cc="scale(",cd="p",ce="moz",cf="M0,",cg="-webkit-tap-highlight-color",ch="squarify",ci="__",cj="MozMousePixelScroll",ck=",1 ",cl="mouseup",cm=".tick",cn="OfYear",co="infinite range",cp="hsl",cq="dragend",cs="=",ct="line",cu="a",cv="transform",cA="ew-resize",cB="end",cC="keydown.brush",cD="x",cE="monday",cF="S",cG="nesw-resize",cH="rect",cI="text",cJ="zoom:zoom",cK="__transition_",cL="+",cM=",0",cN="se",cO='hm',cP="interrupt.zoom",cQ="children",cR="cursor",cS='{0} {1}',cT="skewX(",cU=".%L",cV="tick",cW="µ",cX="X",cY="string",dd="mousemove",de="userSelect",df="thursday",dg='"',dh="A",dk="LineString",dl="k",dm="http://www.w3.org/1999/xhtml",dp="start.brush",dq="H",ds='Hm',du="#",dv="mouseup.brush",dA="\n]",dB="sort",dC="%Y-%m-%dT%H:%M:%S.%LZ",dD=":",dE=".zoom",dF="rangeRound",dG="n",dH="interpolate",dI='wide',dJ="y",dK="sw",dL="friday",dM="resize",dN="x2",dO="precision",dP="Q",dQ="touchend",dR="width",dS="middle",dT="return {",dU="rgba(0,0,0,0)",dV="touchstart.drag",dW="H0V",dX="w",dY=",0)",ea="%Y",eb="on",ec="http://www.w3.org/XML/1998/namespace",ed="Y",ee="]",ef="g",eg="mousedown.drag",eh="http://www.w3.org/1999/xlink",ei="none",ej=" 0 ",ek=" 0 1,",el="brush:brush",em="mousedown.zoom",en="rangeRoundPoints",eo="in",ep="wheel",eq="style.",er="touchstart.zoom",es="dblclick.zoom",et="resize ",eu="Moz",ev=")scale(",ew='medium',ez="o",eA="translate(0,",eB="keyup.brush",eC="body",eD="display",eE="(?:^|\\s+)",eF="selectstart",eG="function",eH="mousemove.brush",eI="touchmove",eJ="^",eK="nwse-resize",eL=")",eM="onwheel",eN="mouseout",eO=".zoom-",eP="svg",eQ='kucken.lib.D3',eR="brush",eS="rangeRoundBands",eT="b",eU="O",eV="post",eW="__O",eX="ns-resize",eY="domain",fa=".dragsuppress-",fc="0",fd="error",fe="zoomstart",ff="d",fg="mousewheel",fh="onload",fi="dragstart.force",fj="sunday",fk="progress",fl="class",fn="U",fo="tuesday",fp="(?:\\s+|$)",fq="rangeBands",fr="end.brush",fs=".71em",ft="m",fu=" 0,",fv=".extent",fw="extent",fz="mouseover.force",fA="move",fB="dragend.force",fC="text/tab-separated-values",fD="wednesday",fE="circle",fF="top",fG="V",fH="path",fI="touchmove.brush",fJ="L",fK="ms",fL="click",fM="\n",fN='function',fO="e",fP="nw",fQ='MMMd',fR="rotate(",fS="|",fT="W",fU="Polygon",fV=".extent,.e>rect,.w>rect",fW="left",fX="application/json",fY=".",ga=")rotate(",gb=" 0 0,",gc=": d[",gd="rgb",ge="object",gf="interrupt",gg="__on",gh="y2",gi="attr.",gj="j",gk="zoom",gl="E",gm=".32em",gn="text/html",go="__transition__",gp="touchstart.brush",gq='',gr="http://www.w3.org/2000/xmlns/",gs="drag",gt="c",gu='""',gv="bottom",gw="0em",gx="r",gy="*",gz="zoomend",gA="rangePoints",gB=">",gC="requestAnimationFrame",gD="onmousewheel",gE="}",gF="^(?:",gG="value",gH=" ",gI="P",gJ="mouseup.zoom",gK="text-anchor",gL="T",gM="mouseout.force",gN=".drag",gO="accept",gP="auto",gQ="pointer-events",gR=".resize",gS="",gT="f",gU="visibility",gV="slice",gW="mousedown.brush",gX="end.zoom",gY="^__on([^.]+)",hd=".background",he="\x00",hf="s",hg="M",hh="get",hj="V0H",hk="$",hm="clamp",hn="dice",ho="translate(",hp=" 0 1,1 0,",hq="all",hr="webkit",ht=",*/*",hu=".domain",hv="\\$&",hw="z",hx=",.",hy="onselectstart",hz=",",hA="matchesSelector",hB="absolute";qx.Class.define(eQ,{statics:{__uz:null,__uA:null,get:function(){if(!this.__uz){this.__uz=this.__uA.call(window);};return this.__uz;},_getLocaleDefinition:function(){var hD=kucken.date.Ldml.toPosix(qx.locale.Date.getDateFormat(ew));var hC=kucken.date.Ldml.toPosix(qx.locale.Date.getTimeFormat(ew));return {'decimal':qx.locale.Number.getDecimalSeparator(),'thousands':qx.locale.Number.getGroupSeparator(),'grouping':[3],'currency':[gq,gq],'dateTime':cS.format(hD,hC),'date':hD,'time':hC,'periods':[qx.locale.Date.getAmMarker(),qx.locale.Date.getPmMarker()],'days':qx.locale.Date.getDayNames(dI),'shortDays':qx.locale.Date.getDayNames(bp),'months':qx.locale.Date.getMonthNames(dI),'shortMonths':qx.locale.Date.getMonthNames(bp)};},_getTimeScaleRangeLocaleDefinition:function(){var hE=new qx.util.format.DateFormat(bd);return [[cU,function(d){return d.getMilliseconds();}],[bw,function(d){return d.getSeconds();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(ds)),function(d){return d.getMinutes();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(cO)),function(d){return d.getHours();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(bO)),function(d){return d.getDay()&&d.getDate()!=1;}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(fQ)),function(d){return d.getDate()!=1;}],[function(d){return hE.format(d);},function(d){return d.getMonth();}],[ea,function(d){return true;}]];},_getUtcTimeScaleRangeLocaleDefinition:function(){var hF=new qx.util.format.DateFormat(bd);return [[cU,function(d){return d.getUTCMilliseconds();}],[bw,function(d){return d.getUTCSeconds();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(ds)),function(d){return d.getUTCMinutes();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(cO)),function(d){return d.getUTCHours();}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(bO)),function(d){return d.getUTCDay()&&d.getUTCDate()!=1;}],[kucken.date.Ldml.toPosix(qx.locale.Date.getDateTimeFormat(fQ)),function(d){return d.getUTCDate()!=1;}],[function(d){return hF.format(d);},function(d){return d.getUTCMonth();}],[ea,function(d){return true;}]];}}});kucken.lib.D3.__uA=function(){var d3={version:bP};var d3_arraySlice=[].slice,d3_array=function(hG){return d3_arraySlice.call(hG);};var d3_document=this.document;function d3_documentElement(hH){return hH&&(hH.ownerDocument||hH.document||hH).documentElement;};function d3_window(hI){return hI&&(hI.ownerDocument&&hI.ownerDocument.defaultView||hI.document&&hI||hI.defaultView);};if(d3_document){try{d3_array(d3_document.documentElement.childNodes)[0].nodeType;}catch(e){d3_array=function(hK){var i=hK.length,hJ=new Array(i);while(i-- )hJ[i]=hK[i];return hJ;};};};if(!Date.now)Date.now=function(){return +new Date();};if(d3_document){try{d3_document.createElement(bH).style.setProperty(bq,0,gS);}catch(hL){var d3_element_prototype=this.Element.prototype,d3_element_setAttribute=d3_element_prototype.setAttribute,d3_element_setAttributeNS=d3_element_prototype.setAttributeNS,d3_style_prototype=this.CSSStyleDeclaration.prototype,d3_style_setProperty=d3_style_prototype.setProperty;d3_element_prototype.setAttribute=function(name,hM){d3_element_setAttribute.call(this,name,hM+gS);};d3_element_prototype.setAttributeNS=function(hP,hN,hO){d3_element_setAttributeNS.call(this,hP,hN,hO+gS);};d3_style_prototype.setProperty=function(name,hR,hQ){d3_style_setProperty.call(this,name,hR+gS,hQ);};};};d3.ascending=d3_ascending;function d3_ascending(a,b){return a<b?-1:a>b?1:a>=b?0:NaN;};d3.descending=function(a,b){return b<a?-1:b>a?1:b>=a?0:NaN;};d3.min=function(hS,f){var i=-1,n=hS.length,a,b;if(arguments.length===1){while( ++i<n)if((b=hS[i])!=null&&b>=b){a=b;break;};while( ++i<n)if((b=hS[i])!=null&&a>b)a=b;}else {while( ++i<n)if((b=f.call(hS,hS[i],i))!=null&&b>=b){a=b;break;};while( ++i<n)if((b=f.call(hS,hS[i],i))!=null&&a>b)a=b;};return a;};d3.max=function(hT,f){var i=-1,n=hT.length,a,b;if(arguments.length===1){while( ++i<n)if((b=hT[i])!=null&&b>=b){a=b;break;};while( ++i<n)if((b=hT[i])!=null&&b>a)a=b;}else {while( ++i<n)if((b=f.call(hT,hT[i],i))!=null&&b>=b){a=b;break;};while( ++i<n)if((b=f.call(hT,hT[i],i))!=null&&b>a)a=b;};return a;};d3.extent=function(hU,f){var i=-1,n=hU.length,a,b,c;if(arguments.length===1){while( ++i<n)if((b=hU[i])!=null&&b>=b){a=c=b;break;};while( ++i<n)if((b=hU[i])!=null){if(a>b)a=b;if(c<b)c=b;};}else {while( ++i<n)if((b=f.call(hU,hU[i],i))!=null&&b>=b){a=c=b;break;};while( ++i<n)if((b=f.call(hU,hU[i],i))!=null){if(a>b)a=b;if(c<b)c=b;};};return [a,c];};function d3_number(x){return x===null?NaN:+x;};function d3_numeric(x){return !isNaN(x);};d3.sum=function(hV,f){var s=0,n=hV.length,a,i=-1;if(arguments.length===1){while( ++i<n)if(d3_numeric(a=+hV[i]))s+=a;}else {while( ++i<n)if(d3_numeric(a=+f.call(hV,hV[i],i)))s+=a;};return s;};d3.mean=function(hW,f){var s=0,n=hW.length,a,i=-1,j=n;if(arguments.length===1){while( ++i<n)if(d3_numeric(a=d3_number(hW[i])))s+=a;else  --j;}else {while( ++i<n)if(d3_numeric(a=d3_number(f.call(hW,hW[i],i))))s+=a;else  --j;};if(j)return s/j;};d3.quantile=function(hX,p){var H=(hX.length-1)*p+1,h=Math.floor(H),v=+hX[h-1],e=H-h;return e?v+e*(hX[h]-v):v;};d3.median=function(ia,f){var hY=[],n=ia.length,a,i=-1;if(arguments.length===1){while( ++i<n)if(d3_numeric(a=d3_number(ia[i])))hY.push(a);}else {while( ++i<n)if(d3_numeric(a=d3_number(f.call(ia,ia[i],i))))hY.push(a);};if(hY.length)return d3.quantile(hY.sort(d3_ascending),.5);};d3.variance=function(ib,f){var n=ib.length,m=0,a,d,s=0,i=-1,j=0;if(arguments.length===1){while( ++i<n){if(d3_numeric(a=d3_number(ib[i]))){d=a-m;m+=d/ ++j;s+=d*(a-m);};};}else {while( ++i<n){if(d3_numeric(a=d3_number(f.call(ib,ib[i],i)))){d=a-m;m+=d/ ++j;s+=d*(a-m);};};};if(j>1)return s/(j-1);};d3.deviation=function(){var v=d3.variance.apply(this,arguments);return v?Math.sqrt(v):v;};function d3_bisector(ic){return {left:function(a,x,ie,ig){if(arguments.length<3)ie=0;if(arguments.length<4)ig=a.length;while(ie<ig){var ih=ie+ig>>>1;if(ic(a[ih],x)<0)ie=ih+1;else ig=ih;};return ie;},right:function(a,x,ii,ij){if(arguments.length<3)ii=0;if(arguments.length<4)ij=a.length;while(ii<ij){var ik=ii+ij>>>1;if(ic(a[ik],x)>0)ij=ik;else ii=ik+1;};return ii;}};};var d3_bisect=d3_bisector(d3_ascending);d3.bisectLeft=d3_bisect.left;d3.bisect=d3.bisectRight=d3_bisect.right;d3.bisector=function(f){return d3_bisector(f.length===1?function(d,x){return d3_ascending(f(d),x);}:f);};d3.shuffle=function(io,im,il){if((m=arguments.length)<3){il=io.length;if(m<2)im=0;};var m=il-im,t,i;while(m){i=Math.random()*m-- |0;t=io[m+im],io[m+im]=io[i+im],io[i+im]=t;};return io;};d3.permute=function(ip,ir){var i=ir.length,iq=new Array(i);while(i-- )iq[i]=ip[ir[i]];return iq;};d3.pairs=function(iv){var i=0,n=iv.length-1,iu,it=iv[0],is=new Array(n<0?0:n);while(i<n)is[i]=[iu=it,it=iv[ ++i]];return is;};d3.transpose=function(iw){if(!(n=iw.length))return [];for(var i=-1,m=d3.min(iw,d3_transposeLength),ix=new Array(m); ++i<m;){for(var j=-1,n,iy=ix[i]=new Array(n); ++j<n;){iy[j]=iw[j][i];};};return ix;};function d3_transposeLength(d){return d.length;};d3.zip=function(){return d3.transpose(arguments);};d3.keys=function(iA){var iz=[];for(var iB in iA)iz.push(iB);return iz;};d3.values=function(iC){var iD=[];for(var iE in iC)iD.push(iC[iE]);return iD;};d3.entries=function(iF){var iH=[];for(var iG in iF)iH.push({key:iG,value:iF[iG]});return iH;};d3.merge=function(iI){var n=iI.length,m,i=-1,j=0,iK,iJ;while( ++i<n)j+=iI[i].length;iK=new Array(j);while( --n>=0){iJ=iI[n];m=iJ.length;while( --m>=0){iK[ --j]=iJ[m];};};return iK;};var abs=Math.abs;d3.range=function(iM,stop,iL){if(arguments.length<3){iL=1;if(arguments.length<2){stop=iM;iM=0;};};if((stop-iM)/iL===Infinity)throw new Error(co);var iN=[],k=d3_range_integerScale(abs(iL)),i=-1,j;iM*=k,stop*=k,iL*=k;if(iL<0){while((j=iM+iL* ++i)>stop)iN.push(j/k);}else {while((j=iM+iL* ++i)<stop)iN.push(j/k);};return iN;};function d3_range_integerScale(x){var k=1;while(x*k%1)k*=10;return k;};function d3_class(iQ,iO){for(var iP in iO){Object.defineProperty(iQ.prototype,iP,{value:iO[iP],enumerable:false});};};d3.map=function(iS,f){var iR=new d3_Map();if(iS instanceof d3_Map){iS.forEach(function(iU,iV){iR.set(iU,iV);});}else if(Array.isArray(iS)){var i=-1,n=iS.length,o;if(arguments.length===1){while( ++i<n)iR.set(i,iS[i]);}else {while( ++i<n)iR.set(f.call(iS,o=iS[i],i),o);};}else {for(var iT in iS)iR.set(iT,iS[iT]);};return iR;};function d3_Map(){this._=Object.create(null);};var d3_map_proto=eW,d3_map_zero=he;d3_class(d3_Map,{has:d3_map_has,get:function(iW){return this._[d3_map_escape(iW)];},set:function(iX,iY){return this._[d3_map_escape(iX)]=iY;},remove:d3_map_remove,keys:d3_map_keys,values:function(){var ja=[];for(var jb in this._)ja.push(this._[jb]);return ja;},entries:function(){var jd=[];for(var jc in this._)jd.push({key:d3_map_unescape(jc),value:this._[jc]});return jd;},size:d3_map_size,empty:d3_map_empty,forEach:function(f){for(var je in this._)f.call(this,d3_map_unescape(je),this._[je]);}});function d3_map_escape(jf){return (jf+=gS)===d3_map_proto||jf[0]===d3_map_zero?d3_map_zero+jf:jf;};function d3_map_unescape(jg){return (jg+=gS)[0]===d3_map_zero?jg.slice(1):jg;};function d3_map_has(jh){return d3_map_escape(jh) in this._;};function d3_map_remove(ji){return (ji=d3_map_escape(ji)) in this._&&delete this._[ji];};function d3_map_keys(){var jj=[];for(var jk in this._)jj.push(d3_map_unescape(jk));return jj;};function d3_map_size(){var jm=0;for(var jl in this._) ++jm;return jm;};function d3_map_empty(){for(var jn in this._)return false;return true;};d3.nest=function(){var js={},jq=[],jo=[],jt,jr;function jp(jz,jC,jx){if(jx>=jq.length)return jr?jr.call(js,jC):jt?jC.sort(jt):jC;var i=-1,n=jC.length,jA=jq[jx++ ],jy,jw,jD,jv=new d3_Map(),jB;while( ++i<n){if(jB=jv.get(jy=jA(jw=jC[i]))){jB.push(jw);}else {jv.set(jy,[jw]);};};if(jz){jw=jz();jD=function(jE,jF){jw.set(jE,jp(jz,jF,jx));};}else {jw={};jD=function(jG,jH){jw[jG]=jp(jz,jH,jx);};};jv.forEach(jD);return jw;};function ju(jI,jJ){if(jJ>=jq.length)return jI;var jK=[],jL=jo[jJ++ ];jI.forEach(function(jN,jM){jK.push({key:jN,values:ju(jM,jJ)});});return jL?jK.sort(function(a,b){return jL(a.key,b.key);}):jK;};js.map=function(jO,jP){return jp(jP,jO,0);};js.entries=function(jQ){return ju(jp(d3.map,jQ,0),0);};js.key=function(d){jq.push(d);return js;};js.sortKeys=function(jR){jo[jq.length-1]=jR;return js;};js.sortValues=function(jS){jt=jS;return js;};js.rollup=function(f){jr=f;return js;};return js;};d3.set=function(jT){var jU=new d3_Set();if(jT){for(var i=0,n=jT.length;i<n; ++i){jU.add(jT[i]);};};return jU;};function d3_Set(){this._=Object.create(null);};d3_class(d3_Set,{has:d3_map_has,add:function(jV){this._[d3_map_escape(jV+=gS)]=true;return jV;},remove:d3_map_remove,values:d3_map_keys,size:d3_map_size,empty:d3_map_empty,forEach:function(f){for(var jW in this._)f.call(this,d3_map_unescape(jW));}});d3.behavior={};function d3_identity(d){return d;};d3.rebind=function(kd,jX){var i=1,n=arguments.length,jY;while( ++i<n)kd[jY=arguments[i]]=d3_rebind(kd,jX,jX[jY]);return kd;};function d3_rebind(kf,ke,kg){return function(){var kh=kg.apply(ke,arguments);return kh===ke?kf:kh;};};function d3_vendorSymbol(ki,name){if(name in ki)return name;name=name.charAt(0).toUpperCase()+name.slice(1);for(var i=0,n=d3_vendorPrefixes.length;i<n; ++i){var kj=d3_vendorPrefixes[i]+name;if(kj in ki)return kj;};};var d3_vendorPrefixes=[hr,fK,ce,eu,ez,eU];function d3_noop(){};d3.dispatch=function(){var kk=new d3_dispatch(),i=-1,n=arguments.length;while( ++i<n)kk[arguments[i]]=d3_dispatch_event(kk);return kk;};function d3_dispatch(){};d3_dispatch.prototype.on=function(km,kl){var i=km.indexOf(fY),name=gS;if(i>=0){name=km.slice(i+1);km=km.slice(0,i);};if(km)return arguments.length<2?this[km].on(name):this[km].on(name,kl);if(arguments.length===2){if(kl==null){for(km in this){if(this.hasOwnProperty(km)){this[km].on(name,null);};};};return this;};};function d3_dispatch_event(kp){var kn=[],ko=new d3_Map();function event(){var z=kn,i=-1,n=z.length,l;while( ++i<n)if(l=z[i].on)l.apply(this,arguments);return kp;};event.on=function(name,kq){var l=ko.get(name),i;if(arguments.length<2)return l&&l.on;if(l){l.on=null;kn=kn.slice(0,i=kn.indexOf(l)).concat(kn.slice(i+1));ko.remove(name);};if(kq)kn.push(ko.set(name,{on:kq}));return kp;};return event;};d3.event=null;function d3_eventPreventDefault(){d3.event.preventDefault();};function d3_eventSource(){var e=d3.event,s;while(s=e.sourceEvent)e=s;return e;};function d3_eventDispatch(kr){var ks=new d3_dispatch(),i=0,n=arguments.length;while( ++i<n)ks[arguments[i]]=d3_dispatch_event(ks);ks.of=function(kt,ku){return function(kv){try{var kw=kv.sourceEvent=d3.event;kv.target=kr;d3.event=kv;ks[kv.type].apply(kt,ku);}finally{d3.event=kw;};};};return ks;};d3.requote=function(s){return s.replace(d3_requote_re,hv);};var d3_requote_re=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g;var d3_subclass={}.__O?function(kB,kA){kB.__O=kA;}:function(kE,kC){for(var kD in kC)kE[kD]=kC[kD];};function d3_selection(kF){d3_subclass(kF,d3_selectionPrototype);return kF;};var d3_select=function(s,n){return n.querySelector(s);},d3_selectAll=function(s,n){return n.querySelectorAll(s);},d3_selectMatches=function(n,s){var kG=n.matches||n[d3_vendorSymbol(n,hA)];d3_selectMatches=function(n,s){return kG.call(n,s);};return d3_selectMatches(n,s);};if(typeof Sizzle===eG){d3_select=function(s,n){return Sizzle(s,n)[0]||null;};d3_selectAll=Sizzle;d3_selectMatches=Sizzle.matchesSelector;};d3.selection=function(){return d3.select(d3_document.documentElement);};var d3_selectionPrototype=d3.selection.prototype=[];d3_selectionPrototype.select=function(kJ){var kK=[],kM,kL,kI,kH;kJ=d3_selection_selector(kJ);for(var j=-1,m=this.length; ++j<m;){kK.push(kM=[]);kM.parentNode=(kI=this[j]).parentNode;for(var i=-1,n=kI.length; ++i<n;){if(kH=kI[i]){kM.push(kL=kJ.call(kH,kH.__uB,i,j));if(kL&&bY in kH)kL.__uB=kH.__uB;}else {kM.push(null);};};};return d3_selection(kK);};function d3_selection_selector(kN){return typeof kN===eG?kN:function(){return d3_select(kN,this);};};d3_selectionPrototype.selectAll=function(kQ){var kR=[],kS,kO;kQ=d3_selection_selectorAll(kQ);for(var j=-1,m=this.length; ++j<m;){for(var kP=this[j],i=-1,n=kP.length; ++i<n;){if(kO=kP[i]){kR.push(kS=d3_array(kQ.call(kO,kO.__uB,i,j)));kS.parentNode=kO;};};};return d3_selection(kR);};function d3_selection_selectorAll(kT){return typeof kT===eG?kT:function(){return d3_selectAll(kT,this);};};var d3_nsXhtml=dm;var d3_nsPrefix={svg:bj,xhtml:d3_nsXhtml,xlink:eh,xml:ec,xmlns:gr};d3.ns={prefix:d3_nsPrefix,qualify:function(name){var i=name.indexOf(dD),kU=name;if(i>=0&&(kU=name.slice(0,i))!==bo)name=name.slice(i+1);return d3_nsPrefix.hasOwnProperty(kU)?{space:d3_nsPrefix[kU],local:name}:name;}};d3_selectionPrototype.attr=function(name,kW){if(arguments.length<2){if(typeof name===cY){var kV=this.node();name=d3.ns.qualify(name);return name.local?kV.getAttributeNS(name.space,name.local):kV.getAttribute(name);};for(kW in name)this.each(d3_selection_attr(kW,name[kW]));return this;};return this.each(d3_selection_attr(name,kW));};function d3_selection_attr(name,la){name=d3.ns.qualify(name);function kY(){this.removeAttribute(name);};function kX(){this.removeAttributeNS(name.space,name.local);};function ld(){this.setAttribute(name,la);};function le(){this.setAttributeNS(name.space,name.local,la);};function lb(){var x=la.apply(this,arguments);if(x==null)this.removeAttribute(name);else this.setAttribute(name,x);};function lf(){var x=la.apply(this,arguments);if(x==null)this.removeAttributeNS(name.space,name.local);else this.setAttributeNS(name.space,name.local,x);};return la==null?name.local?kX:kY:typeof la===eG?name.local?lf:lb:name.local?le:ld;};function d3_collapse(s){return s.trim().replace(/\s+/g,gH);};d3_selectionPrototype.classed=function(name,lh){if(arguments.length<2){if(typeof name===cY){var lg=this.node(),n=(name=d3_selection_classes(name)).length,i=-1;if(lh=lg.classList){while( ++i<n)if(!lh.contains(name[i]))return false;}else {lh=lg.getAttribute(fl);while( ++i<n)if(!d3_selection_classedRe(name[i]).test(lh))return false;};return true;};for(lh in name)this.each(d3_selection_classed(lh,name[lh]));return this;};return this.each(d3_selection_classed(name,lh));};function d3_selection_classedRe(name){return new RegExp(eE+d3.requote(name)+fp,ef);};function d3_selection_classes(name){return (name+gS).trim().split(/^|\s+/);};function d3_selection_classed(name,lk){name=d3_selection_classes(name).map(d3_selection_classedName);var n=name.length;function lj(){var i=-1;while( ++i<n)name[i](this,lk);};function li(){var i=-1,x=lk.apply(this,arguments);while( ++i<n)name[i](this,x);};return typeof lk===eG?li:lj;};function d3_selection_classedName(name){var ll=d3_selection_classedRe(name);return function(lm,ln){if(c=lm.classList)return ln?c.add(name):c.remove(name);var c=lm.getAttribute(fl)||gS;if(ln){ll.lastIndex=0;if(!ll.test(c))lm.setAttribute(fl,d3_collapse(c+gH+name));}else {lm.setAttribute(fl,d3_collapse(c.replace(ll,gH)));};};};d3_selectionPrototype.style=function(name,ls,lr){var n=arguments.length;if(n<3){if(typeof name!==cY){if(n<2)ls=gS;for(lr in name)this.each(d3_selection_style(lr,name[lr],ls));return this;};if(n<2){var lq=this.node();return d3_window(lq).getComputedStyle(lq,null).getPropertyValue(name);};lr=gS;};return this.each(d3_selection_style(name,ls,lr));};function d3_selection_style(name,lt,lu){function lz(){this.style.removeProperty(name);};function lw(){this.style.setProperty(name,lt,lu);};function lv(){var x=lt.apply(this,arguments);if(x==null)this.style.removeProperty(name);else this.style.setProperty(name,x,lu);};return lt==null?lz:typeof lt===eG?lv:lw;};d3_selectionPrototype.property=function(name,lA){if(arguments.length<2){if(typeof name===cY)return this.node()[name];for(lA in name)this.each(d3_selection_property(lA,name[lA]));return this;};return this.each(d3_selection_property(name,lA));};function d3_selection_property(name,lD){function lC(){delete this[name];};function lB(){this[name]=lD;};function lE(){var x=lD.apply(this,arguments);if(x==null)delete this[name];else this[name]=x;};return lD==null?lC:typeof lD===eG?lE:lB;};d3_selectionPrototype.text=function(lF){return arguments.length?this.each(typeof lF===eG?function(){var v=lF.apply(this,arguments);this.textContent=v==null?gS:v;}:lF==null?function(){this.textContent=gS;}:function(){this.textContent=lF;}):this.node().textContent;};d3_selectionPrototype.html=function(lG){return arguments.length?this.each(typeof lG===eG?function(){var v=lG.apply(this,arguments);this.innerHTML=v==null?gS:v;}:lG==null?function(){this.innerHTML=gS;}:function(){this.innerHTML=lG;}):this.node().innerHTML;};d3_selectionPrototype.append=function(name){name=d3_selection_creator(name);return this.select(function(){return this.appendChild(name.apply(this,arguments));});};function d3_selection_creator(name){function lH(){var document=this.ownerDocument,lJ=this.namespaceURI;return lJ===d3_nsXhtml&&document.documentElement.namespaceURI===d3_nsXhtml?document.createElement(name):document.createElementNS(lJ,name);};function lI(){return this.ownerDocument.createElementNS(name.space,name.local);};return typeof name===eG?name:(name=d3.ns.qualify(name)).local?lI:lH;};d3_selectionPrototype.insert=function(name,lK){name=d3_selection_creator(name);lK=d3_selection_selector(lK);return this.select(function(){return this.insertBefore(name.apply(this,arguments),lK.apply(this,arguments)||null);});};d3_selectionPrototype.remove=function(){return this.each(d3_selectionRemove);};function d3_selectionRemove(){var parent=this.parentNode;if(parent)parent.removeChild(this);};d3_selectionPrototype.data=function(lP,lR){var i=-1,n=this.length,lM,lL;if(!arguments.length){lP=new Array(n=(lM=this[0]).length);while( ++i<n){if(lL=lM[i]){lP[i]=lL.__uB;};};return lP;};function lN(lU,lY){var i,n=lU.length,m=lY.length,mc=Math.min(n,m),ma=new Array(m),me=new Array(m),lW=new Array(n),lT,mb;if(lR){var lV=new d3_Map(),lX=new Array(n),md;for(i=-1; ++i<n;){if(lT=lU[i]){if(lV.has(md=lR.call(lT,lT.__uB,i))){lW[i]=lT;}else {lV.set(md,lT);};lX[i]=md;};};for(i=-1; ++i<m;){if(!(lT=lV.get(md=lR.call(lY,mb=lY[i],i)))){me[i]=d3_selection_dataNode(mb);}else if(lT!==true){ma[i]=lT;lT.__uB=mb;};lV.set(md,true);};for(i=-1; ++i<n;){if(i in lX&&lV.get(lX[i])!==true){lW[i]=lU[i];};};}else {for(i=-1; ++i<mc;){lT=lU[i];mb=lY[i];if(lT){lT.__uB=mb;ma[i]=lT;}else {me[i]=d3_selection_dataNode(mb);};};for(;i<m; ++i){me[i]=d3_selection_dataNode(lY[i]);};for(;i<n; ++i){lW[i]=lU[i];};};me.update=ma;me.parentNode=ma.parentNode=lW.parentNode=lU.parentNode;lS.push(me);lO.push(ma);lQ.push(lW);};var lS=d3_selection_enter([]),lO=d3_selection([]),lQ=d3_selection([]);if(typeof lP===eG){while( ++i<n){lN(lM=this[i],lP.call(lM,lM.parentNode.__uB,i));};}else {while( ++i<n){lN(lM=this[i],lP);};};lO.enter=function(){return lS;};lO.exit=function(){return lQ;};return lO;};function d3_selection_dataNode(mf){return {__uB:mf};};d3_selectionPrototype.datum=function(mg){return arguments.length?this.property(bY,mg):this.property(bY);};d3_selectionPrototype.filter=function(mj){var ml=[],mk,mi,mh;if(typeof mj!==eG)mj=d3_selection_filter(mj);for(var j=0,m=this.length;j<m;j++ ){ml.push(mk=[]);mk.parentNode=(mi=this[j]).parentNode;for(var i=0,n=mi.length;i<n;i++ ){if((mh=mi[i])&&mj.call(mh,mh.__uB,i,j)){mk.push(mh);};};};return d3_selection(ml);};function d3_selection_filter(mm){return function(){return d3_selectMatches(this,mm);};};d3_selectionPrototype.order=function(){for(var j=-1,m=this.length; ++j<m;){for(var mo=this[j],i=mo.length-1,mp=mo[i],mn; --i>=0;){if(mn=mo[i]){if(mp&&mp!==mn.nextSibling)mp.parentNode.insertBefore(mn,mp);mp=mn;};};};return this;};d3_selectionPrototype.sort=function(mq){mq=d3_selection_sortComparator.apply(this,arguments);for(var j=-1,m=this.length; ++j<m;)this[j].sort(mq);return this.order();};function d3_selection_sortComparator(mr){if(!arguments.length)mr=d3_ascending;return function(a,b){return a&&b?mr(a.__uB,b.__uB):!a-!b;};};d3_selectionPrototype.each=function(ms){return d3_selection_each(this,function(mt,i,j){ms.call(mt,mt.__uB,i,j);});};function d3_selection_each(mx,mw){for(var j=0,m=mx.length;j<m;j++ ){for(var mv=mx[j],i=0,n=mv.length,mu;i<n;i++ ){if(mu=mv[i])mw(mu,i,j);};};return mx;};d3_selectionPrototype.call=function(my){var mz=d3_array(arguments);my.apply(mz[0]=this,mz);return this;};d3_selectionPrototype.empty=function(){return !this.node();};d3_selectionPrototype.node=function(){for(var j=0,m=this.length;j<m;j++ ){for(var mB=this[j],i=0,n=mB.length;i<n;i++ ){var mA=mB[i];if(mA)return mA;};};return null;};d3_selectionPrototype.size=function(){var n=0;d3_selection_each(this,function(){ ++n;});return n;};function d3_selection_enter(mC){d3_subclass(mC,d3_selection_enterPrototype);return mC;};var d3_selection_enterPrototype=[];d3.selection.enter=d3_selection_enter;d3.selection.enter.prototype=d3_selection_enterPrototype;d3_selection_enterPrototype.append=d3_selectionPrototype.append;d3_selection_enterPrototype.empty=d3_selectionPrototype.empty;d3_selection_enterPrototype.node=d3_selectionPrototype.node;d3_selection_enterPrototype.call=d3_selectionPrototype.call;d3_selection_enterPrototype.size=d3_selectionPrototype.size;d3_selection_enterPrototype.select=function(mG){var mH=[],mJ,mI,mE,mF,mD;for(var j=-1,m=this.length; ++j<m;){mE=(mF=this[j]).update;mH.push(mJ=[]);mJ.parentNode=mF.parentNode;for(var i=-1,n=mF.length; ++i<n;){if(mD=mF[i]){mJ.push(mE[i]=mI=mG.call(mF.parentNode,mD.__uB,i,j));mI.__uB=mD.__uB;}else {mJ.push(null);};};};return d3_selection(mH);};d3_selection_enterPrototype.insert=function(name,mK){if(arguments.length<2)mK=d3_selection_enterInsertBefore(this);return d3_selectionPrototype.insert.call(this,name,mK);};function d3_selection_enterInsertBefore(mN){var mL,mM;return function(d,i,j){var mP=mN[j].update,n=mP.length,mO;if(j!=mM)mM=j,mL=0;if(i>=mL)mL=i+1;while(!(mO=mP[mL])&& ++mL<n);return mO;};};d3.select=function(mQ){var mR;if(typeof mQ===cY){mR=[d3_select(mQ,d3_document)];mR.parentNode=d3_document.documentElement;}else {mR=[mQ];mR.parentNode=d3_documentElement(mQ);};return d3_selection([mR]);};d3.selectAll=function(mS){var mT;if(typeof mS===cY){mT=d3_array(d3_selectAll(mS,d3_document));mT.parentNode=d3_document.documentElement;}else {mT=d3_array(mS);mT.parentNode=null;};return d3_selection([mT]);};d3_selectionPrototype.on=function(mW,mU,mV){var n=arguments.length;if(n<3){if(typeof mW!==cY){if(n<2)mU=false;for(mV in mW)this.each(d3_selection_on(mV,mW[mV],mU));return this;};if(n<2)return (n=this.node()[gg+mW])&&n._;mV=false;};return this.each(d3_selection_on(mW,mU,mV));};function d3_selection_on(ng,nc,mX){var name=gg+ng,i=ng.indexOf(fY),nf=d3_selection_onListener;if(i>0)ng=ng.slice(0,i);var nh=d3_selection_onFilters.get(ng);if(nh)ng=nh,nf=d3_selection_onFilter;function mY(){var l=this[name];if(l){this.removeEventListener(ng,l,l.$);delete this[name];};};function ne(){var l=nf(nc,d3_array(arguments));mY.call(this);this.addEventListener(ng,this[name]=l,l.$=mX);l._=nc;};function nd(){var ni=new RegExp(gY+d3.requote(ng)+hk),nj;for(var name in this){if(nj=name.match(ni)){var l=this[name];this.removeEventListener(nj[1],l,l.$);delete this[name];};};};return i?nc?ne:mY:nc?d3_noop:nd;};var d3_selection_onFilters=d3.map({mouseenter:bX,mouseleave:eN});if(d3_document){d3_selection_onFilters.forEach(function(k){if(eb+k in d3_document)d3_selection_onFilters.remove(k);});};function d3_selection_onListener(nk,nl){return function(e){var o=d3.event;d3.event=e;nl[0]=this.__uB;try{nk.apply(this,nl);}finally{d3.event=o;};};};function d3_selection_onFilter(nm,nn){var l=d3_selection_onListener(nm,nn);return function(e){var no=this,np=e.relatedTarget;if(!np||np!==no&&!(np.compareDocumentPosition(no)&8)){l.call(no,e);};};};var d3_event_dragSelect,d3_event_dragId=0;function d3_event_dragSuppress(nq){var name=fa+( ++d3_event_dragId),nt=fL+name,w=d3.select(d3_window(nq)).on(eI+name,d3_eventPreventDefault).on(bS+name,d3_eventPreventDefault).on(eF+name,d3_eventPreventDefault);if(d3_event_dragSelect==null){d3_event_dragSelect=hy in nq?false:d3_vendorSymbol(nq.style,de);};if(d3_event_dragSelect){var nr=d3_documentElement(nq).style,nu=nr[d3_event_dragSelect];nr[d3_event_dragSelect]=ei;};return function(nv){w.on(name,null);if(d3_event_dragSelect)nr[d3_event_dragSelect]=nu;if(nv){var nw=function(){w.on(nt,null);};w.on(nt,function(){d3_eventPreventDefault();nw();},true);setTimeout(nw,0);};};};d3.mouse=function(nz){return d3_mousePoint(nz,d3_eventSource());};var d3_mouse_bug44083=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function d3_mousePoint(nA,e){if(e.changedTouches)e=e.changedTouches[0];var nC=nA.ownerSVGElement||nA;if(nC.createSVGPoint){var nB=nC.createSVGPoint();if(d3_mouse_bug44083<0){var window=d3_window(nA);if(window.scrollX||window.scrollY){nC=d3.select(eC).append(eP).style({position:hB,top:0,left:0,margin:0,padding:0,border:ei},bt);var nD=nC[0][0].getScreenCTM();d3_mouse_bug44083=!(nD.f||nD.e);nC.remove();};};if(d3_mouse_bug44083)nB.x=e.pageX,nB.y=e.pageY;else nB.x=e.clientX,nB.y=e.clientY;nB=nB.matrixTransform(nA.getScreenCTM().inverse());return [nB.x,nB.y];};var nE=nA.getBoundingClientRect();return [e.clientX-nE.left-nA.clientLeft,e.clientY-nE.top-nA.clientTop];};d3.touch=function(nG,nF,nI){if(arguments.length<3){nI=nF,nF=d3_eventSource().changedTouches;};if(nF){for(var i=0,n=nF.length,nH;i<n; ++i){if((nH=nF[i]).identifier===nI){return d3_mousePoint(nG,nH);};};};};d3.behavior.drag=function(){var event=d3_eventDispatch(nL,gs,bS,cq),nJ=null,nM=nN(d3_noop,d3.mouse,d3_window,dd,cl),nK=nN(d3_behavior_dragTouchId,d3.touch,d3_identity,eI,dQ);function nL(){this.on(eg,nM).on(dV,nK);};function nN(nR,nO,nS,nP,nQ){return function(){var nV=this,nU=d3.event.target.correspondingElement||d3.event.target,parent=nV.parentNode,ob=event.of(nV,arguments),og=0,nT=nR(),nX=gN+(nT==null?gS:E+nT),oa,of=d3.select(nS(nU)).on(nP+nX,nY).on(nQ+nX,od),oe=d3_event_dragSuppress(nU),nW=nO(parent,nT);if(nJ){oa=nJ.apply(nV,arguments);oa=[oa.x-nW[0],oa.y-nW[1]];}else {oa=[0,0];};ob({type:bS});function nY(){var oh=nO(parent,nT),oi,oj;if(!oh)return;oi=oh[0]-nW[0];oj=oh[1]-nW[1];og|=oi|oj;nW=oh;ob({type:gs,x:oh[0]+oa[0],y:oh[1]+oa[1],dx:oi,dy:oj});};function od(){if(!nO(parent,nT))return;of.on(nP+nX,null).on(nQ+nX,null);oe(og);ob({type:cq});};};};nL.origin=function(x){if(!arguments.length)return nJ;nJ=x;return nL;};return d3.rebind(nL,event,eb);};function d3_behavior_dragTouchId(){return d3.event.changedTouches[0].identifier;};d3.touches=function(ol,ok){if(arguments.length<2)ok=d3_eventSource().touches;return ok?d3_array(ok).map(function(om){var on=d3_mousePoint(ol,om);on.identifier=om.identifier;return on;}):[];};var ε=1e-6,ε2=ε*ε,π=Math.PI,τ=2*π,τε=τ-ε,halfπ=π/2,d3_radians=π/180,d3_degrees=180/π;function d3_sgn(x){return x>0?1:x<0?-1:0;};function d3_cross2d(a,b,c){return (b[0]-a[0])*(c[1]-a[1])-(b[1]-a[1])*(c[0]-a[0]);};function d3_acos(x){return x>1?0:x<-1?π:Math.acos(x);};function d3_asin(x){return x>1?halfπ:x<-1?-halfπ:Math.asin(x);};function d3_sinh(x){return ((x=Math.exp(x))-1/x)/2;};function d3_cosh(x){return ((x=Math.exp(x))+1/x)/2;};function d3_tanh(x){return ((x=Math.exp(2*x))-1)/(x+1);};function d3_haversin(x){return (x=Math.sin(x/2))*x;};var ρ=Math.SQRT2,ρ2=2,ρ4=4;d3.interpolateZoom=function(oq,or){var ou=oq[0],op=oq[1],ow=oq[2],ov=or[0],oo=or[1],oE=or[2],oB=ov-ou,oC=oo-op,oD=oB*oB+oC*oC,i,S;if(oD<ε2){S=Math.log(oE/ow)/ρ;i=function(t){return [ou+t*oB,op+t*oC,ow*Math.exp(ρ*t*S)];};}else {var oF=Math.sqrt(oD),oz=(oE*oE-ow*ow+ρ4*oD)/(2*ow*ρ2*oF),oA=(oE*oE-ow*ow-ρ4*oD)/(2*oE*ρ2*oF),os=Math.log(Math.sqrt(oz*oz+1)-oz),ot=Math.log(Math.sqrt(oA*oA+1)-oA);S=(ot-os)/ρ;i=function(t){var s=t*S,oG=d3_cosh(os),u=ow/(ρ2*oF)*(oG*d3_tanh(ρ*s+os)-d3_sinh(os));return [ou+u*oB,op+u*oC,ow*oG/d3_cosh(ρ*s+os)];};};i.duration=S*1e3;return i;};d3.behavior.zoom=function(){var pp={x:0,y:0,k:1},oW,ph,pj,oR=[960,500],oS=d3_behavior_zoomInfinity,oN=250,pk=0,pe=em,pd=bT,oL=gJ,pn,oV=er,pl,event=d3_eventDispatch(pm,fe,gk,gz),pf,pg,oP,oO;if(!d3_behavior_zoomWheel){d3_behavior_zoomWheel=eM in d3_document?(d3_behavior_zoomDelta=function(){return -d3.event.deltaY*(d3.event.deltaMode?120:1);},ep):gD in d3_document?(d3_behavior_zoomDelta=function(){return d3.event.wheelDelta;},fg):(d3_behavior_zoomDelta=function(){return -d3.event.detail;},cj);};function pm(g){g.on(pe,po).on(d3_behavior_zoomWheel+dE,oH).on(es,oY).on(oV,oM);};pm.event=function(g){g.each(function(){var pr=event.of(this,arguments),pq=pp;if(d3_transitionInheritId){d3.select(this).transition().each(bN,function(){pp=this.__uC||{x:0,y:0,k:1};oK(pr);}).tween(cJ,function(){var pu=oR[0],pv=oR[1],pt=ph?ph[0]:pu/2,ps=ph?ph[1]:pv/2,i=d3.interpolateZoom([(pt-pp.x)/pp.k,(ps-pp.y)/pp.k,pu/pp.k],[(pt-pq.x)/pq.k,(ps-pq.y)/pq.k,pu/pq.k]);return function(t){var l=i(t),k=pu/l[2];this.__uC=pp={x:pt-l[0]*k,y:ps-l[1]*k,k:k};oX(pr);};}).each(cP,function(){oJ(pr);}).each(gX,function(){oJ(pr);});}else {this.__uC=pp;oK(pr);oX(pr);oJ(pr);};});};pm.translate=function(_){if(!arguments.length)return [pp.x,pp.y];pp={x:+_[0],y:+_[1],k:pp.k};pc();return pm;};pm.scale=function(_){if(!arguments.length)return pp.k;pp={x:pp.x,y:pp.y,k:null};oQ(+_);pc();return pm;};pm.scaleExtent=function(_){if(!arguments.length)return oS;oS=_==null?d3_behavior_zoomInfinity:[+_[0],+_[1]];return pm;};pm.center=function(_){if(!arguments.length)return pj;pj=_&&[+_[0],+_[1]];return pm;};pm.size=function(_){if(!arguments.length)return oR;oR=_&&[+_[0],+_[1]];return pm;};pm.duration=function(_){if(!arguments.length)return oN;oN=+_;return pm;};pm.x=function(z){if(!arguments.length)return pg;pg=z;pf=z.copy();pp={x:0,y:0,k:1};return pm;};pm.y=function(z){if(!arguments.length)return oO;oO=z;oP=z.copy();pp={x:0,y:0,k:1};return pm;};function location(p){return [(p[0]-pp.x)/pp.k,(p[1]-pp.y)/pp.k];};function oI(l){return [l[0]*pp.k+pp.x,l[1]*pp.k+pp.y];};function oQ(s){pp.k=Math.max(oS[0],Math.min(oS[1],s));};function oT(p,l){l=oI(l);pp.x+=p[0]-l[0];pp.y+=p[1]-l[1];};function oU(pw,p,l,k){pw.__uC={x:pp.x,y:pp.y,k:pp.k};oQ(Math.pow(2,k));oT(ph=p,l);pw=d3.select(pw);if(oN>0)pw=pw.transition().duration(oN);pw.call(pm.event);};function pc(){if(pg)pg.domain(pf.range().map(function(x){return (x-pp.x)/pp.k;}).map(pf.invert));if(oO)oO.domain(oP.range().map(function(y){return (y-pp.y)/pp.k;}).map(oP.invert));};function oK(pz){if(!pk++ )pz({type:fe});};function oX(pA){pc();pA({type:gk,scale:pp.k,translate:[pp.x,pp.y]});};function oJ(pB){if(! --pk)pB({type:gz}),ph=null;};function po(){var pD=this,pF=event.of(pD,arguments),pI=0,pJ=d3.select(d3_window(pD)).on(pd,pE).on(oL,pG),pH=location(d3.mouse(pD)),pC=d3_event_dragSuppress(pD);d3_selection_interrupt.call(pD);oK(pF);function pE(){pI=1;oT(d3.mouse(pD),pH);oX(pF);};function pG(){pJ.on(pd,null).on(oL,null);pC(pI);oJ(pF);};};function oM(){var pO=this,pR=event.of(pO,arguments),pV={},pL=0,pN,pS=eO+d3.event.changedTouches[0].identifier,pT=eI+pS,pK=dQ+pS,pX=[],pY=d3.select(pO),pM=d3_event_dragSuppress(pO);pP();oK(pR);pY.on(pe,null).on(oV,pP);function pW(){var qa=d3.touches(pO);pN=pp.k;qa.forEach(function(t){if(t.identifier in pV)pV[t.identifier]=location(t);});return qa;};function pP(){var qc=d3.event.target;d3.select(qc).on(pT,pQ).on(pK,pU);pX.push(qc);var qd=d3.event.changedTouches;for(var i=0,n=qd.length;i<n; ++i){pV[qd[i].identifier]=null;};var qb=pW(),qg=Date.now();if(qb.length===1){if(qg-pl<500){var p=qb[0];oU(pO,p,pV[p.identifier],Math.floor(Math.log(pp.k)/Math.LN2)+1);d3_eventPreventDefault();};pl=qg;}else if(qb.length>1){var p=qb[0],q=qb[1],qe=p[0]-q[0],qf=p[1]-q[1];pL=qe*qe+qf*qf;};};function pQ(){var qh=d3.touches(pO),qk,qm,qi,qn;d3_selection_interrupt.call(pO);for(var i=0,n=qh.length;i<n; ++i,qn=null){qi=qh[i];if(qn=pV[qi.identifier]){if(qm)break;qk=qi,qm=qn;};};if(qn){var ql=(ql=qi[0]-qk[0])*ql+(ql=qi[1]-qk[1])*ql,qj=pL&&Math.sqrt(ql/pL);qk=[(qk[0]+qi[0])/2,(qk[1]+qi[1])/2];qm=[(qm[0]+qn[0])/2,(qm[1]+qn[1])/2];oQ(qj*pN);};pl=null;oT(qk,qm);oX(pR);};function pU(){if(d3.event.touches.length){var qo=d3.event.changedTouches;for(var i=0,n=qo.length;i<n; ++i){delete pV[qo[i].identifier];};for(var qp in pV){return void pW();};};d3.selectAll(pX).on(pS,null);pY.on(pe,po).on(oV,oM);pM();oJ(pR);};};function oH(){var qq=event.of(this,arguments);if(pn)clearTimeout(pn);else d3_selection_interrupt.call(this),oW=location(ph=pj||d3.mouse(this)),oK(qq);pn=setTimeout(function(){pn=null;oJ(qq);},50);d3_eventPreventDefault();oQ(Math.pow(2,d3_behavior_zoomDelta()*.002)*pp.k);oT(ph,oW);oX(qq);};function oY(){var p=d3.mouse(this),k=Math.log(pp.k)/Math.LN2;oU(this,p,location(p),d3.event.shiftKey?Math.ceil(k)-1:Math.floor(k)+1);};return d3.rebind(pm,event,eb);};var d3_behavior_zoomInfinity=[0,Infinity],d3_behavior_zoomDelta,d3_behavior_zoomWheel;d3.color=d3_color;function d3_color(){};d3_color.prototype.toString=function(){return this.rgb()+gS;};d3.hsl=d3_hsl;function d3_hsl(h,s,l){return this instanceof d3_hsl?void (this.h=+h,this.s=+s,this.l=+l):arguments.length<2?h instanceof d3_hsl?new d3_hsl(h.h,h.s,h.l):d3_rgb_parse(gS+h,d3_rgb_hsl,d3_hsl):new d3_hsl(h,s,l);};var d3_hslPrototype=d3_hsl.prototype=new d3_color();d3_hslPrototype.brighter=function(k){k=Math.pow(.7,arguments.length?k:1);return new d3_hsl(this.h,this.s,this.l/k);};d3_hslPrototype.darker=function(k){k=Math.pow(.7,arguments.length?k:1);return new d3_hsl(this.h,this.s,k*this.l);};d3_hslPrototype.rgb=function(){return d3_hsl_rgb(this.h,this.s,this.l);};function d3_hsl_rgb(h,s,l){var qs,qr;h=isNaN(h)?0:(h%=360)<0?h+360:h;s=isNaN(s)?0:s<0?0:s>1?1:s;l=l<0?0:l>1?1:l;qr=l<=.5?l*(1+s):l+s-l*s;qs=2*l-qr;function v(h){if(h>360)h-=360;else if(h<0)h+=360;if(h<60)return qs+(qr-qs)*h/60;if(h<180)return qr;if(h<240)return qs+(qr-qs)*(240-h)/60;return qs;};function qt(h){return Math.round(v(h)*255);};return new d3_rgb(qt(h+120),qt(h),qt(h-120));};d3.hcl=d3_hcl;function d3_hcl(h,c,l){return this instanceof d3_hcl?void (this.h=+h,this.c=+c,this.l=+l):arguments.length<2?h instanceof d3_hcl?new d3_hcl(h.h,h.c,h.l):h instanceof d3_lab?d3_lab_hcl(h.l,h.a,h.b):d3_lab_hcl((h=d3_rgb_lab((h=d3.rgb(h)).r,h.g,h.b)).l,h.a,h.b):new d3_hcl(h,c,l);};var d3_hclPrototype=d3_hcl.prototype=new d3_color();d3_hclPrototype.brighter=function(k){return new d3_hcl(this.h,this.c,Math.min(100,this.l+d3_lab_K*(arguments.length?k:1)));};d3_hclPrototype.darker=function(k){return new d3_hcl(this.h,this.c,Math.max(0,this.l-d3_lab_K*(arguments.length?k:1)));};d3_hclPrototype.rgb=function(){return d3_hcl_lab(this.h,this.c,this.l).rgb();};function d3_hcl_lab(h,c,l){if(isNaN(h))h=0;if(isNaN(c))c=0;return new d3_lab(l,Math.cos(h*=d3_radians)*c,Math.sin(h)*c);};d3.lab=d3_lab;function d3_lab(l,a,b){return this instanceof d3_lab?void (this.l=+l,this.a=+a,this.b=+b):arguments.length<2?l instanceof d3_lab?new d3_lab(l.l,l.a,l.b):l instanceof d3_hcl?d3_hcl_lab(l.h,l.c,l.l):d3_rgb_lab((l=d3_rgb(l)).r,l.g,l.b):new d3_lab(l,a,b);};var d3_lab_K=18;var d3_lab_X=.95047,d3_lab_Y=1,d3_lab_Z=1.08883;var d3_labPrototype=d3_lab.prototype=new d3_color();d3_labPrototype.brighter=function(k){return new d3_lab(Math.min(100,this.l+d3_lab_K*(arguments.length?k:1)),this.a,this.b);};d3_labPrototype.darker=function(k){return new d3_lab(Math.max(0,this.l-d3_lab_K*(arguments.length?k:1)),this.a,this.b);};d3_labPrototype.rgb=function(){return d3_lab_rgb(this.l,this.a,this.b);};function d3_lab_rgb(l,a,b){var y=(l+16)/116,x=y+a/500,z=y-b/200;x=d3_lab_xyz(x)*d3_lab_X;y=d3_lab_xyz(y)*d3_lab_Y;z=d3_lab_xyz(z)*d3_lab_Z;return new d3_rgb(d3_xyz_rgb(3.2404542*x-1.5371385*y-.4985314*z),d3_xyz_rgb(-.969266*x+1.8760108*y+.041556*z),d3_xyz_rgb(.0556434*x-.2040259*y+1.0572252*z));};function d3_lab_hcl(l,a,b){return l>0?new d3_hcl(Math.atan2(b,a)*d3_degrees,Math.sqrt(a*a+b*b),l):new d3_hcl(NaN,NaN,l);};function d3_lab_xyz(x){return x>.206893034?x*x*x:(x-4/29)/7.787037;};function d3_xyz_lab(x){return x>.008856?Math.pow(x,1/3):7.787037*x+4/29;};function d3_xyz_rgb(r){return Math.round(255*(r<=.00304?12.92*r:1.055*Math.pow(r,1/2.4)-.055));};d3.rgb=d3_rgb;function d3_rgb(r,g,b){return this instanceof d3_rgb?void (this.r=~~r,this.g=~~g,this.b=~~b):arguments.length<2?r instanceof d3_rgb?new d3_rgb(r.r,r.g,r.b):d3_rgb_parse(gS+r,d3_rgb,d3_hsl_rgb):new d3_rgb(r,g,b);};function d3_rgbNumber(qu){return new d3_rgb(qu>>16,qu>>8&255,qu&255);};function d3_rgbString(qv){return d3_rgbNumber(qv)+gS;};var d3_rgbPrototype=d3_rgb.prototype=new d3_color();d3_rgbPrototype.brighter=function(k){k=Math.pow(.7,arguments.length?k:1);var r=this.r,g=this.g,b=this.b,i=30;if(!r&&!g&&!b)return new d3_rgb(i,i,i);if(r&&r<i)r=i;if(g&&g<i)g=i;if(b&&b<i)b=i;return new d3_rgb(Math.min(255,r/k),Math.min(255,g/k),Math.min(255,b/k));};d3_rgbPrototype.darker=function(k){k=Math.pow(.7,arguments.length?k:1);return new d3_rgb(k*this.r,k*this.g,k*this.b);};d3_rgbPrototype.hsl=function(){return d3_rgb_hsl(this.r,this.g,this.b);};d3_rgbPrototype.toString=function(){return du+d3_rgb_hex(this.r)+d3_rgb_hex(this.g)+d3_rgb_hex(this.b);};function d3_rgb_hex(v){return v<16?fc+Math.max(0,v).toString(16):Math.min(255,v).toString(16);};function d3_rgb_parse(qw,qA,qz){var r=0,g=0,b=0,qB,qC,qy;qB=/([a-z]+)\((.*)\)/.exec(qw=qw.toLowerCase());if(qB){qC=qB[2].split(hz);switch(qB[1]){case cp:return qz(parseFloat(qC[0]),parseFloat(qC[1])/100,parseFloat(qC[2])/100);case gd:return qA(d3_rgb_parseNumber(qC[0]),d3_rgb_parseNumber(qC[1]),d3_rgb_parseNumber(qC[2]));};};if(qy=d3_rgb_names.get(qw)){return qA(qy.r,qy.g,qy.b);};if(qw!=null&&qw.charAt(0)===du&&!isNaN(qy=parseInt(qw.slice(1),16))){if(qw.length===4){r=(qy&3840)>>4;r=r>>4|r;g=qy&240;g=g>>4|g;b=qy&15;b=b<<4|b;}else if(qw.length===7){r=(qy&16711680)>>16;g=(qy&65280)>>8;b=qy&255;};};return qA(r,g,b);};function d3_rgb_hsl(r,g,b){var qD=Math.min(r/=255,g/=255,b/=255),qE=Math.max(r,g,b),d=qE-qD,h,s,l=(qE+qD)/2;if(d){s=l<.5?d/(qE+qD):d/(2-qE-qD);if(r==qE)h=(g-b)/d+(g<b?6:0);else if(g==qE)h=(b-r)/d+2;else h=(r-g)/d+4;h*=60;}else {h=NaN;s=l>0&&l<1?0:h;};return new d3_hsl(h,s,l);};function d3_rgb_lab(r,g,b){r=d3_rgb_xyz(r);g=d3_rgb_xyz(g);b=d3_rgb_xyz(b);var x=d3_xyz_lab((.4124564*r+.3575761*g+.1804375*b)/d3_lab_X),y=d3_xyz_lab((.2126729*r+.7151522*g+.072175*b)/d3_lab_Y),z=d3_xyz_lab((.0193339*r+.119192*g+.9503041*b)/d3_lab_Z);return d3_lab(116*y-16,500*(x-y),200*(y-z));};function d3_rgb_xyz(r){return (r/=255)<=.04045?r/12.92:Math.pow((r+.055)/1.055,2.4);};function d3_rgb_parseNumber(c){var f=parseFloat(c);return c.charAt(c.length-1)===bz?Math.round(f*2.55):f;};var d3_rgb_names=d3.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});d3_rgb_names.forEach(function(qF,qG){d3_rgb_names.set(qF,d3_rgbNumber(qG));});function d3_functor(v){return typeof v===eG?v:function(){return v;};};d3.functor=d3_functor;d3.xhr=d3_xhrType(d3_identity);function d3_xhrType(qH){return function(qI,qJ,qK){if(arguments.length===2&&typeof qJ===eG)qK=qJ,qJ=null;return d3_xhr(qI,qJ,qH,qK);};};function d3_xhr(qO,qL,qT,qS){var qN={},qR=d3.dispatch(U,fk,bE,fd),qU={},qQ=new XMLHttpRequest(),qM=null;if(this.XDomainRequest&&!(bI in qQ)&&/^(http(s)?:)?\/\//.test(qO))qQ=new XDomainRequest();fh in qQ?qQ.onload=qQ.onerror=qP:qQ.onreadystatechange=function(){qQ.readyState>3&&qP();};function qP(){var status=qQ.status,qV;if(!status&&d3_xhrHasResponse(qQ)||status>=200&&status<300||status===304){try{qV=qT.call(qN,qQ);}catch(e){qR.error.call(qN,e);return;};qR.load.call(qN,qV);}else {qR.error.call(qN,qQ);};};qQ.onprogress=function(event){var o=d3.event;d3.event=event;try{qR.progress.call(qN,qQ);}finally{d3.event=o;};};qN.header=function(name,qW){name=(name+gS).toLowerCase();if(arguments.length<2)return qU[name];if(qW==null)delete qU[name];else qU[name]=qW+gS;return qN;};qN.mimeType=function(qX){if(!arguments.length)return qL;qL=qX==null?null:qX+gS;return qN;};qN.responseType=function(qY){if(!arguments.length)return qM;qM=qY;return qN;};qN.response=function(rd){qT=rd;return qN;};[hh,eV].forEach(function(rf){qN[rf]=function(){return qN.send.apply(qN,[rf].concat(d3_array(arguments)));};});qN.send=function(ri,rh,rg){if(arguments.length===2&&typeof rh===eG)rg=rh,rh=null;qQ.open(ri,qO,true);if(qL!=null&&!(gO in qU))qU[gO]=qL+ht;if(qQ.setRequestHeader){for(var name in qU){qQ.setRequestHeader(name,qU[name]);};};if(qL!=null&&qQ.overrideMimeType)qQ.overrideMimeType(qL);if(qM!=null)qQ.responseType=qM;if(rg!=null)qN.on(fd,rg).on(bE,function(rj){rg(null,rj);});qR.beforesend.call(qN,qQ);qQ.send(rh==null?null:rh);return qN;};qN.abort=function(){qQ.abort();return qN;};d3.rebind(qN,qR,eb);return qS==null?qN:qN.get(d3_xhr_fixCallback(qS));};function d3_xhr_fixCallback(rk){return rk.length===1?function(rm,rl){rk(rm==null?rl:null);}:rk;};function d3_xhrHasResponse(rn){var ro=rn.responseType;return ro&&ro!==cI?rn.response:rn.responseText;};d3.dsv=function(delimiter,mimeType){var reFormat=new RegExp(bk+delimiter+dA),delimiterCode=delimiter.charCodeAt(0);function dsv(rq,rs,rr){if(arguments.length<3)rr=rs,rs=null;var rt=d3_xhr(rq,mimeType,rs==null?response:typedResponse(rs),rr);rt.row=function(_){return arguments.length?rt.response((rs=_)==null?response:typedResponse(_)):rs;};return rt;};function response(ru){return dsv.parse(ru.responseText);};function typedResponse(f){return function(rv){return dsv.parse(rv.responseText,f);};};dsv.parse=function(text,f){var o;return dsv.parseRows(text,function(row,i){if(o)return o(row,i-1);var a=new Function(ff,dT+row.map(function(name,i){return JSON.stringify(name)+gc+i+ee;}).join(hz)+gE);o=f?function(rw,i){return f(a(rw),i);}:a;});};dsv.parseRows=function(rB,f){var rE={},rA={},rz=[],N=rB.length,I=0,n=0,t,rC;function rD(){if(I>=N)return rA;if(rC)return rC=false,rE;var j=I;if(rB.charCodeAt(j)===34){var i=j;while(i++ <N){if(rB.charCodeAt(i)===34){if(rB.charCodeAt(i+1)!==34)break; ++i;};};I=i+2;var c=rB.charCodeAt(i+1);if(c===13){rC=true;if(rB.charCodeAt(i+2)===10) ++I;}else if(c===10){rC=true;};return rB.slice(j+1,i).replace(/""/g,dg);};while(I<N){var c=rB.charCodeAt(I++ ),k=1;if(c===10)rC=true;else if(c===13){rC=true;if(rB.charCodeAt(I)===10) ++I, ++k;}else if(c!==delimiterCode)continue;return rB.slice(j,I-k);};return rB.slice(j);};while((t=rD())!==rA){var a=[];while(t!==rE&&t!==rA){a.push(t);t=rD();};if(f&&(a=f(a,n++ ))==null)continue;rz.push(a);};return rz;};dsv.format=function(rG){if(Array.isArray(rG[0]))return dsv.formatRows(rG);var rH=new d3_Set(),rF=[];rG.forEach(function(rJ){for(var rI in rJ){if(!rH.has(rI)){rF.push(rH.add(rI));};};});return [rF.map(formatValue).join(delimiter)].concat(rG.map(function(rK){return rF.map(function(rL){return formatValue(rK[rL]);}).join(delimiter);})).join(fM);};dsv.formatRows=function(rM){return rM.map(formatRow).join(fM);};function formatRow(rN){return rN.map(formatValue).join(delimiter);};function formatValue(rO){return reFormat.test(rO)?dg+rO.replace(/\"/g,gu)+dg:rO;};return dsv;};d3.csv=d3.dsv(hz,M);d3.tsv=d3.dsv(gH,fC);var d3_timer_queueHead,d3_timer_queueTail,d3_timer_interval,d3_timer_timeout,d3_timer_frame=this[d3_vendorSymbol(this,gC)]||function(rP){setTimeout(rP,17);};d3.timer=function(){d3_timer.apply(this,arguments);};function d3_timer(rT,rS,rQ){var n=arguments.length;if(n<2)rS=0;if(n<3)rQ=Date.now();var rU=rQ+rS,rR={c:rT,t:rU,n:null};if(d3_timer_queueTail)d3_timer_queueTail.n=rR;else d3_timer_queueHead=rR;d3_timer_queueTail=rR;if(!d3_timer_interval){d3_timer_timeout=clearTimeout(d3_timer_timeout);d3_timer_interval=1;d3_timer_frame(d3_timer_step);};return rR;};function d3_timer_step(){var rW=d3_timer_mark(),rV=d3_timer_sweep()-rW;if(rV>24){if(isFinite(rV)){clearTimeout(d3_timer_timeout);d3_timer_timeout=setTimeout(d3_timer_step,rV);};d3_timer_interval=0;}else {d3_timer_interval=1;d3_timer_frame(d3_timer_step);};};d3.timer.flush=function(){d3_timer_mark();d3_timer_sweep();};function d3_timer_mark(){var rX=Date.now(),rY=d3_timer_queueHead;while(rY){if(rX>=rY.t&&rY.c(rX-rY.t))rY.c=null;rY=rY.n;};return rX;};function d3_timer_sweep(){var sb,sa=d3_timer_queueHead,sc=Infinity;while(sa){if(sa.c){if(sa.t<sc)sc=sa.t;sa=(sb=sa).n;}else {sa=sb?sb.n=sa.n:d3_timer_queueHead=sa.n;};};d3_timer_queueTail=sb;return sc;};function d3_format_precision(x,p){return p-(x?Math.ceil(Math.log(x)/Math.LN10):1);};d3.round=function(x,n){return n?Math.round(x*(n=Math.pow(10,n)))/n:Math.round(x);};var d3_formatPrefixes=[dJ,hw,cu,gT,cd,dG,cW,ft,gS,dl,hg,R,gL,gI,gl,be,ed].map(d3_formatPrefix);d3.formatPrefix=function(se,sd){var i=0;if(se=+se){if(se<0)se*=-1;if(sd)se=d3.round(se,d3_format_precision(se,sd));i=1+Math.floor(1e-12+Math.log(se)/Math.LN10);i=Math.max(-24,Math.min(24,Math.floor((i-1)/3)*3));};return d3_formatPrefixes[8+i/3];};function d3_formatPrefix(d,i){var k=Math.pow(10,abs(8-i)*3);return {scale:i>8?function(d){return d/k;}:function(d){return d*k;},symbol:d};};function d3_locale_numberFormat(sh){var sk=sh.decimal,sf=sh.thousands,si=sh.grouping,sj=sh.currency,sg=si&&sf?function(sl,sm){var i=sl.length,t=[],j=0,g=si[0],length=0;while(i>0&&g>0){if(length+g+1>sm)g=Math.max(1,sm-length);t.push(sl.substring(i-=g,i+g));if((length+=g+1)>sm)break;g=si[j=(j+1)%si.length];};return t.reverse().join(sf);}:d3_identity;return function(sn){var sF=d3_format_re.exec(sn),sC=sF[1]||gH,ss=sF[2]||gB,sv=sF[3]||E,sE=sF[4]||gS,sA=sF[5],sq=+sF[6],su=sF[7],st=sF[8],sD=sF[9],so=1,sz=gS,sp=gS,sB=false,sG=true;if(st)st=+st.substring(1);if(sA||sC===fc&&ss===cs){sA=sC=fc;ss=cs;};switch(sD){case dG:su=true;sD=ef;break;case bz:so=100;sp=bz;sD=gT;break;case cd:so=100;sp=bz;sD=gx;break;case eT:case ez:case cD:case cX:if(sE===du)sz=fc+sD.toLowerCase();case gt:sG=false;case ff:sB=true;st=0;break;case hf:so=-1;sD=gx;break;};if(sE===hk)sz=sj[0],sp=sj[1];if(sD==gx&&!st)sD=ef;if(st!=null){if(sD==ef)st=Math.max(1,Math.min(21,st));else if(sD==fO||sD==gT)st=Math.max(0,Math.min(20,st));};sD=d3_format_types.get(sD)||d3_format_typeDefault;var sw=sA&&su;return function(sL){var sJ=sp;if(sB&&sL%1)return gS;var sI=sL<0||sL===0&&1/sL<0?(sL=-sL,E):sv===E?gS:sv;if(so<0){var sM=d3.formatPrefix(sL,st);sL=sM.scale(sL);sJ=sM.symbol+sp;}else {sL*=so;};sL=sD(sL,st);var i=sL.lastIndexOf(fY),sN,sH;if(i<0){var j=sG?sL.lastIndexOf(fO):-1;if(j<0)sN=sL,sH=gS;else sN=sL.substring(0,j),sH=sL.substring(j);}else {sN=sL.substring(0,i);sH=sk+sL.substring(i+1);};if(!sA&&su)sN=sg(sN,Infinity);var length=sz.length+sN.length+sH.length+(sw?0:sI.length),sK=length<sq?new Array(length=sq-length+1).join(sC):gS;if(sw)sN=sg(sK+sN,sK.length?sq-sH.length:Infinity);sI+=sz;sL=sN+sH;return (ss===bD?sI+sL+sK:ss===gB?sK+sI+sL:ss===eJ?sK.substring(0,length>>=1)+sI+sL+sK.substring(length):sI+(sw?sL:sK+sL))+sJ;};};};var d3_format_re=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i;var d3_format_types=d3.map({b:function(x){return x.toString(2);},c:function(x){return String.fromCharCode(x);},o:function(x){return x.toString(8);},x:function(x){return x.toString(16);},X:function(x){return x.toString(16).toUpperCase();},g:function(x,p){return x.toPrecision(p);},e:function(x,p){return x.toExponential(p);},f:function(x,p){return x.toFixed(p);},r:function(x,p){return (x=d3.round(x,d3_format_precision(x,p))).toFixed(Math.max(0,Math.min(20,d3_format_precision(x*(1+1e-15),p))));}});function d3_format_typeDefault(x){return x+gS;};var d3_time=d3.time={},d3_date=Date;function d3_date_utc(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0]);};d3_date_utc.prototype={getDate:function(){return this._.getUTCDate();},getDay:function(){return this._.getUTCDay();},getFullYear:function(){return this._.getUTCFullYear();},getHours:function(){return this._.getUTCHours();},getMilliseconds:function(){return this._.getUTCMilliseconds();},getMinutes:function(){return this._.getUTCMinutes();},getMonth:function(){return this._.getUTCMonth();},getSeconds:function(){return this._.getUTCSeconds();},getTime:function(){return this._.getTime();},getTimezoneOffset:function(){return 0;},valueOf:function(){return this._.valueOf();},setDate:function(){d3_time_prototype.setUTCDate.apply(this._,arguments);},setDay:function(){d3_time_prototype.setUTCDay.apply(this._,arguments);},setFullYear:function(){d3_time_prototype.setUTCFullYear.apply(this._,arguments);},setHours:function(){d3_time_prototype.setUTCHours.apply(this._,arguments);},setMilliseconds:function(){d3_time_prototype.setUTCMilliseconds.apply(this._,arguments);},setMinutes:function(){d3_time_prototype.setUTCMinutes.apply(this._,arguments);},setMonth:function(){d3_time_prototype.setUTCMonth.apply(this._,arguments);},setSeconds:function(){d3_time_prototype.setUTCSeconds.apply(this._,arguments);},setTime:function(){d3_time_prototype.setTime.apply(this._,arguments);}};var d3_time_prototype=Date.prototype;function d3_time_interval(sV,sS,sQ){function sW(sX){var sY=sV(sX),tc=sT(sY,1);return sX-sY<tc-sX?sY:tc;};function sR(td){sS(td=sV(new d3_date(td-1)),1);return td;};function sT(te,k){sS(te=new d3_date(+te),k);return te;};function sU(ti,th,tf){var tg=sR(ti),tj=[];if(tf>1){while(tg<th){if(!(sQ(tg)%tf))tj.push(new Date(+tg));sS(tg,1);};}else {while(tg<th)tj.push(new Date(+tg)),sS(tg,1);};return tj;};function sP(tm,tn,tl){try{d3_date=d3_date_utc;var tk=new d3_date_utc();tk._=tm;return sU(tk,tn,tl);}finally{d3_date=Date;};};sV.floor=sV;sV.round=sW;sV.ceil=sR;sV.offset=sT;sV.range=sU;var sO=sV.utc=d3_time_interval_utc(sV);sO.floor=sO;sO.round=d3_time_interval_utc(sW);sO.ceil=d3_time_interval_utc(sR);sO.offset=d3_time_interval_utc(sT);sO.range=sP;return sV;};function d3_time_interval_utc(tp){return function(tq,k){try{d3_date=d3_date_utc;var tr=new d3_date_utc();tr._=tq;return tp(tr,k)._;}finally{d3_date=Date;};};};d3_time.year=d3_time_interval(function(ts){ts=d3_time.day(ts);ts.setMonth(0,1);return ts;},function(tt,tu){tt.setFullYear(tt.getFullYear()+tu);},function(tv){return tv.getFullYear();});d3_time.years=d3_time.year.range;d3_time.years.utc=d3_time.year.utc.range;d3_time.day=d3_time_interval(function(tw){var ty=new d3_date(2e3,0);ty.setFullYear(tw.getFullYear(),tw.getMonth(),tw.getDate());return ty;},function(tz,tA){tz.setDate(tz.getDate()+tA);},function(tB){return tB.getDate()-1;});d3_time.days=d3_time.day.range;d3_time.days.utc=d3_time.day.utc.range;d3_time.dayOfYear=function(tC){var tD=d3_time.year(tC);return Math.floor((tC-tD-(tC.getTimezoneOffset()-tD.getTimezoneOffset())*6e4)/864e5);};[fj,cE,fo,fD,df,dL,bB].forEach(function(tF,i){i=7-i;var tE=d3_time[tF]=d3_time_interval(function(tG){(tG=d3_time.day(tG)).setDate(tG.getDate()-(tG.getDay()+i)%7);return tG;},function(tH,tI){tH.setDate(tH.getDate()+Math.floor(tI)*7);},function(tJ){var tK=d3_time.year(tJ).getDay();return Math.floor((d3_time.dayOfYear(tJ)+(tK+i)%7)/7)-(tK!==i);});d3_time[tF+hf]=tE.range;d3_time[tF+hf].utc=tE.utc.range;d3_time[tF+cn]=function(tL){var tM=d3_time.year(tL).getDay();return Math.floor((d3_time.dayOfYear(tL)+(tM+i)%7)/7);};});d3_time.week=d3_time.sunday;d3_time.weeks=d3_time.sunday.range;d3_time.weeks.utc=d3_time.sunday.utc.range;d3_time.weekOfYear=d3_time.sundayOfYear;function d3_locale_timeFormat(tO){var tX=tO.dateTime,uk=tO.date,ug=tO.time,tS=tO.periods,tW=tO.days,uj=tO.shortDays,uo=tO.months,ue=tO.shortMonths;function un(ut){var n=ut.length;function uv(ux){var uw=[],i=-1,j=0,c,p,f;while( ++i<n){if(ut.charCodeAt(i)===37){uw.push(ut.slice(j,i));if((p=d3_time_formatPads[c=ut.charAt( ++i)])!=null)c=ut.charAt( ++i);if(f=tV[c])c=f(ux,p==null?c===fO?gH:fc:p);uw.push(c);j=i+1;};};uw.push(ut.slice(j,i));return uw.join(gS);};uv.parse=function(uz){var d={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null},i=uc(d,ut,uz,0);if(i!=uz.length)return null;if(cd in d)d.H=d.H%12+d.p*12;var uA=d.Z!=null&&d3_date!==d3_date_utc,uy=new (uA?d3_date_utc:d3_date)();if(gj in d)uy.setFullYear(d.y,0,d.j);else if(fT in d||fn in d){if(!(dX in d))d.w=fT in d?1:0;uy.setFullYear(d.y,0,1);uy.setFullYear(d.y,0,fT in d?(d.w+6)%7+d.W*7-(uy.getDay()+5)%7:d.w+d.U*7-(uy.getDay()+6)%7);}else uy.setFullYear(d.y,d.m,d.d);uy.setHours(d.H+(d.Z/100|0),d.M+d.Z%100,d.S,d.L);return uA?uy._:uy;};uv.toString=function(){return ut;};return uv;};function uc(uD,uC,uB,j){var c,p,t,i=0,n=uC.length,m=uB.length;while(i<n){if(j>=m)return -1;c=uC.charCodeAt(i++ );if(c===37){t=uC.charAt(i++ );p=ud[t in d3_time_formatPads?uC.charAt(i++ ):t];if(!p||(j=p(uD,uB,j))<0)return -1;}else if(c!=uB.charCodeAt(j++ )){return -1;};};return j;};un.utc=function(uF){var uE=un(uF);function uG(uH){try{d3_date=d3_date_utc;var uI=new d3_date();uI._=uH;return uE(uI);}finally{d3_date=Date;};};uG.parse=function(uK){try{d3_date=d3_date_utc;var uJ=uE.parse(uK);return uJ&&uJ._;}finally{d3_date=Date;};};uG.toString=uE.toString;return uG;};un.multi=un.utc.multi=d3_time_formatMulti;var ui=d3.map(),tQ=d3_time_formatRe(tW),ul=d3_time_formatLookup(tW),tT=d3_time_formatRe(uj),uf=d3_time_formatLookup(uj),um=d3_time_formatRe(uo),uh=d3_time_formatLookup(uo),uq=d3_time_formatRe(ue),us=d3_time_formatLookup(ue);tS.forEach(function(p,i){ui.set(p.toLowerCase(),i);});var tV={a:function(d){return uj[d.getDay()];},A:function(d){return tW[d.getDay()];},b:function(d){return ue[d.getMonth()];},B:function(d){return uo[d.getMonth()];},c:un(tX),d:function(d,p){return d3_time_formatPad(d.getDate(),p,2);},e:function(d,p){return d3_time_formatPad(d.getDate(),p,2);},H:function(d,p){return d3_time_formatPad(d.getHours(),p,2);},I:function(d,p){return d3_time_formatPad(d.getHours()%12||12,p,2);},j:function(d,p){return d3_time_formatPad(1+d3_time.dayOfYear(d),p,3);},L:function(d,p){return d3_time_formatPad(d.getMilliseconds(),p,3);},m:function(d,p){return d3_time_formatPad(d.getMonth()+1,p,2);},M:function(d,p){return d3_time_formatPad(d.getMinutes(),p,2);},p:function(d){return tS[+(d.getHours()>=12)];},S:function(d,p){return d3_time_formatPad(d.getSeconds(),p,2);},U:function(d,p){return d3_time_formatPad(d3_time.sundayOfYear(d),p,2);},w:function(d){return d.getDay();},W:function(d,p){return d3_time_formatPad(d3_time.mondayOfYear(d),p,2);},x:un(uk),X:un(ug),y:function(d,p){return d3_time_formatPad(d.getFullYear()%100,p,2);},Y:function(d,p){return d3_time_formatPad(d.getFullYear()%1e4,p,4);},Z:d3_time_zone,"%":function(){return bz;}};var ud={a:tU,A:tN,b:tR,B:tY,c:tP,d:d3_time_parseDay,e:d3_time_parseDay,H:d3_time_parseHour24,I:d3_time_parseHour24,j:d3_time_parseDayOfYear,L:d3_time_parseMilliseconds,m:d3_time_parseMonthNumber,M:d3_time_parseMinutes,p:ur,S:d3_time_parseSeconds,U:d3_time_parseWeekNumberSunday,w:d3_time_parseWeekdayNumber,W:d3_time_parseWeekNumberMonday,x:up,X:ub,y:d3_time_parseYear,Y:d3_time_parseFullYear,Z:d3_time_parseZone,"%":d3_time_parseLiteralPercent};function tU(uL,uM,i){tT.lastIndex=0;var n=tT.exec(uM.slice(i));return n?(uL.w=uf.get(n[0].toLowerCase()),i+n[0].length):-1;};function tN(uN,uO,i){tQ.lastIndex=0;var n=tQ.exec(uO.slice(i));return n?(uN.w=ul.get(n[0].toLowerCase()),i+n[0].length):-1;};function tR(uP,uQ,i){uq.lastIndex=0;var n=uq.exec(uQ.slice(i));return n?(uP.m=us.get(n[0].toLowerCase()),i+n[0].length):-1;};function tY(uR,uS,i){um.lastIndex=0;var n=um.exec(uS.slice(i));return n?(uR.m=uh.get(n[0].toLowerCase()),i+n[0].length):-1;};function tP(uT,uU,i){return uc(uT,tV.c.toString(),uU,i);};function up(uV,uW,i){return uc(uV,tV.x.toString(),uW,i);};function ub(uX,uY,i){return uc(uX,tV.X.toString(),uY,i);};function ur(vc,vd,i){var n=ui.get(vd.slice(i,i+=2).toLowerCase());return n==null?-1:(vc.p=n,i);};return un;};var d3_time_formatPads={"-":gS,_:gH,"0":fc},d3_time_numberRe=/^\s*\d+/,d3_time_percentRe=/^%/;function d3_time_formatPad(vf,vi,vh){var vg=vf<0?E:gS,ve=(vg?-vf:vf)+gS,length=ve.length;return vg+(length<vh?new Array(vh-length+1).join(vi)+ve:ve);};function d3_time_formatRe(vj){return new RegExp(gF+vj.map(d3.requote).join(fS)+eL,bW);};function d3_time_formatLookup(vl){var vk=new d3_Map(),i=-1,n=vl.length;while( ++i<n)vk.set(vl[i].toLowerCase(),i);return vk;};function d3_time_parseWeekdayNumber(vm,vn,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vn.slice(i,i+1));return n?(vm.w=+n[0],i+n[0].length):-1;};function d3_time_parseWeekNumberSunday(vo,vp,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vp.slice(i));return n?(vo.U=+n[0],i+n[0].length):-1;};function d3_time_parseWeekNumberMonday(vq,vr,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vr.slice(i));return n?(vq.W=+n[0],i+n[0].length):-1;};function d3_time_parseFullYear(vs,vt,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vt.slice(i,i+4));return n?(vs.y=+n[0],i+n[0].length):-1;};function d3_time_parseYear(vu,vw,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vw.slice(i,i+2));return n?(vu.y=d3_time_expandYear(+n[0]),i+n[0].length):-1;};function d3_time_parseZone(vx,vy,i){return /^[+-]\d{4}$/.test(vy=vy.slice(i,i+5))?(vx.Z=-vy,i+5):-1;};function d3_time_expandYear(d){return d+(d>68?1900:2e3);};function d3_time_parseMonthNumber(vz,vA,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vA.slice(i,i+2));return n?(vz.m=n[0]-1,i+n[0].length):-1;};function d3_time_parseDay(vB,vC,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vC.slice(i,i+2));return n?(vB.d=+n[0],i+n[0].length):-1;};function d3_time_parseDayOfYear(vD,vE,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vE.slice(i,i+3));return n?(vD.j=+n[0],i+n[0].length):-1;};function d3_time_parseHour24(vF,vG,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vG.slice(i,i+2));return n?(vF.H=+n[0],i+n[0].length):-1;};function d3_time_parseMinutes(vH,vI,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vI.slice(i,i+2));return n?(vH.M=+n[0],i+n[0].length):-1;};function d3_time_parseSeconds(vJ,vK,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vK.slice(i,i+2));return n?(vJ.S=+n[0],i+n[0].length):-1;};function d3_time_parseMilliseconds(vL,vM,i){d3_time_numberRe.lastIndex=0;var n=d3_time_numberRe.exec(vM.slice(i,i+3));return n?(vL.L=+n[0],i+n[0].length):-1;};function d3_time_zone(d){var z=d.getTimezoneOffset(),vP=z>0?E:cL,vO=abs(z)/60|0,vN=abs(z)%60;return vP+d3_time_formatPad(vO,fc,2)+d3_time_formatPad(vN,fc,2);};function d3_time_parseLiteralPercent(vQ,vR,i){d3_time_percentRe.lastIndex=0;var n=d3_time_percentRe.exec(vR.slice(i,i+1));return n?i+n[0].length:-1;};function d3_time_formatMulti(vS){var n=vS.length,i=-1;while( ++i<n){vS[i][0]=typeof vS[i][0]==fN?vS[i][0]:this(vS[i][0]);};return function(vT){var i=0,f=vS[i];while(!f[1](vT))f=vS[ ++i];return f[0](vT);};};d3.locale=function(vU){return {numberFormat:d3_locale_numberFormat(vU),timeFormat:d3_locale_timeFormat(vU)};};var d3_locale_default=d3.locale(kucken.lib.D3._getLocaleDefinition());d3.format=d3_locale_default.numberFormat;d3.geo={};function d3_adder(){};d3_adder.prototype={s:0,t:0,add:function(y){d3_adderSum(y,this.t,d3_adderTemp);d3_adderSum(d3_adderTemp.s,this.s,this);if(this.s)this.t+=d3_adderTemp.t;else this.s=d3_adderTemp.t;},reset:function(){this.s=this.t=0;},valueOf:function(){return this.s;}};var d3_adderTemp=new d3_adder();function d3_adderSum(a,b,o){var x=o.s=a+b,vV=x-a,vW=x-vV;o.t=a-vW+(b-vV);};d3.geo.stream=function(vY,vX){if(vY&&d3_geo_streamObjectType.hasOwnProperty(vY.type)){d3_geo_streamObjectType[vY.type](vY,vX);}else {d3_geo_streamGeometry(vY,vX);};};function d3_geo_streamGeometry(wc,wd){if(wc&&d3_geo_streamGeometryType.hasOwnProperty(wc.type)){d3_geo_streamGeometryType[wc.type](wc,wd);};};var d3_geo_streamObjectType={Feature:function(wf,we){d3_geo_streamGeometry(wf.geometry,we);},FeatureCollection:function(wh,wg){var wi=wh.features,i=-1,n=wi.length;while( ++i<n)d3_geo_streamGeometry(wi[i].geometry,wg);}};var d3_geo_streamGeometryType={Sphere:function(wk,wj){wj.sphere();},Point:function(wo,wl){wo=wo.coordinates;wl.point(wo[0],wo[1],wo[2]);},MultiPoint:function(wr,wq){var ws=wr.coordinates,i=-1,n=ws.length;while( ++i<n)wr=ws[i],wq.point(wr[0],wr[1],wr[2]);},LineString:function(wu,wt){d3_geo_streamLine(wu.coordinates,wt,0);},MultiLineString:function(ww,wv){var wx=ww.coordinates,i=-1,n=wx.length;while( ++i<n)d3_geo_streamLine(wx[i],wv,0);},Polygon:function(wz,wy){d3_geo_streamPolygon(wz.coordinates,wy);},MultiPolygon:function(wB,wA){var wC=wB.coordinates,i=-1,n=wC.length;while( ++i<n)d3_geo_streamPolygon(wC[i],wA);},GeometryCollection:function(wE,wD){var wF=wE.geometries,i=-1,n=wF.length;while( ++i<n)d3_geo_streamGeometry(wF[i],wD);}};function d3_geo_streamLine(wG,wH,closed){var i=-1,n=wG.length-closed,wI;wH.lineStart();while( ++i<n)wI=wG[i],wH.point(wI[0],wI[1],wI[2]);wH.lineEnd();};function d3_geo_streamPolygon(wK,wJ){var i=-1,n=wK.length;wJ.polygonStart();while( ++i<n)d3_geo_streamLine(wK[i],wJ,1);wJ.polygonEnd();};d3.geo.area=function(wL){d3_geo_areaSum=0;d3.geo.stream(wL,d3_geo_area);return d3_geo_areaSum;};var d3_geo_areaSum,d3_geo_areaRingSum=new d3_adder();var d3_geo_area={sphere:function(){d3_geo_areaSum+=4*π;},point:d3_noop,lineStart:d3_noop,lineEnd:d3_noop,polygonStart:function(){d3_geo_areaRingSum.reset();d3_geo_area.lineStart=d3_geo_areaRingStart;},polygonEnd:function(){var wM=2*d3_geo_areaRingSum;d3_geo_areaSum+=wM<0?4*π+wM:wM;d3_geo_area.lineStart=d3_geo_area.lineEnd=d3_geo_area.point=d3_noop;}};function d3_geo_areaRingStart(){var wP,wQ,wO,wS,wN;d3_geo_area.point=function(λ,φ){d3_geo_area.point=wR;wO=(wP=λ)*d3_radians,wS=Math.cos(φ=(wQ=φ)*d3_radians/2+π/4),wN=Math.sin(φ);};function wR(λ,φ){λ*=d3_radians;φ=φ*d3_radians/2+π/4;var wW=λ-wO,wV=wW>=0?1:-1,wU=wV*wW,wT=Math.cos(φ),wX=Math.sin(φ),k=wN*wX,u=wS*wT+k*Math.cos(wU),v=k*wV*Math.sin(wU);d3_geo_areaRingSum.add(Math.atan2(v,u));wO=λ,wS=wT,wN=wX;};d3_geo_area.lineEnd=function(){wR(wP,wQ);};};function d3_geo_cartesian(wY){var λ=wY[0],φ=wY[1],xa=Math.cos(φ);return [xa*Math.cos(λ),xa*Math.sin(λ),Math.sin(φ)];};function d3_geo_cartesianDot(a,b){return a[0]*b[0]+a[1]*b[1]+a[2]*b[2];};function d3_geo_cartesianCross(a,b){return [a[1]*b[2]-a[2]*b[1],a[2]*b[0]-a[0]*b[2],a[0]*b[1]-a[1]*b[0]];};function d3_geo_cartesianAdd(a,b){a[0]+=b[0];a[1]+=b[1];a[2]+=b[2];};function d3_geo_cartesianScale(xb,k){return [xb[0]*k,xb[1]*k,xb[2]*k];};function d3_geo_cartesianNormalize(d){var l=Math.sqrt(d[0]*d[0]+d[1]*d[1]+d[2]*d[2]);d[0]/=l;d[1]/=l;d[2]/=l;};function d3_geo_spherical(xc){return [Math.atan2(xc[1],xc[0]),d3_asin(xc[2])];};function d3_geo_sphericalEqual(a,b){return abs(a[0]-b[0])<ε&&abs(a[1]-b[1])<ε;};d3.geo.bounds=function(){var xo,xv,xn,xw,xh,xr,xk,xx,xp,xq,xy;var xe={point:xd,lineStart:xu,lineEnd:xj,polygonStart:function(){xe.point=xA;xe.lineStart=xf;xe.lineEnd=xz;xp=0;d3_geo_area.polygonStart();},polygonEnd:function(){d3_geo_area.polygonEnd();xe.point=xd;xe.lineStart=xu;xe.lineEnd=xj;if(d3_geo_areaRingSum<0)xo=-(xn=180),xv=-(xw=90);else if(xp>ε)xw=90;else if(xp<-ε)xv=-90;xy[0]=xo,xy[1]=xn;}};function xd(λ,φ){xq.push(xy=[xo=λ,xn=λ]);if(φ<xv)xv=φ;if(φ>xw)xw=φ;};function xl(λ,φ){var p=d3_geo_cartesian([λ*d3_radians,φ*d3_radians]);if(xx){var xG=d3_geo_cartesianCross(xx,p),xC=[xG[1],-xG[0],0],xE=d3_geo_cartesianCross(xC,xG);d3_geo_cartesianNormalize(xE);xE=d3_geo_spherical(xE);var xF=λ-xh,s=xF>0?1:-1,xI=xE[0]*d3_degrees*s,xD=abs(xF)>180;if(xD^(s*xh<xI&&xI<s*λ)){var xH=xE[1]*d3_degrees;if(xH>xw)xw=xH;}else if(xI=(xI+360)%360-180,xD^(s*xh<xI&&xI<s*λ)){var xH=-xE[1]*d3_degrees;if(xH<xv)xv=xH;}else {if(φ<xv)xv=φ;if(φ>xw)xw=φ;};if(xD){if(λ<xh){if(xg(xo,λ)>xg(xo,xn))xn=λ;}else {if(xg(λ,xn)>xg(xo,xn))xo=λ;};}else {if(xn>=xo){if(λ<xo)xo=λ;if(λ>xn)xn=λ;}else {if(λ>xh){if(xg(xo,λ)>xg(xo,xn))xn=λ;}else {if(xg(λ,xn)>xg(xo,xn))xo=λ;};};};}else {xd(λ,φ);};xx=p,xh=λ;};function xu(){xe.point=xl;};function xj(){xy[0]=xo,xy[1]=xn;xe.point=xd;xx=null;};function xA(λ,φ){if(xx){var xJ=λ-xh;xp+=abs(xJ)>180?xJ+(xJ>0?360:-360):xJ;}else xr=λ,xk=φ;d3_geo_area.point(λ,φ);xl(λ,φ);};function xf(){d3_geo_area.lineStart();};function xz(){xA(xr,xk);d3_geo_area.lineEnd();if(abs(xp)>ε)xo=-(xn=180);xy[0]=xo,xy[1]=xn;xx=null;};function xg(xL,xK){return (xK-=xL)<0?xK+360:xK;};function xt(a,b){return a[0]-b[0];};function xB(x,xM){return xM[0]<=xM[1]?xM[0]<=x&&x<=xM[1]:x<xM[0]||xM[1]<x;};return function(xN){xw=xn=-(xo=xv=Infinity);xq=[];d3.geo.stream(xN,xe);var n=xq.length;if(n){xq.sort(xt);for(var i=1,a=xq[0],b,xO=[a];i<n; ++i){b=xq[i];if(xB(b[0],a)||xB(b[1],a)){if(xg(a[0],b[1])>xg(a[0],a[1]))a[1]=b[1];if(xg(b[0],a[1])>xg(a[0],a[1]))a[0]=b[0];}else {xO.push(a=b);};};var xP=-Infinity,xQ;for(var n=xO.length-1,i=0,a=xO[n],b;i<=n;a=b, ++i){b=xO[i];if((xQ=xg(a[1],b[0]))>xP)xP=xQ,xo=b[0],xn=a[1];};};xq=xy=null;return xo===Infinity||xv===Infinity?[[NaN,NaN],[NaN,NaN]]:[[xo,xv],[xn,xw]];};}();d3.geo.centroid=function(xR){d3_geo_centroidW0=d3_geo_centroidW1=d3_geo_centroidX0=d3_geo_centroidY0=d3_geo_centroidZ0=d3_geo_centroidX1=d3_geo_centroidY1=d3_geo_centroidZ1=d3_geo_centroidX2=d3_geo_centroidY2=d3_geo_centroidZ2=0;d3.geo.stream(xR,d3_geo_centroid);var x=d3_geo_centroidX2,y=d3_geo_centroidY2,z=d3_geo_centroidZ2,m=x*x+y*y+z*z;if(m<ε2){x=d3_geo_centroidX1,y=d3_geo_centroidY1,z=d3_geo_centroidZ1;if(d3_geo_centroidW1<ε)x=d3_geo_centroidX0,y=d3_geo_centroidY0,z=d3_geo_centroidZ0;m=x*x+y*y+z*z;if(m<ε2)return [NaN,NaN];};return [Math.atan2(y,x)*d3_degrees,d3_asin(z/Math.sqrt(m))*d3_degrees];};var d3_geo_centroidW0,d3_geo_centroidW1,d3_geo_centroidX0,d3_geo_centroidY0,d3_geo_centroidZ0,d3_geo_centroidX1,d3_geo_centroidY1,d3_geo_centroidZ1,d3_geo_centroidX2,d3_geo_centroidY2,d3_geo_centroidZ2;var d3_geo_centroid={sphere:d3_noop,point:d3_geo_centroidPoint,lineStart:d3_geo_centroidLineStart,lineEnd:d3_geo_centroidLineEnd,polygonStart:function(){d3_geo_centroid.lineStart=d3_geo_centroidRingStart;},polygonEnd:function(){d3_geo_centroid.lineStart=d3_geo_centroidLineStart;}};function d3_geo_centroidPoint(λ,φ){λ*=d3_radians;var xS=Math.cos(φ*=d3_radians);d3_geo_centroidPointXYZ(xS*Math.cos(λ),xS*Math.sin(λ),Math.sin(φ));};function d3_geo_centroidPointXYZ(x,y,z){ ++d3_geo_centroidW0;d3_geo_centroidX0+=(x-d3_geo_centroidX0)/d3_geo_centroidW0;d3_geo_centroidY0+=(y-d3_geo_centroidY0)/d3_geo_centroidW0;d3_geo_centroidZ0+=(z-d3_geo_centroidZ0)/d3_geo_centroidW0;};function d3_geo_centroidLineStart(){var xU,xT,xV;d3_geo_centroid.point=function(λ,φ){λ*=d3_radians;var xX=Math.cos(φ*=d3_radians);xU=xX*Math.cos(λ);xT=xX*Math.sin(λ);xV=Math.sin(φ);d3_geo_centroid.point=xW;d3_geo_centroidPointXYZ(xU,xT,xV);};function xW(λ,φ){λ*=d3_radians;var xY=Math.cos(φ*=d3_radians),x=xY*Math.cos(λ),y=xY*Math.sin(λ),z=Math.sin(φ),w=Math.atan2(Math.sqrt((w=xT*z-xV*y)*w+(w=xV*x-xU*z)*w+(w=xU*y-xT*x)*w),xU*x+xT*y+xV*z);d3_geo_centroidW1+=w;d3_geo_centroidX1+=w*(xU+(xU=x));d3_geo_centroidY1+=w*(xT+(xT=y));d3_geo_centroidZ1+=w*(xV+(xV=z));d3_geo_centroidPointXYZ(xU,xT,xV);};};function d3_geo_centroidLineEnd(){d3_geo_centroid.point=d3_geo_centroidPoint;};function d3_geo_centroidRingStart(){var ya,yb,ye,yd,yf;d3_geo_centroid.point=function(λ,φ){ya=λ,yb=φ;d3_geo_centroid.point=yc;λ*=d3_radians;var yg=Math.cos(φ*=d3_radians);ye=yg*Math.cos(λ);yd=yg*Math.sin(λ);yf=Math.sin(φ);d3_geo_centroidPointXYZ(ye,yd,yf);};d3_geo_centroid.lineEnd=function(){yc(ya,yb);d3_geo_centroid.lineEnd=d3_geo_centroidLineEnd;d3_geo_centroid.point=d3_geo_centroidPoint;};function yc(λ,φ){λ*=d3_radians;var yh=Math.cos(φ*=d3_radians),x=yh*Math.cos(λ),y=yh*Math.sin(λ),z=Math.sin(φ),yl=yd*z-yf*y,yk=yf*x-ye*z,yj=ye*y-yd*x,m=Math.sqrt(yl*yl+yk*yk+yj*yj),u=ye*x+yd*y+yf*z,v=m&&-d3_acos(u)/m,w=Math.atan2(m,u);d3_geo_centroidX2+=v*yl;d3_geo_centroidY2+=v*yk;d3_geo_centroidZ2+=v*yj;d3_geo_centroidW1+=w;d3_geo_centroidX1+=w*(ye+(ye=x));d3_geo_centroidY1+=w*(yd+(yd=y));d3_geo_centroidZ1+=w*(yf+(yf=z));d3_geo_centroidPointXYZ(ye,yd,yf);};};function d3_geo_compose(a,b){function yn(x,y){return x=a(x,y),b(x[0],x[1]);};if(a.invert&&b.invert)yn.invert=function(x,y){return x=b.invert(x,y),x&&a.invert(x[0],x[1]);};return yn;};function d3_true(){return true;};function d3_geo_clipPolygon(yu,yp,yz,yv,yo){var yB=[],yq=[];yu.forEach(function(yE){if((n=yE.length-1)<=0)return;var n,yC=yE[0],yD=yE[n];if(d3_geo_sphericalEqual(yC,yD)){yo.lineStart();for(var i=0;i<n; ++i)yo.point((yC=yE[i])[0],yC[1]);yo.lineEnd();return;};var a=new d3_geo_clipPolygonIntersection(yC,yE,null,true),b=new d3_geo_clipPolygonIntersection(yC,null,a,false);a.o=b;yB.push(a);yq.push(b);a=new d3_geo_clipPolygonIntersection(yD,yE,null,false);b=new d3_geo_clipPolygonIntersection(yD,null,a,true);a.o=b;yB.push(a);yq.push(b);});yq.sort(yp);d3_geo_clipPolygonLinkCircular(yB);d3_geo_clipPolygonLinkCircular(yq);if(!yB.length)return;for(var i=0,yA=yz,n=yq.length;i<n; ++i){yq[i].e=yA=!yA;};var yx=yB[0],yy,yr;while(1){var yw=yx,yt=true;while(yw.v)if((yw=yw.n)===yx)return;yy=yw.z;yo.lineStart();do {yw.v=yw.o.v=true;if(yw.e){if(yt){for(var i=0,n=yy.length;i<n; ++i)yo.point((yr=yy[i])[0],yr[1]);}else {yv(yw.x,yw.n.x,1,yo);};yw=yw.n;}else {if(yt){yy=yw.p.z;for(var i=yy.length-1;i>=0; --i)yo.point((yr=yy[i])[0],yr[1]);}else {yv(yw.x,yw.p.x,-1,yo);};yw=yw.p;};yw=yw.o;yy=yw.z;yt=!yt;}while(!yw.v);yo.lineEnd();};};function d3_geo_clipPolygonLinkCircular(yF){if(!(n=yF.length))return;var n,i=0,a=yF[0],b;while( ++i<n){a.n=b=yF[i];b.p=a;a=b;};a.n=b=yF[0];b.p=a;};function d3_geo_clipPolygonIntersection(yJ,yH,yI,yG){this.x=yJ;this.z=yH;this.o=yI;this.e=yG;this.v=false;this.n=this.p=null;};function d3_geo_clip(yK,yM,yN,yL){return function(yO,yY){var yV=yM(yY),yU=yO.invert(yL[0],yL[1]);var yQ={point:yR,lineStart:zd,lineEnd:zb,polygonStart:function(){yQ.point=ze;yQ.lineStart=zg;yQ.lineEnd=zc;yT=[];yP=[];},polygonEnd:function(){yQ.point=yR;yQ.lineStart=zd;yQ.lineEnd=zb;yT=d3.merge(yT);var zi=d3_geo_pointInPolygon(yU,yP);if(yT.length){if(!za)yY.polygonStart(),za=true;d3_geo_clipPolygon(yT,d3_geo_clipSort,zi,yN,yY);}else if(zi){if(!za)yY.polygonStart(),za=true;yY.lineStart();yN(null,null,1,yY);yY.lineEnd();};if(za)yY.polygonEnd(),za=false;yT=yP=null;},sphere:function(){yY.polygonStart();yY.lineStart();yN(null,null,1,yY);yY.lineEnd();yY.polygonEnd();}};function yR(λ,φ){var zj=yO(λ,φ);if(yK(λ=zj[0],φ=zj[1]))yY.point(λ,φ);};function yW(λ,φ){var zk=yO(λ,φ);yV.point(zk[0],zk[1]);};function zd(){yQ.point=yW;yV.lineStart();};function zb(){yQ.point=yR;yV.lineEnd();};var yT;var yS=d3_geo_clipBufferListener(),yX=yM(yS),za=false,yP,zf;function ze(λ,φ){zf.push([λ,φ]);var zl=yO(λ,φ);yX.point(zl[0],zl[1]);};function zg(){yX.lineStart();zf=[];};function zc(){ze(zf[0][0],zf[0][1]);yX.lineEnd();var zp=yX.clean(),zo=yS.buffer(),zq,n=zo.length;zf.pop();yP.push(zf);zf=null;if(!n)return;if(zp&1){zq=zo[0];var n=zq.length-1,i=-1,zn;if(n>0){if(!za)yY.polygonStart(),za=true;yY.lineStart();while( ++i<n)yY.point((zn=zq[i])[0],zn[1]);yY.lineEnd();};return;};if(n>1&&zp&2)zo.push(zo.pop().concat(zo.shift()));yT.push(zo.filter(d3_geo_clipSegmentLength1));};return yQ;};};function d3_geo_clipSegmentLength1(zr){return zr.length>1;};function d3_geo_clipBufferListener(){var zu=[],zt;return {lineStart:function(){zu.push(zt=[]);},point:function(λ,φ){zt.push([λ,φ]);},lineEnd:d3_noop,buffer:function(){var zv=zu;zu=[];zt=null;return zv;},rejoin:function(){if(zu.length>1)zu.push(zu.pop().concat(zu.shift()));}};};function d3_geo_clipSort(a,b){return ((a=a.x)[0]<0?a[1]-halfπ-ε:halfπ-a[1])-((b=b.x)[0]<0?b[1]-halfπ-ε:halfπ-b[1]);};var d3_geo_clipAntimeridian=d3_geo_clip(d3_true,d3_geo_clipAntimeridianLine,d3_geo_clipAntimeridianInterpolate,[-π,-π/2]);function d3_geo_clipAntimeridianLine(zx){var zy=NaN,zw=NaN,zz=NaN,zA;return {lineStart:function(){zx.lineStart();zA=1;},point:function(zC,zB){var zD=zC>0?π:-π,zE=abs(zC-zy);if(abs(zE-π)<ε){zx.point(zy,zw=(zw+zB)/2>0?halfπ:-halfπ);zx.point(zz,zw);zx.lineEnd();zx.lineStart();zx.point(zD,zw);zx.point(zC,zw);zA=0;}else if(zz!==zD&&zE>=π){if(abs(zy-zz)<ε)zy-=zz*ε;if(abs(zC-zD)<ε)zC-=zD*ε;zw=d3_geo_clipAntimeridianIntersect(zy,zw,zC,zB);zx.point(zz,zw);zx.lineEnd();zx.lineStart();zx.point(zD,zw);zA=0;};zx.point(zy=zC,zw=zB);zz=zD;},lineEnd:function(){zx.lineEnd();zy=zw=NaN;},clean:function(){return 2-zA;}};};function d3_geo_clipAntimeridianIntersect(zI,zF,zH,zG){var zK,zL,zJ=Math.sin(zI-zH);return abs(zJ)>ε?Math.atan((Math.sin(zF)*(zL=Math.cos(zG))*Math.sin(zH)-Math.sin(zG)*(zK=Math.cos(zF))*Math.sin(zI))/(zK*zL*zJ)):(zF+zG)/2;};function d3_geo_clipAntimeridianInterpolate(zN,zP,zM,zO){var φ;if(zN==null){φ=zM*halfπ;zO.point(-π,φ);zO.point(0,φ);zO.point(π,φ);zO.point(π,0);zO.point(π,-φ);zO.point(0,-φ);zO.point(-π,-φ);zO.point(-π,0);zO.point(-π,φ);}else if(abs(zN[0]-zP[0])>ε){var s=zN[0]<zP[0]?π:-π;φ=zM*s/2;zO.point(-s,φ);zO.point(0,φ);zO.point(s,φ);}else {zO.point(zP[0],zP[1]);};};function d3_geo_pointInPolygon(zQ,Aa){var Ae=zQ[0],Ai=zQ[1],zV=[Math.sin(Ae),-Math.cos(Ae),0],Ak=0,zS=0;d3_geo_areaRingSum.reset();for(var i=0,n=Aa.length;i<n; ++i){var zX=Aa[i],m=zX.length;if(!m)continue;var Ad=zX[0],Ag=Ad[0],Aj=Ad[1]/2+π/4,Af=Math.sin(Aj),zW=Math.cos(Aj),j=1;while(true){if(j===m)j=0;zQ=zX[j];var λ=zQ[0],φ=zQ[1]/2+π/4,Am=Math.sin(φ),zY=Math.cos(φ),zU=λ-Ag,zR=zU>=0?1:-1,Al=zR*zU,Ac=Al>π,k=Af*Am;d3_geo_areaRingSum.add(Math.atan2(k*zR*Math.sin(Al),zW*zY+k*Math.cos(Al)));Ak+=Ac?zU+zR*τ:zU;if(Ac^Ag>=Ae^λ>=Ae){var zT=d3_geo_cartesianCross(d3_geo_cartesian(Ad),d3_geo_cartesian(zQ));d3_geo_cartesianNormalize(zT);var Ah=d3_geo_cartesianCross(zV,zT);d3_geo_cartesianNormalize(Ah);var Ab=(Ac^zU>=0?-1:1)*d3_asin(Ah[2]);if(Ai>Ab||Ai===Ab&&(zT[0]||zT[1])){zS+=Ac^zU>=0?1:-1;};};if(!j++ )break;Ag=λ,Af=Am,zW=zY,Ad=zQ;};};return (Ak<-ε||Ak<ε&&d3_geo_areaRingSum<0)^zS&1;};function d3_geo_clipCircle(As){var Av=Math.cos(As),Ap=Av>0,At=abs(Av)>ε,Aq=d3_geo_circleInterpolate(As,6*d3_radians);return d3_geo_clip(Ar,Ao,Aq,Ap?[0,-As]:[-π,As-π]);function Ar(λ,φ){return Math.cos(λ)*Math.cos(φ)>Av;};function Ao(Aw){var Ay,AB,Az,Ax,AA;return {lineStart:function(){Ax=Az=false;AA=1;},point:function(λ,φ){var AC=[λ,φ],AD,v=Ar(λ,φ),c=Ap?v?0:An(λ,φ):v?An(λ+(λ<0?π:-π),φ):0;if(!Ay&&(Ax=Az=v))Aw.lineStart();if(v!==Az){AD=Au(Ay,AC);if(d3_geo_sphericalEqual(Ay,AD)||d3_geo_sphericalEqual(AC,AD)){AC[0]+=ε;AC[1]+=ε;v=Ar(AC[0],AC[1]);};};if(v!==Az){AA=0;if(v){Aw.lineStart();AD=Au(AC,Ay);Aw.point(AD[0],AD[1]);}else {AD=Au(Ay,AC);Aw.point(AD[0],AD[1]);Aw.lineEnd();};Ay=AD;}else if(At&&Ay&&Ap^v){var t;if(!(c&AB)&&(t=Au(AC,Ay,true))){AA=0;if(Ap){Aw.lineStart();Aw.point(t[0][0],t[0][1]);Aw.point(t[1][0],t[1][1]);Aw.lineEnd();}else {Aw.point(t[1][0],t[1][1]);Aw.lineEnd();Aw.lineStart();Aw.point(t[0][0],t[0][1]);};};};if(v&&(!Ay||!d3_geo_sphericalEqual(Ay,AC))){Aw.point(AC[0],AC[1]);};Ay=AC,Az=v,AB=c;},lineEnd:function(){if(Az)Aw.lineEnd();Ay=null;},clean:function(){return AA|(Ax&&Az)<<1;}};};function Au(a,b,AJ){var AL=d3_geo_cartesian(a),AK=d3_geo_cartesian(b);var AX=[1,0,0],AY=d3_geo_cartesianCross(AL,AK),AG=d3_geo_cartesianDot(AY,AY),AV=AY[0],AE=AG-AV*AV;if(!AE)return !AJ&&a;var AR=Av*AG/AE,AQ=-Av*AV/AE,AI=d3_geo_cartesianCross(AX,AY),A=d3_geo_cartesianScale(AX,AR),B=d3_geo_cartesianScale(AY,AQ);d3_geo_cartesianAdd(A,B);var u=AI,w=d3_geo_cartesianDot(A,u),AU=d3_geo_cartesianDot(u,u),AW=w*w-AU*(d3_geo_cartesianDot(A,A)-1);if(AW<0)return;var t=Math.sqrt(AW),q=d3_geo_cartesianScale(u,(-w-t)/AU);d3_geo_cartesianAdd(q,A);q=d3_geo_spherical(q);if(!AJ)return q;var AP=a[0],AO=b[0],AS=a[1],AT=b[1],z;if(AO<AP)z=AP,AP=AO,AO=z;var AH=AO-AP,AN=abs(AH-π)<ε,AM=AN||AH<ε;if(!AN&&AT<AS)z=AS,AS=AT,AT=z;if(AM?AN?AS+AT>0^q[1]<(abs(q[0]-AP)<ε?AS:AT):AS<=q[1]&&q[1]<=AT:AH>π^(AP<=q[0]&&q[0]<=AO)){var AF=d3_geo_cartesianScale(u,(-w+t)/AU);d3_geo_cartesianAdd(AF,A);return [q,d3_geo_spherical(AF)];};};function An(λ,φ){var r=Ap?As:π-As,Ba=0;if(λ<-r)Ba|=1;else if(λ>r)Ba|=2;if(φ<-r)Ba|=4;else if(φ>r)Ba|=8;return Ba;};};function d3_geom_clipLine(Bd,Bc,Be,Bb){return function(Bl){var a=Bl.a,b=Bl.b,Bk=a.x,Bj=a.y,Bm=b.x,Bn=b.y,Bf=0,Bg=1,Bh=Bm-Bk,Bi=Bn-Bj,r;r=Bd-Bk;if(!Bh&&r>0)return;r/=Bh;if(Bh<0){if(r<Bf)return;if(r<Bg)Bg=r;}else if(Bh>0){if(r>Bg)return;if(r>Bf)Bf=r;};r=Be-Bk;if(!Bh&&r<0)return;r/=Bh;if(Bh<0){if(r>Bg)return;if(r>Bf)Bf=r;}else if(Bh>0){if(r<Bf)return;if(r<Bg)Bg=r;};r=Bc-Bj;if(!Bi&&r>0)return;r/=Bi;if(Bi<0){if(r<Bf)return;if(r<Bg)Bg=r;}else if(Bi>0){if(r>Bg)return;if(r>Bf)Bf=r;};r=Bb-Bj;if(!Bi&&r<0)return;r/=Bi;if(Bi<0){if(r>Bg)return;if(r>Bf)Bf=r;}else if(Bi>0){if(r<Bf)return;if(r<Bg)Bg=r;};if(Bf>0)Bl.a={x:Bk+Bf*Bh,y:Bj+Bf*Bi};if(Bg<1)Bl.b={x:Bk+Bg*Bh,y:Bj+Bg*Bi};return Bl;};};var d3_geo_clipExtentMAX=1e9;d3.geo.clipExtent=function(){var Bt,Bs,Bu,Br,Bp,Bq,Bo={stream:function(Bv){if(Bp)Bp.valid=false;Bp=Bq(Bv);Bp.valid=true;return Bp;},extent:function(_){if(!arguments.length)return [[Bt,Bs],[Bu,Br]];Bq=d3_geo_clipExtent(Bt=+_[0][0],Bs=+_[0][1],Bu=+_[1][0],Br=+_[1][1]);if(Bp)Bp.valid=false,Bp=null;return Bo;}};return Bo.extent([[0,0],[960,500]]);};function d3_geo_clipExtent(BB,By,BC,Bz){return function(BT){var BV=BT,BU=d3_geo_clipBufferListener(),BG=d3_geom_clipLine(BB,By,BC,Bz),BJ,BI,BH;var BE={point:BF,lineStart:BW,lineEnd:BN,polygonStart:function(){BT=BU;BJ=[];BI=[];BY=true;},polygonEnd:function(){BT=BV;BJ=d3.merge(BJ);var Cb=BX([BB,Bz]),Cc=BY&&Cb,Cd=BJ.length;if(Cc||Cd){BT.polygonStart();if(Cc){BT.lineStart();BS(null,null,1,BT);BT.lineEnd();};if(Cd){d3_geo_clipPolygon(BJ,Bw,Cb,BS,BT);};BT.polygonEnd();};BJ=BI=BH=null;}};function BX(p){var Ce=0,n=BI.length,y=p[1];for(var i=0;i<n; ++i){for(var j=1,v=BI[i],m=v.length,a=v[0],b;j<m; ++j){b=v[j];if(a[1]<=y){if(b[1]>y&&d3_cross2d(a,b,p)>0) ++Ce;}else {if(b[1]<=y&&d3_cross2d(a,b,p)<0) --Ce;};a=b;};};return Ce!==0;};function BS(Ch,Cj,Cg,Cf){var a=0,Ci=0;if(Ch==null||(a=Bx(Ch,Cg))!==(Ci=Bx(Cj,Cg))||BA(Ch,Cj)<0^Cg>0){do {Cf.point(a===0||a===3?BB:BC,a>1?Bz:By);}while((a=(a+Cg+4)%4)!==Ci);}else {Cf.point(Cj[0],Cj[1]);};};function BQ(x,y){return BB<=x&&x<=BC&&By<=y&&y<=Bz;};function BF(x,y){if(BQ(x,y))BT.point(x,y);};var BM,BD,BK,BL,BR,BP,Ca,BY;function BW(){BE.point=BO;if(BI)BI.push(BH=[]);Ca=true;BP=false;BL=BR=NaN;};function BN(){if(BJ){BO(BM,BD);if(BK&&BP)BU.rejoin();BJ.push(BU.buffer());};BE.point=BF;if(BP)BT.lineEnd();};function BO(x,y){x=Math.max(-d3_geo_clipExtentMAX,Math.min(d3_geo_clipExtentMAX,x));y=Math.max(-d3_geo_clipExtentMAX,Math.min(d3_geo_clipExtentMAX,y));var v=BQ(x,y);if(BI)BH.push([x,y]);if(Ca){BM=x,BD=y,BK=v;Ca=false;if(v){BT.lineStart();BT.point(x,y);};}else {if(v&&BP)BT.point(x,y);else {var l={a:{x:BL,y:BR},b:{x:x,y:y}};if(BG(l)){if(!BP){BT.lineStart();BT.point(l.a.x,l.a.y);};BT.point(l.b.x,l.b.y);if(!v)BT.lineEnd();BY=false;}else if(v){BT.lineStart();BT.point(x,y);BY=false;};};};BL=x,BR=y,BP=v;};return BE;};function Bx(p,Ck){return abs(p[0]-BB)<ε?Ck>0?0:3:abs(p[0]-BC)<ε?Ck>0?2:1:abs(p[1]-By)<ε?Ck>0?1:0:Ck>0?3:2;};function Bw(a,b){return BA(a.x,b.x);};function BA(a,b){var Cm=Bx(a,1),Cl=Bx(b,1);return Cm!==Cl?Cm-Cl:Cm===0?b[1]-a[1]:Cm===1?a[0]-b[0]:Cm===2?a[1]-b[1]:b[0]-a[0];};};function d3_geo_conic(Co){var Cn=0,Cp=π/3,m=d3_geo_projectionMutator(Co),p=m(Cn,Cp);p.parallels=function(_){if(!arguments.length)return [Cn/π*180,Cp/π*180];return m(Cn=_[0]*π/180,Cp=_[1]*π/180);};return p;};function d3_geo_conicEqualArea(Cq,Cr){var Cs=Math.sin(Cq),n=(Cs+Math.sin(Cr))/2,C=1+Cs*(2*n-Cs),Ct=Math.sqrt(C)/n;function forward(λ,φ){var ρ=Math.sqrt(C-2*n*Math.sin(φ))/n;return [ρ*Math.sin(λ*=n),Ct-ρ*Math.cos(λ)];};forward.invert=function(x,y){var Cu=Ct-y;return [Math.atan2(x,Cu)/n,d3_asin((C-(x*x+Cu*Cu)*n*n)/(2*n))];};return forward;};(d3.geo.conicEqualArea=function(){return d3_geo_conic(d3_geo_conicEqualArea);}).raw=d3_geo_conicEqualArea;d3.geo.albers=function(){return d3.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070);};d3.geo.albersUsa=function(){var CD=d3.geo.albers();var Cy=d3.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]);var Cz=d3.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]);var Cx,CB={point:function(x,y){Cx=[x,y];}},Cv,CA,CC;function Cw(CE){var x=CE[0],y=CE[1];Cx=null;(Cv(x,y),Cx)||(CA(x,y),Cx)||CC(x,y);return Cx;};Cw.invert=function(CF){var k=CD.scale(),t=CD.translate(),x=(CF[0]-t[0])/k,y=(CF[1]-t[1])/k;return (y>=.12&&y<.234&&x>=-.425&&x<-.214?Cy:y>=.166&&y<.234&&x>=-.214&&x<-.115?Cz:CD).invert(CF);};Cw.stream=function(CH){var CI=CD.stream(CH),CG=Cy.stream(CH),CJ=Cz.stream(CH);return {point:function(x,y){CI.point(x,y);CG.point(x,y);CJ.point(x,y);},sphere:function(){CI.sphere();CG.sphere();CJ.sphere();},lineStart:function(){CI.lineStart();CG.lineStart();CJ.lineStart();},lineEnd:function(){CI.lineEnd();CG.lineEnd();CJ.lineEnd();},polygonStart:function(){CI.polygonStart();CG.polygonStart();CJ.polygonStart();},polygonEnd:function(){CI.polygonEnd();CG.polygonEnd();CJ.polygonEnd();}};};Cw.precision=function(_){if(!arguments.length)return CD.precision();CD.precision(_);Cy.precision(_);Cz.precision(_);return Cw;};Cw.scale=function(_){if(!arguments.length)return CD.scale();CD.scale(_);Cy.scale(_*.35);Cz.scale(_);return Cw.translate(CD.translate());};Cw.translate=function(_){if(!arguments.length)return CD.translate();var k=CD.scale(),x=+_[0],y=+_[1];Cv=CD.translate(_).clipExtent([[x-.455*k,y-.238*k],[x+.455*k,y+.238*k]]).stream(CB).point;CA=Cy.translate([x-.307*k,y+.201*k]).clipExtent([[x-.425*k+ε,y+.12*k+ε],[x-.214*k-ε,y+.234*k-ε]]).stream(CB).point;CC=Cz.translate([x-.205*k,y+.212*k]).clipExtent([[x-.214*k+ε,y+.166*k+ε],[x-.115*k-ε,y+.234*k-ε]]).stream(CB).point;return Cw;};return Cw.scale(1070);};var d3_geo_pathAreaSum,d3_geo_pathAreaPolygon,d3_geo_pathArea={point:d3_noop,lineStart:d3_noop,lineEnd:d3_noop,polygonStart:function(){d3_geo_pathAreaPolygon=0;d3_geo_pathArea.lineStart=d3_geo_pathAreaRingStart;},polygonEnd:function(){d3_geo_pathArea.lineStart=d3_geo_pathArea.lineEnd=d3_geo_pathArea.point=d3_noop;d3_geo_pathAreaSum+=abs(d3_geo_pathAreaPolygon/2);}};function d3_geo_pathAreaRingStart(){var CM,CL,CN,CK;d3_geo_pathArea.point=function(x,y){d3_geo_pathArea.point=CO;CM=CN=x,CL=CK=y;};function CO(x,y){d3_geo_pathAreaPolygon+=CK*x-CN*y;CN=x,CK=y;};d3_geo_pathArea.lineEnd=function(){CO(CM,CL);};};var d3_geo_pathBoundsX0,d3_geo_pathBoundsY0,d3_geo_pathBoundsX1,d3_geo_pathBoundsY1;var d3_geo_pathBounds={point:d3_geo_pathBoundsPoint,lineStart:d3_noop,lineEnd:d3_noop,polygonStart:d3_noop,polygonEnd:d3_noop};function d3_geo_pathBoundsPoint(x,y){if(x<d3_geo_pathBoundsX0)d3_geo_pathBoundsX0=x;if(x>d3_geo_pathBoundsX1)d3_geo_pathBoundsX1=x;if(y<d3_geo_pathBoundsY0)d3_geo_pathBoundsY0=y;if(y>d3_geo_pathBoundsY1)d3_geo_pathBoundsY1=y;};function d3_geo_pathBuffer(){var CP=d3_geo_pathBufferCircle(4.5),CT=[];var CR={point:CS,lineStart:function(){CR.point=CV;},lineEnd:CW,polygonStart:function(){CR.lineEnd=CQ;},polygonEnd:function(){CR.lineEnd=CW;CR.point=CS;},pointRadius:function(_){CP=d3_geo_pathBufferCircle(_);return CR;},result:function(){if(CT.length){var CX=CT.join(gS);CT=[];return CX;};}};function CS(x,y){CT.push(hg,x,hz,y,CP);};function CV(x,y){CT.push(hg,x,hz,y);CR.point=CU;};function CU(x,y){CT.push(fJ,x,hz,y);};function CW(){CR.point=CS;};function CQ(){CT.push(be);};return CR;};function d3_geo_pathBufferCircle(CY){return bK+CY+cu+CY+hz+CY+hp+-2*CY+cu+CY+hz+CY+hp+2*CY+hw;};var d3_geo_pathCentroid={point:d3_geo_pathCentroidPoint,lineStart:d3_geo_pathCentroidLineStart,lineEnd:d3_geo_pathCentroidLineEnd,polygonStart:function(){d3_geo_pathCentroid.lineStart=d3_geo_pathCentroidRingStart;},polygonEnd:function(){d3_geo_pathCentroid.point=d3_geo_pathCentroidPoint;d3_geo_pathCentroid.lineStart=d3_geo_pathCentroidLineStart;d3_geo_pathCentroid.lineEnd=d3_geo_pathCentroidLineEnd;}};function d3_geo_pathCentroidPoint(x,y){d3_geo_centroidX0+=x;d3_geo_centroidY0+=y; ++d3_geo_centroidZ0;};function d3_geo_pathCentroidLineStart(){var Db,Da;d3_geo_pathCentroid.point=function(x,y){d3_geo_pathCentroid.point=Dc;d3_geo_pathCentroidPoint(Db=x,Da=y);};function Dc(x,y){var Dd=x-Db,De=y-Da,z=Math.sqrt(Dd*Dd+De*De);d3_geo_centroidX1+=z*(Db+x)/2;d3_geo_centroidY1+=z*(Da+y)/2;d3_geo_centroidZ1+=z;d3_geo_pathCentroidPoint(Db=x,Da=y);};};function d3_geo_pathCentroidLineEnd(){d3_geo_pathCentroid.point=d3_geo_pathCentroidPoint;};function d3_geo_pathCentroidRingStart(){var Dh,Dg,Di,Df;d3_geo_pathCentroid.point=function(x,y){d3_geo_pathCentroid.point=Dj;d3_geo_pathCentroidPoint(Dh=Di=x,Dg=Df=y);};function Dj(x,y){var Dk=x-Di,Dl=y-Df,z=Math.sqrt(Dk*Dk+Dl*Dl);d3_geo_centroidX1+=z*(Di+x)/2;d3_geo_centroidY1+=z*(Df+y)/2;d3_geo_centroidZ1+=z;z=Df*x-Di*y;d3_geo_centroidX2+=z*(Di+x);d3_geo_centroidY2+=z*(Df+y);d3_geo_centroidZ2+=z*3;d3_geo_pathCentroidPoint(Di=x,Df=y);};d3_geo_pathCentroid.lineEnd=function(){Dj(Dh,Dg);};};function d3_geo_pathContext(Dr){var Ds=4.5;var Dn={point:Do,lineStart:function(){Dn.point=Dq;},lineEnd:Dt,polygonStart:function(){Dn.lineEnd=Dm;},polygonEnd:function(){Dn.lineEnd=Dt;Dn.point=Do;},pointRadius:function(_){Ds=_;return Dn;},result:d3_noop};function Do(x,y){Dr.moveTo(x+Ds,y);Dr.arc(x,y,Ds,0,τ);};function Dq(x,y){Dr.moveTo(x,y);Dn.point=Dp;};function Dp(x,y){Dr.lineTo(x,y);};function Dt(){Dn.point=Do;};function Dm(){Dr.closePath();};return Dn;};function d3_geo_resample(Dz){var Dy=.5,Dv=Math.cos(30*d3_radians),DA=16;function Dw(DC){return (DA?Du:Dx)(DC);};function Dx(DD){return d3_geo_transformPoint(DD,function(x,y){x=Dz(x,y);DD.point(x[0],x[1]);});};function Du(DE){var DM,DI,DO,DL,DG,DW,Ea,DQ,DT,DJ,DS,DH,DU;var DR={point:DF,lineStart:DV,lineEnd:DN,polygonStart:function(){DE.polygonStart();DR.lineStart=DK;},polygonEnd:function(){DE.polygonEnd();DR.lineStart=DV;}};function DF(x,y){x=Dz(x,y);DE.point(x[0],x[1]);};function DV(){DT=NaN;DR.point=DP;DE.lineStart();};function DP(λ,φ){var c=d3_geo_cartesian([λ,φ]),p=Dz(λ,φ);DB(DT,DJ,DQ,DS,DH,DU,DT=p[0],DJ=p[1],DQ=λ,DS=c[0],DH=c[1],DU=c[2],DA,DE);DE.point(DT,DJ);};function DN(){DR.point=DF;DE.lineEnd();};function DK(){DV();DR.point=Ec;DR.lineEnd=Eb;};function Ec(λ,φ){DP(DM=λ,DI=φ),DO=DT,DL=DJ,DG=DS,DW=DH,Ea=DU;DR.point=DP;};function Eb(){DB(DT,DJ,DQ,DS,DH,DU,DO,DL,DM,DG,DW,Ea,DA,DE);DR.lineEnd=DN;DN();};return DR;};function DB(El,Ei,Ep,Es,Ef,Ey,Em,Eh,Eo,Er,Eg,Ex,EA,Ed){var Eu=Em-El,Ev=Eh-Ei,Ek=Eu*Eu+Ev*Ev;if(Ek>4*Dy&&EA-- ){var a=Es+Er,b=Ef+Eg,c=Ey+Ex,m=Math.sqrt(a*a+b*b+c*c),Ez=Math.asin(c/=m),En=abs(abs(c)-1)<ε||abs(Ep-Eo)<ε?(Ep+Eo)/2:Math.atan2(b,a),p=Dz(En,Ez),Ew=p[0],Ej=p[1],Eq=Ew-El,Ee=Ej-Ei,Et=Ev*Eq-Eu*Ee;if(Et*Et/Ek>Dy||abs((Eu*Eq+Ev*Ee)/Ek-.5)>.3||Es*Er+Ef*Eg+Ey*Ex<Dv){DB(El,Ei,Ep,Es,Ef,Ey,Ew,Ej,En,a/=m,b/=m,c,EA,Ed);Ed.point(Ew,Ej);DB(Ew,Ej,En,a,b,c,Em,Eh,Eo,Er,Eg,Ex,EA,Ed);};};};Dw.precision=function(_){if(!arguments.length)return Math.sqrt(Dy);DA=(Dy=_*_)>0&&16;return Dw;};return Dw;};d3.geo.path=function(){var EG=4.5,ED,EF,EI,EC,EE;function EH(EJ){if(EJ){if(typeof EG===eG)EC.pointRadius(+EG.apply(this,arguments));if(!EE||!EE.valid)EE=EI(EC);d3.geo.stream(EJ,EE);};return EC.result();};EH.area=function(EK){d3_geo_pathAreaSum=0;d3.geo.stream(EK,EI(d3_geo_pathArea));return d3_geo_pathAreaSum;};EH.centroid=function(EL){d3_geo_centroidX0=d3_geo_centroidY0=d3_geo_centroidZ0=d3_geo_centroidX1=d3_geo_centroidY1=d3_geo_centroidZ1=d3_geo_centroidX2=d3_geo_centroidY2=d3_geo_centroidZ2=0;d3.geo.stream(EL,EI(d3_geo_pathCentroid));return d3_geo_centroidZ2?[d3_geo_centroidX2/d3_geo_centroidZ2,d3_geo_centroidY2/d3_geo_centroidZ2]:d3_geo_centroidZ1?[d3_geo_centroidX1/d3_geo_centroidZ1,d3_geo_centroidY1/d3_geo_centroidZ1]:d3_geo_centroidZ0?[d3_geo_centroidX0/d3_geo_centroidZ0,d3_geo_centroidY0/d3_geo_centroidZ0]:[NaN,NaN];};EH.bounds=function(EM){d3_geo_pathBoundsX1=d3_geo_pathBoundsY1=-(d3_geo_pathBoundsX0=d3_geo_pathBoundsY0=Infinity);d3.geo.stream(EM,EI(d3_geo_pathBounds));return [[d3_geo_pathBoundsX0,d3_geo_pathBoundsY0],[d3_geo_pathBoundsX1,d3_geo_pathBoundsY1]];};EH.projection=function(_){if(!arguments.length)return ED;EI=(ED=_)?_.stream||d3_geo_pathProjectStream(_):d3_identity;return EB();};EH.context=function(_){if(!arguments.length)return EF;EC=(EF=_)==null?new d3_geo_pathBuffer():new d3_geo_pathContext(_);if(typeof EG!==eG)EC.pointRadius(EG);return EB();};EH.pointRadius=function(_){if(!arguments.length)return EG;EG=typeof _===eG?_:(EC.pointRadius(+_),+_);return EH;};function EB(){EE=null;return EH;};return EH.projection(d3.geo.albersUsa()).context(null);};function d3_geo_pathProjectStream(EN){var EO=d3_geo_resample(function(x,y){return EN([x*d3_degrees,y*d3_degrees]);});return function(EP){return d3_geo_projectionRadians(EO(EP));};};d3.geo.transform=function(EQ){return {stream:function(ES){var ER=new d3_geo_transform(ES);for(var k in EQ)ER[k]=EQ[k];return ER;}};};function d3_geo_transform(ET){this.stream=ET;};d3_geo_transform.prototype={point:function(x,y){this.stream.point(x,y);},sphere:function(){this.stream.sphere();},lineStart:function(){this.stream.lineStart();},lineEnd:function(){this.stream.lineEnd();},polygonStart:function(){this.stream.polygonStart();},polygonEnd:function(){this.stream.polygonEnd();}};function d3_geo_transformPoint(EU,EV){return {point:EV,sphere:function(){EU.sphere();},lineStart:function(){EU.lineStart();},lineEnd:function(){EU.lineEnd();},polygonStart:function(){EU.polygonStart();},polygonEnd:function(){EU.polygonEnd();}};};d3.geo.projection=d3_geo_projection;d3.geo.projectionMutator=d3_geo_projectionMutator;function d3_geo_projection(EW){return d3_geo_projectionMutator(function(){return EW;})();};function d3_geo_projectionMutator(Fh){var Fp,Fl,Fc,Fj=d3_geo_resample(function(x,y){x=Fp(x,y);return [x[0]*k+Fn,Fo-x[1]*k];}),k=150,x=480,y=250,λ=0,φ=0,Fd=0,Fi=0,Fg=0,Fn,Fo,Fq=d3_geo_clipAntimeridian,Fb=d3_identity,Fe=null,Fm=null,Fa;function EY(Fr){Fr=Fc(Fr[0]*d3_radians,Fr[1]*d3_radians);return [Fr[0]*k+Fn,Fo-Fr[1]*k];};function Ff(Fs){Fs=Fc.invert((Fs[0]-Fn)/k,(Fo-Fs[1])/k);return Fs&&[Fs[0]*d3_degrees,Fs[1]*d3_degrees];};EY.stream=function(Ft){if(Fa)Fa.valid=false;Fa=d3_geo_projectionRadians(Fq(Fl,Fj(Fb(Ft))));Fa.valid=true;return Fa;};EY.clipAngle=function(_){if(!arguments.length)return Fe;Fq=_==null?(Fe=_,d3_geo_clipAntimeridian):d3_geo_clipCircle((Fe=+_)*d3_radians);return EX();};EY.clipExtent=function(_){if(!arguments.length)return Fm;Fm=_;Fb=_?d3_geo_clipExtent(_[0][0],_[0][1],_[1][0],_[1][1]):d3_identity;return EX();};EY.scale=function(_){if(!arguments.length)return k;k=+_;return Fk();};EY.translate=function(_){if(!arguments.length)return [x,y];x=+_[0];y=+_[1];return Fk();};EY.center=function(_){if(!arguments.length)return [λ*d3_degrees,φ*d3_degrees];λ=_[0]%360*d3_radians;φ=_[1]%360*d3_radians;return Fk();};EY.rotate=function(_){if(!arguments.length)return [Fd*d3_degrees,Fi*d3_degrees,Fg*d3_degrees];Fd=_[0]%360*d3_radians;Fi=_[1]%360*d3_radians;Fg=_.length>2?_[2]%360*d3_radians:0;return Fk();};d3.rebind(EY,Fj,dO);function Fk(){Fc=d3_geo_compose(Fl=d3_geo_rotation(Fd,Fi,Fg),Fp);var Fu=Fp(λ,φ);Fn=x-Fu[0]*k;Fo=y+Fu[1]*k;return EX();};function EX(){if(Fa)Fa.valid=false,Fa=null;return EY;};return function(){Fp=Fh.apply(this,arguments);EY.invert=Fp.invert&&Ff;return Fk();};};function d3_geo_projectionRadians(Fv){return d3_geo_transformPoint(Fv,function(x,y){Fv.point(x*d3_radians,y*d3_radians);});};function d3_geo_equirectangular(λ,φ){return [λ,φ];};(d3.geo.equirectangular=function(){return d3_geo_projection(d3_geo_equirectangular);}).raw=d3_geo_equirectangular.invert=d3_geo_equirectangular;d3.geo.rotation=function(Fw){Fw=d3_geo_rotation(Fw[0]%360*d3_radians,Fw[1]*d3_radians,Fw.length>2?Fw[2]*d3_radians:0);function forward(Fx){Fx=Fw(Fx[0]*d3_radians,Fx[1]*d3_radians);return Fx[0]*=d3_degrees,Fx[1]*=d3_degrees,Fx;};forward.invert=function(Fy){Fy=Fw.invert(Fy[0]*d3_radians,Fy[1]*d3_radians);return Fy[0]*=d3_degrees,Fy[1]*=d3_degrees,Fy;};return forward;};function d3_geo_identityRotation(λ,φ){return [λ>π?λ-τ:λ<-π?λ+τ:λ,φ];};d3_geo_identityRotation.invert=d3_geo_equirectangular;function d3_geo_rotation(FA,Fz,FB){return FA?Fz||FB?d3_geo_compose(d3_geo_rotationλ(FA),d3_geo_rotationφγ(Fz,FB)):d3_geo_rotationλ(FA):Fz||FB?d3_geo_rotationφγ(Fz,FB):d3_geo_identityRotation;};function d3_geo_forwardRotationλ(FC){return function(λ,φ){return λ+=FC,[λ>π?λ-τ:λ<-π?λ+τ:λ,φ];};};function d3_geo_rotationλ(FE){var FD=d3_geo_forwardRotationλ(FE);FD.invert=d3_geo_forwardRotationλ(-FE);return FD;};function d3_geo_rotationφγ(FJ,FH){var FF=Math.cos(FJ),FG=Math.sin(FJ),FI=Math.cos(FH),FL=Math.sin(FH);function FK(λ,φ){var FM=Math.cos(φ),x=Math.cos(λ)*FM,y=Math.sin(λ)*FM,z=Math.sin(φ),k=z*FF+x*FG;return [Math.atan2(y*FI-k*FL,x*FF-z*FG),d3_asin(k*FI+y*FL)];};FK.invert=function(λ,φ){var FN=Math.cos(φ),x=Math.cos(λ)*FN,y=Math.sin(λ)*FN,z=Math.sin(φ),k=z*FI-y*FL;return [Math.atan2(y*FI+z*FL,x*FF+k*FG),d3_asin(k*FF-x*FG)];};return FK;};d3.geo.circle=function(){var FO=[0,0],FQ,FR=6,FS;function FP(){var FV=typeof FO===eG?FO.apply(this,arguments):FO,FU=d3_geo_rotation(-FV[0]*d3_radians,-FV[1]*d3_radians,0).invert,FT=[];FS(null,null,1,{point:function(x,y){FT.push(x=FU(x,y));x[0]*=d3_degrees,x[1]*=d3_degrees;}});return {type:fU,coordinates:[FT]};};FP.origin=function(x){if(!arguments.length)return FO;FO=x;return FP;};FP.angle=function(x){if(!arguments.length)return FQ;FS=d3_geo_circleInterpolate((FQ=+x)*d3_radians,FR*d3_radians);return FP;};FP.precision=function(_){if(!arguments.length)return FR;FS=d3_geo_circleInterpolate(FQ*d3_radians,(FR=+_)*d3_radians);return FP;};return FP.angle(90);};function d3_geo_circleInterpolate(FX,FY){var FW=Math.cos(FX),Ga=Math.sin(FX);return function(Gc,Gf,Gb,Ge){var Gg=Gb*FY;if(Gc!=null){Gc=d3_geo_circleAngle(FW,Gc);Gf=d3_geo_circleAngle(FW,Gf);if(Gb>0?Gc<Gf:Gc>Gf)Gc+=Gb*τ;}else {Gc=FX+Gb*τ;Gf=FX-.5*Gg;};for(var Gd,t=Gc;Gb>0?t>Gf:t<Gf;t-=Gg){Ge.point((Gd=d3_geo_spherical([FW,-Ga*Math.cos(t),-Ga*Math.sin(t)]))[0],Gd[1]);};};};function d3_geo_circleAngle(Gh,Gj){var a=d3_geo_cartesian(Gj);a[0]-=Gh;d3_geo_cartesianNormalize(a);var Gi=d3_acos(-a[1]);return ((-a[2]<0?-Gi:Gi)+2*Math.PI-ε)%(2*Math.PI);};d3.geo.distance=function(a,b){var Gl=(b[0]-a[0])*d3_radians,Gk=a[1]*d3_radians,Gm=b[1]*d3_radians,Gp=Math.sin(Gl),Gs=Math.cos(Gl),Gn=Math.sin(Gk),Gq=Math.cos(Gk),Go=Math.sin(Gm),Gr=Math.cos(Gm),t;return Math.atan2(Math.sqrt((t=Gr*Gp)*t+(t=Gq*Go-Gn*Gr*Gs)*t),Gn*Go+Gq*Gr*Gs);};d3.geo.graticule=function(){var GE,GD,Gx,GG,Gw,Gu,Gv,Gt,GF=10,GC=GF,GB=90,Gy=360,x,y,X,Y,GA=2.5;function GH(){return {type:bF,coordinates:Gz()};};function Gz(){return d3.range(Math.ceil(GG/GB)*GB,Gx,GB).map(X).concat(d3.range(Math.ceil(Gt/Gy)*Gy,Gv,Gy).map(Y)).concat(d3.range(Math.ceil(GD/GF)*GF,GE,GF).filter(function(x){return abs(x%GB)>ε;}).map(x)).concat(d3.range(Math.ceil(Gu/GC)*GC,Gw,GC).filter(function(y){return abs(y%Gy)>ε;}).map(y));};GH.lines=function(){return Gz().map(function(GI){return {type:dk,coordinates:GI};});};GH.outline=function(){return {type:fU,coordinates:[X(GG).concat(Y(Gv).slice(1),X(Gx).reverse().slice(1),Y(Gt).reverse().slice(1))]};};GH.extent=function(_){if(!arguments.length)return GH.minorExtent();return GH.majorExtent(_).minorExtent(_);};GH.majorExtent=function(_){if(!arguments.length)return [[GG,Gt],[Gx,Gv]];GG=+_[0][0],Gx=+_[1][0];Gt=+_[0][1],Gv=+_[1][1];if(GG>Gx)_=GG,GG=Gx,Gx=_;if(Gt>Gv)_=Gt,Gt=Gv,Gv=_;return GH.precision(GA);};GH.minorExtent=function(_){if(!arguments.length)return [[GD,Gu],[GE,Gw]];GD=+_[0][0],GE=+_[1][0];Gu=+_[0][1],Gw=+_[1][1];if(GD>GE)_=GD,GD=GE,GE=_;if(Gu>Gw)_=Gu,Gu=Gw,Gw=_;return GH.precision(GA);};GH.step=function(_){if(!arguments.length)return GH.minorStep();return GH.majorStep(_).minorStep(_);};GH.majorStep=function(_){if(!arguments.length)return [GB,Gy];GB=+_[0],Gy=+_[1];return GH;};GH.minorStep=function(_){if(!arguments.length)return [GF,GC];GF=+_[0],GC=+_[1];return GH;};GH.precision=function(_){if(!arguments.length)return GA;GA=+_;x=d3_geo_graticuleX(Gu,Gw,90);y=d3_geo_graticuleY(GD,GE,GA);X=d3_geo_graticuleX(Gt,Gv,90);Y=d3_geo_graticuleY(GG,Gx,GA);return GH;};return GH.majorExtent([[-180,-90+ε],[180,90-ε]]).minorExtent([[-180,-80-ε],[180,80+ε]]);};function d3_geo_graticuleX(GK,GJ,GL){var y=d3.range(GK,GJ-ε,GL).concat(GJ);return function(x){return y.map(function(y){return [x,y];});};};function d3_geo_graticuleY(GM,GN,GO){var x=d3.range(GM,GN-ε,GO).concat(GN);return function(y){return x.map(function(x){return [x,y];});};};function d3_source(d){return d.source;};function d3_target(d){return d.target;};d3.geo.greatArc=function(){var GT=d3_source,GR,GP=d3_target,GQ;function GS(){return {type:dk,coordinates:[GR||GT.apply(this,arguments),GQ||GP.apply(this,arguments)]};};GS.distance=function(){return d3.geo.distance(GR||GT.apply(this,arguments),GQ||GP.apply(this,arguments));};GS.source=function(_){if(!arguments.length)return GT;GT=_,GR=typeof _===eG?null:_;return GS;};GS.target=function(_){if(!arguments.length)return GP;GP=_,GQ=typeof _===eG?null:_;return GS;};GS.precision=function(){return arguments.length?GS:0;};return GS;};d3.geo.interpolate=function(GU,GV){return d3_geo_interpolate(GU[0]*d3_radians,GU[1]*d3_radians,GV[0]*d3_radians,GV[1]*d3_radians);};function d3_geo_interpolate(Hh,He,Hj,Hb){var GY=Math.cos(He),Hd=Math.sin(He),GX=Math.cos(Hb),Hc=Math.sin(Hb),Hf=GY*Math.cos(Hh),Hi=GY*Math.sin(Hh),Hg=GX*Math.cos(Hj),GW=GX*Math.sin(Hj),d=2*Math.asin(Math.sqrt(d3_haversin(Hb-He)+GY*GX*d3_haversin(Hj-Hh))),k=1/Math.sin(d);var Ha=d?function(t){var B=Math.sin(t*=d)*k,A=Math.sin(d-t)*k,x=A*Hf+B*Hg,y=A*Hi+B*GW,z=A*Hd+B*Hc;return [Math.atan2(y,x)*d3_degrees,Math.atan2(z,Math.sqrt(x*x+y*y))*d3_degrees];}:function(){return [Hh*d3_degrees,He*d3_degrees];};Ha.distance=d;return Ha;};d3.geo.length=function(Hk){d3_geo_lengthSum=0;d3.geo.stream(Hk,d3_geo_length);return d3_geo_lengthSum;};var d3_geo_lengthSum;var d3_geo_length={sphere:d3_noop,point:d3_noop,lineStart:d3_geo_lengthLineStart,lineEnd:d3_noop,polygonStart:d3_noop,polygonEnd:d3_noop};function d3_geo_lengthLineStart(){var Hn,Hl,Hm;d3_geo_length.point=function(λ,φ){Hn=λ*d3_radians,Hl=Math.sin(φ*=d3_radians),Hm=Math.cos(φ);d3_geo_length.point=Ho;};d3_geo_length.lineEnd=function(){d3_geo_length.point=d3_geo_length.lineEnd=d3_noop;};function Ho(λ,φ){var Hq=Math.sin(φ*=d3_radians),Hp=Math.cos(φ),t=abs((λ*=d3_radians)-Hn),Hr=Math.cos(t);d3_geo_lengthSum+=Math.atan2(Math.sqrt((t=Hp*Math.sin(t))*t+(t=Hm*Hq-Hl*Hp*Hr)*t),Hl*Hq+Hm*Hp*Hr);Hn=λ,Hl=Hq,Hm=Hp;};};function d3_geo_azimuthal(Hs,Ht){function Hu(λ,φ){var Hw=Math.cos(λ),Hv=Math.cos(φ),k=Hs(Hw*Hv);return [k*Hv*Math.sin(λ),k*Math.sin(φ)];};Hu.invert=function(x,y){var ρ=Math.sqrt(x*x+y*y),c=Ht(ρ),Hy=Math.sin(c),Hx=Math.cos(c);return [Math.atan2(x*Hy,ρ*Hx),Math.asin(ρ&&y*Hy/ρ)];};return Hu;};var d3_geo_azimuthalEqualArea=d3_geo_azimuthal(function(Hz){return Math.sqrt(2/(1+Hz));},function(ρ){return 2*Math.asin(ρ/2);});(d3.geo.azimuthalEqualArea=function(){return d3_geo_projection(d3_geo_azimuthalEqualArea);}).raw=d3_geo_azimuthalEqualArea;var d3_geo_azimuthalEquidistant=d3_geo_azimuthal(function(HA){var c=Math.acos(HA);return c&&c/Math.sin(c);},d3_identity);(d3.geo.azimuthalEquidistant=function(){return d3_geo_projection(d3_geo_azimuthalEquidistant);}).raw=d3_geo_azimuthalEquidistant;function d3_geo_conicConformal(HB,HC){var HD=Math.cos(HB),t=function(φ){return Math.tan(π/4+φ/2);},n=HB===HC?Math.sin(HB):Math.log(HD/Math.cos(HC))/Math.log(t(HC)/t(HB)),F=HD*Math.pow(t(HB),n)/n;if(!n)return d3_geo_mercator;function forward(λ,φ){if(F>0){if(φ<-halfπ+ε)φ=-halfπ+ε;}else {if(φ>halfπ-ε)φ=halfπ-ε;};var ρ=F/Math.pow(t(φ),n);return [ρ*Math.sin(n*λ),F-ρ*Math.cos(n*λ)];};forward.invert=function(x,y){var HE=F-y,ρ=d3_sgn(n)*Math.sqrt(x*x+HE*HE);return [Math.atan2(x,HE)/n,2*Math.atan(Math.pow(F/ρ,1/n))-halfπ];};return forward;};(d3.geo.conicConformal=function(){return d3_geo_conic(d3_geo_conicConformal);}).raw=d3_geo_conicConformal;function d3_geo_conicEquidistant(HF,HG){var HH=Math.cos(HF),n=HF===HG?Math.sin(HF):(HH-Math.cos(HG))/(HG-HF),G=HH/n+HF;if(abs(n)<ε)return d3_geo_equirectangular;function forward(λ,φ){var ρ=G-φ;return [ρ*Math.sin(n*λ),G-ρ*Math.cos(n*λ)];};forward.invert=function(x,y){var HI=G-y;return [Math.atan2(x,HI)/n,G-d3_sgn(n)*Math.sqrt(x*x+HI*HI)];};return forward;};(d3.geo.conicEquidistant=function(){return d3_geo_conic(d3_geo_conicEquidistant);}).raw=d3_geo_conicEquidistant;var d3_geo_gnomonic=d3_geo_azimuthal(function(HJ){return 1/HJ;},Math.atan);(d3.geo.gnomonic=function(){return d3_geo_projection(d3_geo_gnomonic);}).raw=d3_geo_gnomonic;function d3_geo_mercator(λ,φ){return [λ,Math.log(Math.tan(π/4+φ/2))];};d3_geo_mercator.invert=function(x,y){return [x,2*Math.atan(Math.exp(y))-halfπ];};function d3_geo_mercatorProjection(HN){var m=d3_geo_projection(HN),HK=m.scale,HM=m.translate,HL=m.clipExtent,HO;m.scale=function(){var v=HK.apply(m,arguments);return v===m?HO?m.clipExtent(null):m:v;};m.translate=function(){var v=HM.apply(m,arguments);return v===m?HO?m.clipExtent(null):m:v;};m.clipExtent=function(_){var v=HL.apply(m,arguments);if(v===m){if(HO=_==null){var k=π*HK(),t=HM();HL([[t[0]-k,t[1]-k],[t[0]+k,t[1]+k]]);};}else if(HO){v=null;};return v;};return m.clipExtent(null);};(d3.geo.mercator=function(){return d3_geo_mercatorProjection(d3_geo_mercator);}).raw=d3_geo_mercator;var d3_geo_orthographic=d3_geo_azimuthal(function(){return 1;},Math.asin);(d3.geo.orthographic=function(){return d3_geo_projection(d3_geo_orthographic);}).raw=d3_geo_orthographic;var d3_geo_stereographic=d3_geo_azimuthal(function(HP){return 1/(1+HP);},function(ρ){return 2*Math.atan(ρ);});(d3.geo.stereographic=function(){return d3_geo_projection(d3_geo_stereographic);}).raw=d3_geo_stereographic;function d3_geo_transverseMercator(λ,φ){return [Math.log(Math.tan(π/4+φ/2)),-λ];};d3_geo_transverseMercator.invert=function(x,y){return [-y,2*Math.atan(Math.exp(x))-halfπ];};(d3.geo.transverseMercator=function(){var HR=d3_geo_mercatorProjection(d3_geo_transverseMercator),HS=HR.center,HQ=HR.rotate;HR.center=function(_){return _?HS([-_[1],_[0]]):(_=HS(),[_[1],-_[0]]);};HR.rotate=function(_){return _?HQ([_[0],_[1],_.length>2?_[2]+90:90]):(_=HQ(),[_[0],_[1],_[2]-90]);};return HQ([0,0,90]);}).raw=d3_geo_transverseMercator;d3.geom={};function d3_geom_pointX(d){return d[0];};function d3_geom_pointY(d){return d[1];};d3.geom.hull=function(HT){var x=d3_geom_pointX,y=d3_geom_pointY;if(arguments.length)return HU(HT);function HU(If){if(If.length<3)return [];var Id=d3_functor(x),Ib=d3_functor(y),i,n=If.length,Ie=[],HV=[];for(i=0;i<n;i++ ){Ie.push([+Id.call(this,If[i],i),+Ib.call(this,If[i],i),i]);};Ie.sort(d3_geom_hullOrder);for(i=0;i<n;i++ )HV.push([Ie[i][0],-Ie[i][1]]);var HW=d3_geom_hullUpper(Ie),HX=d3_geom_hullUpper(HV);var Ic=HX[0]===HW[0],Ia=HX[HX.length-1]===HW[HW.length-1],HY=[];for(i=HW.length-1;i>=0; --i)HY.push(If[Ie[HW[i]][2]]);for(i=+Ic;i<HX.length-Ia; ++i)HY.push(If[Ie[HX[i]][2]]);return HY;};HU.x=function(_){return arguments.length?(x=_,HU):x;};HU.y=function(_){return arguments.length?(y=_,HU):y;};return HU;};function d3_geom_hullUpper(Ih){var n=Ih.length,Ig=[0,1],Ii=2;for(var i=2;i<n;i++ ){while(Ii>1&&d3_cross2d(Ih[Ig[Ii-2]],Ih[Ig[Ii-1]],Ih[i])<=0) --Ii;Ig[Ii++ ]=i;};return Ig.slice(0,Ii);};function d3_geom_hullOrder(a,b){return a[0]-b[0]||a[1]-b[1];};d3.geom.polygon=function(Ij){d3_subclass(Ij,d3_geom_polygonPrototype);return Ij;};var d3_geom_polygonPrototype=d3.geom.polygon.prototype=[];d3_geom_polygonPrototype.area=function(){var i=-1,n=this.length,a,b=this[n-1],Ik=0;while( ++i<n){a=b;b=this[i];Ik+=a[1]*b[0]-a[0]*b[1];};return Ik*.5;};d3_geom_polygonPrototype.centroid=function(k){var i=-1,n=this.length,x=0,y=0,a,b=this[n-1],c;if(!arguments.length)k=-1/(6*this.area());while( ++i<n){a=b;b=this[i];c=a[0]*b[1]-b[0]*a[1];x+=(a[0]+b[0])*c;y+=(a[1]+b[1])*c;};return [x*k,y*k];};d3_geom_polygonPrototype.clip=function(Im){var Il,closed=d3_geom_polygonClosed(Im),i=-1,n=this.length-d3_geom_polygonClosed(this),j,m,a=this[n-1],b,c,d;while( ++i<n){Il=Im.slice();Im.length=0;b=this[i];c=Il[(m=Il.length-closed)-1];j=-1;while( ++j<m){d=Il[j];if(d3_geom_polygonInside(d,a,b)){if(!d3_geom_polygonInside(c,a,b)){Im.push(d3_geom_polygonIntersect(c,d,a,b));};Im.push(d);}else if(d3_geom_polygonInside(c,a,b)){Im.push(d3_geom_polygonIntersect(c,d,a,b));};c=d;};if(closed)Im.push(Im[0]);a=b;};return Im;};function d3_geom_polygonInside(p,a,b){return (b[0]-a[0])*(p[1]-a[1])<(b[1]-a[1])*(p[0]-a[0]);};function d3_geom_polygonIntersect(c,d,a,b){var Iu=c[0],Iq=a[0],Io=d[0]-Iu,In=b[0]-Iq,Ir=c[1],It=a[1],Is=d[1]-Ir,Ip=b[1]-It,Iv=(In*(Ir-It)-Ip*(Iu-Iq))/(Ip*Io-In*Is);return [Iu+Iv*Io,Ir+Iv*Is];};function d3_geom_polygonClosed(Iw){var a=Iw[0],b=Iw[Iw.length-1];return !(a[0]-b[0]||a[1]-b[1]);};var d3_geom_voronoiEdges,d3_geom_voronoiCells,d3_geom_voronoiBeaches,d3_geom_voronoiBeachPool=[],d3_geom_voronoiFirstCircle,d3_geom_voronoiCircles,d3_geom_voronoiCirclePool=[];function d3_geom_voronoiBeach(){d3_geom_voronoiRedBlackNode(this);this.edge=this.site=this.circle=null;};function d3_geom_voronoiCreateBeach(Iy){var Ix=d3_geom_voronoiBeachPool.pop()||new d3_geom_voronoiBeach();Ix.site=Iy;return Ix;};function d3_geom_voronoiDetachBeach(Iz){d3_geom_voronoiDetachCircle(Iz);d3_geom_voronoiBeaches.remove(Iz);d3_geom_voronoiBeachPool.push(Iz);d3_geom_voronoiRedBlackNode(Iz);};function d3_geom_voronoiRemoveBeach(II){var IH=II.circle,x=IH.x,y=IH.cy,IB={x:x,y:y},IJ=II.P,IC=II.N,IF=[II];d3_geom_voronoiDetachBeach(II);var ID=IJ;while(ID.circle&&abs(x-ID.circle.x)<ε&&abs(y-ID.circle.cy)<ε){IJ=ID.P;IF.unshift(ID);d3_geom_voronoiDetachBeach(ID);ID=IJ;};IF.unshift(ID);d3_geom_voronoiDetachCircle(ID);var IA=IC;while(IA.circle&&abs(x-IA.circle.x)<ε&&abs(y-IA.circle.cy)<ε){IC=IA.N;IF.push(IA);d3_geom_voronoiDetachBeach(IA);IA=IC;};IF.push(IA);d3_geom_voronoiDetachCircle(IA);var IG=IF.length,IE;for(IE=1;IE<IG; ++IE){IA=IF[IE];ID=IF[IE-1];d3_geom_voronoiSetEdgeEnd(IA.edge,ID.site,IA.site,IB);};ID=IF[0];IA=IF[IG-1];IA.edge=d3_geom_voronoiCreateEdge(ID.site,IA.site,null,IB);d3_geom_voronoiAttachCircle(ID);d3_geom_voronoiAttachCircle(IA);};function d3_geom_voronoiAddBeach(IS){var x=IS.x,IL=IS.y,IU,IM,IO,IT,IK=d3_geom_voronoiBeaches._;while(IK){IO=d3_geom_voronoiLeftBreakPoint(IK,IL)-x;if(IO>ε)IK=IK.L;else {IT=x-d3_geom_voronoiRightBreakPoint(IK,IL);if(IT>ε){if(!IK.R){IU=IK;break;};IK=IK.R;}else {if(IO>-ε){IU=IK.P;IM=IK;}else if(IT>-ε){IU=IK;IM=IK.N;}else {IU=IM=IK;};break;};};};var Jc=d3_geom_voronoiCreateBeach(IS);d3_geom_voronoiBeaches.insert(IU,Jc);if(!IU&&!IM)return;if(IU===IM){d3_geom_voronoiDetachCircle(IU);IM=d3_geom_voronoiCreateBeach(IU.site);d3_geom_voronoiBeaches.insert(Jc,IM);Jc.edge=IM.edge=d3_geom_voronoiCreateEdge(IU.site,Jc.site);d3_geom_voronoiAttachCircle(IU);d3_geom_voronoiAttachCircle(IM);return;};if(!IM){Jc.edge=d3_geom_voronoiCreateEdge(IU.site,Jc.site);return;};d3_geom_voronoiDetachCircle(IU);d3_geom_voronoiDetachCircle(IM);var IP=IU.site,IY=IP.x,IV=IP.y,IN=IS.x-IY,Jd=IS.y-IV,IQ=IM.site,IX=IQ.x-IY,IW=IQ.y-IV,d=2*(IN*IW-Jd*IX),Ja=IN*IN+Jd*Jd,Jb=IX*IX+IW*IW,IR={x:(IW*Ja-Jd*Jb)/d+IY,y:(IN*Jb-IX*Ja)/d+IV};d3_geom_voronoiSetEdgeEnd(IM.edge,IP,IQ,IR);Jc.edge=d3_geom_voronoiCreateEdge(IP,IS,null,IR);IM.edge=d3_geom_voronoiCreateEdge(IS,IQ,null,IR);d3_geom_voronoiAttachCircle(IU);d3_geom_voronoiAttachCircle(IM);};function d3_geom_voronoiLeftBreakPoint(Jk,Je){var Ji=Jk.site,Jh=Ji.x,Jg=Ji.y,Jp=Jg-Je;if(!Jp)return Jh;var Jj=Jk.P;if(!Jj)return -Infinity;Ji=Jj.site;var Jm=Ji.x,Jl=Ji.y,Jf=Jl-Je;if(!Jf)return Jm;var Jn=Jm-Jh,Jo=1/Jp-1/Jf,b=Jn/Jf;if(Jo)return (-b+Math.sqrt(b*b-2*Jo*(Jn*Jn/(-2*Jf)-Jl+Jf/2+Jg-Jp/2)))/Jo+Jh;return (Jh+Jm)/2;};function d3_geom_voronoiRightBreakPoint(Js,Jq){var Jr=Js.N;if(Jr)return d3_geom_voronoiLeftBreakPoint(Jr,Jq);var Jt=Js.site;return Jt.y===Jq?Jt.x:Infinity;};function d3_geom_voronoiCell(Ju){this.site=Ju;this.edges=[];};d3_geom_voronoiCell.prototype.prepare=function(){var Jv=this.edges,Jx=Jv.length,Jw;while(Jx-- ){Jw=Jv[Jx].edge;if(!Jw.b||!Jw.a)Jv.splice(Jx,1);};Jv.sort(d3_geom_voronoiHalfEdgeOrder);return Jv.length;};function d3_geom_voronoiCloseCells(JH){var JL=JH[0][0],Jz=JH[1][0],Jy=JH[0][1],JB=JH[1][1],JJ,JM,JI,JN,JD=d3_geom_voronoiCells,JC=JD.length,JF,JA,JO,JE,JG,JK;while(JC-- ){JF=JD[JC];if(!JF||!JF.prepare())continue;JO=JF.edges;JE=JO.length;JA=0;while(JA<JE){JK=JO[JA].end(),JI=JK.x,JN=JK.y;JG=JO[ ++JA%JE].start(),JJ=JG.x,JM=JG.y;if(abs(JI-JJ)>ε||abs(JN-JM)>ε){JO.splice(JA,0,new d3_geom_voronoiHalfEdge(d3_geom_voronoiCreateBorderEdge(JF.site,JK,abs(JI-JL)<ε&&JB-JN>ε?{x:JL,y:abs(JJ-JL)<ε?JM:JB}:abs(JN-JB)<ε&&Jz-JI>ε?{x:abs(JM-JB)<ε?JJ:Jz,y:JB}:abs(JI-Jz)<ε&&JN-Jy>ε?{x:Jz,y:abs(JJ-Jz)<ε?JM:Jy}:abs(JN-Jy)<ε&&JI-JL>ε?{x:abs(JM-Jy)<ε?JJ:JL,y:Jy}:null),JF.site,null)); ++JE;};};};};function d3_geom_voronoiHalfEdgeOrder(a,b){return b.angle-a.angle;};function d3_geom_voronoiCircle(){d3_geom_voronoiRedBlackNode(this);this.x=this.y=this.arc=this.site=this.cy=null;};function d3_geom_voronoiAttachCircle(JT){var JQ=JT.P,JR=JT.N;if(!JQ||!JR)return;var JV=JQ.site,JS=JT.site,JU=JR.site;if(JV===JU)return;var Ke=JS.x,Kf=JS.y,Ka=JV.x-Ke,JW=JV.y-Kf,JY=JU.x-Ke,JX=JU.y-Kf;var d=2*(Ka*JX-JW*JY);if(d>=-ε2)return;var Kd=Ka*Ka+JW*JW,Kb=JY*JY+JX*JX,x=(JX*Kd-JW*Kb)/d,y=(Ka*Kb-JY*Kd)/d,JX=y+Kf;var Kc=d3_geom_voronoiCirclePool.pop()||new d3_geom_voronoiCircle();Kc.arc=JT;Kc.site=JS;Kc.x=x+Ke;Kc.y=JX+Math.sqrt(x*x+y*y);Kc.cy=JX;JT.circle=Kc;var Kg=null,JP=d3_geom_voronoiCircles._;while(JP){if(Kc.y<JP.y||Kc.y===JP.y&&Kc.x<=JP.x){if(JP.L)JP=JP.L;else {Kg=JP.P;break;};}else {if(JP.R)JP=JP.R;else {Kg=JP;break;};};};d3_geom_voronoiCircles.insert(Kg,Kc);if(!Kg)d3_geom_voronoiFirstCircle=Kc;};function d3_geom_voronoiDetachCircle(Ki){var Kh=Ki.circle;if(Kh){if(!Kh.P)d3_geom_voronoiFirstCircle=Kh.N;d3_geom_voronoiCircles.remove(Kh);d3_geom_voronoiCirclePool.push(Kh);d3_geom_voronoiRedBlackNode(Kh);Ki.circle=null;};};function d3_geom_voronoiClipEdges(Kk){var Kj=d3_geom_voronoiEdges,Kl=d3_geom_clipLine(Kk[0][0],Kk[0][1],Kk[1][0],Kk[1][1]),i=Kj.length,e;while(i-- ){e=Kj[i];if(!d3_geom_voronoiConnectEdge(e,Kk)||!Kl(e)||abs(e.a.x-e.b.x)<ε&&abs(e.a.y-e.b.y)<ε){e.a=e.b=null;Kj.splice(i,1);};};};function d3_geom_voronoiConnectEdge(Kv,Kw){var Kn=Kv.b;if(Kn)return true;var Km=Kv.a,Kz=Kw[0][0],KA=Kw[1][0],Ky=Kw[0][1],Kx=Kw[1][1],Kt=Kv.l,Ku=Kv.r,KC=Kt.x,KD=Kt.y,Kq=Ku.x,Kr=Ku.y,Ko=(KC+Kq)/2,Kp=(KD+Kr)/2,Ks,KB;if(Kr===KD){if(Ko<Kz||Ko>=KA)return;if(KC>Kq){if(!Km)Km={x:Ko,y:Ky};else if(Km.y>=Kx)return;Kn={x:Ko,y:Kx};}else {if(!Km)Km={x:Ko,y:Kx};else if(Km.y<Ky)return;Kn={x:Ko,y:Ky};};}else {Ks=(KC-Kq)/(Kr-KD);KB=Kp-Ks*Ko;if(Ks<-1||Ks>1){if(KC>Kq){if(!Km)Km={x:(Ky-KB)/Ks,y:Ky};else if(Km.y>=Kx)return;Kn={x:(Kx-KB)/Ks,y:Kx};}else {if(!Km)Km={x:(Kx-KB)/Ks,y:Kx};else if(Km.y<Ky)return;Kn={x:(Ky-KB)/Ks,y:Ky};};}else {if(KD<Kr){if(!Km)Km={x:Kz,y:Ks*Kz+KB};else if(Km.x>=KA)return;Kn={x:KA,y:Ks*KA+KB};}else {if(!Km)Km={x:KA,y:Ks*KA+KB};else if(Km.x<Kz)return;Kn={x:Kz,y:Ks*Kz+KB};};};};Kv.a=Km;Kv.b=Kn;return true;};function d3_geom_voronoiEdge(KE,KF){this.l=KE;this.r=KF;this.a=this.b=null;};function d3_geom_voronoiCreateEdge(KG,KI,KH,KK){var KJ=new d3_geom_voronoiEdge(KG,KI);d3_geom_voronoiEdges.push(KJ);if(KH)d3_geom_voronoiSetEdgeEnd(KJ,KG,KI,KH);if(KK)d3_geom_voronoiSetEdgeEnd(KJ,KI,KG,KK);d3_geom_voronoiCells[KG.i].edges.push(new d3_geom_voronoiHalfEdge(KJ,KG,KI));d3_geom_voronoiCells[KI.i].edges.push(new d3_geom_voronoiHalfEdge(KJ,KI,KG));return KJ;};function d3_geom_voronoiCreateBorderEdge(KL,KM,KN){var KO=new d3_geom_voronoiEdge(KL,null);KO.a=KM;KO.b=KN;d3_geom_voronoiEdges.push(KO);return KO;};function d3_geom_voronoiSetEdgeEnd(KR,KP,KQ,KS){if(!KR.a&&!KR.b){KR.a=KS;KR.l=KP;KR.r=KQ;}else if(KR.l===KQ){KR.b=KS;}else {KR.a=KS;};};function d3_geom_voronoiHalfEdge(KW,KT,KX){var KU=KW.a,KV=KW.b;this.edge=KW;this.site=KT;this.angle=KX?Math.atan2(KX.y-KT.y,KX.x-KT.x):KW.l===KT?Math.atan2(KV.x-KU.x,KU.y-KV.y):Math.atan2(KU.x-KV.x,KV.y-KU.y);};d3_geom_voronoiHalfEdge.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b;},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a;}};function d3_geom_voronoiRedBlackTree(){this._=null;};function d3_geom_voronoiRedBlackNode(KY){KY.U=KY.C=KY.L=KY.R=KY.P=KY.N=null;};d3_geom_voronoiRedBlackTree.prototype={insert:function(Lc,La){var parent,Lb,Ld;if(Lc){La.P=Lc;La.N=Lc.N;if(Lc.N)Lc.N.P=La;Lc.N=La;if(Lc.R){Lc=Lc.R;while(Lc.L)Lc=Lc.L;Lc.L=La;}else {Lc.R=La;};parent=Lc;}else if(this._){Lc=d3_geom_voronoiRedBlackFirst(this._);La.P=null;La.N=Lc;Lc.P=Lc.L=La;parent=Lc;}else {La.P=La.N=null;this._=La;parent=null;};La.L=La.R=null;La.U=parent;La.C=true;Lc=La;while(parent&&parent.C){Lb=parent.U;if(parent===Lb.L){Ld=Lb.R;if(Ld&&Ld.C){parent.C=Ld.C=false;Lb.C=true;Lc=Lb;}else {if(Lc===parent.R){d3_geom_voronoiRedBlackRotateLeft(this,parent);Lc=parent;parent=Lc.U;};parent.C=false;Lb.C=true;d3_geom_voronoiRedBlackRotateRight(this,Lb);};}else {Ld=Lb.L;if(Ld&&Ld.C){parent.C=Ld.C=false;Lb.C=true;Lc=Lb;}else {if(Lc===parent.L){d3_geom_voronoiRedBlackRotateRight(this,parent);Lc=parent;parent=Lc.U;};parent.C=false;Lb.C=true;d3_geom_voronoiRedBlackRotateLeft(this,Lb);};};parent=Lc.U;};this._.C=false;},remove:function(Le){if(Le.N)Le.N.P=Le.P;if(Le.P)Le.P.N=Le.N;Le.N=Le.P=null;var parent=Le.U,Lh,Lj=Le.L,Lf=Le.R,Lg,Li;if(!Lj)Lg=Lf;else if(!Lf)Lg=Lj;else Lg=d3_geom_voronoiRedBlackFirst(Lf);if(parent){if(parent.L===Le)parent.L=Lg;else parent.R=Lg;}else {this._=Lg;};if(Lj&&Lf){Li=Lg.C;Lg.C=Le.C;Lg.L=Lj;Lj.U=Lg;if(Lg!==Lf){parent=Lg.U;Lg.U=Le.U;Le=Lg.R;parent.L=Le;Lg.R=Lf;Lf.U=Lg;}else {Lg.U=parent;parent=Lg;Le=Lg.R;};}else {Li=Le.C;Le=Lg;};if(Le)Le.U=parent;if(Li)return;if(Le&&Le.C){Le.C=false;return;};do {if(Le===this._)break;if(Le===parent.L){Lh=parent.R;if(Lh.C){Lh.C=false;parent.C=true;d3_geom_voronoiRedBlackRotateLeft(this,parent);Lh=parent.R;};if(Lh.L&&Lh.L.C||Lh.R&&Lh.R.C){if(!Lh.R||!Lh.R.C){Lh.L.C=false;Lh.C=true;d3_geom_voronoiRedBlackRotateRight(this,Lh);Lh=parent.R;};Lh.C=parent.C;parent.C=Lh.R.C=false;d3_geom_voronoiRedBlackRotateLeft(this,parent);Le=this._;break;};}else {Lh=parent.L;if(Lh.C){Lh.C=false;parent.C=true;d3_geom_voronoiRedBlackRotateRight(this,parent);Lh=parent.L;};if(Lh.L&&Lh.L.C||Lh.R&&Lh.R.C){if(!Lh.L||!Lh.L.C){Lh.R.C=false;Lh.C=true;d3_geom_voronoiRedBlackRotateLeft(this,Lh);Lh=parent.L;};Lh.C=parent.C;parent.C=Lh.L.C=false;d3_geom_voronoiRedBlackRotateRight(this,parent);Le=this._;break;};};Lh.C=true;Le=parent;parent=parent.U;}while(!Le.C);if(Le)Le.C=false;}};function d3_geom_voronoiRedBlackRotateLeft(Ll,Lk){var p=Lk,q=Lk.R,parent=p.U;if(parent){if(parent.L===p)parent.L=q;else parent.R=q;}else {Ll._=q;};q.U=parent;p.U=q;p.R=q.L;if(p.R)p.R.U=p;q.L=p;};function d3_geom_voronoiRedBlackRotateRight(Ln,Lm){var p=Lm,q=Lm.L,parent=p.U;if(parent){if(parent.L===p)parent.L=q;else parent.R=q;}else {Ln._=q;};q.U=parent;p.U=q;p.L=q.R;if(p.L)p.L.U=p;q.R=p;};function d3_geom_voronoiRedBlackFirst(Lo){while(Lo.L)Lo=Lo.L;return Lo;};function d3_geom_voronoi(Lq,Ls){var Lp=Lq.sort(d3_geom_voronoiVertexOrder).pop(),Lu,Lt,Lv;d3_geom_voronoiEdges=[];d3_geom_voronoiCells=new Array(Lq.length);d3_geom_voronoiBeaches=new d3_geom_voronoiRedBlackTree();d3_geom_voronoiCircles=new d3_geom_voronoiRedBlackTree();while(true){Lv=d3_geom_voronoiFirstCircle;if(Lp&&(!Lv||Lp.y<Lv.y||Lp.y===Lv.y&&Lp.x<Lv.x)){if(Lp.x!==Lu||Lp.y!==Lt){d3_geom_voronoiCells[Lp.i]=new d3_geom_voronoiCell(Lp);d3_geom_voronoiAddBeach(Lp);Lu=Lp.x,Lt=Lp.y;};Lp=Lq.pop();}else if(Lv){d3_geom_voronoiRemoveBeach(Lv.arc);}else {break;};};if(Ls)d3_geom_voronoiClipEdges(Ls),d3_geom_voronoiCloseCells(Ls);var Lr={cells:d3_geom_voronoiCells,edges:d3_geom_voronoiEdges};d3_geom_voronoiBeaches=d3_geom_voronoiCircles=d3_geom_voronoiEdges=d3_geom_voronoiCells=null;return Lr;};function d3_geom_voronoiVertexOrder(a,b){return b.y-a.y||b.x-a.x;};d3.geom.voronoi=function(LB){var x=d3_geom_pointX,y=d3_geom_pointY,Lx=x,Ly=y,Lw=d3_geom_voronoiClipExtent;if(LB)return LA(LB);function LA(LG){var LH=new Array(LG.length),LE=Lw[0][0],LD=Lw[0][1],LF=Lw[1][0],LC=Lw[1][1];d3_geom_voronoi(Lz(LG),Lw).cells.forEach(function(LI,i){var LJ=LI.edges,LK=LI.site,LL=LH[i]=LJ.length?LJ.map(function(e){var s=e.start();return [s.x,s.y];}):LK.x>=LE&&LK.x<=LF&&LK.y>=LD&&LK.y<=LC?[[LE,LC],[LF,LC],[LF,LD],[LE,LD]]:[];LL.point=LG[i];});return LH;};function Lz(LM){return LM.map(function(d,i){return {x:Math.round(Lx(d,i)/ε)*ε,y:Math.round(Ly(d,i)/ε)*ε,i:i};});};LA.links=function(LN){return d3_geom_voronoi(Lz(LN)).edges.filter(function(LO){return LO.l&&LO.r;}).map(function(LP){return {source:LN[LP.l.i],target:LN[LP.r.i]};});};LA.triangles=function(LQ){var LR=[];d3_geom_voronoi(Lz(LQ)).cells.forEach(function(LV,i){var LU=LV.site,LW=LV.edges.sort(d3_geom_voronoiHalfEdgeOrder),j=-1,m=LW.length,LY,LT,LX=LW[m-1].edge,LS=LX.l===LU?LX.r:LX.l;while( ++j<m){LY=LX;LT=LS;LX=LW[j].edge;LS=LX.l===LU?LX.r:LX.l;if(i<LT.i&&i<LS.i&&d3_geom_voronoiTriangleArea(LU,LT,LS)<0){LR.push([LQ[i],LQ[LT.i],LQ[LS.i]]);};};});return LR;};LA.x=function(_){return arguments.length?(Lx=d3_functor(x=_),LA):x;};LA.y=function(_){return arguments.length?(Ly=d3_functor(y=_),LA):y;};LA.clipExtent=function(_){if(!arguments.length)return Lw===d3_geom_voronoiClipExtent?null:Lw;Lw=_==null?d3_geom_voronoiClipExtent:_;return LA;};LA.size=function(_){if(!arguments.length)return Lw===d3_geom_voronoiClipExtent?null:Lw&&Lw[1];return LA.clipExtent(_&&[[0,0],_]);};return LA;};var d3_geom_voronoiClipExtent=[[-1e6,-1e6],[1e6,1e6]];function d3_geom_voronoiTriangleArea(a,b,c){return (a.x-c.x)*(b.y-a.y)-(a.x-b.x)*(c.y-a.y);};d3.geom.delaunay=function(Ma){return d3.geom.voronoi().triangles(Ma);};d3.geom.quadtree=function(Mg,Mc,Md,Mf,Mh){var x=d3_geom_pointX,y=d3_geom_pointY,Mb;if(Mb=arguments.length){x=d3_geom_quadtreeCompatX;y=d3_geom_quadtreeCompatY;if(Mb===3){Mh=Md;Mf=Mc;Md=Mc=0;};return Me(Mg);};function Me(Mi){var d,Mk=d3_functor(x),Ml=d3_functor(y),Mu,Mv,i,n,Mw,Mn,Mp,Mt;if(Mc!=null){Mw=Mc,Mn=Md,Mp=Mf,Mt=Mh;}else {Mp=Mt=-(Mw=Mn=Infinity);Mu=[],Mv=[];n=Mi.length;if(Mb){for(i=0;i<n; ++i){d=Mi[i];if(d.x<Mw)Mw=d.x;if(d.y<Mn)Mn=d.y;if(d.x>Mp)Mp=d.x;if(d.y>Mt)Mt=d.y;Mu.push(d.x);Mv.push(d.y);};}else {for(i=0;i<n; ++i){var Mr=+Mk(d=Mi[i],i),Mo=+Ml(d,i);if(Mr<Mw)Mw=Mr;if(Mo<Mn)Mn=Mo;if(Mr>Mp)Mp=Mr;if(Mo>Mt)Mt=Mo;Mu.push(Mr);Mv.push(Mo);};};};var Ms=Mp-Mw,Mm=Mt-Mn;if(Ms>Mm)Mt=Mn+Ms;else Mp=Mw+Mm;function Mj(n,d,x,y,Mz,MA,MD,ME){if(isNaN(x)||isNaN(y))return;if(n.leaf){var MB=n.x,MC=n.y;if(MB!=null){if(abs(MB-x)+abs(MC-y)<.01){Mq(n,d,x,y,Mz,MA,MD,ME);}else {var My=n.point;n.x=n.y=n.point=null;Mq(n,My,MB,MC,Mz,MA,MD,ME);Mq(n,d,x,y,Mz,MA,MD,ME);};}else {n.x=x,n.y=y,n.point=d;};}else {Mq(n,d,x,y,Mz,MA,MD,ME);};};function Mq(n,d,x,y,MI,MJ,ML,MM){var MH=(MI+ML)*.5,MG=(MJ+MM)*.5,MF=x>=MH,MK=y>=MG,i=MK<<1|MF;n.leaf=false;n=n.nodes[i]||(n.nodes[i]=d3_geom_quadtreeNode());if(MF)MI=MH;else ML=MH;if(MK)MJ=MG;else MM=MG;Mj(n,d,x,y,MI,MJ,ML,MM);};var Mx=d3_geom_quadtreeNode();Mx.add=function(d){Mj(Mx,d,+Mk(d, ++i),+Ml(d,i),Mw,Mn,Mp,Mt);};Mx.visit=function(f){d3_geom_quadtreeVisit(f,Mx,Mw,Mn,Mp,Mt);};Mx.find=function(MN){return d3_geom_quadtreeFind(Mx,MN[0],MN[1],Mw,Mn,Mp,Mt);};i=-1;if(Mc==null){while( ++i<n){Mj(Mx,Mi[i],Mu[i],Mv[i],Mw,Mn,Mp,Mt);}; --i;}else Mi.forEach(Mx.add);Mu=Mv=Mi=d=null;return Mx;};Me.x=function(_){return arguments.length?(x=_,Me):x;};Me.y=function(_){return arguments.length?(y=_,Me):y;};Me.extent=function(_){if(!arguments.length)return Mc==null?null:[[Mc,Md],[Mf,Mh]];if(_==null)Mc=Md=Mf=Mh=null;else Mc=+_[0][0],Md=+_[0][1],Mf=+_[1][0],Mh=+_[1][1];return Me;};Me.size=function(_){if(!arguments.length)return Mc==null?null:[Mf-Mc,Mh-Md];if(_==null)Mc=Md=Mf=Mh=null;else Mc=Md=0,Mf=+_[0],Mh=+_[1];return Me;};return Me;};function d3_geom_quadtreeCompatX(d){return d.x;};function d3_geom_quadtreeCompatY(d){return d.y;};function d3_geom_quadtreeNode(){return {leaf:true,nodes:[],point:null,x:null,y:null};};function d3_geom_quadtreeVisit(f,MO,MR,MS,MT,MU){if(!f(MO,MR,MS,MT,MU)){var MQ=(MR+MT)*.5,MP=(MS+MU)*.5,MV=MO.nodes;if(MV[0])d3_geom_quadtreeVisit(f,MV[0],MR,MS,MQ,MP);if(MV[1])d3_geom_quadtreeVisit(f,MV[1],MQ,MS,MT,MP);if(MV[2])d3_geom_quadtreeVisit(f,MV[2],MR,MP,MQ,MU);if(MV[3])d3_geom_quadtreeVisit(f,MV[3],MQ,MP,MT,MU);};};function d3_geom_quadtreeFind(Nc,x,y,Nb,Na,MX,Nd){var MW=Infinity,MY;(function find(Ne,Nj,Nl,Np,Nq){if(Nj>MX||Nl>Nd||Np<Nb||Nq<Na)return;if(Ni=Ne.point){var Ni,Nn=x-Ne.x,No=y-Ne.y,Nf=Nn*Nn+No*No;if(Nf<MW){var Ns=Math.sqrt(MW=Nf);Nb=x-Ns,Na=y-Ns;MX=x+Ns,Nd=y+Ns;MY=Ni;};};var Nr=Ne.nodes,Nk=(Nj+Np)*.5,Nh=(Nl+Nq)*.5,Ng=x>=Nk,Nm=y>=Nh;for(var i=Nm<<1|Ng,j=i+4;i<j; ++i){if(Ne=Nr[i&3])switch(i&3){case 0:find(Ne,Nj,Nl,Nk,Nh);break;case 1:find(Ne,Nk,Nl,Np,Nh);break;case 2:find(Ne,Nj,Nh,Nk,Nq);break;case 3:find(Ne,Nk,Nh,Np,Nq);break;};};})(Nc,Nb,Na,MX,Nd);return MY;};d3.interpolateRgb=d3_interpolateRgb;function d3_interpolateRgb(a,b){a=d3.rgb(a);b=d3.rgb(b);var Ny=a.r,Nv=a.g,Nw=a.b,Nx=b.r-Ny,Nt=b.g-Nv,Nu=b.b-Nw;return function(t){return du+d3_rgb_hex(Math.round(Ny+Nx*t))+d3_rgb_hex(Math.round(Nv+Nt*t))+d3_rgb_hex(Math.round(Nw+Nu*t));};};d3.interpolateObject=d3_interpolateObject;function d3_interpolateObject(a,b){var i={},c={},k;for(k in a){if(k in b){i[k]=d3_interpolate(a[k],b[k]);}else {c[k]=a[k];};};for(k in b){if(!(k in a)){c[k]=b[k];};};return function(t){for(k in i)c[k]=i[k](t);return c;};};d3.interpolateNumber=d3_interpolateNumber;function d3_interpolateNumber(a,b){a=+a,b=+b;return function(t){return a*(1-t)+b*t;};};d3.interpolateString=d3_interpolateString;function d3_interpolateString(a,b){var NB=d3_interpolate_numberA.lastIndex=d3_interpolate_numberB.lastIndex=0,NA,Nz,NC,i=-1,s=[],q=[];a=a+gS,b=b+gS;while((NA=d3_interpolate_numberA.exec(a))&&(Nz=d3_interpolate_numberB.exec(b))){if((NC=Nz.index)>NB){NC=b.slice(NB,NC);if(s[i])s[i]+=NC;else s[ ++i]=NC;};if((NA=NA[0])===(Nz=Nz[0])){if(s[i])s[i]+=Nz;else s[ ++i]=Nz;}else {s[ ++i]=null;q.push({i:i,x:d3_interpolateNumber(NA,Nz)});};NB=d3_interpolate_numberB.lastIndex;};if(NB<b.length){NC=b.slice(NB);if(s[i])s[i]+=NC;else s[ ++i]=NC;};return s.length<2?q[0]?(b=q[0].x,function(t){return b(t)+gS;}):function(){return b;}:(b=q.length,function(t){for(var i=0,o;i<b; ++i)s[(o=q[i]).i]=o.x(t);return s.join(gS);});};var d3_interpolate_numberA=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,d3_interpolate_numberB=new RegExp(d3_interpolate_numberA.source,ef);d3.interpolate=d3_interpolate;function d3_interpolate(a,b){var i=d3.interpolators.length,f;while( --i>=0&&!(f=d3.interpolators[i](a,b)));return f;};d3.interpolators=[function(a,b){var t=typeof b;return (t===cY?d3_rgb_names.has(b.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(b)?d3_interpolateRgb:d3_interpolateString:b instanceof d3_color?d3_interpolateRgb:Array.isArray(b)?d3_interpolateArray:t===ge&&isNaN(b)?d3_interpolateObject:d3_interpolateNumber)(a,b);}];d3.interpolateArray=d3_interpolateArray;function d3_interpolateArray(a,b){var x=[],c=[],ND=a.length,NE=b.length,NF=Math.min(a.length,b.length),i;for(i=0;i<NF; ++i)x.push(d3_interpolate(a[i],b[i]));for(;i<ND; ++i)c[i]=a[i];for(;i<NE; ++i)c[i]=b[i];return function(t){for(i=0;i<NF; ++i)c[i]=x[i](t);return c;};};var d3_ease_default=function(){return d3_identity;};var d3_ease=d3.map({linear:d3_ease_default,poly:d3_ease_poly,quad:function(){return d3_ease_quad;},cubic:function(){return d3_ease_cubic;},sin:function(){return d3_ease_sin;},exp:function(){return d3_ease_exp;},circle:function(){return d3_ease_circle;},elastic:d3_ease_elastic,back:d3_ease_back,bounce:function(){return d3_ease_bounce;}});var d3_ease_mode=d3.map({"in":d3_identity,out:d3_ease_reverse,"in-out":d3_ease_reflect,"out-in":function(f){return d3_ease_reflect(d3_ease_reverse(f));}});d3.ease=function(name){var i=name.indexOf(E),t=i>=0?name.slice(0,i):name,m=i>=0?name.slice(i+1):eo;t=d3_ease.get(t)||d3_ease_default;m=d3_ease_mode.get(m)||d3_identity;return d3_ease_clamp(m(t.apply(null,d3_arraySlice.call(arguments,1))));};function d3_ease_clamp(f){return function(t){return t<=0?0:t>=1?1:f(t);};};function d3_ease_reverse(f){return function(t){return 1-f(1-t);};};function d3_ease_reflect(f){return function(t){return .5*(t<.5?f(2*t):2-f(2-2*t));};};function d3_ease_quad(t){return t*t;};function d3_ease_cubic(t){return t*t*t;};function d3_ease_cubicInOut(t){if(t<=0)return 0;if(t>=1)return 1;var NG=t*t,NH=NG*t;return 4*(t<.5?NH:3*(t-NG)+NH-.75);};function d3_ease_poly(e){return function(t){return Math.pow(t,e);};};function d3_ease_sin(t){return 1-Math.cos(t*halfπ);};function d3_ease_exp(t){return Math.pow(2,10*(t-1));};function d3_ease_circle(t){return 1-Math.sqrt(1-t*t);};function d3_ease_elastic(a,p){var s;if(arguments.length<2)p=.45;if(arguments.length)s=p/τ*Math.asin(1/a);else a=1,s=p/4;return function(t){return 1+a*Math.pow(2,-10*t)*Math.sin((t-s)*τ/p);};};function d3_ease_back(s){if(!s)s=1.70158;return function(t){return t*t*((s+1)*t-s);};};function d3_ease_bounce(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375;};d3.interpolateHcl=d3_interpolateHcl;function d3_interpolateHcl(a,b){a=d3.hcl(a);b=d3.hcl(b);var NL=a.h,NI=a.c,NN=a.l,NM=b.h-NL,NJ=b.c-NI,NK=b.l-NN;if(isNaN(NJ))NJ=0,NI=isNaN(NI)?b.c:NI;if(isNaN(NM))NM=0,NL=isNaN(NL)?b.h:NL;else if(NM>180)NM-=360;else if(NM<-180)NM+=360;return function(t){return d3_hcl_lab(NL+NM*t,NI+NJ*t,NN+NK*t)+gS;};};d3.interpolateHsl=d3_interpolateHsl;function d3_interpolateHsl(a,b){a=d3.hsl(a);b=d3.hsl(b);var NP=a.h,NS=a.s,NR=a.l,NQ=b.h-NP,NT=b.s-NS,NO=b.l-NR;if(isNaN(NT))NT=0,NS=isNaN(NS)?b.s:NS;if(isNaN(NQ))NQ=0,NP=isNaN(NP)?b.h:NP;else if(NQ>180)NQ-=360;else if(NQ<-180)NQ+=360;return function(t){return d3_hsl_rgb(NP+NQ*t,NS+NT*t,NR+NO*t)+gS;};};d3.interpolateLab=d3_interpolateLab;function d3_interpolateLab(a,b){a=d3.lab(a);b=d3.lab(b);var NY=a.l,NU=a.a,Oa=a.b,NX=b.l-NY,NV=b.a-NU,NW=b.b-Oa;return function(t){return d3_lab_rgb(NY+NX*t,NU+NV*t,Oa+NW*t)+gS;};};d3.interpolateRound=d3_interpolateRound;function d3_interpolateRound(a,b){b-=a;return function(t){return Math.round(a+b*t);};};d3.transform=function(Ob){var g=d3_document.createElementNS(d3.ns.prefix.svg,ef);return (d3.transform=function(Oc){if(Oc!=null){g.setAttribute(cv,Oc);var t=g.transform.baseVal.consolidate();};return new d3_transform(t?t.matrix:d3_transformIdentity);})(Ob);};function d3_transform(m){var Od=[m.a,m.b],Oe=[m.c,m.d],Oh=d3_transformNormalize(Od),Of=d3_transformDot(Od,Oe),Og=d3_transformNormalize(d3_transformCombine(Oe,Od,-Of))||0;if(Od[0]*Oe[1]<Oe[0]*Od[1]){Od[0]*=-1;Od[1]*=-1;Oh*=-1;Of*=-1;};this.rotate=(Oh?Math.atan2(Od[1],Od[0]):Math.atan2(-Oe[0],Oe[1]))*d3_degrees;this.translate=[m.e,m.f];this.scale=[Oh,Og];this.skew=Og?Math.atan2(Of,Og)*d3_degrees:0;};d3_transform.prototype.toString=function(){return ho+this.translate+ga+this.rotate+bM+this.skew+ev+this.scale+eL;};function d3_transformDot(a,b){return a[0]*b[0]+a[1]*b[1];};function d3_transformNormalize(a){var k=Math.sqrt(d3_transformDot(a,a));if(k){a[0]/=k;a[1]/=k;};return k;};function d3_transformCombine(a,b,k){a[0]+=k*b[0];a[1]+=k*b[1];return a;};var d3_transformIdentity={a:1,b:0,c:0,d:1,e:0,f:0};d3.interpolateTransform=d3_interpolateTransform;function d3_interpolateTransformPop(s){return s.length?s.pop()+hz:gS;};function d3_interpolateTranslate(Oj,Oi,s,q){if(Oj[0]!==Oi[0]||Oj[1]!==Oi[1]){var i=s.push(ho,null,hz,null,eL);q.push({i:i-4,x:d3_interpolateNumber(Oj[0],Oi[0])},{i:i-2,x:d3_interpolateNumber(Oj[1],Oi[1])});}else if(Oi[0]||Oi[1]){s.push(ho+Oi+eL);};};function d3_interpolateRotate(Ok,Ol,s,q){if(Ok!==Ol){if(Ok-Ol>180)Ol+=360;else if(Ol-Ok>180)Ok+=360;q.push({i:s.push(d3_interpolateTransformPop(s)+fR,null,eL)-2,x:d3_interpolateNumber(Ok,Ol)});}else if(Ol){s.push(d3_interpolateTransformPop(s)+fR+Ol+eL);};};function d3_interpolateSkew(On,Om,s,q){if(On!==Om){q.push({i:s.push(d3_interpolateTransformPop(s)+cT,null,eL)-2,x:d3_interpolateNumber(On,Om)});}else if(Om){s.push(d3_interpolateTransformPop(s)+cT+Om+eL);};};function d3_interpolateScale(Op,Oo,s,q){if(Op[0]!==Oo[0]||Op[1]!==Oo[1]){var i=s.push(d3_interpolateTransformPop(s)+cc,null,hz,null,eL);q.push({i:i-4,x:d3_interpolateNumber(Op[0],Oo[0])},{i:i-2,x:d3_interpolateNumber(Op[1],Oo[1])});}else if(Oo[0]!==1||Oo[1]!==1){s.push(d3_interpolateTransformPop(s)+cc+Oo+eL);};};function d3_interpolateTransform(a,b){var s=[],q=[];a=d3.transform(a),b=d3.transform(b);d3_interpolateTranslate(a.translate,b.translate,s,q);d3_interpolateRotate(a.rotate,b.rotate,s,q);d3_interpolateSkew(a.skew,b.skew,s,q);d3_interpolateScale(a.scale,b.scale,s,q);a=b=null;return function(t){var i=-1,n=q.length,o;while( ++i<n)s[(o=q[i]).i]=o.x(t);return s.join(gS);};};function d3_uninterpolateNumber(a,b){b=(b-=a=+a)||1/b;return function(x){return (x-a)/b;};};function d3_uninterpolateClamp(a,b){b=(b-=a=+a)||1/b;return function(x){return Math.max(0,Math.min(1,(x-a)/b));};};d3.layout={};d3.layout.bundle=function(){return function(Or){var Oq=[],i=-1,n=Or.length;while( ++i<n)Oq.push(d3_layout_bundlePath(Or[i]));return Oq;};};function d3_layout_bundlePath(Ov){var Ot=Ov.source,Os=Ov.target,Ow=d3_layout_bundleLeastCommonAncestor(Ot,Os),Ou=[Ot];while(Ot!==Ow){Ot=Ot.parent;Ou.push(Ot);};var k=Ou.length;while(Os!==Ow){Ou.splice(k,0,Os);Os=Os.parent;};return Ou;};function d3_layout_bundleAncestors(Ox){var Oy=[],parent=Ox.parent;while(parent!=null){Oy.push(Ox);Ox=parent;parent=parent.parent;};Oy.push(Ox);return Oy;};function d3_layout_bundleLeastCommonAncestor(a,b){if(a===b)return a;var Oz=d3_layout_bundleAncestors(a),OA=d3_layout_bundleAncestors(b),OC=Oz.pop(),OB=OA.pop(),OD=null;while(OC===OB){OD=OC;OC=Oz.pop();OB=OA.pop();};return OD;};d3.layout.chord=function(){var OE={},OH,OL,OF,n,OJ=0,OG,ON,OM;function OI(){var OY={},OX=[],OR=d3.range(n),OU=[],k,x,OW,i,j;OH=[];OL=[];k=0,i=-1;while( ++i<n){x=0,j=-1;while( ++j<n){x+=OF[i][j];};OX.push(x);OU.push(d3.range(n));k+=x;};if(OG){OR.sort(function(a,b){return OG(OX[a],OX[b]);});};if(ON){OU.forEach(function(d,i){d.sort(function(a,b){return ON(OF[i][a],OF[i][b]);});});};k=(τ-OJ*n)/k;x=0,i=-1;while( ++i<n){OW=x,j=-1;while( ++j<n){var OQ=OR[i],OO=OU[OQ][j],v=OF[OQ][OO],OT=x,OS=x+=v*k;OY[OQ+E+OO]={index:OQ,subindex:OO,startAngle:OT,endAngle:OS,value:v};};OL[OQ]={index:OQ,startAngle:OW,endAngle:x,value:OX[OQ]};x+=OJ;};i=-1;while( ++i<n){j=i-1;while( ++j<n){var OV=OY[i+E+j],OP=OY[j+E+i];if(OV.value||OP.value){OH.push(OV.value<OP.value?{source:OP,target:OV}:{source:OV,target:OP});};};};if(OM)OK();};function OK(){OH.sort(function(a,b){return OM((a.source.value+a.target.value)/2,(b.source.value+b.target.value)/2);});};OE.matrix=function(x){if(!arguments.length)return OF;n=(OF=x)&&OF.length;OH=OL=null;return OE;};OE.padding=function(x){if(!arguments.length)return OJ;OJ=x;OH=OL=null;return OE;};OE.sortGroups=function(x){if(!arguments.length)return OG;OG=x;OH=OL=null;return OE;};OE.sortSubgroups=function(x){if(!arguments.length)return ON;ON=x;OH=null;return OE;};OE.sortChords=function(x){if(!arguments.length)return OM;OM=x;if(OH)OK();return OE;};OE.chords=function(){if(!OH)OI();return OH;};OE.groups=function(){if(!OL)OI();return OL;};return OE;};d3.layout.force=function(){var Pc={},event=d3.dispatch(bR,cV,cB),Pi,Ps=[1,1],Pm,Po,Pg=.9,Pl=d3_layout_forceLinkDistance,Pn=d3_layout_forceLinkStrength,Pk=-30,Pj=d3_layout_forceChargeDistance2,Ph=.1,Pa=.64,Pp=[],Pd=[],Pb,Pq,Pf;function Pe(Pt){return function(Pv,PA,_,Py){if(Pv.point!==Pt){var Pw=Pv.cx-Pt.x,Px=Pv.cy-Pt.y,Pz=Py-PA,Pu=Pw*Pw+Px*Px;if(Pz*Pz/Pa<Pu){if(Pu<Pj){var k=Pv.charge/Pu;Pt.px-=Pw*k;Pt.py-=Px*k;};return true;};if(Pv.point&&Pu&&Pu<Pj){var k=Pv.pointCharge/Pu;Pt.px-=Pw*k;Pt.py-=Px*k;};};return !Pv.charge;};};Pc.tick=function(){if((Po*=.99)<.005){Pi=null;event.end({type:cB,alpha:Po=0});return true;};var n=Pp.length,m=Pd.length,q,i,o,s,t,l,k,x,y;for(i=0;i<m; ++i){o=Pd[i];s=o.source;t=o.target;x=t.x-s.x;y=t.y-s.y;if(l=x*x+y*y){l=Po*Pq[i]*((l=Math.sqrt(l))-Pb[i])/l;x*=l;y*=l;t.x-=x*(k=s.weight+t.weight?s.weight/(s.weight+t.weight):.5);t.y-=y*k;s.x+=x*(k=1-k);s.y+=y*k;};};if(k=Po*Ph){x=Ps[0]/2;y=Ps[1]/2;i=-1;if(k)while( ++i<n){o=Pp[i];o.x+=(x-o.x)*k;o.y+=(y-o.y)*k;};};if(Pk){d3_layout_forceAccumulate(q=d3.geom.quadtree(Pp),Po,Pf);i=-1;while( ++i<n){if(!(o=Pp[i]).fixed){q.visit(Pe(o));};};};i=-1;while( ++i<n){o=Pp[i];if(o.fixed){o.x=o.px;o.y=o.py;}else {o.x-=(o.px-(o.px=o.x))*Pg;o.y-=(o.py-(o.py=o.y))*Pg;};};event.tick({type:cV,alpha:Po});};Pc.nodes=function(x){if(!arguments.length)return Pp;Pp=x;return Pc;};Pc.links=function(x){if(!arguments.length)return Pd;Pd=x;return Pc;};Pc.size=function(x){if(!arguments.length)return Ps;Ps=x;return Pc;};Pc.linkDistance=function(x){if(!arguments.length)return Pl;Pl=typeof x===eG?x:+x;return Pc;};Pc.distance=Pc.linkDistance;Pc.linkStrength=function(x){if(!arguments.length)return Pn;Pn=typeof x===eG?x:+x;return Pc;};Pc.friction=function(x){if(!arguments.length)return Pg;Pg=+x;return Pc;};Pc.charge=function(x){if(!arguments.length)return Pk;Pk=typeof x===eG?x:+x;return Pc;};Pc.chargeDistance=function(x){if(!arguments.length)return Math.sqrt(Pj);Pj=x*x;return Pc;};Pc.gravity=function(x){if(!arguments.length)return Ph;Ph=+x;return Pc;};Pc.theta=function(x){if(!arguments.length)return Math.sqrt(Pa);Pa=x*x;return Pc;};Pc.alpha=function(x){if(!arguments.length)return Po;x=+x;if(Po){if(x>0){Po=x;}else {Pi.c=null,Pi.t=NaN,Pi=null;event.end({type:cB,alpha:Po=0});};}else if(x>0){event.start({type:bR,alpha:Po=x});Pi=d3_timer(Pc.tick);};return Pc;};Pc.start=function(){var i,n=Pp.length,m=Pd.length,w=Ps[0],h=Ps[1],PB,o;for(i=0;i<n; ++i){(o=Pp[i]).index=i;o.weight=0;};for(i=0;i<m; ++i){o=Pd[i];if(typeof o.source==bU)o.source=Pp[o.source];if(typeof o.target==bU)o.target=Pp[o.target]; ++o.source.weight; ++o.target.weight;};for(i=0;i<n; ++i){o=Pp[i];if(isNaN(o.x))o.x=PC(cD,w);if(isNaN(o.y))o.y=PC(dJ,h);if(isNaN(o.px))o.px=o.x;if(isNaN(o.py))o.py=o.y;};Pb=[];if(typeof Pl===eG){for(i=0;i<m; ++i)Pb[i]=+Pl.call(this,Pd[i],i);}else {for(i=0;i<m; ++i)Pb[i]=Pl;};Pq=[];if(typeof Pn===eG){for(i=0;i<m; ++i)Pq[i]=+Pn.call(this,Pd[i],i);}else {for(i=0;i<m; ++i)Pq[i]=Pn;};Pf=[];if(typeof Pk===eG){for(i=0;i<n; ++i)Pf[i]=+Pk.call(this,Pp[i],i);}else {for(i=0;i<n; ++i)Pf[i]=Pk;};function PC(PE,PF){if(!PB){PB=new Array(n);for(j=0;j<n; ++j){PB[j]=[];};for(j=0;j<m; ++j){var o=Pd[j];PB[o.source.index].push(o.target);PB[o.target.index].push(o.source);};};var PD=PB[i],j=-1,l=PD.length,x;while( ++j<l)if(!isNaN(x=PD[j][PE]))return x;return Math.random()*PF;};return Pc.resume();};Pc.resume=function(){return Pc.alpha(.1);};Pc.stop=function(){return Pc.alpha(0);};Pc.drag=function(){if(!Pm)Pm=d3.behavior.drag().origin(d3_identity).on(fi,d3_layout_forceDragstart).on(bL,Pr).on(fB,d3_layout_forceDragend);if(!arguments.length)return Pm;this.on(fz,d3_layout_forceMouseover).on(gM,d3_layout_forceMouseout).call(Pm);};function Pr(d){d.px=d3.event.x,d.py=d3.event.y;Pc.resume();};return d3.rebind(Pc,event,eb);};function d3_layout_forceDragstart(d){d.fixed|=2;};function d3_layout_forceDragend(d){d.fixed&=~6;};function d3_layout_forceMouseover(d){d.fixed|=4;d.px=d.x,d.py=d.y;};function d3_layout_forceMouseout(d){d.fixed&=~4;};function d3_layout_forceAccumulate(PJ,PK,PG){var PI=0,PH=0;PJ.charge=0;if(!PJ.leaf){var PL=PJ.nodes,n=PL.length,i=-1,c;while( ++i<n){c=PL[i];if(c==null)continue;d3_layout_forceAccumulate(c,PK,PG);PJ.charge+=c.charge;PI+=c.charge*c.cx;PH+=c.charge*c.cy;};};if(PJ.point){if(!PJ.leaf){PJ.point.x+=Math.random()-.5;PJ.point.y+=Math.random()-.5;};var k=PK*PG[PJ.point.index];PJ.charge+=PJ.pointCharge=k;PI+=k*PJ.point.x;PH+=k*PJ.point.y;};PJ.cx=PI/PJ.charge;PJ.cy=PH/PJ.charge;};var d3_layout_forceLinkDistance=20,d3_layout_forceLinkStrength=1,d3_layout_forceChargeDistance2=Infinity;d3.layout.hierarchy=function(){var PM=d3_layout_hierarchySort,PO=d3_layout_hierarchyChildren,PP=d3_layout_hierarchyValue;function PN(PU){var PV=[PU],PT=[],PQ;PU.depth=0;while((PQ=PV.pop())!=null){PT.push(PQ);if((PR=PO.call(PN,PQ,PQ.depth))&&(n=PR.length)){var n,PR,PS;while( --n>=0){PV.push(PS=PR[n]);PS.parent=PQ;PS.depth=PQ.depth+1;};if(PP)PQ.value=0;PQ.children=PR;}else {if(PP)PQ.value=+PP.call(PN,PQ,PQ.depth)||0;delete PQ.children;};};d3_layout_hierarchyVisitAfter(PU,function(PW){var PX,parent;if(PM&&(PX=PW.children))PX.sort(PM);if(PP&&(parent=PW.parent))parent.value+=PW.value;});return PT;};PN.sort=function(x){if(!arguments.length)return PM;PM=x;return PN;};PN.children=function(x){if(!arguments.length)return PO;PO=x;return PN;};PN.value=function(x){if(!arguments.length)return PP;PP=x;return PN;};PN.revalue=function(PY){if(PP){d3_layout_hierarchyVisitBefore(PY,function(Qa){if(Qa.children)Qa.value=0;});d3_layout_hierarchyVisitAfter(PY,function(Qb){var parent;if(!Qb.children)Qb.value=+PP.call(PN,Qb,Qb.depth)||0;if(parent=Qb.parent)parent.value+=Qb.value;});};return PY;};return PN;};function d3_layout_hierarchyRebind(Qd,Qc){d3.rebind(Qd,Qc,dB,cQ,gG);Qd.nodes=Qd;Qd.links=d3_layout_hierarchyLinks;return Qd;};function d3_layout_hierarchyVisitBefore(Qe,Qf){var Qg=[Qe];while((Qe=Qg.pop())!=null){Qf(Qe);if((Qh=Qe.children)&&(n=Qh.length)){var n,Qh;while( --n>=0)Qg.push(Qh[n]);};};};function d3_layout_hierarchyVisitAfter(Qi,Qk){var Ql=[Qi],Qj=[];while((Qi=Ql.pop())!=null){Qj.push(Qi);if((Qm=Qi.children)&&(n=Qm.length)){var i=-1,n,Qm;while( ++i<n)Ql.push(Qm[i]);};};while((Qi=Qj.pop())!=null){Qk(Qi);};};function d3_layout_hierarchyChildren(d){return d.children;};function d3_layout_hierarchyValue(d){return d.value;};function d3_layout_hierarchySort(a,b){return b.value-a.value;};function d3_layout_hierarchyLinks(Qn){return d3.merge(Qn.map(function(parent){return (parent.children||[]).map(function(Qo){return {source:parent,target:Qo};});}));};d3.layout.partition=function(){var Qp=d3.layout.hierarchy(),Qt=[1,1];function Qq(Qu,x,Qv,Qw){var Qx=Qu.children;Qu.x=x;Qu.y=Qu.depth*Qw;Qu.dx=Qv;Qu.dy=Qw;if(Qx&&(n=Qx.length)){var i=-1,n,c,d;Qv=Qu.value?Qv/Qu.value:0;while( ++i<n){Qq(c=Qx[i],x,d=c.value*Qv,Qw);x+=d;};};};function Qr(Qy){var Qz=Qy.children,d=0;if(Qz&&(n=Qz.length)){var i=-1,n;while( ++i<n)d=Math.max(d,Qr(Qz[i]));};return 1+d;};function Qs(d,i){var QA=Qp.call(this,d,i);Qq(QA[0],0,Qt[0],Qt[1]/Qr(QA[0]));return QA;};Qs.size=function(x){if(!arguments.length)return Qt;Qt=x;return Qs;};return d3_layout_hierarchyRebind(Qs,Qp);};d3.layout.pie=function(){var QE=Number,QB=d3_layout_pieSortByValue,QG=0,QF=τ,QC=0;function QD(QN){var n=QN.length,QL=QN.map(function(d,i){return +QE.call(QD,d,i);}),a=+(typeof QG===eG?QG.apply(this,arguments):QG),QM=(typeof QF===eG?QF.apply(this,arguments):QF)-a,p=Math.min(Math.abs(QM)/n,+(typeof QC===eG?QC.apply(this,arguments):QC)),QK=p*(QM<0?-1:1),QJ=d3.sum(QL),k=QJ?(QM-n*QK)/QJ:0,QH=d3.range(n),QI=[],v;if(QB!=null)QH.sort(QB===d3_layout_pieSortByValue?function(i,j){return QL[j]-QL[i];}:function(i,j){return QB(QN[i],QN[j]);});QH.forEach(function(i){QI[i]={data:QN[i],value:v=QL[i],startAngle:a,endAngle:a+=v*k+QK,padAngle:p};});return QI;};QD.value=function(_){if(!arguments.length)return QE;QE=_;return QD;};QD.sort=function(_){if(!arguments.length)return QB;QB=_;return QD;};QD.startAngle=function(_){if(!arguments.length)return QG;QG=_;return QD;};QD.endAngle=function(_){if(!arguments.length)return QF;QF=_;return QD;};QD.padAngle=function(_){if(!arguments.length)return QC;QC=_;return QD;};return QD;};var d3_layout_pieSortByValue={};d3.layout.stack=function(){var QP=d3_identity,QR=d3_layout_stackOrderDefault,QQ=d3_layout_stackOffsetZero,QS=d3_layout_stackOut,x=d3_layout_stackX,y=d3_layout_stackY;function QO(QX,QT){if(!(n=QX.length))return QX;var QV=QX.map(function(d,i){return QP.call(QO,d,i);});var QW=QV.map(function(d){return d.map(function(v,i){return [x.call(QO,v,i),y.call(QO,v,i)];});});var QY=QR.call(QO,QW,QT);QV=d3.permute(QV,QY);QW=d3.permute(QW,QY);var QU=QQ.call(QO,QW,QT);var m=QV[0].length,n,i,j,o;for(j=0;j<m; ++j){QS.call(QO,QV[0][j],o=QU[j],QW[0][j][1]);for(i=1;i<n; ++i){QS.call(QO,QV[i][j],o+=QW[i-1][j][1],QW[i][j][1]);};};return QX;};QO.values=function(x){if(!arguments.length)return QP;QP=x;return QO;};QO.order=function(x){if(!arguments.length)return QR;QR=typeof x===eG?x:d3_layout_stackOrders.get(x)||d3_layout_stackOrderDefault;return QO;};QO.offset=function(x){if(!arguments.length)return QQ;QQ=typeof x===eG?x:d3_layout_stackOffsets.get(x)||d3_layout_stackOffsetZero;return QO;};QO.x=function(z){if(!arguments.length)return x;x=z;return QO;};QO.y=function(z){if(!arguments.length)return y;y=z;return QO;};QO.out=function(z){if(!arguments.length)return QS;QS=z;return QO;};return QO;};function d3_layout_stackX(d){return d.x;};function d3_layout_stackY(d){return d.y;};function d3_layout_stackOut(d,Ra,y){d.y0=Ra;d.y=y;};var d3_layout_stackOrders=d3.map({"inside-out":function(Rf){var n=Rf.length,i,j,Rd=Rf.map(d3_layout_stackMaxIndex),Re=Rf.map(d3_layout_stackReduceSum),Rb=d3.range(n).sort(function(a,b){return Rd[a]-Rd[b];}),top=0,Rc=0,Rh=[],Rg=[];for(i=0;i<n; ++i){j=Rb[i];if(top<Rc){top+=Re[j];Rh.push(j);}else {Rc+=Re[j];Rg.push(j);};};return Rg.reverse().concat(Rh);},reverse:function(Ri){return d3.range(Ri.length).reverse();},"default":d3_layout_stackOrderDefault});var d3_layout_stackOffsets=d3.map({silhouette:function(Rm){var n=Rm.length,m=Rm[0].length,Rj=[],Rk=0,i,j,o,Rl=[];for(j=0;j<m; ++j){for(i=0,o=0;i<n;i++ )o+=Rm[i][j][1];if(o>Rk)Rk=o;Rj.push(o);};for(j=0;j<m; ++j){Rl[j]=(Rk-Rj[j])/2;};return Rl;},wiggle:function(Rr){var n=Rr.length,x=Rr[0],m=x.length,i,j,k,Rs,Rn,Ro,Rp,o,Rt,Rq=[];Rq[0]=o=Rt=0;for(j=1;j<m; ++j){for(i=0,Rs=0;i<n; ++i)Rs+=Rr[i][j][1];for(i=0,Rn=0,Rp=x[j][0]-x[j-1][0];i<n; ++i){for(k=0,Ro=(Rr[i][j][1]-Rr[i][j-1][1])/(2*Rp);k<i; ++k){Ro+=(Rr[k][j][1]-Rr[k][j-1][1])/Rp;};Rn+=Ro*Rr[i][j][1];};Rq[j]=o-=Rs?Rn/Rs*Rp:0;if(o<Rt)Rt=o;};for(j=0;j<m; ++j)Rq[j]-=Rt;return Rq;},expand:function(Rv){var n=Rv.length,m=Rv[0].length,k=1/n,i,j,o,Ru=[];for(j=0;j<m; ++j){for(i=0,o=0;i<n;i++ )o+=Rv[i][j][1];if(o){for(i=0;i<n;i++ ){Rv[i][j][1]/=o;};}else {for(i=0;i<n;i++ ){Rv[i][j][1]=k;};};};for(j=0;j<m; ++j){Ru[j]=0;};return Ru;},zero:d3_layout_stackOffsetZero});function d3_layout_stackOrderDefault(Rw){return d3.range(Rw.length);};function d3_layout_stackOffsetZero(Rx){var j=-1,m=Rx[0].length,Ry=[];while( ++j<m)Ry[j]=0;return Ry;};function d3_layout_stackMaxIndex(Rz){var i=1,j=0,v=Rz[0][1],k,n=Rz.length;for(;i<n; ++i){if((k=Rz[i][1])>v){j=i;v=k;};};return j;};function d3_layout_stackReduceSum(d){return d.reduce(d3_layout_stackSum,0);};function d3_layout_stackSum(p,d){return p+d[1];};d3.layout.histogram=function(){var RB=true,RD=Number,RA=d3_layout_histogramRange,RC=d3_layout_histogramBinSturges;function RE(RJ,i){var RK=[],RI=RJ.map(RD,this),RH=RA.call(this,RI,i),RG=RC.call(this,RH,RI,i),RF,i=-1,n=RI.length,m=RG.length-1,k=RB?1:1/n,x;while( ++i<m){RF=RK[i]=[];RF.dx=RG[i+1]-(RF.x=RG[i]);RF.y=0;};if(m>0){i=-1;while( ++i<n){x=RI[i];if(x>=RH[0]&&x<=RH[1]){RF=RK[d3.bisect(RG,x,1,m)-1];RF.y+=k;RF.push(RJ[i]);};};};return RK;};RE.value=function(x){if(!arguments.length)return RD;RD=x;return RE;};RE.range=function(x){if(!arguments.length)return RA;RA=d3_functor(x);return RE;};RE.bins=function(x){if(!arguments.length)return RC;RC=typeof x===bU?function(RL){return d3_layout_histogramBinFixed(RL,x);}:d3_functor(x);return RE;};RE.frequency=function(x){if(!arguments.length)return RB;RB=!!x;return RE;};return RE;};function d3_layout_histogramBinSturges(RM,RN){return d3_layout_histogramBinFixed(RM,Math.ceil(Math.log(RN.length)/Math.LN2+1));};function d3_layout_histogramBinFixed(RO,n){var x=-1,b=+RO[0],m=(RO[1]-b)/n,f=[];while( ++x<=n)f[x]=m*x+b;return f;};function d3_layout_histogramRange(RP){return [d3.min(RP),d3.max(RP)];};d3.layout.pack=function(){var RQ=d3.layout.hierarchy().sort(d3_layout_packSort),RR=0,RS=[1,1],RT;function RU(d,i){var RW=RQ.call(this,d,i),RV=RW[0],w=RS[0],h=RS[1],r=RT==null?Math.sqrt:typeof RT===eG?RT:function(){return RT;};RV.x=RV.y=0;d3_layout_hierarchyVisitAfter(RV,function(d){d.r=+r(d.value);});d3_layout_hierarchyVisitAfter(RV,d3_layout_packSiblings);if(RR){var RX=RR*(RT?1:Math.max(2*RV.r/w,2*RV.r/h))/2;d3_layout_hierarchyVisitAfter(RV,function(d){d.r+=RX;});d3_layout_hierarchyVisitAfter(RV,d3_layout_packSiblings);d3_layout_hierarchyVisitAfter(RV,function(d){d.r-=RX;});};d3_layout_packTransform(RV,w/2,h/2,RT?1:1/Math.max(2*RV.r/w,2*RV.r/h));return RW;};RU.size=function(_){if(!arguments.length)return RS;RS=_;return RU;};RU.radius=function(_){if(!arguments.length)return RT;RT=_==null||typeof _===eG?_:+_;return RU;};RU.padding=function(_){if(!arguments.length)return RR;RR=+_;return RU;};return d3_layout_hierarchyRebind(RU,RQ);};function d3_layout_packSort(a,b){return a.value-b.value;};function d3_layout_packInsert(a,b){var c=a._pack_next;a._pack_next=b;b._pack_prev=a;b._pack_next=c;c._pack_prev=b;};function d3_layout_packSplice(a,b){a._pack_next=b;b._pack_prev=a;};function d3_layout_packIntersects(a,b){var Sa=b.x-a.x,Sb=b.y-a.y,RY=a.r+b.r;return .999*RY*RY>Sa*Sa+Sb*Sb;};function d3_layout_packSiblings(Sc){if(!(Sn=Sc.children)||!(n=Sn.length))return;var Sn,Sl=Infinity,Sk=-Infinity,So=Infinity,Sd=-Infinity,a,b,c,i,j,k,n;function Sh(Sp){Sl=Math.min(Sp.x-Sp.r,Sl);Sk=Math.max(Sp.x+Sp.r,Sk);So=Math.min(Sp.y-Sp.r,So);Sd=Math.max(Sp.y+Sp.r,Sd);};Sn.forEach(d3_layout_packLink);a=Sn[0];a.x=-a.r;a.y=0;Sh(a);if(n>1){b=Sn[1];b.x=b.r;b.y=0;Sh(b);if(n>2){c=Sn[2];d3_layout_packPlace(a,b,c);Sh(c);d3_layout_packInsert(a,c);a._pack_prev=c;d3_layout_packInsert(c,b);b=a._pack_next;for(i=3;i<n;i++ ){d3_layout_packPlace(a,b,c=Sn[i]);var Sg=0,Sf=1,Se=1;for(j=b._pack_next;j!==b;j=j._pack_next,Sf++ ){if(d3_layout_packIntersects(j,c)){Sg=1;break;};};if(Sg==1){for(k=a._pack_prev;k!==j._pack_prev;k=k._pack_prev,Se++ ){if(d3_layout_packIntersects(k,c)){break;};};};if(Sg){if(Sf<Se||Sf==Se&&b.r<a.r)d3_layout_packSplice(a,b=j);else d3_layout_packSplice(a=k,b);i-- ;}else {d3_layout_packInsert(a,c);b=c;Sh(c);};};};};var Sj=(Sl+Sk)/2,Si=(So+Sd)/2,Sm=0;for(i=0;i<n;i++ ){c=Sn[i];c.x-=Sj;c.y-=Si;Sm=Math.max(Sm,c.r+Math.sqrt(c.x*c.x+c.y*c.y));};Sc.r=Sm;Sn.forEach(d3_layout_packUnlink);};function d3_layout_packLink(Sq){Sq._pack_next=Sq._pack_prev=Sq;};function d3_layout_packUnlink(Sr){delete Sr._pack_next;delete Sr._pack_prev;};function d3_layout_packTransform(Ss,x,y,k){var St=Ss.children;Ss.x=x+=k*Ss.x;Ss.y=y+=k*Ss.y;Ss.r*=k;if(St){var i=-1,n=St.length;while( ++i<n)d3_layout_packTransform(St[i],x,y,k);};};function d3_layout_packPlace(a,b,c){var Su=a.r+c.r,Sx=b.x-a.x,Sy=b.y-a.y;if(Su&&(Sx||Sy)){var Sw=b.r+c.r,Sv=Sx*Sx+Sy*Sy;Sw*=Sw;Su*=Su;var x=.5+(Su-Sw)/(2*Sv),y=Math.sqrt(Math.max(0,2*Sw*(Su+Sv)-(Su-=Sv)*Su-Sw*Sw))/(2*Sv);c.x=a.x+x*Sx+y*Sy;c.y=a.y+x*Sy-y*Sx;}else {c.x=a.x+Su;c.y=a.y;};};d3.layout.tree=function(){var SB=d3.layout.hierarchy().sort(null).value(null),SF=d3_layout_treeSeparation,Sz=[1,1],SD=null;function SC(d,i){var SQ=SB.call(this,d,i),SM=SQ[0],SP=SE(SM);d3_layout_hierarchyVisitAfter(SP,SG),SP.parent.m=-SP.z;d3_layout_hierarchyVisitBefore(SP,SA);if(SD)d3_layout_hierarchyVisitBefore(SM,SH);else {var SR=SM,SJ=SM,SL=SM;d3_layout_hierarchyVisitBefore(SM,function(SS){if(SS.x<SR.x)SR=SS;if(SS.x>SJ.x)SJ=SS;if(SS.depth>SL.depth)SL=SS;});var SK=SF(SR,SJ)/2-SR.x,SO=Sz[0]/(SJ.x+SF(SJ,SR)/2+SK),SN=Sz[1]/(SL.depth||1);d3_layout_hierarchyVisitBefore(SM,function(ST){ST.x=(ST.x+SK)*SO;ST.y=ST.depth*SN;});};return SQ;};function SE(Ta){var SX={A:null,children:[Ta]},SU=[SX],SW;while((SW=SU.pop())!=null){for(var SY=SW.children,SV,i=0,n=SY.length;i<n; ++i){SU.push((SY[i]=SV={_:SY[i],parent:SW,children:(SV=SY[i].children)&&SV.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:i}).a=SV);};};return SX.children[0];};function SG(v){var Td=v.children,Tb=v.parent.children,w=v.i?Tb[v.i-1]:null;if(Td.length){d3_layout_treeShift(v);var Tc=(Td[0].z+Td[Td.length-1].z)/2;if(w){v.z=w.z+SF(v._,w._);v.m=v.z-Tc;}else {v.z=Tc;};}else if(w){v.z=w.z+SF(v._,w._);};v.parent.A=SI(v,w,v.parent.A||Tb[0]);};function SA(v){v._.x=v.z+v.parent.m;v.m+=v.parent.m;};function SI(v,w,Tm){if(w){var Tj=v,Tk=v,Th=w,Tf=Tj.parent.children[0],Te=Tj.m,Ti=Tk.m,Tn=Th.m,Tg=Tf.m,Tl;while(Th=d3_layout_treeRight(Th),Tj=d3_layout_treeLeft(Tj),Th&&Tj){Tf=d3_layout_treeLeft(Tf);Tk=d3_layout_treeRight(Tk);Tk.a=v;Tl=Th.z+Tn-Tj.z-Te+SF(Th._,Tj._);if(Tl>0){d3_layout_treeMove(d3_layout_treeAncestor(Th,v,Tm),v,Tl);Te+=Tl;Ti+=Tl;};Tn+=Th.m;Te+=Tj.m;Tg+=Tf.m;Ti+=Tk.m;};if(Th&&!d3_layout_treeRight(Tk)){Tk.t=Th;Tk.m+=Tn-Ti;};if(Tj&&!d3_layout_treeLeft(Tf)){Tf.t=Tj;Tf.m+=Te-Tg;Tm=v;};};return Tm;};function SH(To){To.x*=Sz[0];To.y=To.depth*Sz[1];};SC.separation=function(x){if(!arguments.length)return SF;SF=x;return SC;};SC.size=function(x){if(!arguments.length)return SD?null:Sz;SD=(Sz=x)==null?SH:null;return SC;};SC.nodeSize=function(x){if(!arguments.length)return SD?Sz:null;SD=(Sz=x)==null?null:SH;return SC;};return d3_layout_hierarchyRebind(SC,SB);};function d3_layout_treeSeparation(a,b){return a.parent==b.parent?1:2;};function d3_layout_treeLeft(v){var Tp=v.children;return Tp.length?Tp[0]:v.t;};function d3_layout_treeRight(v){var Tq=v.children,n;return (n=Tq.length)?Tq[n-1]:v.t;};function d3_layout_treeMove(Ts,Tu,Tr){var Tt=Tr/(Tu.i-Ts.i);Tu.c-=Tt;Tu.s+=Tr;Ts.c+=Tt;Tu.z+=Tr;Tu.m+=Tr;};function d3_layout_treeShift(v){var Tv=0,Tx=0,Tw=v.children,i=Tw.length,w;while( --i>=0){w=Tw[i];w.z+=Tv;w.m+=Tv;Tv+=w.s+(Tx+=w.c);};};function d3_layout_treeAncestor(Ty,v,Tz){return Ty.a.parent===v.parent?Ty.a:Tz;};d3.layout.cluster=function(){var TA=d3.layout.hierarchy().sort(null).value(null),TD=d3_layout_treeSeparation,TC=[1,1],TE=false;function TB(d,i){var TH=TA.call(this,d,i),TJ=TH[0],TF,x=0;d3_layout_hierarchyVisitAfter(TJ,function(TM){var TN=TM.children;if(TN&&TN.length){TM.x=d3_layout_clusterX(TN);TM.y=d3_layout_clusterY(TN);}else {TM.x=TF?x+=TD(TM,TF):0;TM.y=0;TF=TM;};});var TL=d3_layout_clusterLeft(TJ),TG=d3_layout_clusterRight(TJ),TK=TL.x-TD(TL,TG)/2,TI=TG.x+TD(TG,TL)/2;d3_layout_hierarchyVisitAfter(TJ,TE?function(TO){TO.x=(TO.x-TJ.x)*TC[0];TO.y=(TJ.y-TO.y)*TC[1];}:function(TP){TP.x=(TP.x-TK)/(TI-TK)*TC[0];TP.y=(1-(TJ.y?TP.y/TJ.y:1))*TC[1];});return TH;};TB.separation=function(x){if(!arguments.length)return TD;TD=x;return TB;};TB.size=function(x){if(!arguments.length)return TE?null:TC;TE=(TC=x)==null;return TB;};TB.nodeSize=function(x){if(!arguments.length)return TE?TC:null;TE=(TC=x)!=null;return TB;};return d3_layout_hierarchyRebind(TB,TA);};function d3_layout_clusterY(TQ){return 1+d3.max(TQ,function(TR){return TR.y;});};function d3_layout_clusterX(TS){return TS.reduce(function(x,TT){return x+TT.x;},0)/TS.length;};function d3_layout_clusterLeft(TU){var TV=TU.children;return TV&&TV.length?d3_layout_clusterLeft(TV[0]):TU;};function d3_layout_clusterRight(TW){var TX=TW.children,n;return TX&&(n=TX.length)?d3_layout_clusterRight(TX[n-1]):TW;};d3.layout.treemap=function(){var Ud=d3.layout.hierarchy(),Um=Math.round,Un=[1,1],Ug=null,Ui=d3_layout_treemapPadNull,Uf=false,Uh,Uj=ch,Ub=.5*(1+Math.sqrt(5));function Ua(Uq,k){var i=-1,n=Uq.length,Up,Uo;while( ++i<n){Uo=(Up=Uq[i]).value*(k<0?0:k);Up.area=isNaN(Uo)||Uo<=0?0:Uo;};};function Uc(Ur){var Uw=Ur.children;if(Uw&&Uw.length){var Ut=Ui(Ur),Uv=[],Uy=Uw.slice(),Uu,Ux=Infinity,Us,u=Uj===gV?Ut.dx:Uj===hn?Ut.dy:Uj===bC?Ur.depth&1?Ut.dy:Ut.dx:Math.min(Ut.dx,Ut.dy),n;Ua(Uy,Ut.dx*Ut.dy/Ur.value);Uv.area=0;while((n=Uy.length)>0){Uv.push(Uu=Uy[n-1]);Uv.area+=Uu.area;if(Uj!==ch||(Us=TY(Uv,u))<=Ux){Uy.pop();Ux=Us;}else {Uv.area-=Uv.pop().area;Ul(Uv,u,Ut,false);u=Math.min(Ut.dx,Ut.dy);Uv.length=Uv.area=0;Ux=Infinity;};};if(Uv.length){Ul(Uv,u,Ut,true);Uv.length=Uv.area=0;};Uw.forEach(Uc);};};function Uk(Uz){var UC=Uz.children;if(UC&&UC.length){var UD=Ui(Uz),UA=UC.slice(),UB,UE=[];Ua(UA,UD.dx*UD.dy/Uz.value);UE.area=0;while(UB=UA.pop()){UE.push(UB);UE.area+=UB.area;if(UB.z!=null){Ul(UE,UB.z?UD.dx:UD.dy,UD,!UA.length);UE.length=UE.area=0;};};UC.forEach(Uk);};};function TY(UH,u){var s=UH.area,r,UG=0,UF=Infinity,i=-1,n=UH.length;while( ++i<n){if(!(r=UH[i].area))continue;if(r<UF)UF=r;if(r>UG)UG=r;};s*=s;u*=u;return s?Math.max(u*UG*Ub/s,s/(u*UF*Ub)):Infinity;};function Ul(UK,u,UJ,UI){var i=-1,n=UK.length,x=UJ.x,y=UJ.y,v=u?Um(UK.area/u):0,o;if(u==UJ.dx){if(UI||v>UJ.dy)v=UJ.dy;while( ++i<n){o=UK[i];o.x=x;o.y=y;o.dy=v;x+=o.dx=Math.min(UJ.x+UJ.dx-x,v?Um(o.area/v):0);};o.z=true;o.dx+=UJ.x+UJ.dx-x;UJ.y+=v;UJ.dy-=v;}else {if(UI||v>UJ.dx)v=UJ.dx;while( ++i<n){o=UK[i];o.x=x;o.y=y;o.dx=v;y+=o.dy=Math.min(UJ.y+UJ.dy-y,v?Um(o.area/v):0);};o.z=false;o.dy+=UJ.y+UJ.dy-y;UJ.x+=v;UJ.dx-=v;};};function Ue(d){var UL=Uh||Ud(d),UM=UL[0];UM.x=UM.y=0;if(UM.value)UM.dx=Un[0],UM.dy=Un[1];else UM.dx=UM.dy=0;if(Uh)Ud.revalue(UM);Ua([UM],UM.dx*UM.dy/UM.value);(Uh?Uk:Uc)(UM);if(Uf)Uh=UL;return UL;};Ue.size=function(x){if(!arguments.length)return Un;Un=x;return Ue;};Ue.padding=function(x){if(!arguments.length)return Ug;function UN(UQ){var p=x.call(Ue,UQ,UQ.depth);return p==null?d3_layout_treemapPadNull(UQ):d3_layout_treemapPad(UQ,typeof p===bU?[p,p,p,p]:p);};function UO(UR){return d3_layout_treemapPad(UR,x);};var UP;Ui=(Ug=x)==null?d3_layout_treemapPadNull:(UP=typeof x)===eG?UN:UP===bU?(x=[x,x,x,x],UO):UO;return Ue;};Ue.round=function(x){if(!arguments.length)return Um!=Number;Um=x?Math.round:Number;return Ue;};Ue.sticky=function(x){if(!arguments.length)return Uf;Uf=x;Uh=null;return Ue;};Ue.ratio=function(x){if(!arguments.length)return Ub;Ub=x;return Ue;};Ue.mode=function(x){if(!arguments.length)return Uj;Uj=x+gS;return Ue;};return d3_layout_hierarchyRebind(Ue,Ud);};function d3_layout_treemapPadNull(US){return {x:US.x,y:US.y,dx:US.dx,dy:US.dy};};function d3_layout_treemapPad(UT,UU){var x=UT.x+UU[3],y=UT.y+UU[0],UV=UT.dx-UU[1]-UU[3],UW=UT.dy-UU[0]-UU[2];if(UV<0){x+=UV/2;UV=0;};if(UW<0){y+=UW/2;UW=0;};return {x:x,y:y,dx:UV,dy:UW};};d3.random={normal:function(µ,σ){var n=arguments.length;if(n<2)σ=1;if(n<1)µ=0;return function(){var x,y,r;do {x=Math.random()*2-1;y=Math.random()*2-1;r=x*x+y*y;}while(!r||r>1);return µ+σ*x*Math.sqrt(-2*Math.log(r)/r);};},logNormal:function(){var UX=d3.random.normal.apply(d3,arguments);return function(){return Math.exp(UX());};},bates:function(m){var UY=d3.random.irwinHall(m);return function(){return UY()/m;};},irwinHall:function(m){return function(){for(var s=0,j=0;j<m;j++ )s+=Math.random();return s;};}};d3.scale={};function d3_scaleExtent(Vb){var Va=Vb[0],stop=Vb[Vb.length-1];return Va<stop?[Va,stop]:[stop,Va];};function d3_scaleRange(Vc){return Vc.rangeExtent?Vc.rangeExtent():d3_scaleExtent(Vc.range());};function d3_scale_bilinear(Vd,Vf,Vg,Ve){var u=Vg(Vd[0],Vd[1]),i=Ve(Vf[0],Vf[1]);return function(x){return i(u(x));};};function d3_scale_nice(Vh,Vn){var Vj=0,Vi=Vh.length-1,Vl=Vh[Vj],Vm=Vh[Vi],Vk;if(Vm<Vl){Vk=Vj,Vj=Vi,Vi=Vk;Vk=Vl,Vl=Vm,Vm=Vk;};Vh[Vj]=Vn.floor(Vl);Vh[Vi]=Vn.ceil(Vm);return Vh;};function d3_scale_niceStep(Vo){return Vo?{floor:function(x){return Math.floor(x/Vo)*Vo;},ceil:function(x){return Math.ceil(x/Vo)*Vo;}}:d3_scale_niceIdentity;};var d3_scale_niceIdentity={floor:d3_identity,ceil:d3_identity};function d3_scale_polylinear(Vp,Vr,Vs,Vq){var u=[],i=[],j=0,k=Math.min(Vp.length,Vr.length)-1;if(Vp[k]<Vp[0]){Vp=Vp.slice().reverse();Vr=Vr.slice().reverse();};while( ++j<=k){u.push(Vs(Vp[j-1],Vp[j]));i.push(Vq(Vr[j-1],Vr[j]));};return function(x){var j=d3.bisect(Vp,x,1,k)-1;return i[j](u[j](x));};};d3.scale.linear=function(){return d3_scale_linear([0,1],[0,1],d3_interpolate,false);};function d3_scale_linear(Vu,Vy,Vx,Vt){var Vz,VA;function Vw(){var VB=Math.min(Vu.length,Vy.length)>2?d3_scale_polylinear:d3_scale_bilinear,VC=Vt?d3_uninterpolateClamp:d3_uninterpolateNumber;Vz=VB(Vu,Vy,VC,Vx);VA=VB(Vy,Vu,VC,d3_interpolate);return Vv;};function Vv(x){return Vz(x);};Vv.invert=function(y){return VA(y);};Vv.domain=function(x){if(!arguments.length)return Vu;Vu=x.map(Number);return Vw();};Vv.range=function(x){if(!arguments.length)return Vy;Vy=x;return Vw();};Vv.rangeRound=function(x){return Vv.range(x).interpolate(d3_interpolateRound);};Vv.clamp=function(x){if(!arguments.length)return Vt;Vt=x;return Vw();};Vv.interpolate=function(x){if(!arguments.length)return Vx;Vx=x;return Vw();};Vv.ticks=function(m){return d3_scale_linearTicks(Vu,m);};Vv.tickFormat=function(m,VD){return d3_scale_linearTickFormat(Vu,m,VD);};Vv.nice=function(m){d3_scale_linearNice(Vu,m);return Vw();};Vv.copy=function(){return d3_scale_linear(Vu,Vy,Vx,Vt);};return Vw();};function d3_scale_linearRebind(VE,VF){return d3.rebind(VE,VF,bu,dF,dH,hm);};function d3_scale_linearNice(VG,m){d3_scale_nice(VG,d3_scale_niceStep(d3_scale_linearTickRange(VG,m)[2]));d3_scale_nice(VG,d3_scale_niceStep(d3_scale_linearTickRange(VG,m)[2]));return VG;};function d3_scale_linearTickRange(VH,m){if(m==null)m=10;var VL=d3_scaleExtent(VH),VI=VL[1]-VL[0],VK=Math.pow(10,Math.floor(Math.log(VI/m)/Math.LN10)),VJ=m/VI*VK;if(VJ<=.15)VK*=10;else if(VJ<=.35)VK*=5;else if(VJ<=.75)VK*=2;VL[0]=Math.ceil(VL[0]/VK)*VK;VL[1]=Math.floor(VL[1]/VK)*VK+VK*.5;VL[2]=VK;return VL;};function d3_scale_linearTicks(VM,m){return d3.range.apply(d3,d3_scale_linearTickRange(VM,m));};function d3_scale_linearTickFormat(VN,m,VO){var VP=d3_scale_linearTickRange(VN,m);if(VO){var VR=d3_format_re.exec(VO);VR.shift();if(VR[8]===hf){var VQ=d3.formatPrefix(Math.max(abs(VP[0]),abs(VP[1])));if(!VR[7])VR[7]=fY+d3_scale_linearPrecision(VQ.scale(VP[2]));VR[8]=gT;VO=d3.format(VR.join(gS));return function(d){return VO(VQ.scale(d))+VQ.symbol;};};if(!VR[7])VR[7]=fY+d3_scale_linearFormatPrecision(VR[8],VP);VO=VR.join(gS);}else {VO=hx+d3_scale_linearPrecision(VP[2])+gT;};return d3.format(VO);};var d3_scale_linearFormatSignificant={s:1,g:1,p:1,r:1,e:1};function d3_scale_linearPrecision(VS){return -Math.floor(Math.log(VS)/Math.LN10+.01);};function d3_scale_linearFormatPrecision(VU,VT){var p=d3_scale_linearPrecision(VT[2]);return VU in d3_scale_linearFormatSignificant?Math.abs(p-d3_scale_linearPrecision(Math.max(abs(VT[0]),abs(VT[1]))))+(+(VU!==fO)):p-(VU===bz)*2;};d3.scale.log=function(){return d3_scale_log(d3.scale.linear().domain([0,1]),10,true,[1,10]);};function d3_scale_log(VX,Wa,VY,VV){function Wc(x){return (VY?Math.log(x<0?0:x):-Math.log(x>0?0:-x))/Math.log(Wa);};function Wb(x){return VY?Math.pow(Wa,x):-Math.pow(Wa,-x);};function VW(x){return VX(Wc(x));};VW.invert=function(x){return Wb(VX.invert(x));};VW.domain=function(x){if(!arguments.length)return VV;VY=x[0]>=0;VX.domain((VV=x.map(Number)).map(Wc));return VW;};VW.base=function(_){if(!arguments.length)return Wa;Wa=+_;VX.domain(VV.map(Wc));return VW;};VW.nice=function(){var Wd=d3_scale_nice(VV.map(Wc),VY?Math:d3_scale_logNiceNegative);VX.domain(Wd);VV=Wd.map(Wb);return VW;};VW.ticks=function(){var Wf=d3_scaleExtent(VV),We=[],u=Wf[0],v=Wf[1],i=Math.floor(Wc(u)),j=Math.ceil(Wc(v)),n=Wa%1?2:Wa;if(isFinite(j-i)){if(VY){for(;i<j;i++ ){for(var k=1;k<n;k++ ){We.push(Wb(i)*k);};};We.push(Wb(i));}else {We.push(Wb(i));for(;i++ <j;){for(var k=n-1;k>0;k-- ){We.push(Wb(i)*k);};};};for(i=0;We[i]<u;i++ ){};for(j=We.length;We[j-1]>v;j-- ){};We=We.slice(i,j);};return We;};VW.tickFormat=function(n,Wg){if(!arguments.length)return d3_scale_logFormat;if(arguments.length<2){Wg=d3_scale_logFormat;}else if(typeof Wg!==eG){Wg=d3.format(Wg);};var k=Math.max(1,Wa*n/VW.ticks().length);return function(d){var i=d/Wb(Math.round(Wc(d)));if(i*Wa<Wa-.5)i*=Wa;return i<=k?Wg(d):gS;};};VW.copy=function(){return d3_scale_log(VX.copy(),Wa,VY,VV);};return d3_scale_linearRebind(VW,VX);};var d3_scale_logFormat=d3.format(bJ),d3_scale_logNiceNegative={floor:function(x){return -Math.ceil(-x);},ceil:function(x){return -Math.floor(-x);}};d3.scale.pow=function(){return d3_scale_pow(d3.scale.linear(),1,[0,1]);};function d3_scale_pow(Wj,Wm,Wh){var Wk=d3_scale_powPow(Wm),Wl=d3_scale_powPow(1/Wm);function Wi(x){return Wj(Wk(x));};Wi.invert=function(x){return Wl(Wj.invert(x));};Wi.domain=function(x){if(!arguments.length)return Wh;Wj.domain((Wh=x.map(Number)).map(Wk));return Wi;};Wi.ticks=function(m){return d3_scale_linearTicks(Wh,m);};Wi.tickFormat=function(m,Wn){return d3_scale_linearTickFormat(Wh,m,Wn);};Wi.nice=function(m){return Wi.domain(d3_scale_linearNice(Wh,m));};Wi.exponent=function(x){if(!arguments.length)return Wm;Wk=d3_scale_powPow(Wm=x);Wl=d3_scale_powPow(1/Wm);Wj.domain(Wh.map(Wk));return Wi;};Wi.copy=function(){return d3_scale_pow(Wj.copy(),Wm,Wh);};return d3_scale_linearRebind(Wi,Wj);};function d3_scale_powPow(e){return function(x){return x<0?-Math.pow(-x,e):Math.pow(x,e);};};d3.scale.sqrt=function(){return d3.scale.pow().exponent(.5);};d3.scale.ordinal=function(){return d3_scale_ordinal([],{t:bu,a:[[]]});};function d3_scale_ordinal(Wp,Wr){var Wo,Ws,Wu;function Wq(x){return Ws[((Wo.get(x)||(Wr.t===bu?Wo.set(x,Wp.push(x)):NaN))-1)%Ws.length];};function Wt(Wv,Ww){return d3.range(Wp.length).map(function(i){return Wv+Ww*i;});};Wq.domain=function(x){if(!arguments.length)return Wp;Wp=[];Wo=new d3_Map();var i=-1,n=x.length,Wx;while( ++i<n)if(!Wo.has(Wx=x[i]))Wo.set(Wx,Wp.push(Wx));return Wq[Wr.t].apply(Wq,Wr.a);};Wq.range=function(x){if(!arguments.length)return Ws;Ws=x;Wu=0;Wr={t:bu,a:arguments};return Wq;};Wq.rangePoints=function(x,Wy){if(arguments.length<2)Wy=0;var Wz=x[0],stop=x[1],WA=Wp.length<2?(Wz=(Wz+stop)/2,0):(stop-Wz)/(Wp.length-1+Wy);Ws=Wt(Wz+WA*Wy/2,WA);Wu=0;Wr={t:gA,a:arguments};return Wq;};Wq.rangeRoundPoints=function(x,WB){if(arguments.length<2)WB=0;var WC=x[0],stop=x[1],WD=Wp.length<2?(WC=stop=Math.round((WC+stop)/2),0):(stop-WC)/(Wp.length-1+WB)|0;Ws=Wt(WC+Math.round(WD*WB/2+(stop-WC-(Wp.length-1+WB)*WD)/2),WD);Wu=0;Wr={t:en,a:arguments};return Wq;};Wq.rangeBands=function(x,WF,WI){if(arguments.length<2)WF=0;if(arguments.length<3)WI=WF;var WE=x[1]<x[0],WG=x[WE-0],stop=x[1-WE],WH=(stop-WG)/(Wp.length-WF+2*WI);Ws=Wt(WG+WH*WI,WH);if(WE)Ws.reverse();Wu=WH*(1-WF);Wr={t:fq,a:arguments};return Wq;};Wq.rangeRoundBands=function(x,WK,WN){if(arguments.length<2)WK=0;if(arguments.length<3)WN=WK;var WJ=x[1]<x[0],WL=x[WJ-0],stop=x[1-WJ],WM=Math.floor((stop-WL)/(Wp.length-WK+2*WN));Ws=Wt(WL+Math.round((stop-WL-(Wp.length-WK)*WM)/2),WM);if(WJ)Ws.reverse();Wu=Math.round(WM*(1-WK));Wr={t:eS,a:arguments};return Wq;};Wq.rangeBand=function(){return Wu;};Wq.rangeExtent=function(){return d3_scaleExtent(Wr.a[0]);};Wq.copy=function(){return d3_scale_ordinal(Wp,Wr);};return Wq.domain(Wp);};d3.scale.category10=function(){return d3.scale.ordinal().range(d3_category10);};d3.scale.category20=function(){return d3.scale.ordinal().range(d3_category20);};d3.scale.category20b=function(){return d3.scale.ordinal().range(d3_category20b);};d3.scale.category20c=function(){return d3.scale.ordinal().range(d3_category20c);};var d3_category10=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(d3_rgbString);var d3_category20=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(d3_rgbString);var d3_category20b=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(d3_rgbString);var d3_category20c=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(d3_rgbString);d3.scale.quantile=function(){return d3_scale_quantile([],[]);};function d3_scale_quantile(WS,WP){var WQ;function WO(){var k=0,q=WP.length;WQ=[];while( ++k<q)WQ[k-1]=d3.quantile(WS,k/q);return WR;};function WR(x){if(!isNaN(x=+x))return WP[d3.bisect(WQ,x)];};WR.domain=function(x){if(!arguments.length)return WS;WS=x.map(d3_number).filter(d3_numeric).sort(d3_ascending);return WO();};WR.range=function(x){if(!arguments.length)return WP;WP=x;return WO();};WR.quantiles=function(){return WQ;};WR.invertExtent=function(y){y=WP.indexOf(y);return y<0?[NaN,NaN]:[y>0?WQ[y-1]:WS[0],y<WQ.length?WQ[y]:WS[WS.length-1]];};WR.copy=function(){return d3_scale_quantile(WS,WP);};return WO();};d3.scale.quantize=function(){return d3_scale_quantize(0,1,[0,1]);};function d3_scale_quantize(WX,WU,WW){var WY,i;function WT(x){return WW[Math.max(0,Math.min(i,Math.floor(WY*(x-WX))))];};function WV(){WY=WW.length/(WU-WX);i=WW.length-1;return WT;};WT.domain=function(x){if(!arguments.length)return [WX,WU];WX=+x[0];WU=+x[x.length-1];return WV();};WT.range=function(x){if(!arguments.length)return WW;WW=x;return WV();};WT.invertExtent=function(y){y=WW.indexOf(y);y=y<0?NaN:y/WY+WX;return [y,y+1/WY];};WT.copy=function(){return d3_scale_quantize(WX,WU,WW);};return WV();};d3.scale.threshold=function(){return d3_scale_threshold([.5],[0,1]);};function d3_scale_threshold(Xa,Xc){function Xb(x){if(x<=x)return Xc[d3.bisect(Xa,x)];};Xb.domain=function(_){if(!arguments.length)return Xa;Xa=_;return Xb;};Xb.range=function(_){if(!arguments.length)return Xc;Xc=_;return Xb;};Xb.invertExtent=function(y){y=Xc.indexOf(y);return [Xa[y-1],Xa[y]];};Xb.copy=function(){return d3_scale_threshold(Xa,Xc);};return Xb;};d3.scale.identity=function(){return d3_scale_identity([0,1]);};function d3_scale_identity(Xd){function Xe(x){return +x;};Xe.invert=Xe;Xe.domain=Xe.range=function(x){if(!arguments.length)return Xd;Xd=x.map(Xe);return Xe;};Xe.ticks=function(m){return d3_scale_linearTicks(Xd,m);};Xe.tickFormat=function(m,Xf){return d3_scale_linearTickFormat(Xd,m,Xf);};Xe.copy=function(){return d3_scale_identity(Xd);};return Xe;};d3.svg={};function d3_zero(){return 0;};d3.svg.arc=function(){var Xj=d3_svg_arcInnerRadius,Xg=d3_svg_arcOuterRadius,Xn=d3_zero,Xi=d3_svg_arcAuto,Xo=d3_svg_arcStartAngle,Xk=d3_svg_arcEndAngle,Xh=d3_svg_arcPadAngle;function Xm(){var XQ=Math.max(0,+Xj.apply(this,arguments)),XR=Math.max(0,+Xg.apply(this,arguments)),XG=Xo.apply(this,arguments)-halfπ,XF=Xk.apply(this,arguments)-halfπ,XE=Math.abs(XF-XG),Xy=XG>XF?0:1;if(XR<XQ)XC=XR,XR=XQ,XQ=XC;if(XE>=τε)return Xl(XR,Xy)+(XQ?Xl(XQ,1-Xy):gS)+be;var XC,Xt,Xz,Xs,XO=0,XP=0,XJ,Xv,XK,XS,XH,Xx,XI,Xw,Yb=[];if(Xs=(+Xh.apply(this,arguments)||0)/2){Xz=Xi===d3_svg_arcAuto?Math.sqrt(XQ*XQ+XR*XR):+Xi.apply(this,arguments);if(!Xy)XP*=-1;if(XR)XP=d3_asin(Xz/XR*Math.sin(Xs));if(XQ)XO=d3_asin(Xz/XQ*Math.sin(Xs));};if(XR){XJ=XR*Math.cos(XG+XP);Xv=XR*Math.sin(XG+XP);XK=XR*Math.cos(XF-XP);XS=XR*Math.sin(XF-XP);var XY=Math.abs(XF-XG-2*XP)<=π?0:1;if(XP&&d3_svg_arcSweep(XJ,Xv,XK,XS)===Xy^XY){var Xr=(XG+XF)/2;XJ=XR*Math.cos(Xr);Xv=XR*Math.sin(Xr);XK=XS=null;};}else {XJ=Xv=0;};if(XQ){XH=XQ*Math.cos(XF-XO);Xx=XQ*Math.sin(XF-XO);XI=XQ*Math.cos(XG+XO);Xw=XQ*Math.sin(XG+XO);var XX=Math.abs(XG-XF+2*XO)<=π?0:1;if(XO&&d3_svg_arcSweep(XH,Xx,XI,Xw)===1-Xy^XX){var Xq=(XG+XF)/2;XH=XQ*Math.cos(Xq);Xx=XQ*Math.sin(Xq);XI=Xw=null;};}else {XH=Xx=0;};if(XE>ε&&(XC=Math.min(Math.abs(XR-XQ)/2,+Xn.apply(this,arguments)))>.001){Xt=XQ<XR^Xy?0:1;var XU=XC,Xp=XC;if(XE<π){var XT=XI==null?[XH,Xx]:XK==null?[XJ,Xv]:d3_geom_polygonIntersect([XJ,Xv],[XI,Xw],[XK,XS],[XH,Xx]),XV=XJ-XT[0],Xu=Xv-XT[1],XL=XK-XT[0],XM=XS-XT[1],XN=1/Math.sin(Math.acos((XV*XL+Xu*XM)/(Math.sqrt(XV*XV+Xu*Xu)*Math.sqrt(XL*XL+XM*XM)))/2),XA=Math.sqrt(XT[0]*XT[0]+XT[1]*XT[1]);Xp=Math.min(XC,(XQ-XA)/(XN-1));XU=Math.min(XC,(XR-XA)/(XN+1));};if(XK!=null){var XD=d3_svg_arcCornerTangents(XI==null?[XH,Xx]:[XI,Xw],[XJ,Xv],XR,XU,Xy),XB=d3_svg_arcCornerTangents([XK,XS],[XH,Xx],XR,XU,Xy);if(XC===XU){Yb.push(hg,XD[0],dh,XU,hz,XU,gb,Xt,gH,XD[1],dh,XR,hz,XR,ej,1-Xy^d3_svg_arcSweep(XD[1][0],XD[1][1],XB[1][0],XB[1][1]),hz,Xy,gH,XB[1],dh,XU,hz,XU,gb,Xt,gH,XB[0]);}else {Yb.push(hg,XD[0],dh,XU,hz,XU,ek,Xt,gH,XB[0]);};}else {Yb.push(hg,XJ,hz,Xv);};if(XI!=null){var XW=d3_svg_arcCornerTangents([XJ,Xv],[XI,Xw],XQ,-Xp,Xy),Ya=d3_svg_arcCornerTangents([XH,Xx],XK==null?[XJ,Xv]:[XK,XS],XQ,-Xp,Xy);if(XC===Xp){Yb.push(fJ,Ya[0],dh,Xp,hz,Xp,gb,Xt,gH,Ya[1],dh,XQ,hz,XQ,ej,Xy^d3_svg_arcSweep(Ya[1][0],Ya[1][1],XW[1][0],XW[1][1]),hz,1-Xy,gH,XW[1],dh,Xp,hz,Xp,gb,Xt,gH,XW[0]);}else {Yb.push(fJ,Ya[0],dh,Xp,hz,Xp,gb,Xt,gH,XW[0]);};}else {Yb.push(fJ,XH,hz,Xx);};}else {Yb.push(hg,XJ,hz,Xv);if(XK!=null)Yb.push(dh,XR,hz,XR,ej,XY,hz,Xy,gH,XK,hz,XS);Yb.push(fJ,XH,hz,Xx);if(XI!=null)Yb.push(dh,XQ,hz,XQ,ej,XX,hz,1-Xy,gH,XI,hz,Xw);};Yb.push(be);return Yb.join(gS);};function Xl(Yd,Yc){return cf+Yd+dh+Yd+hz+Yd+ek+Yc+fu+-Yd+dh+Yd+hz+Yd+ek+Yc+fu+Yd;};Xm.innerRadius=function(v){if(!arguments.length)return Xj;Xj=d3_functor(v);return Xm;};Xm.outerRadius=function(v){if(!arguments.length)return Xg;Xg=d3_functor(v);return Xm;};Xm.cornerRadius=function(v){if(!arguments.length)return Xn;Xn=d3_functor(v);return Xm;};Xm.padRadius=function(v){if(!arguments.length)return Xi;Xi=v==d3_svg_arcAuto?d3_svg_arcAuto:d3_functor(v);return Xm;};Xm.startAngle=function(v){if(!arguments.length)return Xo;Xo=d3_functor(v);return Xm;};Xm.endAngle=function(v){if(!arguments.length)return Xk;Xk=d3_functor(v);return Xm;};Xm.padAngle=function(v){if(!arguments.length)return Xh;Xh=d3_functor(v);return Xm;};Xm.centroid=function(){var r=(+Xj.apply(this,arguments)+(+Xg.apply(this,arguments)))/2,a=(+Xo.apply(this,arguments)+(+Xk.apply(this,arguments)))/2-halfπ;return [Math.cos(a)*r,Math.sin(a)*r];};return Xm;};var d3_svg_arcAuto=gP;function d3_svg_arcInnerRadius(d){return d.innerRadius;};function d3_svg_arcOuterRadius(d){return d.outerRadius;};function d3_svg_arcStartAngle(d){return d.startAngle;};function d3_svg_arcEndAngle(d){return d.endAngle;};function d3_svg_arcPadAngle(d){return d&&d.padAngle;};function d3_svg_arcSweep(Yg,Yf,Yh,Ye){return (Yg-Yh)*Yf-(Yf-Ye)*Yg>0?0:1;};function d3_svg_arcCornerTangents(YE,YF,YD,Ys,Yp){var Yt=YE[0]-YF[0],Yq=YE[1]-YF[1],Yr=(Yp?Ys:-Ys)/Math.sqrt(Yt*Yt+Yq*Yq),YI=Yr*Yq,YH=-Yr*Yt,YC=YE[0]+YI,Ym=YE[1]+YH,YA=YF[0]+YI,Yo=YF[1]+YH,YB=(YC+YA)/2,Yn=(Ym+Yo)/2,Yy=YA-YC,Yz=Yo-Ym,YG=Yy*Yy+Yz*Yz,r=YD-Ys,D=YC*Yo-YA*Ym,d=(Yz<0?-1:1)*Math.sqrt(Math.max(0,r*r*YG-D*D)),Yu=(D*Yz-Yy*d)/YG,Yj=(-D*Yy-Yz*d)/YG,Yv=(D*Yz+Yy*d)/YG,Yi=(-D*Yy+Yz*d)/YG,Yx=Yu-YB,Yk=Yj-Yn,Yw=Yv-YB,Yl=Yi-Yn;if(Yx*Yx+Yk*Yk>Yw*Yw+Yl*Yl)Yu=Yv,Yj=Yi;return [[Yu-YI,Yj-YH],[Yu*YD/r,Yj*YD/r]];};function d3_svg_line(YK){var x=d3_geom_pointX,y=d3_geom_pointY,YL=d3_true,YN=d3_svg_lineLinear,YM=YN.key,YJ=.7;function YO(YT){var YQ=[],YS=[],i=-1,n=YT.length,d,YR=d3_functor(x),YP=d3_functor(y);function YU(){YQ.push(hg,YN(YK(YS),YJ));};while( ++i<n){if(YL.call(this,d=YT[i],i)){YS.push([+YR.call(this,d,i),+YP.call(this,d,i)]);}else if(YS.length){YU();YS=[];};};if(YS.length)YU();return YQ.length?YQ.join(gS):null;};YO.x=function(_){if(!arguments.length)return x;x=_;return YO;};YO.y=function(_){if(!arguments.length)return y;y=_;return YO;};YO.defined=function(_){if(!arguments.length)return YL;YL=_;return YO;};YO.interpolate=function(_){if(!arguments.length)return YM;if(typeof _===eG)YM=YN=_;else YM=(YN=d3_svg_lineInterpolators.get(_)||d3_svg_lineLinear).key;return YO;};YO.tension=function(_){if(!arguments.length)return YJ;YJ=_;return YO;};return YO;};d3.svg.line=function(){return d3_svg_line(d3_identity);};var d3_svg_lineInterpolators=d3.map({linear:d3_svg_lineLinear,"linear-closed":d3_svg_lineLinearClosed,step:d3_svg_lineStep,"step-before":d3_svg_lineStepBefore,"step-after":d3_svg_lineStepAfter,basis:d3_svg_lineBasis,"basis-open":d3_svg_lineBasisOpen,"basis-closed":d3_svg_lineBasisClosed,bundle:d3_svg_lineBundle,cardinal:d3_svg_lineCardinal,"cardinal-open":d3_svg_lineCardinalOpen,"cardinal-closed":d3_svg_lineCardinalClosed,monotone:d3_svg_lineMonotone});d3_svg_lineInterpolators.forEach(function(YV,YW){YW.key=YV;YW.closed=/-closed$/.test(YV);});function d3_svg_lineLinear(YX){return YX.length>1?YX.join(fJ):YX+be;};function d3_svg_lineLinearClosed(YY){return YY.join(fJ)+be;};function d3_svg_lineStep(baa){var i=0,n=baa.length,p=baa[0],bab=[p[0],hz,p[1]];while( ++i<n)bab.push(dq,(p[0]+(p=baa[i])[0])/2,fG,p[1]);if(n>1)bab.push(dq,p[0]);return bab.join(gS);};function d3_svg_lineStepBefore(bac){var i=0,n=bac.length,p=bac[0],bad=[p[0],hz,p[1]];while( ++i<n)bad.push(fG,(p=bac[i])[1],dq,p[0]);return bad.join(gS);};function d3_svg_lineStepAfter(bae){var i=0,n=bae.length,p=bae[0],baf=[p[0],hz,p[1]];while( ++i<n)baf.push(dq,(p=bae[i])[0],fG,p[1]);return baf.join(gS);};function d3_svg_lineCardinalOpen(bah,bag){return bah.length<4?d3_svg_lineLinear(bah):bah[1]+d3_svg_lineHermite(bah.slice(1,-1),d3_svg_lineCardinalTangents(bah,bag));};function d3_svg_lineCardinalClosed(baj,bai){return baj.length<3?d3_svg_lineLinearClosed(baj):baj[0]+d3_svg_lineHermite((baj.push(baj[0]),baj),d3_svg_lineCardinalTangents([baj[baj.length-2]].concat(baj,[baj[1]]),bai));};function d3_svg_lineCardinal(bal,bak){return bal.length<3?d3_svg_lineLinear(bal):bal[0]+d3_svg_lineHermite(bal,d3_svg_lineCardinalTangents(bal,bak));};function d3_svg_lineHermite(bap,bam){if(bam.length<1||bap.length!=bam.length&&bap.length!=bam.length+2){return d3_svg_lineLinear(bap);};var bar=bap.length!=bam.length,bas=gS,ban=bap[0],p=bap[1],bao=bam[0],t=bao,bat=1;if(bar){bas+=dP+(p[0]-bao[0]*2/3)+hz+(p[1]-bao[1]*2/3)+hz+p[0]+hz+p[1];ban=bap[1];bat=2;};if(bam.length>1){t=bam[1];p=bap[bat];bat++ ;bas+=T+(ban[0]+bao[0])+hz+(ban[1]+bao[1])+hz+(p[0]-t[0])+hz+(p[1]-t[1])+hz+p[0]+hz+p[1];for(var i=2;i<bam.length;i++ ,bat++ ){p=bap[bat];t=bam[i];bas+=cF+(p[0]-t[0])+hz+(p[1]-t[1])+hz+p[0]+hz+p[1];};};if(bar){var baq=bap[bat];bas+=dP+(p[0]+t[0]*2/3)+hz+(p[1]+t[1]*2/3)+hz+baq[0]+hz+baq[1];};return bas;};function d3_svg_lineCardinalTangents(baz,bau){var bav=[],a=(1-bau)/2,bax,baw=baz[0],bay=baz[1],i=1,n=baz.length;while( ++i<n){bax=baw;baw=bay;bay=baz[i];bav.push([a*(bay[0]-bax[0]),a*(bay[1]-bax[1])]);};return bav;};function d3_svg_lineBasis(baC){if(baC.length<3)return d3_svg_lineLinear(baC);var i=1,n=baC.length,baG=baC[0],baF=baG[0],baD=baG[1],baA=[baF,baF,baF,(baG=baC[1])[0]],baB=[baD,baD,baD,baG[1]],baE=[baF,hz,baD,fJ,d3_svg_lineDot4(d3_svg_lineBasisBezier3,baA),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier3,baB)];baC.push(baC[n-1]);while( ++i<=n){baG=baC[i];baA.shift();baA.push(baG[0]);baB.shift();baB.push(baG[1]);d3_svg_lineBasisBezier(baE,baA,baB);};baC.pop();baE.push(fJ,baG);return baE.join(gS);};function d3_svg_lineBasisOpen(baJ){if(baJ.length<4)return d3_svg_lineLinear(baJ);var baK=[],i=-1,n=baJ.length,baL,baH=[0],baI=[0];while( ++i<3){baL=baJ[i];baH.push(baL[0]);baI.push(baL[1]);};baK.push(d3_svg_lineDot4(d3_svg_lineBasisBezier3,baH)+hz+d3_svg_lineDot4(d3_svg_lineBasisBezier3,baI)); --i;while( ++i<n){baL=baJ[i];baH.shift();baH.push(baL[0]);baI.shift();baI.push(baL[1]);d3_svg_lineBasisBezier(baK,baH,baI);};return baK.join(gS);};function d3_svg_lineBasisClosed(baO){var baP,i=-1,n=baO.length,m=n+4,baQ,baM=[],baN=[];while( ++i<4){baQ=baO[i%n];baM.push(baQ[0]);baN.push(baQ[1]);};baP=[d3_svg_lineDot4(d3_svg_lineBasisBezier3,baM),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier3,baN)]; --i;while( ++i<m){baQ=baO[i%n];baM.shift();baM.push(baQ[0]);baN.shift();baN.push(baQ[1]);d3_svg_lineBasisBezier(baP,baM,baN);};return baP.join(gS);};function d3_svg_lineBundle(baS,baR){var n=baS.length-1;if(n){var baW=baS[0][0],baV=baS[0][1],baT=baS[n][0]-baW,baU=baS[n][1]-baV,i=-1,p,t;while( ++i<=n){p=baS[i];t=i/n;p[0]=baR*p[0]+(1-baR)*(baW+t*baT);p[1]=baR*p[1]+(1-baR)*(baV+t*baU);};};return d3_svg_lineBasis(baS);};function d3_svg_lineDot4(a,b){return a[0]*b[0]+a[1]*b[1]+a[2]*b[2]+a[3]*b[3];};var d3_svg_lineBasisBezier1=[0,2/3,1/3,0],d3_svg_lineBasisBezier2=[0,1/3,2/3,0],d3_svg_lineBasisBezier3=[0,1/6,2/3,1/6];function d3_svg_lineBasisBezier(baX,x,y){baX.push(T,d3_svg_lineDot4(d3_svg_lineBasisBezier1,x),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier1,y),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier2,x),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier2,y),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier3,x),hz,d3_svg_lineDot4(d3_svg_lineBasisBezier3,y));};function d3_svg_lineSlope(baY,bba){return (bba[1]-baY[1])/(bba[0]-baY[0]);};function d3_svg_lineFiniteDifferences(bbd){var i=0,j=bbd.length-1,m=[],bbb=bbd[0],bbc=bbd[1],d=m[0]=d3_svg_lineSlope(bbb,bbc);while( ++i<j){m[i]=(d+(d=d3_svg_lineSlope(bbb=bbc,bbc=bbd[i+1])))/2;};m[i]=d;return m;};function d3_svg_lineMonotoneTangents(bbf){var bbe=[],d,a,b,s,m=d3_svg_lineFiniteDifferences(bbf),i=-1,j=bbf.length-1;while( ++i<j){d=d3_svg_lineSlope(bbf[i],bbf[i+1]);if(abs(d)<ε){m[i]=m[i+1]=0;}else {a=m[i]/d;b=m[i+1]/d;s=a*a+b*b;if(s>9){s=d*3/Math.sqrt(s);m[i]=s*a;m[i+1]=s*b;};};};i=-1;while( ++i<=j){s=(bbf[Math.min(j,i+1)][0]-bbf[Math.max(0,i-1)][0])/(6*(1+m[i]*m[i]));bbe.push([s||0,m[i]*s||0]);};return bbe;};function d3_svg_lineMonotone(bbg){return bbg.length<3?d3_svg_lineLinear(bbg):bbg[0]+d3_svg_lineHermite(bbg,d3_svg_lineMonotoneTangents(bbg));};d3.svg.line.radial=function(){var bbh=d3_svg_line(d3_svg_lineRadial);bbh.radius=bbh.x,delete bbh.x;bbh.angle=bbh.y,delete bbh.y;return bbh;};function d3_svg_lineRadial(bbj){var bbi,i=-1,n=bbj.length,r,a;while( ++i<n){bbi=bbj[i];r=bbi[0];a=bbi[1]-halfπ;bbi[0]=r*Math.cos(a);bbi[1]=r*Math.sin(a);};return bbj;};function d3_svg_area(bbm){var bbt=d3_geom_pointX,bbl=d3_geom_pointX,bbs=0,bbr=d3_geom_pointY,bbo=d3_true,bbq=d3_svg_lineLinear,bbp=bbq.key,bbu=bbq,L=fJ,bbk=.7;function bbn(bbC){var bbx=[],bbv=[],bbw=[],i=-1,n=bbC.length,d,bbz=d3_functor(bbt),bbA=d3_functor(bbs),bby=bbt===bbl?function(){return x;}:d3_functor(bbl),bbB=bbs===bbr?function(){return y;}:d3_functor(bbr),x,y;function bbD(){bbx.push(hg,bbq(bbm(bbw),bbk),L,bbu(bbm(bbv.reverse()),bbk),be);};while( ++i<n){if(bbo.call(this,d=bbC[i],i)){bbv.push([x=+bbz.call(this,d,i),y=+bbA.call(this,d,i)]);bbw.push([+bby.call(this,d,i),+bbB.call(this,d,i)]);}else if(bbv.length){bbD();bbv=[];bbw=[];};};if(bbv.length)bbD();return bbx.length?bbx.join(gS):null;};bbn.x=function(_){if(!arguments.length)return bbl;bbt=bbl=_;return bbn;};bbn.x0=function(_){if(!arguments.length)return bbt;bbt=_;return bbn;};bbn.x1=function(_){if(!arguments.length)return bbl;bbl=_;return bbn;};bbn.y=function(_){if(!arguments.length)return bbr;bbs=bbr=_;return bbn;};bbn.y0=function(_){if(!arguments.length)return bbs;bbs=_;return bbn;};bbn.y1=function(_){if(!arguments.length)return bbr;bbr=_;return bbn;};bbn.defined=function(_){if(!arguments.length)return bbo;bbo=_;return bbn;};bbn.interpolate=function(_){if(!arguments.length)return bbp;if(typeof _===eG)bbp=bbq=_;else bbp=(bbq=d3_svg_lineInterpolators.get(_)||d3_svg_lineLinear).key;bbu=bbq.reverse||bbq;L=bbq.closed?hg:fJ;return bbn;};bbn.tension=function(_){if(!arguments.length)return bbk;bbk=_;return bbn;};return bbn;};d3_svg_lineStepBefore.reverse=d3_svg_lineStepAfter;d3_svg_lineStepAfter.reverse=d3_svg_lineStepBefore;d3.svg.area=function(){return d3_svg_area(d3_identity);};d3.svg.area.radial=function(){var bbE=d3_svg_area(d3_svg_lineRadial);bbE.radius=bbE.x,delete bbE.x;bbE.innerRadius=bbE.x0,delete bbE.x0;bbE.outerRadius=bbE.x1,delete bbE.x1;bbE.angle=bbE.y,delete bbE.y;bbE.startAngle=bbE.y0,delete bbE.y0;bbE.endAngle=bbE.y1,delete bbE.y1;return bbE;};d3.svg.chord=function(){var bbK=d3_source,bbG=d3_target,bbM=d3_svg_chordRadius,bbN=d3_svg_arcStartAngle,bbJ=d3_svg_arcEndAngle;function bbF(d,i){var s=bbO(this,bbK,d,i),t=bbO(this,bbG,d,i);return hg+s.p0+bbL(s.r,s.p1,s.a1-s.a0)+(bbI(s,t)?bbH(s.r,s.p1,s.r,s.p0):bbH(s.r,s.p1,t.r,t.p0)+bbL(t.r,t.p1,t.a1-t.a0)+bbH(t.r,t.p1,s.r,s.p0))+be;};function bbO(self,f,d,i){var bbR=f.call(self,d,i),r=bbM.call(self,bbR,i),bbQ=bbN.call(self,bbR,i)-halfπ,bbP=bbJ.call(self,bbR,i)-halfπ;return {r:r,a0:bbQ,a1:bbP,p0:[r*Math.cos(bbQ),r*Math.sin(bbQ)],p1:[r*Math.cos(bbP),r*Math.sin(bbP)]};};function bbI(a,b){return a.a0==b.a0&&a.a1==b.a1;};function bbL(r,p,a){return dh+r+hz+r+ej+(+(a>π))+ck+p;};function bbH(bbU,bbS,bbV,bbT){return K+bbT;};bbF.radius=function(v){if(!arguments.length)return bbM;bbM=d3_functor(v);return bbF;};bbF.source=function(v){if(!arguments.length)return bbK;bbK=d3_functor(v);return bbF;};bbF.target=function(v){if(!arguments.length)return bbG;bbG=d3_functor(v);return bbF;};bbF.startAngle=function(v){if(!arguments.length)return bbN;bbN=d3_functor(v);return bbF;};bbF.endAngle=function(v){if(!arguments.length)return bbJ;bbJ=d3_functor(v);return bbF;};return bbF;};function d3_svg_chordRadius(d){return d.radius;};d3.svg.diagonal=function(){var bbW=d3_source,bca=d3_target,bbX=d3_svg_diagonalProjection;function bbY(d,i){var bcc=bbW.call(this,d,i),bcb=bca.call(this,d,i),m=(bcc.y+bcb.y)/2,p=[bcc,{x:bcc.x,y:m},{x:bcb.x,y:m},bcb];p=p.map(bbX);return hg+p[0]+T+p[1]+gH+p[2]+gH+p[3];};bbY.source=function(x){if(!arguments.length)return bbW;bbW=d3_functor(x);return bbY;};bbY.target=function(x){if(!arguments.length)return bca;bca=d3_functor(x);return bbY;};bbY.projection=function(x){if(!arguments.length)return bbX;bbX=x;return bbY;};return bbY;};function d3_svg_diagonalProjection(d){return [d.x,d.y];};d3.svg.diagonal.radial=function(){var bce=d3.svg.diagonal(),bcf=d3_svg_diagonalProjection,bcd=bce.projection;bce.projection=function(x){return arguments.length?bcd(d3_svg_diagonalRadialProjection(bcf=x)):bcf;};return bce;};function d3_svg_diagonalRadialProjection(bcg){return function(){var d=bcg.apply(this,arguments),r=d[0],a=d[1]-halfπ;return [r*Math.cos(a),r*Math.sin(a)];};};d3.svg.symbol=function(){var bci=d3_svg_symbolType,bcj=d3_svg_symbolSize;function bch(d,i){return (d3_svg_symbols.get(bci.call(this,d,i))||d3_svg_symbolCircle)(bcj.call(this,d,i));};bch.type=function(x){if(!arguments.length)return bci;bci=d3_functor(x);return bch;};bch.size=function(x){if(!arguments.length)return bcj;bcj=d3_functor(x);return bch;};return bch;};function d3_svg_symbolSize(){return 64;};function d3_svg_symbolType(){return fE;};function d3_svg_symbolCircle(bck){var r=Math.sqrt(bck/π);return cf+r+dh+r+hz+r+hp+-r+dh+r+hz+r+hp+r+be;};var d3_svg_symbols=d3.map({circle:d3_svg_symbolCircle,cross:function(bcl){var r=Math.sqrt(bcl/5)/2;return hg+-3*r+hz+-r+dq+-r+fG+-3*r+dq+r+fG+-r+dq+3*r+fG+r+dq+r+fG+3*r+dq+-r+fG+r+dq+-3*r+be;},diamond:function(bco){var bcn=Math.sqrt(bco/(2*d3_svg_symbolTan30)),bcm=bcn*d3_svg_symbolTan30;return cf+-bcn+fJ+bcm+cM+fu+bcn+gH+-bcm+cM+be;},square:function(bcp){var r=Math.sqrt(bcp)/2;return hg+-r+hz+-r+fJ+r+hz+-r+gH+r+hz+r+gH+-r+hz+r+be;},"triangle-down":function(bcs){var bcq=Math.sqrt(bcs/d3_svg_symbolSqrt3),bcr=bcq*d3_svg_symbolSqrt3/2;return cf+bcr+fJ+bcq+hz+-bcr+gH+-bcq+hz+-bcr+be;},"triangle-up":function(bcv){var bct=Math.sqrt(bcv/d3_svg_symbolSqrt3),bcu=bct*d3_svg_symbolSqrt3/2;return cf+-bcu+fJ+bct+hz+bcu+gH+-bct+hz+bcu+be;}});d3.svg.symbolTypes=d3_svg_symbols.keys();var d3_svg_symbolSqrt3=Math.sqrt(3),d3_svg_symbolTan30=Math.tan(30*d3_radians);d3_selectionPrototype.transition=function(name){var bcB=d3_transitionInheritId|| ++d3_transitionId,bcA=d3_transitionNamespace(name),bcC=[],bcz,bcw,bcx=d3_transitionInherit||{time:Date.now(),ease:d3_ease_cubicInOut,delay:0,duration:250};for(var j=-1,m=this.length; ++j<m;){bcC.push(bcz=[]);for(var bcy=this[j],i=-1,n=bcy.length; ++i<n;){if(bcw=bcy[i])d3_transitionNode(bcw,i,bcA,bcB,bcx);bcz.push(bcw);};};return d3_transition(bcC,bcA,bcB);};d3_selectionPrototype.interrupt=function(name){return this.each(name==null?d3_selection_interrupt:d3_selection_interruptNS(d3_transitionNamespace(name)));};var d3_selection_interrupt=d3_selection_interruptNS(d3_transitionNamespace());function d3_selection_interruptNS(bcD){return function(){var bcF,bcG,bcE;if((bcF=this[bcD])&&(bcE=bcF[bcG=bcF.active])){bcE.timer.c=null;bcE.timer.t=NaN;if( --bcF.count)delete bcF[bcG];else delete this[bcD];bcF.active+=.5;bcE.event&&bcE.event.interrupt.call(this,this.__uB,bcE.index);};};};function d3_transition(bcJ,bcH,bcI){d3_subclass(bcJ,d3_transitionPrototype);bcJ.namespace=bcH;bcJ.id=bcI;return bcJ;};var d3_transitionPrototype=[],d3_transitionId=0,d3_transitionInheritId,d3_transitionInherit;d3_transitionPrototype.call=d3_selectionPrototype.call;d3_transitionPrototype.empty=d3_selectionPrototype.empty;d3_transitionPrototype.node=d3_selectionPrototype.node;d3_transitionPrototype.size=d3_selectionPrototype.size;d3.transition=function(bcK,name){return bcK&&bcK.transition?d3_transitionInheritId?bcK.transition(name):bcK:d3.selection().transition(bcK);};d3.transition.prototype=d3_transitionPrototype;d3_transitionPrototype.select=function(bcO){var bcQ=this.id,bcM=this.namespace,bcS=[],bcP,bcR,bcL;bcO=d3_selection_selector(bcO);for(var j=-1,m=this.length; ++j<m;){bcS.push(bcP=[]);for(var bcN=this[j],i=-1,n=bcN.length; ++i<n;){if((bcL=bcN[i])&&(bcR=bcO.call(bcL,bcL.__uB,i,j))){if(bY in bcL)bcR.__uB=bcL.__uB;d3_transitionNode(bcR,i,bcM,bcQ,bcL[bcM][bcQ]);bcP.push(bcR);}else {bcP.push(null);};};};return d3_transition(bcS,bcM,bcQ);};d3_transitionPrototype.selectAll=function(bcX){var bdb=this.id,bcW=this.namespace,bdd=[],bda,bcY,bcT,bdc,bcU;bcX=d3_selection_selectorAll(bcX);for(var j=-1,m=this.length; ++j<m;){for(var bcV=this[j],i=-1,n=bcV.length; ++i<n;){if(bcT=bcV[i]){bcU=bcT[bcW][bdb];bcY=bcX.call(bcT,bcT.__uB,i,j);bdd.push(bda=[]);for(var k=-1,o=bcY.length; ++k<o;){if(bdc=bcY[k])d3_transitionNode(bdc,k,bcW,bdb,bcU);bda.push(bdc);};};};};return d3_transition(bdd,bcW,bdb);};d3_transitionPrototype.filter=function(bdg){var bdi=[],bdh,bdf,bde;if(typeof bdg!==eG)bdg=d3_selection_filter(bdg);for(var j=0,m=this.length;j<m;j++ ){bdi.push(bdh=[]);for(var bdf=this[j],i=0,n=bdf.length;i<n;i++ ){if((bde=bdf[i])&&bdg.call(bde,bde.__uB,i,j)){bdh.push(bde);};};};return d3_transition(bdi,this.namespace,this.id);};d3_transitionPrototype.tween=function(name,bdj){var bdl=this.id,bdk=this.namespace;if(arguments.length<2)return this.node()[bdk][bdl].tween.get(name);return d3_selection_each(this,bdj==null?function(bdm){bdm[bdk][bdl].tween.remove(name);}:function(bdn){bdn[bdk][bdl].tween.set(name,bdj);});};function d3_transition_tween(bdq,name,bdo,bdp){var bds=bdq.id,bdr=bdq.namespace;return d3_selection_each(bdq,typeof bdo===eG?function(bdt,i,j){bdt[bdr][bds].tween.set(name,bdp(bdo.call(bdt,bdt.__uB,i,j)));}:(bdo=bdp(bdo),function(bdu){bdu[bdr][bds].tween.set(name,bdo);}));};d3_transitionPrototype.attr=function(bdy,bdA){if(arguments.length<2){for(bdA in bdy)this.attr(bdA,bdy[bdA]);return this;};var bdx=bdy==cv?d3_interpolateTransform:d3_interpolate,name=d3.ns.qualify(bdy);function bdw(){this.removeAttribute(name);};function bdv(){this.removeAttributeNS(name.space,name.local);};function bdz(b){return b==null?bdw:(b+=gS,function(){var a=this.getAttribute(name),i;return a!==b&&(i=bdx(a,b),function(t){this.setAttribute(name,i(t));});});};function bdB(b){return b==null?bdv:(b+=gS,function(){var a=this.getAttributeNS(name.space,name.local),i;return a!==b&&(i=bdx(a,b),function(t){this.setAttributeNS(name.space,name.local,i(t));});});};return d3_transition_tween(this,gi+bdy,bdA,name.local?bdB:bdz);};d3_transitionPrototype.attrTween=function(bdE,bdC){var name=d3.ns.qualify(bdE);function bdF(d,i){var f=bdC.call(this,d,i,this.getAttribute(name));return f&&function(t){this.setAttribute(name,f(t));};};function bdD(d,i){var f=bdC.call(this,d,i,this.getAttributeNS(name.space,name.local));return f&&function(t){this.setAttributeNS(name.space,name.local,f(t));};};return this.tween(gi+bdE,name.local?bdD:bdF);};d3_transitionPrototype.style=function(name,bdH,bdI){var n=arguments.length;if(n<3){if(typeof name!==cY){if(n<2)bdH=gS;for(bdI in name)this.style(bdI,name[bdI],bdH);return this;};bdI=gS;};function bdG(){this.style.removeProperty(name);};function bdJ(b){return b==null?bdG:(b+=gS,function(){var a=d3_window(this).getComputedStyle(this,null).getPropertyValue(name),i;return a!==b&&(i=d3_interpolate(a,b),function(t){this.style.setProperty(name,i(t),bdI);});});};return d3_transition_tween(this,eq+name,bdH,bdJ);};d3_transitionPrototype.styleTween=function(name,bdL,bdK){if(arguments.length<3)bdK=gS;function bdM(d,i){var f=bdL.call(this,d,i,d3_window(this).getComputedStyle(this,null).getPropertyValue(name));return f&&function(t){this.style.setProperty(name,f(t),bdK);};};return this.tween(eq+name,bdM);};d3_transitionPrototype.text=function(bdN){return d3_transition_tween(this,cI,bdN,d3_transition_text);};function d3_transition_text(b){if(b==null)b=gS;return function(){this.textContent=b;};};d3_transitionPrototype.remove=function(){var bdO=this.namespace;return this.each(Q,function(){var p;if(this[bdO].count<2&&(p=this.parentNode))p.removeChild(this);});};d3_transitionPrototype.ease=function(bdR){var bdQ=this.id,bdP=this.namespace;if(arguments.length<1)return this.node()[bdP][bdQ].ease;if(typeof bdR!==eG)bdR=d3.ease.apply(d3,arguments);return d3_selection_each(this,function(bdS){bdS[bdP][bdQ].ease=bdR;});};d3_transitionPrototype.delay=function(bdV){var bdU=this.id,bdT=this.namespace;if(arguments.length<1)return this.node()[bdT][bdU].delay;return d3_selection_each(this,typeof bdV===eG?function(bdW,i,j){bdW[bdT][bdU].delay=+bdV.call(bdW,bdW.__uB,i,j);}:(bdV=+bdV,function(bdX){bdX[bdT][bdU].delay=bdV;}));};d3_transitionPrototype.duration=function(beb){var bea=this.id,bdY=this.namespace;if(arguments.length<1)return this.node()[bdY][bea].duration;return d3_selection_each(this,typeof beb===eG?function(bec,i,j){bec[bdY][bea].duration=Math.max(1,beb.call(bec,bec.__uB,i,j));}:(beb=Math.max(1,beb),function(bed){bed[bdY][bea].duration=beb;}));};d3_transitionPrototype.each=function(bei,beg){var bej=this.id,bee=this.namespace;if(arguments.length<2){var bef=d3_transitionInherit,beh=d3_transitionInheritId;try{d3_transitionInheritId=bej;d3_selection_each(this,function(bek,i,j){d3_transitionInherit=bek[bee][bej];bei.call(bek,bek.__uB,i,j);});}finally{d3_transitionInherit=bef;d3_transitionInheritId=beh;};}else {d3_selection_each(this,function(bel){var bem=bel[bee][bej];(bem.event||(bem.event=d3.dispatch(bR,cB,gf))).on(bei,beg);});};return this;};d3_transitionPrototype.transition=function(){var ber=this.id,bes= ++d3_transitionId,beq=this.namespace,bet=[],beu,bep,ben,beo;for(var j=0,m=this.length;j<m;j++ ){bet.push(beu=[]);for(var bep=this[j],i=0,n=bep.length;i<n;i++ ){if(ben=bep[i]){beo=ben[beq][ber];d3_transitionNode(ben,i,beq,bes,{time:beo.time,ease:beo.ease,delay:beo.delay+beo.duration,duration:beo.duration});};beu.push(ben);};};return d3_transition(bet,beq,bes);};function d3_transitionNamespace(name){return name==null?go:cK+name+ci;};function d3_transitionNode(bev,i,bew,beC,beB){var bey=bev[bew]||(bev[bew]={active:0,count:0}),beA=bey[beC],beF,beE,beG,bez,beI;function bex(beK){var beJ=beA.delay;beE.t=beJ+beF;if(beJ<=beK)return beD(beK-beJ);beE.c=beD;};function beD(beP){var beN=bey.active,beM=bey[beN];if(beM){beM.timer.c=null;beM.timer.t=NaN; --bey.count;delete bey[beN];beM.event&&beM.event.interrupt.call(bev,bev.__uB,beM.index);};for(var beO in bey){if(+beO<beC){var beL=bey[beO];beL.timer.c=null;beL.timer.t=NaN; --bey.count;delete bey[beO];};};beE.c=beH;d3_timer(function(){if(beE.c&&beH(beP||1)){beE.c=null;beE.t=NaN;};return 1;},0,beF);bey.active=beC;beA.event&&beA.event.start.call(bev,bev.__uB,i);beI=[];beA.tween.forEach(function(beQ,beR){if(beR=beR.call(bev,bev.__uB,i)){beI.push(beR);};});bez=beA.ease;beG=beA.duration;};function beH(beS){var t=beS/beG,e=bez(t),n=beI.length;while(n>0){beI[ --n].call(bev,e);};if(t>=1){beA.event&&beA.event.end.call(bev,bev.__uB,i);if( --bey.count)delete bey[beC];else delete bev[bew];return 1;};};if(!beA){beF=beB.time;beE=d3_timer(bex,0,beF);beA=bey[beC]={tween:new d3_Map(),time:beF,timer:beE,delay:beB.delay,duration:beB.duration,ease:beB.ease,index:i};beB=null; ++bey.count;};};d3.svg.axis=function(){var beU=d3.scale.linear(),bfa=d3_svg_axisDefaultOrient,beT=6,beW=6,beX=3,beV=[10],beY=null,bfb;function bfc(g){g.each(function(){var g=d3.select(this);var bfn=this.__uC||beU,bfo=this.__uC=beU.copy();var bfm=beY==null?bfo.ticks?bfo.ticks.apply(bfo,beV):bfo.domain():beY,bfe=bfb==null?bfo.tickFormat?bfo.tickFormat.apply(bfo,beV):d3_identity:bfb,bfu=g.selectAll(cm).data(bfm,bfo),bfv=bfu.enter().insert(ef,hu).attr(fl,cV).style(bq,ε),bfr=d3.transition(bfu.exit()).style(bq,ε).remove(),bfx=d3.transition(bfu.order()).style(bq,1),bfd=Math.max(beT,0)+beX,bfp;var bfy=d3_scaleRange(bfo),bft=g.selectAll(hu).data([0]),bfw=(bft.enter().append(fH).attr(fl,eY),d3.transition(bft));bfv.append(ct);bfv.append(cI);var bfk=bfv.select(ct),bfA=bfx.select(ct),bff=bfu.select(cI).text(bfe),bfs=bfv.select(cI),bfz=bfx.select(cI),bfg=bfa===fF||bfa===fW?-1:1,bfl,bfh,bfi,bfj;if(bfa===gv||bfa===fF){bfp=d3_svg_axisX,bfl=cD,bfi=dJ,bfh=dN,bfj=gh;bff.attr(bn,bfg<0?gw:fs).style(gK,dS);bfw.attr(ff,hg+bfy[0]+hz+bfg*beW+hj+bfy[1]+fG+bfg*beW);}else {bfp=d3_svg_axisY,bfl=dJ,bfi=cD,bfh=gh,bfj=dN;bff.attr(bn,gm).style(gK,bfg<0?cB:bR);bfw.attr(ff,hg+bfg*beW+hz+bfy[0]+dW+bfy[1]+dq+bfg*beW);};bfk.attr(bfj,bfg*beT);bfs.attr(bfi,bfg*bfd);bfA.attr(bfh,0).attr(bfj,bfg*beT);bfz.attr(bfl,0).attr(bfi,bfg*bfd);if(bfo.rangeBand){var x=bfo,bfq=x.rangeBand()/2;bfn=bfo=function(d){return x(d)+bfq;};}else if(bfn.rangeBand){bfn=bfo;}else {bfr.call(bfp,bfo,bfn);};bfv.call(bfp,bfn,bfo);bfx.call(bfp,bfo,bfo);});};bfc.scale=function(x){if(!arguments.length)return beU;beU=x;return bfc;};bfc.orient=function(x){if(!arguments.length)return bfa;bfa=x in d3_svg_axisOrients?x+gS:d3_svg_axisDefaultOrient;return bfc;};bfc.ticks=function(){if(!arguments.length)return beV;beV=d3_array(arguments);return bfc;};bfc.tickValues=function(x){if(!arguments.length)return beY;beY=x;return bfc;};bfc.tickFormat=function(x){if(!arguments.length)return bfb;bfb=x;return bfc;};bfc.tickSize=function(x){var n=arguments.length;if(!n)return beT;beT=+x;beW=+arguments[n-1];return bfc;};bfc.innerTickSize=function(x){if(!arguments.length)return beT;beT=+x;return bfc;};bfc.outerTickSize=function(x){if(!arguments.length)return beW;beW=+x;return bfc;};bfc.tickPadding=function(x){if(!arguments.length)return beX;beX=+x;return bfc;};bfc.tickSubdivide=function(){return arguments.length&&bfc;};return bfc;};var d3_svg_axisDefaultOrient=gv,d3_svg_axisOrients={top:1,right:1,bottom:1,left:1};function d3_svg_axisX(bfC,bfB,bfD){bfC.attr(cv,function(d){var bfE=bfB(d);return ho+(isFinite(bfE)?bfE:bfD(d))+dY;});};function d3_svg_axisY(bfH,bfG,bfF){bfH.attr(cv,function(d){var bfI=bfG(d);return eA+(isFinite(bfI)?bfI:bfF(d))+eL;});};d3.svg.brush=function(){var event=d3_eventDispatch(bfR,bf,eR,bA),x=null,y=null,bfP=[0,0],bfK=[0,0],bfJ,bfQ,bfN=true,bfS=true,bfU=d3_svg_brushResizes[0];function bfR(g){g.each(function(){var g=d3.select(this).style(gQ,hq).style(cg,dU).on(gW,bfO).on(gp,bfO);var bfX=g.selectAll(hd).data([0]);bfX.enter().append(cH).attr(fl,V).style(gU,bG).style(cR,bV);g.selectAll(fv).data([0]).enter().append(cH).attr(fl,fw).style(cR,fA);var bga=g.selectAll(gR).data(bfU,d3_identity);bga.exit().remove();bga.enter().append(ef).attr(fl,function(d){return et+d;}).style(cR,function(d){return d3_svg_brushCursor[d];}).append(cH).attr(cD,function(d){return /[ew]$/.test(d)?-3:null;}).attr(dJ,function(d){return /^[ns]/.test(d)?-3:null;}).attr(dR,6).attr(O,6).style(gU,bG);bga.style(eD,bfR.empty()?ei:null);var bfV=d3.transition(g),bfY=d3.transition(bfX),bfW;if(x){bfW=d3_scaleRange(x);bfY.attr(cD,bfW[0]).attr(dR,bfW[1]-bfW[0]);bfL(bfV);};if(y){bfW=d3_scaleRange(y);bfY.attr(dJ,bfW[0]).attr(O,bfW[1]-bfW[0]);bfM(bfV);};bfT(bfV);});};bfR.event=function(g){g.each(function(){var bgb=event.of(this,arguments),bgc={x:bfP,y:bfK,i:bfJ,j:bfQ},bgd=this.__uC||bgc;this.__uC=bgc;if(d3_transitionInheritId){d3.select(this).transition().each(dp,function(){bfJ=bgd.i;bfQ=bgd.j;bfP=bgd.x;bfK=bgd.y;bgb({type:bf});}).tween(el,function(){var bgf=d3_interpolateArray(bfP,bgc.x),bge=d3_interpolateArray(bfK,bgc.y);bfJ=bfQ=null;return function(t){bfP=bgc.x=bgf(t);bfK=bgc.y=bge(t);bgb({type:eR,mode:dM});};}).each(fr,function(){bfJ=bgc.i;bfQ=bgc.j;bgb({type:eR,mode:dM});bgb({type:bA});});}else {bgb({type:bf});bgb({type:eR,mode:dM});bgb({type:bA});};});};function bfT(g){g.selectAll(gR).attr(cv,function(d){return ho+bfP[+/e$/.test(d)]+hz+bfK[+/^s/.test(d)]+eL;});};function bfL(g){g.select(fv).attr(cD,bfP[0]);g.selectAll(J).attr(dR,bfP[1]-bfP[0]);};function bfM(g){g.select(fv).attr(dJ,bfK[0]);g.selectAll(fV).attr(O,bfK[1]-bfK[0]);};function bfO(){var bgw=this,bgm=d3.select(d3.event.target),bgn=event.of(bgw,arguments),g=d3.select(bgw),bgu=bgm.datum(),bgh=!/^(n|s)$/.test(bgu)&&x,bgp=!/^(e|w)$/.test(bgu)&&y,bgv=bgm.classed(fw),bgi=d3_event_dragSuppress(bgw),bgj,bgg=d3.mouse(bgw),bgt;var w=d3.select(d3_window(bgw)).on(cC,bgl).on(eB,bgk);if(d3.event.changedTouches){w.on(fI,bgs).on(bQ,bgx);}else {w.on(eH,bgs).on(dv,bgx);};g.interrupt().selectAll(gy).interrupt();if(bgv){bgg[0]=bfP[0]-bgg[0];bgg[1]=bfK[0]-bgg[1];}else if(bgu){var bgr=+/w$/.test(bgu),bgq=+/^n/.test(bgu);bgt=[bfP[1-bgr]-bgg[0],bfK[1-bgq]-bgg[1]];bgg[0]=bfP[bgr];bgg[1]=bfK[bgq];}else if(d3.event.altKey)bgj=bgg.slice();g.style(gQ,ei).selectAll(gR).style(eD,null);d3.select(eC).style(cR,bgm.style(cR));bgn({type:bf});bgs();function bgl(){if(d3.event.keyCode==32){if(!bgv){bgj=null;bgg[0]-=bfP[1];bgg[1]-=bfK[1];bgv=2;};d3_eventPreventDefault();};};function bgk(){if(d3.event.keyCode==32&&bgv==2){bgg[0]+=bfP[1];bgg[1]+=bfK[1];bgv=0;d3_eventPreventDefault();};};function bgs(){var bgz=d3.mouse(bgw),bgy=false;if(bgt){bgz[0]+=bgt[0];bgz[1]+=bgt[1];};if(!bgv){if(d3.event.altKey){if(!bgj)bgj=[(bfP[0]+bfP[1])/2,(bfK[0]+bfK[1])/2];bgg[0]=bfP[+(bgz[0]<bgj[0])];bgg[1]=bfK[+(bgz[1]<bgj[1])];}else bgj=null;};if(bgh&&bgo(bgz,x,0)){bfL(g);bgy=true;};if(bgp&&bgo(bgz,y,1)){bfM(g);bgy=true;};if(bgy){bfT(g);bgn({type:eR,mode:bgv?fA:dM});};};function bgo(bgD,bgA,i){var bgG=d3_scaleRange(bgA),bgB=bgG[0],bgC=bgG[1],bgI=bgg[i],bgH=i?bfK:bfP,bgJ=bgH[1]-bgH[0],bgF,bgE;if(bgv){bgB-=bgI;bgC-=bgJ+bgI;};bgF=(i?bfS:bfN)?Math.max(bgB,Math.min(bgC,bgD[i])):bgD[i];if(bgv){bgE=(bgF+=bgI)+bgJ;}else {if(bgj)bgI=Math.max(bgB,Math.min(bgC,2*bgj[i]-bgF));if(bgI<bgF){bgE=bgF;bgF=bgI;}else {bgE=bgI;};};if(bgH[0]!=bgF||bgH[1]!=bgE){if(i)bfQ=null;else bfJ=null;bgH[0]=bgF;bgH[1]=bgE;return true;};};function bgx(){bgs();g.style(gQ,hq).selectAll(gR).style(eD,bfR.empty()?ei:null);d3.select(eC).style(cR,null);w.on(eH,null).on(dv,null).on(fI,null).on(bQ,null).on(cC,null).on(eB,null);bgi();bgn({type:bA});};};bfR.x=function(z){if(!arguments.length)return x;x=z;bfU=d3_svg_brushResizes[!x<<1|!y];return bfR;};bfR.y=function(z){if(!arguments.length)return y;y=z;bfU=d3_svg_brushResizes[!x<<1|!y];return bfR;};bfR.clamp=function(z){if(!arguments.length)return x&&y?[bfN,bfS]:x?bfN:y?bfS:null;if(x&&y)bfN=!!z[0],bfS=!!z[1];else if(x)bfN=!!z;else if(y)bfS=!!z;return bfR;};bfR.extent=function(z){var bgM,bgN,bgL,bgK,t;if(!arguments.length){if(x){if(bfJ){bgM=bfJ[0],bgN=bfJ[1];}else {bgM=bfP[0],bgN=bfP[1];if(x.invert)bgM=x.invert(bgM),bgN=x.invert(bgN);if(bgN<bgM)t=bgM,bgM=bgN,bgN=t;};};if(y){if(bfQ){bgL=bfQ[0],bgK=bfQ[1];}else {bgL=bfK[0],bgK=bfK[1];if(y.invert)bgL=y.invert(bgL),bgK=y.invert(bgK);if(bgK<bgL)t=bgL,bgL=bgK,bgK=t;};};return x&&y?[[bgM,bgL],[bgN,bgK]]:x?[bgM,bgN]:y&&[bgL,bgK];};if(x){bgM=z[0],bgN=z[1];if(y)bgM=bgM[0],bgN=bgN[0];bfJ=[bgM,bgN];if(x.invert)bgM=x(bgM),bgN=x(bgN);if(bgN<bgM)t=bgM,bgM=bgN,bgN=t;if(bgM!=bfP[0]||bgN!=bfP[1])bfP=[bgM,bgN];};if(y){bgL=z[0],bgK=z[1];if(x)bgL=bgL[1],bgK=bgK[1];bfQ=[bgL,bgK];if(y.invert)bgL=y(bgL),bgK=y(bgK);if(bgK<bgL)t=bgL,bgL=bgK,bgK=t;if(bgL!=bfK[0]||bgK!=bfK[1])bfK=[bgL,bgK];};return bfR;};bfR.clear=function(){if(!bfR.empty()){bfP=[0,0],bfK=[0,0];bfJ=bfQ=null;};return bfR;};bfR.empty=function(){return !!x&&bfP[0]==bfP[1]||!!y&&bfK[0]==bfK[1];};return d3.rebind(bfR,event,eb);};var d3_svg_brushCursor={n:eX,e:cA,s:eX,w:cA,nw:eK,ne:cG,se:eK,sw:cG};var d3_svg_brushResizes=[[dG,fO,hf,dX,fP,W,cN,dK],[fO,dX],[dG,hf],[]];var d3_time_format=d3_time.format=d3_locale_default.timeFormat;var d3_time_formatUtc=d3_time_format.utc;var d3_time_formatIso=d3_time_formatUtc(dC);d3_time_format.iso=Date.prototype.toISOString&&+new Date(P)?d3_time_formatIsoNative:d3_time_formatIso;function d3_time_formatIsoNative(bgO){return bgO.toISOString();};d3_time_formatIsoNative.parse=function(bgQ){var bgP=new Date(bgQ);return isNaN(bgP)?null:bgP;};d3_time_formatIsoNative.toString=d3_time_formatIso.toString;d3_time.second=d3_time_interval(function(bgR){return new d3_date(Math.floor(bgR/1e3)*1e3);},function(bgS,bgT){bgS.setTime(bgS.getTime()+Math.floor(bgT)*1e3);},function(bgU){return bgU.getSeconds();});d3_time.seconds=d3_time.second.range;d3_time.seconds.utc=d3_time.second.utc.range;d3_time.minute=d3_time_interval(function(bgV){return new d3_date(Math.floor(bgV/6e4)*6e4);},function(bgW,bgX){bgW.setTime(bgW.getTime()+Math.floor(bgX)*6e4);},function(bgY){return bgY.getMinutes();});d3_time.minutes=d3_time.minute.range;d3_time.minutes.utc=d3_time.minute.utc.range;d3_time.hour=d3_time_interval(function(bha){var bhb=bha.getTimezoneOffset()/60;return new d3_date((Math.floor(bha/36e5-bhb)+bhb)*36e5);},function(bhc,bhd){bhc.setTime(bhc.getTime()+Math.floor(bhd)*36e5);},function(bhe){return bhe.getHours();});d3_time.hours=d3_time.hour.range;d3_time.hours.utc=d3_time.hour.utc.range;d3_time.month=d3_time_interval(function(bhf){bhf=d3_time.day(bhf);bhf.setDate(1);return bhf;},function(bhg,bhh){bhg.setMonth(bhg.getMonth()+bhh);},function(bhi){return bhi.getMonth();});d3_time.months=d3_time.month.range;d3_time.months.utc=d3_time.month.utc.range;function d3_time_scale(bhm,bhj,bhn){function bhl(x){return bhm(x);};bhl.invert=function(x){return d3_time_scaleDate(bhm.invert(x));};bhl.domain=function(x){if(!arguments.length)return bhm.domain().map(d3_time_scaleDate);bhm.domain(x);return bhl;};function bhk(bhr,bho){var bhp=bhr[1]-bhr[0],bhq=bhp/bho,i=d3.bisect(d3_time_scaleSteps,bhq);return i==d3_time_scaleSteps.length?[bhj.year,d3_scale_linearTickRange(bhr.map(function(d){return d/31536e6;}),bho)[2]]:!i?[d3_time_scaleMilliseconds,d3_scale_linearTickRange(bhr,bho)[2]]:bhj[bhq/d3_time_scaleSteps[i-1]<d3_time_scaleSteps[i]/bhq?i-1:i];};bhl.nice=function(bhv,bhu){var bhs=bhl.domain(),bhw=d3_scaleExtent(bhs),bhx=bhv==null?bhk(bhw,10):typeof bhv===bU&&bhk(bhw,bhv);if(bhx)bhv=bhx[0],bhu=bhx[1];function bht(bhy){return !isNaN(bhy)&&!bhv.range(bhy,d3_time_scaleDate(+bhy+1),bhu).length;};return bhl.domain(d3_scale_nice(bhs,bhu>1?{floor:function(bhz){while(bht(bhz=bhv.floor(bhz)))bhz=d3_time_scaleDate(bhz-1);return bhz;},ceil:function(bhA){while(bht(bhA=bhv.ceil(bhA)))bhA=d3_time_scaleDate(+bhA+1);return bhA;}}:bhv));};bhl.ticks=function(bhC,bhB){var bhE=d3_scaleExtent(bhl.domain()),bhD=bhC==null?bhk(bhE,10):typeof bhC===bU?bhk(bhE,bhC):!bhC.range&&[{range:bhC},bhB];if(bhD)bhC=bhD[0],bhB=bhD[1];return bhC.range(bhE[0],d3_time_scaleDate(+bhE[1]+1),bhB<1?1:bhB);};bhl.tickFormat=function(){return bhn;};bhl.copy=function(){return d3_time_scale(bhm.copy(),bhj,bhn);};return d3_scale_linearRebind(bhl,bhm);};function d3_time_scaleDate(t){return new Date(t);};var d3_time_scaleSteps=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6];var d3_time_scaleLocalMethods=[[d3_time.second,1],[d3_time.second,5],[d3_time.second,15],[d3_time.second,30],[d3_time.minute,1],[d3_time.minute,5],[d3_time.minute,15],[d3_time.minute,30],[d3_time.hour,1],[d3_time.hour,3],[d3_time.hour,6],[d3_time.hour,12],[d3_time.day,1],[d3_time.day,2],[d3_time.week,1],[d3_time.month,1],[d3_time.month,3],[d3_time.year,1]];var d3_time_scaleLocalFormat=d3_time_format.multi(kucken.lib.D3._getTimeScaleRangeLocaleDefinition());var d3_time_scaleMilliseconds={range:function(bhF,stop,bhG){return d3.range(Math.ceil(bhF/bhG)*bhG,+stop,bhG).map(d3_time_scaleDate);},floor:d3_identity,ceil:d3_identity};d3_time_scaleLocalMethods.year=d3_time.year;d3_time.scale=function(){return d3_time_scale(d3.scale.linear(),d3_time_scaleLocalMethods,d3_time_scaleLocalFormat);};var d3_time_scaleUtcMethods=d3_time_scaleLocalMethods.map(function(m){return [m[0].utc,m[1]];});var d3_time_scaleUtcFormat=d3_time_formatUtc.multi(kucken.lib.D3._getUtcTimeScaleRangeLocaleDefinition());d3_time_scaleUtcMethods.year=d3_time.year.utc;d3_time.scale.utc=function(){return d3_time_scale(d3.scale.linear(),d3_time_scaleUtcMethods,d3_time_scaleUtcFormat);};d3.text=d3_xhrType(function(bhH){return bhH.responseText;});d3.json=function(bhI,bhJ){return d3_xhr(bhI,fX,d3_json,bhJ);};function d3_json(bhK){return JSON.parse(bhK.responseText);};d3.html=function(bhL,bhM){return d3_xhr(bhL,gn,d3_html,bhM);};function d3_html(bhO){var bhN=d3_document.createRange();bhN.selectNode(d3_document.body);return bhN.createContextualFragment(bhO.responseText);};d3.xml=d3_xhrType(function(bhP){return bhP.responseXML;});return d3;};})();(function(){var a="format",b='format',c="short",d="HH:mm",e='_',f="HHmmsszz",g="HHmm",h="HHmmss",j="thu",k="This case should never happen.",l="sat",m="cldr_date_format_",n="HH:mm:ss zz",o="full",p="cldr_pm",q="cldr_day_",r="_",s="cldr_month_",t="long",u="wed",v="medium",w="fri",x="cldr_am",y="tue",z="qx.locale.Date",A="mon",B="cldr_date_time_format_",C="sun",D="cldr_time_format_",E="HH:mm:ss",F='stand-alone';qx.Class.define(z,{statics:{__uD:qx.locale.Manager.getInstance(),getAmMarker:function(G){return this.__uD.localize(x,[],G);},getPmMarker:function(H){return this.__uD.localize(p,[],H);},getDayNames:function(length,J,N,K){var N=N?N:a;{};var L=[C,A,y,u,j,w,l];var M=[];for(var i=0;i<L.length;i++ ){var I=q+N+r+length+r+L[i];M.push(K?this.__uE(N,N===b?F:b,I,J):this.__uD.localize(I,[],J));};return M;},getDayName:function(length,T,Q,P,S){var P=P?P:a;{};var R=[C,A,y,u,j,w,l];var O=q+P+r+length+r+R[T];return S?this.__uE(P,P===b?F:b,O,Q):this.__uD.localize(O,[],Q);},getMonthNames:function(length,V,Y,W){var Y=Y?Y:a;{};var X=[];for(var i=0;i<12;i++ ){var U=s+Y+r+length+r+(i+1);X.push(W?this.__uE(Y,Y===b?F:b,U,V):this.__uD.localize(U,[],V));};return X;},getMonthName:function(length,bd,bc,ba,bb){var ba=ba?ba:a;{};var be=s+ba+r+length+r+(bd+1);return bb?this.__uE(ba,ba===b?F:b,be,bc):this.__uD.localize(be,[],bc);},getDateFormat:function(bh,bf){{};var bg=m+bh;return this.__uD.localize(bg,[],bf);},getDateTimeFormat:function(bm,bk,bi){var bl=B+bm;var bj=this.__uD.localize(bl,[],bi);if(bj==bl){bj=bk;};return bj;},getTimeFormat:function(bq,bn){{};var bp=D+bq;var bo=this.__uD.localize(bp,[],bn);if(bo!=bp){return bo;};switch(bq){case c:case v:return qx.locale.Date.getDateTimeFormat(g,d);case t:return qx.locale.Date.getDateTimeFormat(h,E);case o:return qx.locale.Date.getDateTimeFormat(f,n);default:throw new Error(k);};},getWeekStart:function(br){var bs={"MV":5,"AE":6,"AF":6,"BH":6,"DJ":6,"DZ":6,"EG":6,"ER":6,"ET":6,"IQ":6,"IR":6,"JO":6,"KE":6,"KW":6,"LB":6,"LY":6,"MA":6,"OM":6,"QA":6,"SA":6,"SD":6,"SO":6,"TN":6,"YE":6,"AS":0,"AU":0,"AZ":0,"BW":0,"CA":0,"CN":0,"FO":0,"GE":0,"GL":0,"GU":0,"HK":0,"IE":0,"IL":0,"IS":0,"JM":0,"JP":0,"KG":0,"KR":0,"LA":0,"MH":0,"MN":0,"MO":0,"MP":0,"MT":0,"NZ":0,"PH":0,"PK":0,"SG":0,"TH":0,"TT":0,"TW":0,"UM":0,"US":0,"UZ":0,"VI":0,"ZA":0,"ZW":0,"MW":0,"NG":0,"TJ":0};var bt=qx.locale.Date._getTerritory(br);return bs[bt]!=null?bs[bt]:1;},getWeekendStart:function(bu){var bw={"EG":5,"IL":5,"SY":5,"IN":0,"AE":4,"BH":4,"DZ":4,"IQ":4,"JO":4,"KW":4,"LB":4,"LY":4,"MA":4,"OM":4,"QA":4,"SA":4,"SD":4,"TN":4,"YE":4};var bv=qx.locale.Date._getTerritory(bu);return bw[bv]!=null?bw[bv]:6;},getWeekendEnd:function(bx){var by={"AE":5,"BH":5,"DZ":5,"IQ":5,"JO":5,"KW":5,"LB":5,"LY":5,"MA":5,"OM":5,"QA":5,"SA":5,"SD":5,"TN":5,"YE":5,"AF":5,"IR":5,"EG":6,"IL":6,"SY":6};var bz=qx.locale.Date._getTerritory(bx);return by[bz]!=null?by[bz]:0;},isWeekend:function(bC,bA){var bD=qx.locale.Date.getWeekendStart(bA);var bB=qx.locale.Date.getWeekendEnd(bA);if(bB>bD){return ((bC>=bD)&&(bC<=bB));}else {return ((bC>=bD)||(bC<=bB));};},_getTerritory:function(bE){if(bE){var bF=bE.split(r)[1]||bE;}else {bF=this.__uD.getTerritory()||this.__uD.getLanguage();};return bF.toUpperCase();},__uE:function(bI,bH,bL,bK){var bJ=this.__uD.localize(bL,[],bK);if(bJ==bL){var bG=bL.replace(e+bI+e,e+bH+e);return this.__uD.localize(bG,[],bK);}else {return bJ;};}}});})();(function(){var a="cldr_number_decimal_separator",b="cldr_number_percent_format",c="qx.locale.Number",d="cldr_number_group_separator";qx.Class.define(c,{statics:{getDecimalSeparator:function(e){return qx.locale.Manager.getInstance().localize(a,[],e);},getGroupSeparator:function(f){return qx.locale.Manager.getInstance().localize(d,[],f);},getPercentFormat:function(g){return qx.locale.Manager.getInstance().localize(b,[],g);}}});})();(function(){var c='%I',d='%a',e='%M',f='%Z',g='kucken.date.Ldml',h='%-M',i='%j',j='%A',k='%y',l='%-e',m='(%-?)?{0}',n='%S',o='%H',p='%-m',q='%-I',r='g',s='%b',t='%Y',u='%d',v='%p',w='%-S',x='%m',y='%B',z='%-H';qx.Class.define(g,{statics:{__uF:{'y':t,'yy':k,'yyyy':t,'M':p,'MM':x,'MMM':s,'MMMM':y,'d':l,'dd':u,'D':i,'EEEE':j,'E':d,'ccc':d,'h':q,'hh':c,'H':z,'HH':o,'m':h,'mm':e,'s':w,'ss':n,'a':v,'Z':f,'z':f,'zzzz':f},toPosix:function(A){kucken.lang.Object.items(this.__uF).sort(function(a,b){return b[0].length-a[0].length;}).forEach(function(B){var C=new RegExp(m.format(B[0]),r);A=A.replace(C,function(E,D){return D?E:B[1];});});return A;}}});})();(function(){var a='kucken.lang.Object';qx.Class.define(a,{statics:{dict:function(b){var c={};b.forEach(function(d){c[d[0]]=d[1];});return c;},items:function(e){return Object.keys(e).map(function(f){return [f,e[f]];});},merge:function(h,g){for(var i=1,l=arguments.length;i<l;i+=1){qx.lang.Object.mergeWith(h,arguments[i]);};return h;},keys:function(j){return Object.keys(j);},values:function(k){return Object.keys(k).map(function(m){return k[m];});},select:function(o,n){return n[o];}}});})();(function(){var a="qx.util.format.IFormat";qx.Interface.define(a,{members:{format:function(b){},parse:function(c){}}});})();(function(){var a="-",b="QQQ",c='W',d="qqqq",e="h",f="KK",g='L',h=" is not supported",m="Z",n="Date string '",o="GGGGG",p='abbreviated',q="Y+",r=". Wildcard ",s="eeeee",t="(\\d\\d?)",u="LL",v="abbreviated",w="EEEE",x="^",y=":",z='y',A="quoted_literal",B="weekOfYear",C="locale",D="SSS",E='a',F="day",G="(-*",H="qqq",I="(\\d\\d)",J='3rd quarter',K="K",L='q',M="pm",N="Error parsing date '",O='Anno Domini',P='G',Q="a",R='2nd quarter',S="yyyy-MM-dd'T'HH:mm:ss",T="GMT",U="HH:mm:ss",V="dd",W="+",X="qx.util.format.DateFormat",Y='weekDay',el="am",eg="eee",em="quarter",ei="ee",ej="q",ef="QQQQ",ek="HHmmss",eq="ww",er="H",es='Y+',et="wide",en='wide',eo="(\\d\\d\\d?)",eh="(GMT[\\+\\-]\\d\\d:\\d\\d)",ep="_applyLocale",ex="Q",fb="c",ey="(",ez="weekOfMonth",eu="ccc",ev="long",gc="Malformed date format: ",ew="EEEEE",eA='Y',eB="EE",eC="GGG",eH='-',eI="w",eJ="mm",eD='h',eE="S",eF='s',eG='A',eO="yyyy-MM-dd",eP="G",eQ='z',eR="GG",eK=")",eL="kk",eM="ss",eN="([\\+\\-]\\d\\d\\d\\d)",eV="default",eW='BC',gg='H',eX='S',eS='1st quarter',eT="stand-alone",ge="0",eU="MMMM",eY='c',fa="d",fm='Q',fl='Q1',fk="eeee",fq="QQ",fp="LLLLL",fo="HH",fn='k',ff="m",fe="DDD",fd="D",fc='D',fj="LLLL",fi="(\\d\\d*?)",fh='e',fg="': the value for day or month is too large",fx="literal",fw='K',fv="L",fu="hh",fB="ms",fA="(\\d\\d?\\d?)",fz="cccc",fy="e",ft='y+',fs="|",fr="W",fM="dayOfYear",fL="GGGG",fK='Q2',fQ='B',fP="MM",fO='Q4',fN="y+",fF='narrow',fE="ccccc",fD="E",fC="wildcard",fJ='',fI="' does not match the date format: ",fH="short",fG='d',fW="unkown",fV="narrow",fU="\\d?",fT="'",gb="k",ga='Before Christ',fY='Z',fX='m',fS=" ",fR="yyyy-MM-dd'T'HH:mm:ss'Z'",dP="String",dO='Q3',gh="z",dM="DD",dN="min",dL="",gf='M',dJ="sec",dK='isoUtcDateTime',dI='4th quarter',gd="(\\d?)",dG="SS",dH="MMM",dF="s",dY="M",ea='w',dW="EEE",dX="$",dU="?",dV='AD',dT="\\d",dE="+?",dR="hour",dS="MMMMM",dQ='E',ee='month',ec="LLL",ed="qq",eb="format";qx.Class.define(X,{extend:qx.core.Object,implement:qx.util.format.IFormat,construct:function(gj,gi){qx.core.Object.call(this);if(!gi){this.__ln=qx.locale.Manager.getInstance().getLocale();this.__uG=qx.locale.Manager.getInstance().bind(C,this,C);}else {this.__ln=gi;this.setLocale(gi);};this.__uH=this.__ln;if(gj!=null){this.__uI=gj.toString();if(this.__uI in qx.util.format.DateFormat.ISO_MASKS){if(this.__uI===dK){this.__uJ=true;};this.__uI=qx.util.format.DateFormat.ISO_MASKS[this.__uI];};}else {this.__uI=qx.locale.Date.getDateFormat(ev,this.__ln)+fS+qx.locale.Date.getDateTimeFormat(ek,U,this.__ln);};},properties:{locale:{apply:ep,nullable:true,check:dP}},statics:{getDateInstance:function(){var gk=qx.util.format.DateFormat;var gl=qx.locale.Date.getDateFormat(fH)+dL;if(gk._dateInstance==null||gk._dateInstance.__uI!=gl){gk._dateInstance=new gk(gl);};return gk._dateInstance;},getDateTimeInstance:function(){var gm=qx.util.format.DateFormat;var gn=qx.locale.Date.getDateFormat(ev)+fS+qx.locale.Date.getDateTimeFormat(ek,U);if(gm._dateTimeInstance==null||gm._dateTimeInstance.__uI!=gn){gm._dateTimeInstance=new gm(gn);};return gm._dateTimeInstance;},ASSUME_YEAR_2000_THRESHOLD:30,ISO_MASKS:{isoDate:eO,isoTime:U,isoDateTime:S,isoUtcDateTime:fR},AM_MARKER:el,PM_MARKER:M},members:{__uG:null,__ln:null,__uH:null,__uI:null,__uK:null,__uL:null,__uM:null,__uJ:null,__uN:function(gp,go){var gq=dL+(gp<0?(-1*gp):gp);while(gq.length<go){gq=ge+gq;};return gp<0?a+gq:gq;},__uO:function(gr){var gs=new Date(gr.getTime());var gt=gs.getDate();while(gs.getMonth()!=0){gs.setDate(-1);gt+=gs.getDate()+1;};return gt;},__uP:function(gu){return new Date(gu.getTime()+(3-((gu.getDay()+6)%7))*86400000);},__uQ:function(gv){var gx=this.__uP(gv);var gy=gx.getFullYear();var gw=this.__uP(new Date(gy,0,4));return Math.floor(1.5+(gx.getTime()-gw.getTime())/86400000/7);},__uR:function(gz){var gB=this.__uP(gz);var gA=this.__uP(new Date(gz.getFullYear(),gz.getMonth(),4));return Math.floor(1.5+(gB.getTime()-gA.getTime())/86400000/7);},__uS:function(gC){var gD=this.__uP(gC);return gD.getFullYear();},__uT:function(gF){var gE=new Date(gF,2,1);gE.setDate(-1);return gE.getDate()+1===29;},__uU:function(gK,gL){var gJ=0;var gM=0;if(!gL){gL=1971;};var gG=0;for(var i=1;i<=12;i++ ){var gI=new Date(gL,i,1);gI.setDate(-1);var gH=gI.getDate()+1;gG+=gH;if(gG<gK){gJ++ ;gM+=gH;}else {gM=gK-(gG-gH);break;};};return {month:gJ,day:gM};},__uV:function(gQ,gO,gN){var gP;switch(gO){case 11:gP=gQ-1;if(gQ!=this.__uS(new Date(gP,gO,gN))){gP=gQ;};break;case 0:gP=gQ+1;if(gQ!=this.__uS(new Date(gP,gO,gN))){gP=gQ;};break;default:gP=gQ;};return gP;},_applyLocale:function(gS,gR){this.__ln=gS===null?this.setLocale(this.__uH):gS;},format:function(hj){if(hj==null){return null;};if(isNaN(hj.getTime())){{};return null;};if(this.__uJ){hj=new Date(hj.getUTCFullYear(),hj.getUTCMonth(),hj.getUTCDate(),hj.getUTCHours(),hj.getUTCMinutes(),hj.getUTCSeconds(),hj.getUTCMilliseconds());};var gV=this.__ln;var hb=hj.getFullYear();var gW=hj.getMonth();var ha=hj.getDate();var he=hj.getDay();var hh=hj.getHours();var ho=hj.getMinutes();var hf=hj.getSeconds();var hm=hj.getMilliseconds();var hd=hj.getTimezoneOffset();var hi=hd>0?1:-1;var gT=Math.floor(Math.abs(hd)/60);var hl=Math.abs(hd)%60;this.__uW();var hn=dL;for(var i=0;i<this.__uM.length;i++ ){var hc=this.__uM[i];if(hc.type==fx){hn+=hc.text;}else {var gU=hc.character;var hg=hc.size;var hp=dU;switch(gU){case z:if(hg==2){hp=this.__uN(hb%100,2);}else {var gX=Math.abs(hb);hp=gX+dL;if(hg>hp.length){for(var j=hp.length;j<hg;j++ ){hp=ge+hp;};};if(hb<0){hp=a+hp;};};break;case eA:hp=this.__uS(hj)+dL;var gX=hp.replace(eH,fJ);if(hg>hp.length){for(var j=gX.length;j<hg;j++ ){gX=ge+gX;};};hp=hp.indexOf(a)!=-1?a+gX:gX;break;case P:if(hg>=1&&hg<=3){hp=hb>0?dV:eW;}else if(hg==4){hp=hb>0?O:ga;}else if(hg==5){hp=hb>0?eG:fQ;};break;case fm:if(hg==1||hg==2){hp=this.__uN(parseInt(gW/4)+1,hg);};if(hg==3){hp=fm+(parseInt(gW/4)+1);};break;case L:if(hg==1||hg==2){hp=this.__uN(parseInt(gW/4)+1,hg);};if(hg==3){hp=fm+(parseInt(gW/4)+1);};break;case fc:hp=this.__uN(this.__uO(hj),hg);break;case fG:hp=this.__uN(ha,hg);break;case ea:hp=this.__uN(this.__uQ(hj),hg);break;case c:hp=this.__uR(hj);break;case dQ:if(hg>=1&&hg<=3){hp=qx.locale.Date.getDayName(v,he,gV,eb,true);}else if(hg==4){hp=qx.locale.Date.getDayName(et,he,gV,eb,true);}else if(hg==5){hp=qx.locale.Date.getDayName(fV,he,gV,eb,true);};break;case fh:var gY=qx.locale.Date.getWeekStart(gV);var hk=1+((he-gY>=0)?(he-gY):7+(he-gY));if(hg>=1&&hg<=2){hp=this.__uN(hk,hg);}else if(hg==3){hp=qx.locale.Date.getDayName(v,he,gV,eb,true);}else if(hg==4){hp=qx.locale.Date.getDayName(et,he,gV,eb,true);}else if(hg==5){hp=qx.locale.Date.getDayName(fV,he,gV,eb,true);};break;case eY:var gY=qx.locale.Date.getWeekStart(gV);var hk=1+((he-gY>=0)?(he-gY):7+(he-gY));if(hg==1){hp=fJ+hk;}else if(hg==3){hp=qx.locale.Date.getDayName(v,he,gV,eT,true);}else if(hg==4){hp=qx.locale.Date.getDayName(et,he,gV,eT,true);}else if(hg==5){hp=qx.locale.Date.getDayName(fV,he,gV,eT,true);};break;case gf:if(hg==1||hg==2){hp=this.__uN(gW+1,hg);}else if(hg==3){hp=qx.locale.Date.getMonthName(v,gW,gV,eb,true);}else if(hg==4){hp=qx.locale.Date.getMonthName(et,gW,gV,eb,true);}else if(hg==5){hp=qx.locale.Date.getMonthName(fV,gW,gV,eb,true);};break;case g:if(hg==1||hg==2){hp=this.__uN(gW+1,hg);}else if(hg==3){hp=qx.locale.Date.getMonthName(v,gW,gV,eT,true);}else if(hg==4){hp=qx.locale.Date.getMonthName(et,gW,gV,eT,true);}else if(hg==5){hp=qx.locale.Date.getMonthName(fV,gW,gV,eT,true);};break;case E:hp=(hh<12)?qx.locale.Date.getAmMarker(gV):qx.locale.Date.getPmMarker(gV);break;case gg:hp=this.__uN(hh,hg);break;case fn:hp=this.__uN((hh==0)?24:hh,hg);break;case fw:hp=this.__uN(hh%12,hg);break;case eD:hp=this.__uN(((hh%12)==0)?12:(hh%12),hg);break;case fX:hp=this.__uN(ho,hg);break;case eF:hp=this.__uN(hf,hg);break;case eX:hp=this.__uN(hm,3);if(hg<hp.length){hp=hp.substr(0,hg);}else {while(hg>hp.length){hp+=ge;};};break;case eQ:if(hg>=1&&hg<=4){hp=T+((hi>0)?a:W)+this.__uN(Math.abs(gT),2)+y+this.__uN(hl,2);};break;case fY:if(hg>=1&&hg<=3){hp=((hi>0)?a:W)+this.__uN(Math.abs(gT),2)+this.__uN(hl,2);}else {hp=T+((hi>0)?a:W)+this.__uN(Math.abs(gT),2)+y+this.__uN(hl,2);};break;};hn+=hp;};};return hn;},parse:function(hw){this.__uX();var hz=this.__uK.regex.exec(hw);if(hz==null){throw new Error(n+hw+fI+this.__uI);};var hq={era:1,year:1970,quarter:1,month:0,day:1,dayOfYear:1,hour:0,ispm:false,weekDay:4,weekYear:1970,weekOfMonth:1,weekOfYear:1,min:0,sec:0,ms:0};var hu=1;var hr=false;var hs=false;for(var i=0;i<this.__uK.usedRules.length;i++ ){var ht=this.__uK.usedRules[i];var hv=hz[hu];if(ht.field!=null){hq[ht.field]=parseInt(hv,10);}else {ht.manipulator(hq,hv,ht.pattern);};if(ht.pattern==q){var hx=false;for(var k=0;k<this.__uK.usedRules.length;k++ ){if(this.__uK.usedRules[k].pattern==ft){hx=true;break;};};if(!hx){hr=true;};};if(ht.pattern.indexOf(fd)!=-1){var hB=false;for(var k=0;k<this.__uK.usedRules.length;k++ ){if(this.__uK.usedRules[k].pattern.indexOf(fa)!=-1){hB=true;break;};};if(!hB){hs=true;};};hu+=(ht.groups==null)?1:ht.groups;};if(hr){hq.year=this.__uV(hq.weekYear,hq.month,hq.day);};if(hs){var hA=this.__uU(hq.dayOfYear,hq.year);hq.month=hA.month;hq.day=hA.day;};if(hq.era<0&&(hq.year*hq.era<0)){hq.year=hq.year*hq.era;};var hy=new Date(hq.year,hq.month,hq.day,(hq.ispm)?(hq.hour+12):hq.hour,hq.min,hq.sec,hq.ms);if(this.__uJ){hy=new Date(hy.getUTCFullYear(),hy.getUTCMonth(),hy.getUTCDate(),hy.getUTCHours(),hy.getUTCMinutes(),hy.getUTCSeconds(),hy.getUTCMilliseconds());};if(hq.month!=hy.getMonth()||hq.year!=hy.getFullYear()){throw new Error(N+hw+fg);};return hy;},__uW:function(){if(this.__uM!=null){return;};this.__uM=[];var hG;var hE=0;var hI=dL;var hC=this.__uI;var hF=eV;var i=0;while(i<hC.length){var hH=hC.charAt(i);switch(hF){case A:if(hH==fT){if(i+1>=hC.length){i++ ;break;};var hD=hC.charAt(i+1);if(hD==fT){hI+=hH;i++ ;}else {i++ ;hF=fW;};}else {hI+=hH;i++ ;};break;case fC:if(hH==hG){hE++ ;i++ ;}else {this.__uM.push({type:fC,character:hG,size:hE});hG=null;hE=0;hF=eV;};break;default:if((hH>=E&&hH<=eQ)||(hH>=eG&&hH<=fY)){hG=hH;hF=fC;}else if(hH==fT){if(i+1>=hC.length){hI+=hH;i++ ;break;};var hD=hC.charAt(i+1);if(hD==fT){hI+=hH;i++ ;};i++ ;hF=A;}else {hF=eV;};if(hF!=eV){if(hI.length>0){this.__uM.push({type:fx,text:hI});hI=dL;};}else {hI+=hH;i++ ;};break;};};if(hG!=null){this.__uM.push({type:fC,character:hG,size:hE});}else if(hI.length>0){this.__uM.push({type:fx,text:hI});};},__uX:function(){if(this.__uK!=null){return;};var hM=this.__uI;this.__va();this.__uW();var hS=[];var hN=x;for(var hK=0;hK<this.__uM.length;hK++ ){var hT=this.__uM[hK];if(hT.type==fx){hN+=qx.lang.String.escapeRegexpChars(hT.text);}else {var hL=hT.character;var hO=hT.size;var hQ;for(var hU=0;hU<this.__uL.length;hU++ ){var hP=this.__uL[hU];if(this.__uY(hP,hL,hO)){hQ=hP;break;};};if(hQ==null){var hR=dL;for(var i=0;i<hO;i++ ){hR+=hL;};throw new Error(gc+hM+r+hR+h);}else {hS.push(hQ);hN+=hQ.regex;};};};hN+=dX;var hJ;try{hJ=new RegExp(hN);}catch(hV){throw new Error(gc+hM);};this.__uK={regex:hJ,"usedRules":hS,pattern:hN};},__uY:function(hW,hX,hY){if(hX===z&&hW.pattern===ft){hW.regex=hW.regexFunc(hY);return true;}else if(hX===eA&&hW.pattern===es){hW.regex=hW.regexFunc(hY);return true;}else {return hX==hW.pattern.charAt(0)&&hY==hW.pattern.length;};},__va:function(){var ip=qx.util.format.DateFormat;var is=qx.lang.String;if(this.__uL!=null){return;};var iq=this.__uL=[];var ik=qx.locale.Date.getAmMarker(this.__ln).toString()||ip.AM_MARKER;var iz=qx.locale.Date.getPmMarker(this.__ln).toString()||ip.PM_MARKER;var ib=this.__ln;var ih=function(iC,iD){iD=parseInt(iD,10);if(iD>=0){if(iD<ip.ASSUME_YEAR_2000_THRESHOLD){iD+=2000;}else if(iD<100){iD+=1900;};};iC.year=iD;};var iB=function(iE,iF){iF=parseInt(iF,10);if(iF>=0){if(iF<ip.ASSUME_YEAR_2000_THRESHOLD){iF+=2000;}else if(iF<100){iF+=1900;};};iE.weekYear=iF;};var ij=function(iG,iH){iG.month=parseInt(iH,10)-1;};var ie=function(iK,iL){var iJ=qx.locale.Date.getWeekStart(ib);var iI=(parseInt(iL,10)-1+iJ)<=6?parseInt(iL,10)-1+iJ:(parseInt(iL,10)-1+iJ)-7;iK.weekDay=iI;};var id=function(iM,iN){var iO=qx.locale.Date.getPmMarker(ib).toString()||ip.PM_MARKER;iM.ispm=(iN==iO);};var ir=function(iP,iQ){iP.hour=parseInt(iQ,10)%24;};var ic=function(iR,iS){iR.hour=parseInt(iS,10)%12;};var iu=function(iT,iU){return;};var iv=[eG,fQ];var iw=function(iV,iW){iV.era=iW==eG?1:-1;};var io=[dV,eW];var im=function(iX,iY){iX.era=iY==dV?1:-1;};var iy=[O,ga];var il=function(ja,jb){ja.era=jb==O?1:-1;};var iA=[fl,fK,dO,fO];var ia=function(jc,jd){jc.quarter=iA.indexOf(jd);};var ix=[eS,R,J,dI];var it=function(je,jf){je.quarter=ix.indexOf(jf);};var ii={};var ig=function(jj){var jl=[g,gf];var jh=[eY,fh,dQ];var jo=jj.charAt(0);var ji=jl.indexOf(jo)>=0;var jk=function(){var jq=ji?jl:jh;var jr=jo===jq[0]?eT:eb;var jp=jj.length;var js=p;switch(jp){case 4:js=en;break;case 5:js=fF;break;default:js=p;};return [jr,js];};if(!ii[jj]){ii[jj]={};var jg=jk();var jn=ji?qx.locale.Date.getMonthNames:qx.locale.Date.getDayNames;var jm=jn.call(qx.locale.Date,jg[1],ib,jg[0],true);for(var i=0,l=jm.length;i<l;i++ ){jm[i]=is.escapeRegexpChars(jm[i].toString());};ii[jj].data=jm;ii[jj].func=function(jt,ju){ju=is.escapeRegexpChars(ju);jt[ji?ee:Y]=jm.indexOf(ju);};};return ii[jj];};iq.push({pattern:fN,regexFunc:function(jw){var jv=G;for(var i=0;i<jw;i++ ){jv+=dT;if(i===jw-1&&i!==1){jv+=dE;};};jv+=eK;return jv;},manipulator:ih});iq.push({pattern:q,regexFunc:function(jy){var jx=G;for(var i=0;i<jy;i++ ){jx+=dT;if(i===jy-1){jx+=dE;};};jx+=eK;return jx;},manipulator:iB});iq.push({pattern:eP,regex:ey+io.join(fs)+eK,manipulator:im});iq.push({pattern:eR,regex:ey+io.join(fs)+eK,manipulator:im});iq.push({pattern:eC,regex:ey+io.join(fs)+eK,manipulator:im});iq.push({pattern:fL,regex:ey+iy.join(fs)+eK,manipulator:il});iq.push({pattern:o,regex:ey+iv.join(fs)+eK,manipulator:iw});iq.push({pattern:ex,regex:fi,field:em});iq.push({pattern:fq,regex:t,field:em});iq.push({pattern:b,regex:ey+iA.join(fs)+eK,manipulator:ia});iq.push({pattern:ef,regex:ey+ix.join(fs)+eK,manipulator:it});iq.push({pattern:ej,regex:fi,field:em});iq.push({pattern:ed,regex:t,field:em});iq.push({pattern:H,regex:ey+iA.join(fs)+eK,manipulator:ia});iq.push({pattern:d,regex:ey+ix.join(fs)+eK,manipulator:it});iq.push({pattern:dY,regex:fi,manipulator:ij});iq.push({pattern:fP,regex:t,manipulator:ij});iq.push({pattern:dH,regex:ey+ig(dH).data.join(fs)+eK,manipulator:ig(dH).func});iq.push({pattern:eU,regex:ey+ig(eU).data.join(fs)+eK,manipulator:ig(eU).func});iq.push({pattern:dS,regex:ey+ig(dS).data.join(fs)+eK,manipulator:ig(dS).func});iq.push({pattern:fv,regex:fi,manipulator:ij});iq.push({pattern:u,regex:t,manipulator:ij});iq.push({pattern:ec,regex:ey+ig(ec).data.join(fs)+eK,manipulator:ig(ec).func});iq.push({pattern:fj,regex:ey+ig(fj).data.join(fs)+eK,manipulator:ig(fj).func});iq.push({pattern:fp,regex:ey+ig(fp).data.join(fs)+eK,manipulator:ig(fp).func});iq.push({pattern:V,regex:t,field:F});iq.push({pattern:fa,regex:fi,field:F});iq.push({pattern:fd,regex:gd,field:fM});iq.push({pattern:dM,regex:t,field:fM});iq.push({pattern:fe,regex:eo,field:fM});iq.push({pattern:fD,regex:ey+ig(fD).data.join(fs)+eK,manipulator:ig(fD).func});iq.push({pattern:eB,regex:ey+ig(eB).data.join(fs)+eK,manipulator:ig(eB).func});iq.push({pattern:dW,regex:ey+ig(dW).data.join(fs)+eK,manipulator:ig(dW).func});iq.push({pattern:w,regex:ey+ig(w).data.join(fs)+eK,manipulator:ig(w).func});iq.push({pattern:ew,regex:ey+ig(ew).data.join(fs)+eK,manipulator:ig(ew).func});iq.push({pattern:fy,regex:gd,manipulator:ie});iq.push({pattern:ei,regex:t,manipulator:ie});iq.push({pattern:eg,regex:ey+ig(eg).data.join(fs)+eK,manipulator:ig(eg).func});iq.push({pattern:fk,regex:ey+ig(fk).data.join(fs)+eK,manipulator:ig(fk).func});iq.push({pattern:s,regex:ey+ig(s).data.join(fs)+eK,manipulator:ig(s).func});iq.push({pattern:fb,regex:fU,manipulator:ie});iq.push({pattern:eu,regex:ey+ig(eu).data.join(fs)+eK,manipulator:ig(eu).func});iq.push({pattern:fz,regex:ey+ig(fz).data.join(fs)+eK,manipulator:ig(fz).func});iq.push({pattern:fE,regex:ey+ig(fE).data.join(fs)+eK,manipulator:ig(fE).func});iq.push({pattern:Q,regex:ey+ik+fs+iz+eK,manipulator:id});iq.push({pattern:fr,regex:gd,field:ez});iq.push({pattern:eI,regex:t,field:B});iq.push({pattern:eq,regex:I,field:B});iq.push({pattern:fo,regex:t,field:dR});iq.push({pattern:er,regex:t,field:dR});iq.push({pattern:eL,regex:t,manipulator:ir});iq.push({pattern:gb,regex:t,manipulator:ir});iq.push({pattern:f,regex:t,field:dR});iq.push({pattern:K,regex:t,field:dR});iq.push({pattern:fu,regex:t,manipulator:ic});iq.push({pattern:e,regex:t,manipulator:ic});iq.push({pattern:eJ,regex:t,field:dN});iq.push({pattern:ff,regex:t,field:dN});iq.push({pattern:eM,regex:t,field:dJ});iq.push({pattern:dF,regex:t,field:dJ});iq.push({pattern:D,regex:fA,field:fB});iq.push({pattern:dG,regex:fA,field:fB});iq.push({pattern:eE,regex:fA,field:fB});iq.push({pattern:m,regex:eN,manipulator:iu});iq.push({pattern:gh,regex:eh,manipulator:iu});}},destruct:function(){if(this.__uG!=null){qx.locale.Manager.getInstance().removeBinding(this.__uG);};this.__uM=this.__uK=this.__uL=null;}});})();(function(){var c='kucken.lang.Array';qx.Class.define(c,{statics:{range:function(d,stop,e){if(stop===undefined){stop=d;d=0;};if(e===undefined){e=1;};if((e>0&&d>=stop)||(e<0&&d<=stop)){return [];};var f=[];for(var i=d;e>0?i<stop:i>stop;i+=e){f.push(i);};return f;},zip:function(j){var g=qx.lang.Array.fromArguments(arguments);var h=g.length==0?[]:g.reduce(function(a,b){return a.length<b.length?a:b;});return h.map(function(l,k){return g.map(function(m){return m[k];});});}}});})();(function(){var a='qx.event.type.Event',b='qx.core.Object',c='Must be overriden in descendent class',d='kucken.ui.form.mvc.Model',e='qx.event.type.Data',f='_applyFormModel',g='Must be overriden in descendant class',h='abstract';qx.Class.define(d,{extend:qx.core.Object,type:h,events:{preload:a,loaded:e,saved:e,failed:e},properties:{formModel:{check:b,nullable:true,apply:f}},members:{_item:null,__vb:null,_createFormModel:function(){throw new Error(g);},ifNot:function(j,i){return j!==undefined?j:i;},_applyFormModel:function(k,l){this.__vb=l;if(k&&this.__vb){this.__vb.dispose();this.__vb=null;};},_preload:function(){this._createFormModel();},load:function(m){this._item=m;this.resetFormModel();this._preload();},save:function(){throw new Error(c);}}});})();(function(){var a='DEBUG',b='Last 30 days',c='loaded',d='before',e='Last 7 days',f='Hour',g='after',h='Last 90 days',i='Last 24 hours',j='Today',k='today1',l='Last 1 hour',m='clui.model.form.Overview',n='preload',o='Last 5 minutes',p='Day before yesterday',q='day',r='Last 3 hours',s='Last 30 minutes',t='Yesterday',u='Last 6 hours',v='Last 15 minutes',w='Day',x='Last 60 days',y='saved',z='today0',A='Last 12 hours';qx.Class.define(m,{extend:kucken.ui.form.mvc.Model,statics:{groupBy:{'day':qx.locale.Manager.tr(w),'hour':qx.locale.Manager.tr(f)},quickRange:{'today0/today1':qx.locale.Manager.tr(j),'today0-P1D/today1-P1D':qx.locale.Manager.tr(t),'today0-P2D/today1-P2D':qx.locale.Manager.tr(p),'now-PT5M/now':qx.locale.Manager.tr(o),'now-PT15M/now':qx.locale.Manager.tr(v),'now-PT30M/now':qx.locale.Manager.tr(s),'now-PT1H/now':qx.locale.Manager.tr(l),'now-PT3H/now':qx.locale.Manager.tr(r),'now-PT6H/now':qx.locale.Manager.tr(u),'now-PT12H/now':qx.locale.Manager.tr(A),'now-PT24H/now':qx.locale.Manager.tr(i),'now-P7D/now':qx.locale.Manager.tr(e),'now-P30D/now':qx.locale.Manager.tr(b),'now-P60D/now':qx.locale.Manager.tr(x),'now-P90D/now':qx.locale.Manager.tr(h)}},members:{_createFormModel:function(){var B={'after':z,'before':k,'level':qx.lang.Object.invert(clui.model.form.Record.levelMap)[a],'name':null,'group':q};this.fireEvent(n);this.setFormModel(qx.data.marshal.Json.createModel(B,true));this.fireDataEvent(c,B);},save:function(){var C=qx.util.Serializer.toNativeObject(this.getFormModel());C[g]=new kucken.date.RelativeDate(C[g]);C[d]=new kucken.date.RelativeDate(C[d]);this.fireDataEvent(y,C);return C;}}});})();(function(){var a='ERROR',b='Failed to get record',c='INFO',d='CRITICAL',e='DEBUG',f='message',g='name',h='loaded',i='ts',j='WARNING',k='id',l='saved',m='clui.model.form.Record',n='logrec',o='Opening record',p='preload',q='level',r='failed',s='_record';qx.Class.define(m,{extend:kucken.ui.form.mvc.Model,statics:{levelMap:{'50':d,'40':a,'30':j,'20':c,'10':e}},construct:function(){kucken.ui.form.mvc.Model.call(this);this._record=new clui.io.PromisedRecord();},destruct:function(){this._disposeObjects(s);},members:{_record:null,_createFormModel:function(){var t={'id':this._item[k],'name':this._item[g],'message':this._item[f],'level':this._item[q],'ts':this._item[i],'logrec':qx.lang.Json.stringify(this._item[n])};this.debug(o,t[k]);this.fireEvent(p);if(this._item[n]){this.setFormModel(qx.data.marshal.Json.createModel(t));this.fireDataEvent(h,t);}else {this._record.get(this._item[k]).then(function(u){t[n]=qx.lang.Json.stringify(u[n]);this.setFormModel(qx.data.marshal.Json.createModel(t));this.fireDataEvent(h,t);},this).caught(function(v){this.error(b,v);this.fireDataEvent(r,v);},this);};},save:function(){this.fireDataEvent(l);}}});})();(function(){var a='clui.io.PromisedRecord',b='success',c='error';qx.Class.define(a,{extend:qx.core.Object,members:{_createRecord:function(){return new clui.io.Record();},count:function(e,d,f){return new kucken.Promise(function(h,i){var g=this._createRecord();g.addListener(b,function(event){if(e){h({'timeSeries':g.getTimeSeries(),'count':g.getCount()});}else {h(g.getCount());};g.dispose();},this);g.addListener(c,function(event){i(event.getData());g.dispose();});g.loadCount(e,d,f);},this);},range:function(l,j,k){return new kucken.Promise(function(n,o){var m=this._createRecord();m.addListener(b,function(event){n(m.getRecordRange());m.dispose();},this);m.addListener(c,function(){o(event.getData());m.dispose();});m.loadRange(l,j,k);},this);},get:function(p){return new kucken.Promise(function(r,s){var q=this._createRecord();q.addListener(b,function(event){r(q.getRecordRange()[0]);q.dispose();},this);q.addListener(c,function(){s(event.getData());q.dispose();});q.loadRecord(p);},this);}}});})();(function(){var b='./timers.js',c='cancel',g="new Promise",h="caller",k="constructor",m=" Use ",q="cannot await properties of a non-object\u000a\u000a    See http://goo.gl/MqrFmX\u000a",w="range error",y="BLUEBIRD_WARNINGS",z='any',A="use strict",B="kucken.Promise",C="div",D='caught',E="prototype",F="cannot .spread() a non-array: ",G="warning",H="stack",I="(<",J=" has no method '",K='each',L="rejectionHandled",M=" instead.",N=" items",O='all',P=" items but contains only ",Q="color: red",R="_getDomain",S="Promise has already been resolved or rejected",U='mapSeries',V="Warning",W="...",X="_makeSelfResolutionError",Y="No async scheduler available\u000a\u000a    See http://goo.gl/MqrFmX\u000a",ba="\u001b[0m\n",bb="number",bc="Promise.spawn()",bd="unhandledrejection",be="cancellation error",bf='./generators.js',bg="Object ",bh="Input array must contain at least ",bi='filter',bj="cannot enable cancellation after promises are in use",bk="promiseRejected",bl="options argument must be an object but it is ",bm='spread',bn="./schedule",bo="./thenables",bp='./any.js',bq="promiseResolved",br="at ",bs="cancellation",bt="promiseCreated",bu="kucken.Promise.warnings",bv='finally',bw="./debuggability",bx=" size",by="Promise.reduce",bz="but was not returned from it, ",bA="From previous event:",bB='./promisify.js',bC="./catch_filter",bD="handler ",bE="AggregateError",bF="arity",bG="CancellationError",bH='./race.js',bI="string",bJ="[no string representation]",bK="cannot get rejection reason of a non-rejected promise\u000a\u000a    See http://goo.gl/MqrFmX\u000a",bL="callee",bM="(not from exception)",bN="cancellation is disabled",bO="./promise",bP='./each.js',bQ='./nodeify.js',bR="./cancel",bS="Unhandled promise rejection: ",bT=":",bU='./call_get.js',bV='reject',bW='catch',bX="\u001b[33m",bY="Promise.using",ca='expecting an object but got A catch statement predicate ',cc="BLUEBIRD_W_FORGOTTEN_RETURN",cd="Promise.try",ce="promiseChained",cf="Cannot promisify an API that has normal methods with '%s'-suffix\u000a\u000a    See http://goo.gl/MqrFmX\u000a",cg=".",ch="./async",ci="a promise was created in a ",cj="you must pass at least 2 arguments to Promise.using",ck="./finally",cl="a promise was rejected with a non-error: ",cm="CustomEvent",cn=".all() was passed arguments but it does not take any",co="circular promise resolution chain\u000a\u000a    See http://goo.gl/MqrFmX\u000a",cp="color: darkorange",cq="A value %s was yielded that could not be treated as a promise\u000a\u000a    See http://goo.gl/MqrFmX\u000a\u000a",cs=" ",ct="Promises are installed and initialised but disabled from properties because kucken.Promise==false; this may cause unexpected behaviour",cu="testingtheevent",cv="__vn",cw="__stackCleaned__",cx="BLUEBIRD_DEBUG",cy="foo",cz="function",cA="expecting a function but got ",cB="message",cC="From coroutine:\u000a",cD="./nodeback",cE='join pop push shift unshift slice filter forEach some every map indexOf lastIndexOf reduce reduceRight sort reverse',cF="./promise_array",cG="kucken.Promise.longStackTraces",cH="AggregateError of:",cI="late cancellation observer",cJ=".settle()",cK="return",cL=">, no stack trace)",cM="aggregate error",cN="RangeError",cO="suffix must be a valid identifier\u000a\u000a    See http://goo.gl/MqrFmX\u000a",cP="the promise constructor cannot be invoked directly\u000a\u000a    See http://goo.gl/MqrFmX\u000a",cQ="Unhandled rejection ",cR='./filter.js',cS=".reflect()",cT="[object Promise]",cU="unhandledRejection",cV="MODULE_NOT_FOUND",cW='props',cX="throw",cY="break",da="type error",db="the target of promisifyAll must be an object or a function\u000a\u000a    See http://goo.gl/MqrFmX\u000a",dc='lastly',dd="arguments",de='some',df='map',dg="timeout error",dh="_",di="catch",dj=" is deprecated and will be removed in a future version.",dk="Promise.method",dl="Class",dm="[object process]",dn="promiseCancelled",dp='./using.js',dq=", ",dr="Promise.coroutine()",ds="anonymous",dt="./util",du="'concurrency' must be a number but it is ",dv="\n",dw="operation timed out",dx='reduce',dy='race',dz="generatorFunction must be a function\u000a\u000a    See http://goo.gl/MqrFmX\u000a",dA="expecting a positive integer\u000a\u000a    See http://goo.gl/MqrFmX\u000a",dB="./errors",dC="|",dD="stackDetection@",dE="generator .return() sentinel",dF="__BluebirdErrorTypes__",dG="./synchronous_inspection",dH="promiseFulfilled",dI="_async",dJ="try",dK="on",dL="./join",dM=")$",dN="onCancel must be a function, got: ",dO="object",dP="OperationalError",dQ="warnings",dR="name",dS=".then() only accepts functions but was passed: ",dT="wForgottenReturn",dU="_promise0",dV="./direct_resolve",dW='./map.js',dX="length",dY="%c",ea="TimeoutError",eb="monitoring",ec="./context",ed="Promise.defer",ee="'",ef='./reduce.js',eg="./method",eh="Fatal ",ei="expecting an array or an iterable object but got ",ej="Async",ek="^(?:",el="./queue",em="BLUEBIRD_LONG_STACK_TRACES",en="Promise.each",eo="$",ep="Cannot find module '",eq="",er="Promise.filter",es="%s",et='./settle.js',eu="Promise cannot be resolved externally",ev="cannot get fulfillment value of a non-fulfilled promise\u000a\u000a    See http://goo.gl/MqrFmX\u000a",ew="]",ex="\u001b[31m",ey="finally",ez="./bind",eA="longStackTraces",eB="TypeError",eC="[function ",eD="see http://goo.gl/rRqMUw",eE="./es5",eF="    ",eG="calling Promise.try with more than 1 argument",eH="Promise.map",eI="[object Array]",eJ='then',eK="3.4.5",eL='./some.js',eM="[Circular AggregateError]",eN="\\$",eO='./props.js',eP="    (No stack trace)",eQ="(empty array)",eR="undefined",eS="cannot enable long stack traces after promises have been created\u000a\u000a    See http://goo.gl/MqrFmX\u000a",eT="isOperational";qx.Class.define(B,{extend:qx.core.Object,construct:function(eU,eV){qx.core.Object.call(this);kucken.Promise.__vh();if(eU instanceof kucken.Promise.Bluebird){this.__vc=eU;}else if(eU){if(eV!==undefined&&eV!==null){eU=eU.bind(eV);};this.__vc=new kucken.Promise.Bluebird(eU);}else {this.__vc=new kucken.Promise.Bluebird(this.__ve.bind(this));};qx.core.Assert.assertTrue(!this.__vc.$$qxPromise);this.__vc.$$qxPromise=this;if(eV!==undefined&&eV!==null){this.__vc=this.__vc.bind(eV);};},destruct:function(){delete this.__vc.$$qxPromise;delete this.__vc;},members:{__vc:null,__vd:null,then:function(eX,eW){return this._callMethod(eJ,arguments);},"catch":function(eY){return this._callMethod(bW,arguments);},bind:function(fa){return kucken.Promise.__vj(this.__vc.bind(fa));},spread:function(fb){return this._callMethod(bm,arguments);},"finally":function(fc){return this._callMethod(bv,arguments);},cancel:function(){return this._callMethod(c,arguments);},all:function(){return this._callIterableMethod(O,arguments);},race:function(fd){return this._callIterableMethod(dy,arguments);},any:function(fe){return this._callIterableMethod(z,arguments);},some:function(fg,ff){return this._callIterableMethod(de,arguments);},forEach:function(fh,fi){return this._callIterableMethod(K,arguments);},filter:function(fj,fk,fl){return this._callIterableMethod(bi,arguments);},map:function(fm,fo,fp){return this._callIterableMethod(df,arguments);},mapSeries:function(fq,fr){return this._callIterableMethod(U,arguments);},reduce:function(fu,fs,ft){return this._callIterableMethod(dx,arguments);},__ve:function(fv,fw){this.__vd={resolve:fv,reject:fw,complete:false};},__vf:function(){if(!this.__vd){throw new Error(eu);};if(this.__vd.complete){throw new Error(S);};this.__vd.complete=true;return this.__vd;},resolve:function(fx){this.__vf().resolve(fx);},reject:function(fy){this.__vf().reject(fy);},_callIterableMethod:function(fA,fz){fz=kucken.Promise.__vk(fz);return kucken.Promise.__vj(this.__vc.then(function(fC){var fB=kucken.Promise.Bluebird.resolve(fC instanceof qx.data.Array?fC.toArray():fC);return kucken.Promise.__vj(fB[fA].apply(fB,fz));}));},_callMethod:function(fE,fD){fD=kucken.Promise.__vk(fD);return kucken.Promise.__vj(this.__vc[fE].apply(this.__vc,fD));},toPromise:function(){return this.__vc;},caught:function(fF){return this._callMethod(D,arguments);},lastly:function(fG){return this._callMethod(dc,arguments);}},statics:{Bluebird:null,Native:null,Promise:null,resolve:function(fJ,fI){var fH;if(fJ instanceof kucken.Promise){fH=fJ;}else {fH=this.__vj(kucken.Promise.Bluebird.resolve(fJ));};if(fI!==undefined){fH=fH.bind(fI);};return fH;},reject:function(fK,fM){var fL=this.__vl(bV,arguments,0);if(fM!==undefined){fL=fL.bind(fM);};return fL;},all:function(fN){return this.__vl(O,arguments);},race:function(fO){return this.__vl(dy,arguments);},any:function(fP){return this.__vl(z,arguments);},some:function(fR,fQ){return this.__vl(de,arguments);},forEach:function(fS,fT){return this.__vl(K,arguments);},filter:function(fU,fV,fW){return this.__vl(bi,arguments);},map:function(fX,fY,ga){return this.__vl(df,arguments);},mapSeries:function(gb,gc){return this.__vl(U,arguments);},reduce:function(gf,gd,ge){return this.__vl(dx,arguments);},method:function(gg){var gh=kucken.Promise.Bluebird.method(gg);return function(){return kucken.Promise.__vj(gh.apply(this,arguments));};},props:function(gi){return this.__vl(cW,arguments);},__vg:function(gj){this.Bluebird=gj;gj.config({warnings:qx.core.Environment.get(bu),longStackTraces:qx.core.Environment.get(cG),cancellation:true});},__dG:false,__vh:function(){if(this.__dG){return;};this.__dG=true;qx.bom.Event.addNativeListener(window,bd,this.__vi.bind(this));if(!qx.core.Environment.get(B)){qx.log.Logger.error(this,ct);};},__vi:function(e){e.preventDefault();var gk=null;if(e instanceof Error){gk=e;}else if(e.reason instanceof Error){gk=e.reason;}else if(e.detail&&e.detail.reason instanceof Error){gk=e.detail.reason;};qx.log.Logger.error(this,bS+(gk?gk.stack:bM));qx.event.GlobalError.handleError(gk);},__vj:function(gl){if(gl instanceof kucken.Promise.Bluebird){if(gl.$$qxPromise){gl=gl.$$qxPromise;}else {gl=new kucken.Promise(gl);};};return gl;},__vk:function(gm,gn){gm=qx.lang.Array.fromArguments(gm);if(gn===undefined){gn=1;};if(gm.length>gn){var go=gm[gm.length-1];if(go instanceof qx.core.Object||go&&go.$$type===dl&&go.constructor===go){gm.pop();for(var i=0;i<gm.length;i++ ){if(typeof gm[i]==cz){gm[i]=gm[i].bind(go);};};};};return gm;},__vl:function(gp,gq,gr){gq=kucken.Promise.__vk(gq,gr);return this.__vj(kucken.Promise.Bluebird[gp].apply(kucken.Promise.Bluebird,this.__vm(gq)));},__vm:function(gt){var gs=[];gt.forEach(function(gu){if(gu instanceof qx.data.Array){gs.push(gu.toArray());}else if(gu instanceof kucken.Promise){gs.push(gu.toPromise());}else {gs.push(gu);};});return gs;}},defer:function(gw,gx){gw.Promise=gw.Native=window.Promise;var gv=false;qx.core.Environment.add(bu,gv);qx.core.Environment.add(cG,false);qx.core.Environment.add(B,true);}});(function(){!function(e){kucken.Promise.__vg(e());}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof _dereq_==cz&&_dereq_;if(!u&&a)return a(o,true);if(i)return i(o,true);var f=new Error(ep+o+ee);throw f.code=cV,f;};var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e);},l,l.exports,e,t,n,r);};return n[o].exports;};var i=typeof _dereq_==cz&&_dereq_;for(var o=0;o<r.length;o++ )s(r[o]);return s;})({'1':[function(gy,gA,gz){A;gA.exports=function(gB){var gD=gB._SomePromiseArray;function gC(gE){var gG=new gD(gE);var gF=gG.promise();gG.setHowMany(1);gG.setUnwrap();gG.init();return gF;};gB.any=function(gH){return gC(gH);};gB.prototype.any=function(){return gC(this);};};},{}],'2':[function(gS,gO,gJ){A;var gQ;try{throw new Error();}catch(e){gQ=e;};var gN=gS(bn);var gI=gS(el);var gP=gS(dt);function gR(){this._customScheduler=false;this._isTickUsed=false;this._lateQueue=new gI(16);this._normalQueue=new gI(16);this._haveDrainedQueues=false;this._trampolineEnabled=true;var self=this;this.drainQueues=function(){self._drainQueues();};this._schedule=gN;};gR.prototype.setScheduler=function(gU){var gT=this._schedule;this._schedule=gU;this._customScheduler=true;return gT;};gR.prototype.hasCustomScheduler=function(){return this._customScheduler;};gR.prototype.enableTrampoline=function(){this._trampolineEnabled=true;};gR.prototype.disableTrampolineIfNecessary=function(){if(gP.hasDevTools){this._trampolineEnabled=false;};};gR.prototype.haveItemsQueued=function(){return this._isTickUsed||this._haveDrainedQueues;};gR.prototype.fatalError=function(e,gV){if(gV){process.stderr.write(eh+(e instanceof Error?e.stack:e)+dv);process.exit(2);}else {this.throwLater(e);};};gR.prototype.throwLater=function(gW,gX){if(arguments.length===1){gX=gW;gW=function(){throw gX;};};if(typeof setTimeout!==eR){setTimeout(function(){gW(gX);},0);}else try{this._schedule(function(){gW(gX);});}catch(e){throw new Error(Y);};};function gM(ha,gY,hb){this._lateQueue.push(ha,gY,hb);this._queueTick();};function gK(hd,hc,he){this._normalQueue.push(hd,hc,he);this._queueTick();};function gL(hf){this._normalQueue._pushOne(hf);this._queueTick();};if(!gP.hasDevTools){gR.prototype.invokeLater=gM;gR.prototype.invoke=gK;gR.prototype.settlePromises=gL;}else {gR.prototype.invokeLater=function(hh,hg,hi){if(this._trampolineEnabled){gM.call(this,hh,hg,hi);}else {this._schedule(function(){setTimeout(function(){hh.call(hg,hi);},100);});};};gR.prototype.invoke=function(hk,hj,hl){if(this._trampolineEnabled){gK.call(this,hk,hj,hl);}else {this._schedule(function(){hk.call(hj,hl);});};};gR.prototype.settlePromises=function(hm){if(this._trampolineEnabled){gL.call(this,hm);}else {this._schedule(function(){hm._settlePromises();});};};};gR.prototype.invokeFirst=function(ho,hn,hp){this._normalQueue.unshift(ho,hn,hp);this._queueTick();};gR.prototype._drainQueue=function(hq){while(hq.length()>0){var hs=hq.shift();if(typeof hs!==cz){hs._settlePromises();continue;};var hr=hq.shift();var ht=hq.shift();hs.call(hr,ht);};};gR.prototype._drainQueues=function(){this._drainQueue(this._normalQueue);this._reset();this._haveDrainedQueues=true;this._drainQueue(this._lateQueue);};gR.prototype._queueTick=function(){if(!this._isTickUsed){this._isTickUsed=true;this._schedule(this.drainQueues);};};gR.prototype._reset=function(){this._isTickUsed=false;};gO.exports=gR;gO.exports.firstLineError=gQ;},{"./queue":26,"./schedule":29,"./util":36}],'3':[function(hu,hw,hv){A;hw.exports=function(hx,hA,hC,hD){var hB=false;var hy=function(_,e){this._reject(e);};var hF=function(e,hG){hG.promiseRejectionQueued=true;hG.bindingPromise._then(hy,hy,null,this,e);};var hE=function(hI,hH){if(((this._bitField&50397184)===0)){this._resolveCallback(hH.target);};};var hz=function(e,hJ){if(!hJ.promiseRejectionQueued)this._reject(e);};hx.prototype.bind=function(hO){if(!hB){hB=true;hx.prototype._propagateFrom=hD.propagateFromFunction();hx.prototype._boundValue=hD.boundValueFunction();};var hL=hC(hO);var hN=new hx(hA);hN._propagateFrom(this,1);var hM=this._target();hN._setBoundTo(hL);if(hL instanceof hx){var hK={promiseRejectionQueued:false,promise:hN,target:hM,bindingPromise:hL};hM._then(hA,hF,undefined,hN,hK);hL._then(hE,hz,undefined,hN,hK);hN._setOnCancel(hL);}else {hN._resolveCallback(hM);};return hN;};hx.prototype._setBoundTo=function(hP){if(hP!==undefined){this._bitField=this._bitField|2097152;this._boundTo=hP;}else {this._bitField=this._bitField&-2097153;};};hx.prototype._isBound=function(){return (this._bitField&2097152)===2097152;};hx.bind=function(hR,hQ){return hx.resolve(hQ).bind(hR);};};},{}],'4':[function(hW,hV,hS){A;var hT;if(typeof Promise!==eR)hT=Promise;function hU(){try{if(Promise===hX)Promise=hT;}catch(e){};return hX;};var hX=hW(bO)();hX.noConflict=hU;hV.exports=hX;},{"./promise":22}],'5':[function(ie,ib,ia){A;var ic=Object.create;if(ic){var hY=ic(null);var id=ic(null);hY[bx]=id[bx]=0;};ib.exports=function(iq){var im=ie(dt);var ig=im.canEvaluate;var ir=im.isIdentifier;var is;var ij;{var ih,io,ii;};function iu(iv,ix){var iy;if(iv!=null)iy=iv[ix];if(typeof iy!==cz){var iw=bg+im.classString(iv)+J+im.toString(ix)+ee;throw new iq.TypeError(iw);};return iy;};function ik(iz){var iA=this.pop();var iB=iu(iz,iA);return iB.apply(iz,this);};iq.prototype.call=function(iE){var iD=[].slice.call(arguments,1);;{var iC;};iD.push(iE);return this._then(ik,undefined,undefined,iD,undefined);};function il(iF){return iF[this];};function ip(iH){var iG=+this;if(iG<0)iG=Math.max(0,iG+iH.length);return iH[iG];};iq.prototype.get=function(iK){var iJ=(typeof iK===bb);var iL;if(!iJ){if(ig){var iI=ij(iK);iL=iI!==null?iI:il;}else {iL=il;};}else {iL=ip;};return this._then(iL,undefined,undefined,iK,undefined);};};},{"./util":36}],'6':[function(iM,iO,iN){A;iO.exports=function(iS,iP,iR,iU){var iQ=iM(dt);var iW=iQ.tryCatch;var iT=iQ.errorObj;var iV=iS._async;iS.prototype[cY]=iS.prototype.cancel=function(){if(!iU.cancellation())return this._warn(bN);var iX=this;var iY=iX;while(iX._isCancellable()){if(!iX._cancelBy(iY)){if(iY._isFollowing()){iY._followee().cancel();}else {iY._cancelBranched();};break;};var parent=iX._cancellationParent;if(parent==null||!parent._isCancellable()){if(iX._isFollowing()){iX._followee().cancel();}else {iX._cancelBranched();};break;}else {if(iX._isFollowing())iX._followee().cancel();iX._setWillBeCancelled();iY=iX;iX=parent;};};};iS.prototype._branchHasCancelled=function(){this._branchesRemainingToCancel-- ;};iS.prototype._enoughBranchesHaveCancelled=function(){return this._branchesRemainingToCancel===undefined||this._branchesRemainingToCancel<=0;};iS.prototype._cancelBy=function(ja){if(ja===this){this._branchesRemainingToCancel=0;this._invokeOnCancel();return true;}else {this._branchHasCancelled();if(this._enoughBranchesHaveCancelled()){this._invokeOnCancel();return true;};};return false;};iS.prototype._cancelBranched=function(){if(this._enoughBranchesHaveCancelled()){this._cancel();};};iS.prototype._cancel=function(){if(!this._isCancellable())return;this._setCancelled();iV.invoke(this._cancelPromises,this,undefined);};iS.prototype._cancelPromises=function(){if(this._length()>0)this._settlePromises();};iS.prototype._unsetOnCancel=function(){this._onCancelField=undefined;};iS.prototype._isCancellable=function(){return this.isPending()&&!this._isCancelled();};iS.prototype.isCancellable=function(){return this.isPending()&&!this.isCancelled();};iS.prototype._doInvokeOnCancel=function(jb,jc){if(iQ.isArray(jb)){for(var i=0;i<jb.length; ++i){this._doInvokeOnCancel(jb[i],jc);};}else if(jb!==undefined){if(typeof jb===cz){if(!jc){var e=iW(jb).call(this._boundValue());if(e===iT){this._attachExtraTrace(e.e);iV.throwLater(e.e);};};}else {jb._resultCancelled(this);};};};iS.prototype._invokeOnCancel=function(){var jd=this._onCancel();this._unsetOnCancel();iV.invoke(this._doInvokeOnCancel,this,jd);};iS.prototype._invokeInternalOnCancel=function(){if(this._isCancellable()){this._doInvokeOnCancel(this._onCancel(),true);this._unsetOnCancel();};};iS.prototype._resultCancelled=function(){this.cancel();};};},{"./util":36}],'7':[function(je,jg,jf){A;jg.exports=function(ji){var jk=je(dt);var jj=je(eE).keys;var jl=jk.tryCatch;var jm=jk.errorObj;function jh(jn,jp,jo){return function(e){var js=jo._boundValue();predicateLoop:for(var i=0;i<jn.length; ++i){var jr=jn[i];if(jr===Error||(jr!=null&&jr.prototype instanceof Error)){if(e instanceof jr){return jl(jp).call(js,e);};}else if(typeof jr===cz){var jq=jl(jr).call(js,e);if(jq===jm){return jq;}else if(jq){return jl(jp).call(js,e);};}else if(jk.isObject(e)){var jt=jj(jr);for(var j=0;j<jt.length; ++j){var ju=jt[j];if(jr[ju]!=e[ju]){continue predicateLoop;};};return jl(jp).call(js,e);};};return ji;};};return jh;};},{"./es5":13,"./util":36}],'8':[function(jv,jx,jw){A;jx.exports=function(jA){var jD=false;var jC=[];jA.prototype._promiseCreated=function(){};jA.prototype._pushContext=function(){};jA.prototype._popContext=function(){return null;};jA._peekContext=jA.prototype._peekContext=function(){};function jB(){this._trace=new jB.CapturedTrace(jz());};jB.prototype._pushContext=function(){if(this._trace!==undefined){this._trace._promiseCreated=null;jC.push(this._trace);};};jB.prototype._popContext=function(){if(this._trace!==undefined){var jF=jC.pop();var jE=jF._promiseCreated;jF._promiseCreated=null;return jE;};return null;};function jy(){if(jD)return new jB();};function jz(){var jG=jC.length-1;if(jG>=0){return jC[jG];};return undefined;};jB.CapturedTrace=null;jB.create=jy;jB.deactivateLongStackTraces=function(){};jB.activateLongStackTraces=function(){var jK=jA.prototype._pushContext;var jI=jA.prototype._popContext;var jJ=jA._peekContext;var jL=jA.prototype._peekContext;var jH=jA.prototype._promiseCreated;jB.deactivateLongStackTraces=function(){jA.prototype._pushContext=jK;jA.prototype._popContext=jI;jA._peekContext=jJ;jA.prototype._peekContext=jL;jA.prototype._promiseCreated=jH;jD=false;};jD=true;jA.prototype._pushContext=jB.prototype._pushContext;jA.prototype._popContext=jB.prototype._popContext;jA._peekContext=jA.prototype._peekContext=jz;jA.prototype._promiseCreated=function(){var jM=this._peekContext();if(jM&&jM._promiseCreated==null)jM._promiseCreated=this;};};return jB;};},{}],'9':[function(jN,jP,jO){A;jP.exports=function(ko,kC){var kA=ko._getDomain;var kU=ko._async;var kQ=jN(dB).Warning;var kB=jN(dt);var kd=kB.canAttachTrace;var jY;var kj;var jR=/[\\\/]bluebird[\\\/]js[\\\/](release|debug|instrumented)/;var kS=/\((?:timers\.js):\d+:\d+\)/;var kp=/[\/<\(](.+?):(\d+):(\d+)\)?\s*$/;var jU=null;var kv=null;var kn=false;var kx;var jQ=!!(kB.env(cx)!=0&&true);var kk=!!(kB.env(y)!=0&&(jQ||kB.env(y)));var kr=!!(kB.env(em)!=0&&(jQ||kB.env(em)));var kl=kB.env(cc)!=0&&(kk||!!kB.env(cc));ko.prototype.suppressUnhandledRejections=function(){var kY=this._target();kY._bitField=((kY._bitField&-1048577)|524288);};ko.prototype._ensurePossibleRejectionHandled=function(){if((this._bitField&524288)!==0)return;this._setRejectionIsUnhandled();kU.invokeLater(this._notifyUnhandledRejection,this,undefined);};ko.prototype._notifyUnhandledRejectionIsHandled=function(){kK(L,jY,undefined,this);};ko.prototype._setReturnedNonUndefined=function(){this._bitField=this._bitField|268435456;};ko.prototype._returnedNonUndefined=function(){return (this._bitField&268435456)!==0;};ko.prototype._notifyUnhandledRejection=function(){if(this._isRejectionUnhandled()){var la=this._settledValue();this._setUnhandledRejectionIsNotified();kK(cU,kj,la,this);};};ko.prototype._setUnhandledRejectionIsNotified=function(){this._bitField=this._bitField|262144;};ko.prototype._unsetUnhandledRejectionIsNotified=function(){this._bitField=this._bitField&-262145;};ko.prototype._isUnhandledRejectionNotified=function(){return (this._bitField&262144)>0;};ko.prototype._setRejectionIsUnhandled=function(){this._bitField=this._bitField|1048576;};ko.prototype._unsetRejectionIsUnhandled=function(){this._bitField=this._bitField&-1048577;if(this._isUnhandledRejectionNotified()){this._unsetUnhandledRejectionIsNotified();this._notifyUnhandledRejectionIsHandled();};};ko.prototype._isRejectionUnhandled=function(){return (this._bitField&1048576)>0;};ko.prototype._warn=function(lc,lb,ld){return kN(lc,lb,ld||this);};ko.onPossiblyUnhandledRejection=function(lf){var le=kA();kj=typeof lf===cz?(le===null?lf:kB.domainBind(le,lf)):undefined;};ko.onUnhandledRejectionHandled=function(lh){var lg=kA();jY=typeof lh===cz?(lg===null?lh:kB.domainBind(lg,lh)):undefined;};var kz=function(){};ko.longStackTraces=function(){if(kU.haveItemsQueued()&&!kq.longStackTraces){throw new Error(eS);};if(!kq.longStackTraces&&ke()){var li=ko.prototype._captureStackTrace;var lj=ko.prototype._attachExtraTrace;kq.longStackTraces=true;kz=function(){if(kU.haveItemsQueued()&&!kq.longStackTraces){throw new Error(eS);};ko.prototype._captureStackTrace=li;ko.prototype._attachExtraTrace=lj;kC.deactivateLongStackTraces();kU.enableTrampoline();kq.longStackTraces=false;};ko.prototype._captureStackTrace=kb;ko.prototype._attachExtraTrace=kI;kC.activateLongStackTraces();kU.disableTrampolineIfNecessary();};};ko.hasLongStackTraces=function(){return kq.longStackTraces&&ke();};var kW=(function(){try{if(typeof CustomEvent===cz){var event=new CustomEvent(cm);kB.global.dispatchEvent(event);return function(name,event){var lk=new CustomEvent(name.toLowerCase(),{detail:event,cancelable:true});return !kB.global.dispatchEvent(lk);};}else if(typeof Event===cz){var event=new Event(cm);kB.global.dispatchEvent(event);return function(name,event){var ll=new Event(name.toLowerCase(),{cancelable:true});ll.detail=event;return !kB.global.dispatchEvent(ll);};}else {var event=document.createEvent(cm);event.initCustomEvent(cu,false,true,{});kB.global.dispatchEvent(event);return function(name,event){var lm=document.createEvent(cm);lm.initCustomEvent(name.toLowerCase(),false,true,event);return !kB.global.dispatchEvent(lm);};};}catch(e){};return function(){return false;};})();var ky=(function(){if(kB.isNode){return function(){return process.emit.apply(process,arguments);};}else {if(!kB.global){return function(){return false;};};return function(name){var ln=dK+name.toLowerCase();var lo=kB.global[ln];if(!lo)return false;lo.apply(kB.global,[].slice.call(arguments,1));return true;};};})();function kM(name,lp){return {promise:lp};};var ki={promiseCreated:kM,promiseFulfilled:kM,promiseRejected:kM,promiseResolved:kM,promiseCancelled:kM,promiseChained:function(name,lq,lr){return {promise:lq,child:lr};},warning:function(name,ls){return {warning:ls};},unhandledRejection:function(name,lt,lu){return {reason:lt,promise:lu};},rejectionHandled:kM};var jS=function(name){var lw=false;try{lw=ky.apply(null,arguments);}catch(e){kU.throwLater(e);lw=true;};var lv=false;try{lv=kW(name,ki[name].apply(null,arguments));}catch(e){kU.throwLater(e);lv=true;};return lv||lw;};ko.config=function(ly){ly=Object(ly);if(eA in ly){if(ly.longStackTraces){ko.longStackTraces();}else if(!ly.longStackTraces&&ko.hasLongStackTraces()){kz();};};if(dQ in ly){var lx=ly.warnings;kq.warnings=!!lx;kl=kq.warnings;if(kB.isObject(lx)){if(dT in lx){kl=!!lx.wForgottenReturn;};};};if(bs in ly&&ly.cancellation&&!kq.cancellation){if(kU.haveItemsQueued()){throw new Error(bj);};ko.prototype._clearCancellationData=kF;ko.prototype._propagateFrom=km;ko.prototype._onCancel=kT;ko.prototype._setOnCancel=kH;ko.prototype._attachCancellationCallback=kR;ko.prototype._execute=kO;jT=km;kq.cancellation=true;};if(eb in ly){if(ly.monitoring&&!kq.monitoring){kq.monitoring=true;ko.prototype._fireEvent=jS;}else if(!ly.monitoring&&kq.monitoring){kq.monitoring=false;ko.prototype._fireEvent=kh;};};};function kh(){return false;};ko.prototype._fireEvent=kh;ko.prototype._execute=function(lA,lz,lB){try{lA(lz,lB);}catch(e){return e;};};ko.prototype._onCancel=function(){};ko.prototype._setOnCancel=function(lC){;};ko.prototype._attachCancellationCallback=function(lD){;};ko.prototype._captureStackTrace=function(){};ko.prototype._attachExtraTrace=function(){};ko.prototype._clearCancellationData=function(){};ko.prototype._propagateFrom=function(parent,lE){;;};function kO(lH,lF,lI){var lG=this;try{lH(lF,lI,function(lJ){if(typeof lJ!==cz){throw new TypeError(dN+kB.toString(lJ));};lG._attachCancellationCallback(lJ);});}catch(e){return e;};};function kR(lK){if(!this._isCancellable())return this;var lL=this._onCancel();if(lL!==undefined){if(kB.isArray(lL)){lL.push(lK);}else {this._setOnCancel([lL,lK]);};}else {this._setOnCancel(lK);};};function kT(){return this._onCancelField;};function kH(lM){this._onCancelField=lM;};function kF(){this._cancellationParent=undefined;this._onCancelField=undefined;};function km(parent,lN){if((lN&1)!==0){this._cancellationParent=parent;var lO=parent._branchesRemainingToCancel;if(lO===undefined){lO=0;};parent._branchesRemainingToCancel=lO+1;};if((lN&2)!==0&&parent._isBound()){this._setBoundTo(parent._boundTo);};};function kg(parent,lP){if((lP&2)!==0&&parent._isBound()){this._setBoundTo(parent._boundTo);};};var jT=kg;function kc(){var lQ=this._boundTo;if(lQ!==undefined){if(lQ instanceof ko){if(lQ.isFulfilled()){return lQ.value();}else {return undefined;};};};return lQ;};function kb(){this._trace=new kE(this._peekContext());};function kI(lU,lS){if(kd(lU)){var lT=this._trace;if(lT!==undefined){if(lS)lT=lT._parent;};if(lT!==undefined){lT.attachExtraTrace(lU);}else if(!lU.__stackCleaned__){var lR=kX(lU);kB.notEnumerableProp(lU,H,lR.message+dv+lR.stack.join(dv));kB.notEnumerableProp(lU,cw,true);};};};function kw(mc,lX,name,ma,parent){if(mc===undefined&&lX!==null&&kl){if(parent!==undefined&&parent._returnedNonUndefined())return;if((ma._bitField&65535)===0)return;if(name)name=name+cs;var lV=eq;var mb=eq;if(lX._trace){var lY=lX._trace.stack.split(dv);var mg=ka(lY);for(var i=mg.length-1;i>=0; --i){var mf=mg[i];if(!kS.test(mf)){var lW=mf.match(kp);if(lW){lV=br+lW[1]+bT+lW[2]+bT+lW[3]+cs;};break;};};if(mg.length>0){var me=mg[0];for(var i=0;i<lY.length; ++i){if(lY[i]===me){if(i>0){mb=dv+lY[i-1];};break;};};};};var md=ci+name+bD+lV+bz+eD+mb;ma._warn(md,true,lX);};};function kL(name,mi){var mh=name+dj;if(mi)mh+=m+mi+M;return kN(mh);};function kN(mn,mm,ml){if(!kq.warnings)return;var mk=new kQ(mn);var mj;if(mm){ml._attachExtraTrace(mk);}else if(kq.longStackTraces&&(mj=ko._peekContext())){mj.attachExtraTrace(mk);}else {var mo=kX(mk);mk.stack=mo.message+dv+mo.stack.join(dv);};if(!jS(G,mk)){ks(mk,eq,true);};};function kJ(mp,mq){for(var i=0;i<mq.length-1; ++i){mq[i].push(bA);mq[i]=mq[i].join(dv);};if(i<mq.length){mq[i]=mq[i].join(dv);};return mp+dv+mq.join(dv);};function kD(mr){for(var i=0;i<mr.length; ++i){if(mr[i].length===0||((i+1<mr.length)&&mr[i][0]===mr[i+1][0])){mr.splice(i,1);i-- ;};};};function kG(mx){var mu=mx[0];for(var i=1;i<mx.length; ++i){var mw=mx[i];var mt=mu.length-1;var my=mu[mt];var mz=-1;for(var j=mw.length-1;j>=0; --j){if(mw[j]===my){mz=j;break;};};for(var j=mz;j>=0; --j){var mv=mw[j];if(mu[mt]===mv){mu.pop();mt-- ;}else {break;};};mu=mw;};};function ka(mE){var mB=[];for(var i=0;i<mE.length; ++i){var mD=mE[i];var mC=eP===mD||jU.test(mD);var mA=mC&&ku(mD);if(mC&&!mA){if(kn&&mD.charAt(0)!==cs){mD=eF+mD;};mB.push(mD);};};return mB;};function kV(mH){var mG=mH.stack.replace(/\s+$/g,eq).split(dv);for(var i=0;i<mG.length; ++i){var mF=mG[i];if(eP===mF||jU.test(mF)){break;};};if(i>0){mG=mG.slice(i);};return mG;};function kX(mK){var mJ=mK.stack;var mI=mK.toString();mJ=typeof mJ===bI&&mJ.length>0?kV(mK):[eP];return {message:mI,stack:ka(mJ)};};function ks(mM,mP,mO){if(typeof console!==eR){var mL;if(kB.isObject(mM)){var mN=mM.stack;mL=mP+kv(mN,mM);}else {mL=mP+String(mM);};if(typeof kx===cz){kx(mL,mO);}else if(typeof console.log===cz||typeof console.log===dO){console.log(mL);};};};function kK(name,mR,mQ,mS){var mT=false;try{if(typeof mR===cz){mT=true;if(name===L){mR(mS);}else {mR(mQ,mS);};};}catch(e){kU.throwLater(e);};if(name===cU){if(!jS(name,mQ,mS)&&!mT){ks(mQ,cQ);};}else {jS(name,mS);};};function kP(mV){var mX;if(typeof mV===cz){mX=eC+(mV.name||ds)+ew;}else {mX=mV&&typeof mV.toString===cz?mV.toString():kB.toString(mV);var mU=/\[object [a-zA-Z0-9$_]+\]/;if(mU.test(mX)){try{var mW=JSON.stringify(mV);mX=mW;}catch(e){};};if(mX.length===0){mX=eQ;};};return (I+jV(mX)+cL);};function jV(na){var mY=41;if(na.length<mY){return na;};return na.substr(0,mY-3)+W;};function ke(){return typeof jX===cz;};var ku=function(){return false;};var kf=/[\/<\(]([^:\/]+):(\d+):(?:\d+)\)?\s*$/;function jW(nc){var nb=nc.match(kf);if(nb){return {fileName:nb[1],line:parseInt(nb[2],10)};};};function kt(nh,nd){if(!ke())return;var nk=nh.stack.split(dv);var ng=nd.stack.split(dv);var nl=-1;var nf=-1;var ni;var ne;for(var i=0;i<nk.length; ++i){var nj=jW(nk[i]);if(nj){ni=nj.fileName;nl=nj.line;break;};};for(var i=0;i<ng.length; ++i){var nj=jW(ng[i]);if(nj){ne=nj.fileName;nf=nj.line;break;};};if(nl<0||nf<0||!ni||!ne||ni!==ne||nl>=nf){return;};ku=function(nn){if(jR.test(nn))return true;var nm=jW(nn);if(nm){if(nm.fileName===ni&&(nl<=nm.line&&nm.line<=nf)){return true;};};return false;};};function kE(parent){this._parent=parent;this._promisesCreated=0;var length=this._length=1+(parent===undefined?0:parent._length);jX(this,kE);if(length>32)this.uncycle();};kB.inherits(kE,Error);kC.CapturedTrace=kE;kE.prototype.uncycle=function(){var length=this._length;if(length<2)return;var nu=[];var np={};for(var i=0,no=this;no!==undefined; ++i){nu.push(no);no=no._parent;};length=this._length=i;for(var i=length-1;i>=0; --i){var nr=nu[i].stack;if(np[nr]===undefined){np[nr]=i;};};for(var i=0;i<length; ++i){var nt=nu[i].stack;var nq=np[nt];if(nq!==undefined&&nq!==i){if(nq>0){nu[nq-1]._parent=undefined;nu[nq-1]._length=1;};nu[i]._parent=undefined;nu[i]._length=1;var ns=i>0?nu[i-1]:this;if(nq<length-1){ns._parent=nu[nq+1];ns._parent.uncycle();ns._length=ns._parent._length+1;}else {ns._parent=undefined;ns._length=1;};var nv=ns._length+1;for(var j=i-2;j>=0; --j){nu[j]._length=nv;nv++ ;};return;};};};kE.prototype.attachExtraTrace=function(nA){if(nA.__stackCleaned__)return;this.uncycle();var ny=kX(nA);var nw=ny.message;var nx=[ny.stack];var nz=this;while(nz!==undefined){nx.push(ka(nz.stack.split(dv)));nz=nz._parent;};kG(nx);kD(nx);kB.notEnumerableProp(nA,H,kJ(nw,nx));kB.notEnumerableProp(nA,cw,true);};var jX=(function nG(){var nB=/^\s*at\s*/;var nE=function(nH,nI){if(typeof nH===bI)return nH;if(nI.name!==undefined&&nI.message!==undefined){return nI.toString();};return kP(nI);};if(typeof Error.stackTraceLimit===bb&&typeof Error.captureStackTrace===cz){Error.stackTraceLimit+=6;jU=nB;kv=nE;var nD=Error.captureStackTrace;ku=function(nJ){return jR.test(nJ);};return function(nL,nK){Error.stackTraceLimit+=6;nD(nL,nK);Error.stackTraceLimit-=6;};};var nC=new Error();if(typeof nC.stack===bI&&nC.stack.split(dv)[0].indexOf(dD)>=0){jU=/@/;kv=nE;kn=true;return function nM(o){o.stack=new Error().stack;};};var nF;try{throw new Error();}catch(e){nF=(H in e);};if(!(H in nC)&&nF&&typeof Error.stackTraceLimit===bb){jU=nB;kv=nE;return function nN(o){Error.stackTraceLimit+=6;try{throw new Error();}catch(e){o.stack=e.stack;};Error.stackTraceLimit-=6;};};kv=function(nO,nP){if(typeof nO===bI)return nO;if((typeof nP===dO||typeof nP===cz)&&nP.name!==undefined&&nP.message!==undefined){return nP.toString();};return kP(nP);};return null;})([]);if(typeof console!==eR&&typeof console.warn!==eR){kx=function(nQ){console.warn(nQ);};if(kB.isNode&&process.stderr.isTTY){kx=function(nS,nT){var nR=nT?bX:ex;console.warn(nR+nS+ba);};}else if(!kB.isNode&&typeof (new Error().stack)===bI){kx=function(nU,nV){console.warn(dY+nU,nV?cp:Q);};};};var kq={warnings:kk,longStackTraces:false,cancellation:false,monitoring:false};if(kr)ko.longStackTraces();return {longStackTraces:function(){return kq.longStackTraces;},warnings:function(){return kq.warnings;},cancellation:function(){return kq.cancellation;},monitoring:function(){return kq.monitoring;},propagateFromFunction:function(){return jT;},boundValueFunction:function(){return kc;},checkForgottenReturns:kw,setBounds:kt,warn:kN,deprecated:kL,CapturedTrace:kE,fireDomEvent:kW,fireGlobalEvent:ky};};},{"./errors":12,"./util":36}],'10':[function(nW,nY,nX){A;nY.exports=function(oc){function ob(){return this.value;};function oa(){throw this.reason;};oc.prototype[cK]=oc.prototype.thenReturn=function(od){if(od instanceof oc)od.suppressUnhandledRejections();return this._then(ob,undefined,undefined,{value:od},undefined);};oc.prototype[cX]=oc.prototype.thenThrow=function(oe){return this._then(oa,undefined,undefined,{reason:oe},undefined);};oc.prototype.catchThrow=function(of){if(arguments.length<=1){return this._then(undefined,oa,undefined,{reason:of},undefined);}else {var oh=arguments[1];var og=function(){throw oh;};return this.caught(of,og);};};oc.prototype.catchReturn=function(ok){if(arguments.length<=1){if(ok instanceof oc)ok.suppressUnhandledRejections();return this._then(undefined,ob,undefined,{value:ok},undefined);}else {var oi=arguments[1];if(oi instanceof oc)oi.suppressUnhandledRejections();var oj=function(){return oi;};return this.caught(ok,oj);};};};},{}],'11':[function(ol,on,om){A;on.exports=function(ot,os){var oq=ot.reduce;var or=ot.all;function op(){return or(this);};function oo(ou,ov){return oq(ou,ov,os,os);};ot.prototype.each=function(ow){return oq(this,ow,os,0)._then(op,undefined,undefined,this,undefined);};ot.prototype.mapSeries=function(ox){return oq(this,ox,os,os);};ot.each=function(oy,oz){return oq(oy,oz,os,0)._then(op,undefined,undefined,oy,undefined);};ot.mapSeries=oo;};},{}],'12':[function(oP,oI,oC){A;var oH=oP(eE);var oO=oH.freeze;var oK=oP(dt);var oA=oK.inherits;var oJ=oK.notEnumerableProp;function oD(oT,oV){function oU(oW){if(!(this instanceof oU))return new oU(oW);oJ(this,cB,typeof oW===bI?oW:oV);oJ(this,dR,oT);if(Error.captureStackTrace){Error.captureStackTrace(this,this.constructor);}else {Error.call(this);};};oA(oU,Error);return oU;};var oB,oS;var oL=oD(V,G);var oN=oD(bG,be);var oM=oD(ea,dg);var oF=oD(bE,cM);try{oB=TypeError;oS=RangeError;}catch(e){oB=oD(eB,da);oS=oD(cN,w);};var oE=cE.split(cs);for(var i=0;i<oE.length; ++i){if(typeof Array.prototype[oE[i]]===cz){oF.prototype[oE[i]]=Array.prototype[oE[i]];};};oH.defineProperty(oF.prototype,dX,{value:0,configurable:false,writable:true,enumerable:true});oF.prototype[eT]=true;var oG=0;oF.prototype.toString=function(){var oX=Array(oG*4+1).join(cs);var pa=dv+oX+cH+dv;oG++ ;oX=Array(oG*4+1).join(cs);for(var i=0;i<this.length; ++i){var pb=this[i]===this?eM:this[i]+eq;var oY=pb.split(dv);for(var j=0;j<oY.length; ++j){oY[j]=oX+oY[j];};pb=oY.join(dv);pa+=pb+dv;};oG-- ;return pa;};function oR(pc){if(!(this instanceof oR))return new oR(pc);oJ(this,dR,dP);oJ(this,cB,pc);this.cause=pc;this[eT]=true;if(pc instanceof Error){oJ(this,cB,pc.message);oJ(this,H,pc.stack);}else if(Error.captureStackTrace){Error.captureStackTrace(this,this.constructor);};};oA(oR,Error);var oQ=Error[dF];if(!oQ){oQ=oO({CancellationError:oN,TimeoutError:oM,OperationalError:oR,RejectionError:oR,AggregateError:oF});oH.defineProperty(Error,dF,{value:oQ,writable:false,enumerable:false,configurable:false});};oI.exports={Error:Error,TypeError:oB,RangeError:oS,CancellationError:oQ.CancellationError,OperationalError:oQ.OperationalError,TimeoutError:oQ.TimeoutError,AggregateError:oQ.AggregateError,Warning:oL};},{"./es5":13,"./util":36}],'13':[function(pn,pk,pd){var pp=(function(){A;return this===undefined;})();if(pp){pk.exports={freeze:Object.freeze,defineProperty:Object.defineProperty,getDescriptor:Object.getOwnPropertyDescriptor,keys:Object.keys,names:Object.getOwnPropertyNames,getPrototypeOf:Object.getPrototypeOf,isArray:Array.isArray,isES5:pp,propertyIsWritable:function(pr,ps){var pq=Object.getOwnPropertyDescriptor(pr,ps);return !!(!pq||pq.writable||pq.set);}};}else {var po={}.hasOwnProperty;var pl={}.toString;var ph={}.constructor.prototype;var pi=function(o){var pt=[];for(var pu in o){if(po.call(o,pu)){pt.push(pu);};};return pt;};var pm=function(o,pv){return {value:o[pv]};};var pe=function(o,pw,px){o[pw]=px.value;return o;};var pf=function(py){return py;};var pj=function(pz){try{return Object(pz).constructor.prototype;}catch(e){return ph;};};var pg=function(pA){try{return pl.call(pA)===eI;}catch(e){return false;};};pk.exports={isArray:pg,keys:pi,names:pi,defineProperty:pe,getDescriptor:pm,freeze:pf,getPrototypeOf:pj,isES5:pp,propertyIsWritable:function(){return true;}};};},{}],'14':[function(pB,pD,pC){A;pD.exports=function(pF,pE){var pG=pF.map;pF.prototype.filter=function(pI,pH){return pG(this,pI,pH,pE);};pF.filter=function(pJ,pL,pK){return pG(pJ,pL,pK,pE);};};},{}],'15':[function(pM,pO,pN){A;pO.exports=function(pV,pW){var pP=pM(dt);var pS=pV.CancellationError;var pY=pP.errorObj;function pT(qb,qd,qc){this.promise=qb;this.type=qd;this.handler=qc;this.called=false;this.cancelPromise=null;};pT.prototype.isFinallyHandler=function(){return this.type===0;};function pR(qe){this.finallyHandler=qe;};pR.prototype._resultCancelled=function(){qa(this.finallyHandler);};function qa(qg,qf){if(qg.cancelPromise!=null){if(arguments.length>1){qg.cancelPromise._reject(qf);}else {qg.cancelPromise._cancel();};qg.cancelPromise=null;return true;};return false;};function pU(){return pQ.call(this,this.promise._target()._settledValue());};function pX(qh){if(qa(this,qh))return;pY.e=qh;return pY;};function pQ(qn){var qm=this.promise;var ql=this.handler;if(!this.called){this.called=true;var qj=this.isFinallyHandler()?ql.call(qm._boundValue()):ql.call(qm._boundValue(),qn);if(qj!==undefined){qm._setReturnedNonUndefined();var qi=pW(qj,qm);if(qi instanceof pV){if(this.cancelPromise!=null){if(qi._isCancelled()){var qk=new pS(cI);qm._attachExtraTrace(qk);pY.e=qk;return pY;}else if(qi.isPending()){qi._attachCancellationCallback(new pR(this));};};return qi._then(pU,pX,undefined,this,undefined);};};};if(qm.isRejected()){qa(this);pY.e=qn;return pY;}else {qa(this);return qn;};};pV.prototype._passThrough=function(qp,qq,qr,qo){if(typeof qp!==cz)return this.then();return this._then(qr,qo,undefined,new pT(this,qq,qp),undefined);};pV.prototype.lastly=pV.prototype[ey]=function(qs){return this._passThrough(qs,0,pQ,pQ);};pV.prototype.tap=function(qt){return this._passThrough(qt,1,pQ);};return pT;};},{"./util":36}],'16':[function(qu,qw,qv){A;qw.exports=function(qG,qB,qF,qH,qE,qI){var qA=qu(dB);var TypeError=qA.TypeError;var qD=qu(dt);var qJ=qD.errorObj;var qK=qD.tryCatch;var qC=[];function qz(qM,qL,qP){for(var i=0;i<qL.length; ++i){qP._pushContext();var qQ=qK(qL[i])(qM);qP._popContext();if(qQ===qJ){qP._pushContext();var qO=qG.reject(qJ.e);qP._popContext();return qO;};var qN=qH(qQ,qP);if(qN instanceof qG)return qN;};return null;};function qy(qV,qU,qR,qX){if(qI.cancellation()){var qS=new qG(qF);var qW=this._finallyPromise=new qG(qF);this._promise=qS.lastly(function(){return qW;});qS._captureStackTrace();qS._setOnCancel(this);}else {var qT=this._promise=new qG(qF);qT._captureStackTrace();};this._stack=qX;this._generatorFunction=qV;this._receiver=qU;this._generator=undefined;this._yieldHandlers=typeof qR===cz?[qR].concat(qC):qC;this._yieldedPromise=null;this._cancellationPhase=false;};qD.inherits(qy,qE);qy.prototype._isResolved=function(){return this._promise===null;};qy.prototype._cleanup=function(){this._promise=this._generator=null;if(qI.cancellation()&&this._finallyPromise!==null){this._finallyPromise._fulfill();this._finallyPromise=null;};};qy.prototype._promiseCancelled=function(){if(this._isResolved())return;var qY=typeof this._generator[cK]!==eR;var rb;if(!qY){var ra=new qG.CancellationError(dE);qG.coroutine.returnSentinel=ra;this._promise._attachExtraTrace(ra);this._promise._pushContext();rb=qK(this._generator[cX]).call(this._generator,ra);this._promise._popContext();}else {this._promise._pushContext();rb=qK(this._generator[cK]).call(this._generator,undefined);this._promise._popContext();};this._cancellationPhase=true;this._yieldedPromise=null;this._continue(rb);};qy.prototype._promiseFulfilled=function(rd){this._yieldedPromise=null;this._promise._pushContext();var rc=qK(this._generator.next).call(this._generator,rd);this._promise._popContext();this._continue(rc);};qy.prototype._promiseRejected=function(re){this._yieldedPromise=null;this._promise._attachExtraTrace(re);this._promise._pushContext();var rf=qK(this._generator[cX]).call(this._generator,re);this._promise._popContext();this._continue(rf);};qy.prototype._resultCancelled=function(){if(this._yieldedPromise instanceof qG){var rg=this._yieldedPromise;this._yieldedPromise=null;rg.cancel();};};qy.prototype.promise=function(){return this._promise;};qy.prototype._run=function(){this._generator=this._generatorFunction.call(this._receiver);this._receiver=this._generatorFunction=undefined;this._promiseFulfilled(undefined);};qy.prototype._continue=function(rj){var ri=this._promise;if(rj===qJ){this._cleanup();if(this._cancellationPhase){return ri.cancel();}else {return ri._rejectCallback(rj.e,false);};};var rk=rj.value;if(rj.done===true){this._cleanup();if(this._cancellationPhase){return ri.cancel();}else {return ri._resolveCallback(rk);};}else {var rh=qH(rk,this._promise);if(!(rh instanceof qG)){rh=qz(rh,this._yieldHandlers,this._promise);if(rh===null){this._promiseRejected(new TypeError(cq.replace(es,rk)+cC+this._stack.split(dv).slice(1,-7).join(dv)));return;};};rh=rh._target();var rl=rh._bitField;;if(((rl&50397184)===0)){this._yieldedPromise=rh;rh._proxy(this,null);}else if(((rl&33554432)!==0)){qG._async.invoke(this._promiseFulfilled,this,rh._value());}else if(((rl&16777216)!==0)){qG._async.invoke(this._promiseRejected,this,rh._reason());}else {this._promiseCancelled();};};};qG.coroutine=function(ro,rq){if(typeof ro!==cz){throw new TypeError(dz);};var rn=Object(rq).yieldHandler;var rp=qy;var rm=new Error().stack;return function(){var rt=ro.apply(this,arguments);var rr=new rp(undefined,undefined,rn,rm);var rs=rr.promise();rr._generator=rt;rr._promiseFulfilled(undefined);return rs;};};qG.coroutine.addYieldHandler=function(ru){if(typeof ru!==cz){throw new TypeError(cA+qD.classString(ru));};qC.push(ru);};qG.spawn=function(rw){qI.deprecated(bc,dr);if(typeof rw!==cz){return qB(dz);};var rv=new qy(rw,this);var rx=rv.promise();rv._run(qG.spawn);return rx;};};},{"./errors":12,"./util":36}],'17':[function(ry,rA,rz){A;rA.exports=function(rQ,rF,rM,rK,rE,rC){var rJ=ry(dt);var rB=rJ.canEvaluate;var rP=rJ.tryCatch;var rH=rJ.errorObj;var rO;{var rL,rD,rR,rI,rN,rG,i;};rQ.join=function(){var rU=arguments.length-1;var sc;if(rU>0&&typeof arguments[rU]===cz){sc=arguments[rU];{var rW,rS,sb,rY,i,sa,rX,rT;};};var rV=[].slice.call(arguments);;if(sc)rV.pop();var rW=new rF(rV).promise();return sc!==undefined?rW.spread(sc):rW;};};},{"./util":36}],'18':[function(sd,sf,se){A;sf.exports=function(sm,si,sk,sn,sl,sp){var sg=sm._getDomain;var sj=sd(dt);var sr=sj.tryCatch;var sq=sj.errorObj;function so(su,sv,st,sw){this.constructor$(su);this._promise._captureStackTrace();var ss=sg();this._callback=ss===null?sv:sj.domainBind(ss,sv);this._preservedValues=sw===sl?new Array(this.length()):null;this._limit=st;this._inFlight=0;this._queue=[];this._init$(undefined,-2);};sj.inherits(so,si);so.prototype._init=function(){};so.prototype._promiseFulfilled=function(sC,sx){var sG=this._values;var length=this.length();var sz=this._preservedValues;var sB=this._limit;if(sx<0){sx=(sx*-1)-1;sG[sx]=sC;if(sB>=1){this._inFlight-- ;this._drainQueue();if(this._isResolved())return true;};}else {if(sB>=1&&this._inFlight>=sB){sG[sx]=sC;this._queue.push(sx);return false;};if(sz!==null)sz[sx]=sC;var sJ=this._promise;var sE=this._callback;var sI=sJ._boundValue();sJ._pushContext();var sH=sr(sE).call(sI,sC,sx,length);var sF=sJ._popContext();sp.checkForgottenReturns(sH,sF,sz!==null?er:eH,sJ);if(sH===sq){this._reject(sH.e);return true;};var sA=sn(sH,this._promise);if(sA instanceof sm){sA=sA._target();var sD=sA._bitField;;if(((sD&50397184)===0)){if(sB>=1)this._inFlight++ ;sG[sx]=sA;sA._proxy(this,(sx+1)*-1);return false;}else if(((sD&33554432)!==0)){sH=sA._value();}else if(((sD&16777216)!==0)){this._reject(sA._reason());return true;}else {this._cancel();return true;};};sG[sx]=sH;};var sy= ++this._totalResolved;if(sy>=length){if(sz!==null){this._filter(sG,sz);}else {this._resolve(sG);};return true;};return false;};so.prototype._drainQueue=function(){var sK=this._queue;var sM=this._limit;var sL=this._values;while(sK.length>0&&this._inFlight<sM){if(this._isResolved())return;var sN=sK.pop();this._promiseFulfilled(sL[sN],sN);};};so.prototype._filter=function(sO,sQ){var sP=sQ.length;var sR=new Array(sP);var j=0;for(var i=0;i<sP; ++i){if(sO[i])sR[j++ ]=sQ[i];};sR.length=j;this._resolve(sR);};so.prototype.preservedValues=function(){return this._preservedValues;};function sh(sS,sV,sW,sU){if(typeof sV!==cz){return sk(cA+sj.classString(sV));};var sT=0;if(sW!==undefined){if(typeof sW===dO&&sW!==null){if(typeof sW.concurrency!==bb){return sm.reject(new TypeError(du+sj.classString(sW.concurrency)));};sT=sW.concurrency;}else {return sm.reject(new TypeError(bl+sj.classString(sW)));};};sT=typeof sT===bb&&isFinite(sT)&&sT>=1?sT:0;return new so(sS,sV,sT,sU).promise();};sm.prototype.map=function(sY,sX){return sh(this,sY,sX,null);};sm.map=function(ta,tc,tb,td){return sh(ta,tc,tb,td);};};},{"./util":36}],'19':[function(te,tg,tf){A;tg.exports=function(tk,tj,tl,ti,tm){var th=te(dt);var tn=th.tryCatch;tk.method=function(tp){if(typeof tp!==cz){throw new tk.TypeError(cA+th.classString(tp));};return function(){var tr=new tk(tj);tr._captureStackTrace();tr._pushContext();var ts=tn(tp).apply(this,arguments);var tq=tr._popContext();tm.checkForgottenReturns(ts,tq,dk,tr);tr._resolveFromSyncValue(ts);return tr;};};tk.attempt=tk[dJ]=function(ty){if(typeof ty!==cz){return ti(cA+th.classString(ty));};var tv=new tk(tj);tv._captureStackTrace();tv._pushContext();var tw;if(arguments.length>1){tm.deprecated(eG);var tx=arguments[1];var tu=arguments[2];tw=th.isArray(tx)?tn(ty).apply(tu,tx):tn(ty).call(tu,tx);}else {tw=tn(ty)();};var tt=tv._popContext();tm.checkForgottenReturns(tw,tt,cd,tv);tv._resolveFromSyncValue(tw);return tv;};tk.prototype._resolveFromSyncValue=function(tz){if(tz===th.errorObj){this._rejectCallback(tz.e,false);}else {this._resolveCallback(tz,true);};};};},{"./util":36}],'20':[function(tJ,tF,tE){A;var tG=tJ(dt);var tA=tG.maybeWrapAsError;var tB=tJ(dB);var tL=tB.OperationalError;var tI=tJ(eE);function tC(tM){return tM instanceof Error&&tI.getPrototypeOf(tM)===Error.prototype;};var tD=/^(?:name|message|stack|cause)$/;function tK(tO){var tP;if(tC(tO)){tP=new tL(tO);tP.name=tO.name;tP.message=tO.message;tP.stack=tO.stack;var tN=tI.keys(tO);for(var i=0;i<tN.length; ++i){var tQ=tN[i];if(!tD.test(tQ)){tP[tQ]=tO[tQ];};};return tP;};tG.markAsOriginatingFromRejection(tO);return tO;};function tH(tR,tS){return function(tV,tW){if(tR===null)return;if(tV){var tT=tK(tA(tV));tR._attachExtraTrace(tT);tR._reject(tT);}else if(!tS){tR._fulfill(tW);}else {var tU=[].slice.call(arguments,1);;tR._fulfill(tU);};tR=null;};};tF.exports=tH;},{"./errors":12,"./es5":13,"./util":36}],'21':[function(tX,ua,tY){A;ua.exports=function(ue){var ud=tX(dt);var uf=ue._async;var ug=ud.tryCatch;var uh=ud.errorObj;function ui(ul,uk){var uj=this;if(!ud.isArray(ul))return ub.call(uj,ul,uk);var um=ug(uk).apply(uj._boundValue(),[null].concat(ul));if(um===uh){uf.throwLater(um.e);};};function ub(uq,up){var uo=this;var un=uo._boundValue();var ur=uq===undefined?ug(up).call(un,null):ug(up).call(un,null,uq);if(ur===uh){uf.throwLater(ur.e);};};function uc(us,uu){var ut=this;if(!us){var uw=new Error(us+eq);uw.cause=us;us=uw;};var uv=ug(uu).call(ut._boundValue(),us);if(uv===uh){uf.throwLater(uv.e);};};ue.prototype.asCallback=ue.prototype.nodeify=function(uz,uy){if(typeof uz==cz){var ux=ub;if(uy!==undefined&&Object(uy).spread){ux=ui;};this._then(ux,uc,undefined,this,uz);};return this;};};},{"./util":36}],'22':[function(uA,uC,uB){A;uC.exports=function(){var uF=function(){return new TypeError(co);};var vc=function(){return new vg.PromiseInspection(this._target());};var vd=function(vj){return vg.reject(new TypeError(vj));};function uT(){};var uU={};var uS=uA(dt);var va;if(uS.isNode){va=function(){var vk=process.domain;if(vk===undefined)vk=null;return vk;};}else {va=function(){return null;};};uS.notEnumerableProp(vg,R,va);var vb=uA(eE);var uY=uA(ch);var vi=new uY();vb.defineProperty(vg,dI,{value:vi});var uJ=uA(dB);var TypeError=vg.TypeError=uJ.TypeError;vg.RangeError=uJ.RangeError;var uX=vg.CancellationError=uJ.CancellationError;vg.TimeoutError=uJ.TimeoutError;vg.OperationalError=uJ.OperationalError;vg.RejectionError=uJ.OperationalError;vg.AggregateError=uJ.AggregateError;var vf=function(){};var uO={};var uR={};var uV=uA(bo)(vg,vf);var uK=uA(cF)(vg,vf,uV,vd,uT);var uW=uA(ec)(vg);var uD=uW.create;var vh=uA(bw)(vg,uW);var uE=vh.CapturedTrace;var ve=uA(ck)(vg,uV);var uP=uA(bC)(uR);var uI=uA(cD);var uG=uS.errorObj;var uN=uS.tryCatch;function uH(self,vl){if(typeof vl!==cz){throw new TypeError(cA+uS.classString(vl));};if(self.constructor!==vg){throw new TypeError(cP);};};function vg(vm){this._bitField=0;this._fulfillmentHandler0=undefined;this._rejectionHandler0=undefined;this._promise0=undefined;this._receiver0=undefined;if(vm!==vf){uH(this,vm);this._resolveFromExecutor(vm);};this._promiseCreated();this._fireEvent(bt,this);};vg.prototype.toString=function(){return cT;};vg.prototype.caught=vg.prototype[di]=function(vq){var vo=arguments.length;if(vo>1){var vn=new Array(vo-1),j=0,i;for(i=0;i<vo-1; ++i){var vp=arguments[i];if(uS.isObject(vp)){vn[j++ ]=vp;}else {return vd(ca+uS.classString(vp));};};vn.length=j;vq=arguments[i];return this.then(undefined,uP(vn,vq,this));};return this.then(undefined,vq);};vg.prototype.reflect=function(){return this._then(vc,vc,undefined,this,undefined);};vg.prototype.then=function(vs,vt){if(vh.warnings()&&arguments.length>0&&typeof vs!==cz&&typeof vt!==cz){var vr=dS+uS.classString(vs);if(arguments.length>1){vr+=dq+uS.classString(vt);};this._warn(vr);};return this._then(vs,vt,undefined,undefined,undefined);};vg.prototype.done=function(vv,vw){var vu=this._then(vv,vw,undefined,undefined,undefined);vu._setIsFinal();};vg.prototype.spread=function(vx){if(typeof vx!==cz){return vd(cA+uS.classString(vx));};return this.all()._then(vx,undefined,undefined,uO,undefined);};vg.prototype.toJSON=function(){var vy={isFulfilled:false,isRejected:false,fulfillmentValue:undefined,rejectionReason:undefined};if(this.isFulfilled()){vy.fulfillmentValue=this.value();vy.isFulfilled=true;}else if(this.isRejected()){vy.rejectionReason=this.reason();vy.isRejected=true;};return vy;};vg.prototype.all=function(){if(arguments.length>0){this._warn(cn);};return new uK(this).promise();};vg.prototype.error=function(vz){return this.caught(uS.originatesFromRejection,vz);};vg.getNewLibraryCopy=uC.exports;vg.is=function(vA){return vA instanceof vg;};vg.fromNode=vg.fromCallback=function(vB){var vD=new vg(vf);vD._captureStackTrace();var vE=arguments.length>1?!!Object(arguments[1]).multiArgs:false;var vC=uN(vB)(uI(vD,vE));if(vC===uG){vD._rejectCallback(vC.e,true);};if(!vD._isFateSealed())vD._setAsyncGuaranteed();return vD;};vg.all=function(vF){return new uK(vF).promise();};vg.cast=function(vG){var vH=uV(vG);if(!(vH instanceof vg)){vH=new vg(vf);vH._captureStackTrace();vH._setFulfilled();vH._rejectionHandler0=vG;};return vH;};vg.resolve=vg.fulfilled=vg.cast;vg.reject=vg.rejected=function(vI){var vJ=new vg(vf);vJ._captureStackTrace();vJ._rejectCallback(vI,true);return vJ;};vg.setScheduler=function(vK){if(typeof vK!==cz){throw new TypeError(cA+uS.classString(vK));};return vi.setScheduler(vK);};vg.prototype._then=function(vM,vN,_,vV,vP){var vS=vP!==undefined;var vU=vS?vP:new vg(vf);var vW=this._target();var vR=vW._bitField;if(!vS){vU._propagateFrom(this,3);vU._captureStackTrace();if(vV===undefined&&((this._bitField&2097152)!==0)){if(!((vR&50397184)===0)){vV=this._boundValue();}else {vV=vW===this?undefined:this._boundTo;};};this._fireEvent(ce,this,vU);};var vL=va();if(!((vR&50397184)===0)){var vT,vQ,vO=vW._settlePromiseCtx;if(((vR&33554432)!==0)){vQ=vW._rejectionHandler0;vT=vM;}else if(((vR&16777216)!==0)){vQ=vW._fulfillmentHandler0;vT=vN;vW._unsetRejectionIsUnhandled();}else {vO=vW._settlePromiseLateCancellationObserver;vQ=new uX(cI);vW._attachExtraTrace(vQ);vT=vN;};vi.invoke(vO,vW,{handler:vL===null?vT:(typeof vT===cz&&uS.domainBind(vL,vT)),promise:vU,receiver:vV,value:vQ});}else {vW._addCallbacks(vM,vN,vU,vV,vL);};return vU;};vg.prototype._length=function(){return this._bitField&65535;};vg.prototype._isFateSealed=function(){return (this._bitField&117506048)!==0;};vg.prototype._isFollowing=function(){return (this._bitField&67108864)===67108864;};vg.prototype._setLength=function(vX){this._bitField=(this._bitField&-65536)|(vX&65535);};vg.prototype._setFulfilled=function(){this._bitField=this._bitField|33554432;this._fireEvent(dH,this);};vg.prototype._setRejected=function(){this._bitField=this._bitField|16777216;this._fireEvent(bk,this);};vg.prototype._setFollowing=function(){this._bitField=this._bitField|67108864;this._fireEvent(bq,this);};vg.prototype._setIsFinal=function(){this._bitField=this._bitField|4194304;};vg.prototype._isFinal=function(){return (this._bitField&4194304)>0;};vg.prototype._unsetCancelled=function(){this._bitField=this._bitField&-65537;};vg.prototype._setCancelled=function(){this._bitField=this._bitField|65536;this._fireEvent(dn,this);};vg.prototype._setWillBeCancelled=function(){this._bitField=this._bitField|8388608;};vg.prototype._setAsyncGuaranteed=function(){if(vi.hasCustomScheduler())return;this._bitField=this._bitField|134217728;};vg.prototype._receiverAt=function(vY){var wa=vY===0?this._receiver0:this[vY*4-4+3];if(wa===uU){return undefined;}else if(wa===undefined&&this._isBound()){return this._boundValue();};return wa;};vg.prototype._promiseAt=function(wb){return this[wb*4-4+2];};vg.prototype._fulfillmentHandlerAt=function(wc){return this[wc*4-4+0];};vg.prototype._rejectionHandlerAt=function(wd){return this[wd*4-4+1];};vg.prototype._boundValue=function(){};vg.prototype._migrateCallback0=function(wg){var wf=wg._bitField;var wj=wg._fulfillmentHandler0;var wi=wg._rejectionHandler0;var wh=wg._promise0;var we=wg._receiverAt(0);if(we===undefined)we=uU;this._addCallbacks(wj,wi,wh,we,null);};vg.prototype._migrateCallbackAt=function(wm,wk){var wp=wm._fulfillmentHandlerAt(wk);var wo=wm._rejectionHandlerAt(wk);var wn=wm._promiseAt(wk);var wl=wm._receiverAt(wk);if(wl===undefined)wl=uU;this._addCallbacks(wp,wo,wn,wl,null);};vg.prototype._addCallbacks=function(ww,ws,wu,wv,wr){var wq=this._length();if(wq>=65531){wq=0;this._setLength(0);};if(wq===0){this._promise0=wu;this._receiver0=wv;if(typeof ww===cz){this._fulfillmentHandler0=wr===null?ww:uS.domainBind(wr,ww);};if(typeof ws===cz){this._rejectionHandler0=wr===null?ws:uS.domainBind(wr,ws);};}else {var wt=wq*4-4;this[wt+2]=wu;this[wt+3]=wv;if(typeof ww===cz){this[wt+0]=wr===null?ww:uS.domainBind(wr,ww);};if(typeof ws===cz){this[wt+1]=wr===null?ws:uS.domainBind(wr,ws);};};this._setLength(wq+1);return wq;};vg.prototype._proxy=function(wx,wy){this._addCallbacks(undefined,undefined,wy,wx,null);};vg.prototype._resolveCallback=function(wz,wF){if(((this._bitField&117506048)!==0))return;if(wz===this)return this._rejectCallback(uF(),false);var wC=uV(wz,this);if(!(wC instanceof vg))return this._fulfill(wz);if(wF)this._propagateFrom(wC,2);var wD=wC._target();if(wD===this){this._reject(uF());return;};var wA=wD._bitField;if(((wA&50397184)===0)){var wE=this._length();if(wE>0)wD._migrateCallback0(this);for(var i=1;i<wE; ++i){wD._migrateCallbackAt(this,i);};this._setFollowing();this._setLength(0);this._setFollowee(wD);}else if(((wA&33554432)!==0)){this._fulfill(wD._value());}else if(((wA&16777216)!==0)){this._reject(wD._reason());}else {var wB=new uX(cI);wD._attachExtraTrace(wB);this._reject(wB);};};vg.prototype._rejectCallback=function(wJ,wH,wI){var wG=uS.ensureErrorObject(wJ);var wK=wG===wJ;if(!wK&&!wI&&vh.warnings()){var wL=cl+uS.classString(wJ);this._warn(wL,true);};this._attachExtraTrace(wG,wH?wK:false);this._reject(wJ);};vg.prototype._resolveFromExecutor=function(wO){var wM=this;this._captureStackTrace();this._pushContext();var wN=true;var r=this._execute(wO,function(wP){wM._resolveCallback(wP);},function(wQ){wM._rejectCallback(wQ,wN);});wN=false;this._popContext();if(r!==undefined){wM._rejectCallback(r,true);};};vg.prototype._settlePromiseFromHandler=function(wU,wW,wS,wV){var wT=wV._bitField;if(((wT&65536)!==0))return;wV._pushContext();var x;if(wW===uO){if(!wS||typeof wS.length!==bb){x=uG;x.e=new TypeError(F+uS.classString(wS));}else {x=uN(wU).apply(this._boundValue(),wS);};}else {x=uN(wU).call(wW,wS);};var wR=wV._popContext();wT=wV._bitField;if(((wT&65536)!==0))return;if(x===uR){wV._reject(wS);}else if(x===uG){wV._rejectCallback(x.e,false);}else {vh.checkForgottenReturns(x,wR,eq,wV,this);wV._resolveCallback(x);};};vg.prototype._target=function(){var wX=this;while(wX._isFollowing())wX=wX._followee();return wX;};vg.prototype._followee=function(){return this._rejectionHandler0;};vg.prototype._setFollowee=function(wY){this._rejectionHandler0=wY;};vg.prototype._settlePromise=function(xf,xe,xg,xb){var xd=xf instanceof vg;var xc=this._bitField;var xa=((xc&134217728)!==0);if(((xc&65536)!==0)){if(xd)xf._invokeInternalOnCancel();if(xg instanceof ve&&xg.isFinallyHandler()){xg.cancelPromise=xf;if(uN(xe).call(xg,xb)===uG){xf._reject(uG.e);};}else if(xe===vc){xf._fulfill(vc.call(xg));}else if(xg instanceof uT){xg._promiseCancelled(xf);}else if(xd||xf instanceof uK){xf._cancel();}else {xg.cancel();};}else if(typeof xe===cz){if(!xd){xe.call(xg,xb,xf);}else {if(xa)xf._setAsyncGuaranteed();this._settlePromiseFromHandler(xe,xg,xb,xf);};}else if(xg instanceof uT){if(!xg._isResolved()){if(((xc&33554432)!==0)){xg._promiseFulfilled(xb,xf);}else {xg._promiseRejected(xb,xf);};};}else if(xd){if(xa)xf._setAsyncGuaranteed();if(((xc&33554432)!==0)){xf._fulfill(xb);}else {xf._reject(xb);};};};vg.prototype._settlePromiseLateCancellationObserver=function(xj){var xi=xj.handler;var xh=xj.promise;var xl=xj.receiver;var xk=xj.value;if(typeof xi===cz){if(!(xh instanceof vg)){xi.call(xl,xk,xh);}else {this._settlePromiseFromHandler(xi,xl,xk,xh);};}else if(xh instanceof vg){xh._reject(xk);};};vg.prototype._settlePromiseCtx=function(xm){this._settlePromise(xm.promise,xm.handler,xm.receiver,xm.value);};vg.prototype._settlePromise0=function(xn,xq,xr){var xo=this._promise0;var xp=this._receiverAt(0);this._promise0=undefined;this._receiver0=undefined;this._settlePromise(xo,xn,xp,xq);};vg.prototype._clearCallbackDataAtIndex=function(xs){var xt=xs*4-4;this[xt+2]=this[xt+3]=this[xt+0]=this[xt+1]=undefined;};vg.prototype._fulfill=function(xu){var xw=this._bitField;if(((xw&117506048)>>>16))return;if(xu===this){var xv=uF();this._attachExtraTrace(xv);return this._reject(xv);};this._setFulfilled();this._rejectionHandler0=xu;if((xw&65535)>0){if(((xw&134217728)!==0)){this._settlePromises();}else {vi.settlePromises(this);};};};vg.prototype._reject=function(xx){var xy=this._bitField;if(((xy&117506048)>>>16))return;this._setRejected();this._fulfillmentHandler0=xx;if(this._isFinal()){return vi.fatalError(xx,uS.isNode);};if((xy&65535)>0){vi.settlePromises(this);}else {this._ensurePossibleRejectionHandled();};};vg.prototype._fulfillPromises=function(xz,xC){for(var i=1;i<xz;i++ ){var xA=this._fulfillmentHandlerAt(i);var xB=this._promiseAt(i);var xD=this._receiverAt(i);this._clearCallbackDataAtIndex(i);this._settlePromise(xB,xA,xD,xC);};};vg.prototype._rejectPromises=function(xE,xF){for(var i=1;i<xE;i++ ){var xG=this._rejectionHandlerAt(i);var xH=this._promiseAt(i);var xI=this._receiverAt(i);this._clearCallbackDataAtIndex(i);this._settlePromise(xH,xG,xI,xF);};};vg.prototype._settlePromises=function(){var xM=this._bitField;var xK=(xM&65535);if(xK>0){if(((xM&16842752)!==0)){var xJ=this._fulfillmentHandler0;this._settlePromise0(this._rejectionHandler0,xJ,xM);this._rejectPromises(xK,xJ);}else {var xL=this._rejectionHandler0;this._settlePromise0(this._fulfillmentHandler0,xL,xM);this._fulfillPromises(xK,xL);};this._setLength(0);};this._clearCancellationData();};vg.prototype._settledValue=function(){var xN=this._bitField;if(((xN&33554432)!==0)){return this._rejectionHandler0;}else if(((xN&16777216)!==0)){return this._fulfillmentHandler0;};};function uL(v){this.promise._resolveCallback(v);};function uM(v){this.promise._rejectCallback(v,false);};vg.defer=vg.pending=function(){vh.deprecated(ed,g);var xO=new vg(vf);return {promise:xO,resolve:uL,reject:uM};};uS.notEnumerableProp(vg,X,uF);uA(eg)(vg,vf,uV,vd,vh);uA(ez)(vg,vf,uV,vh);uA(bR)(vg,uK,vd,vh);uA(dV)(vg);uA(dG)(vg);uA(dL)(vg,uK,uV,vf,vi,va);vg.Promise=vg;vg.version=eK;uA(dW)(vg,uK,vd,uV,vf,vh);uA(bU)(vg);uA(dp)(vg,vd,uV,uD,vf,vh);uA(b)(vg,vf,vh);uA(bf)(vg,vd,vf,uV,uT,vh);uA(bQ)(vg);uA(bB)(vg,vf);uA(eO)(vg,uK,uV,vd);uA(bH)(vg,vf,uV,vd);uA(ef)(vg,uK,vd,uV,vf,vh);uA(et)(vg,uK,vh);uA(eL)(vg,uK,vd);uA(cR)(vg,vf);uA(bP)(vg,vf);uA(bp)(vg);uS.toFastProperties(vg);uS.toFastProperties(vg.prototype);function uQ(xP){var p=new vg(vf);p._fulfillmentHandler0=xP;p._rejectionHandler0=xP;p._promise0=xP;p._receiver0=xP;};uQ({a:1});uQ({b:2});uQ({c:3});uQ(1);uQ(function(){});uQ(undefined);uQ(false);uQ(new vg(vf));vh.setBounds(uY.firstLineError,uS.lastLineError);return vg;};},{"./any.js":1,"./async":2,"./bind":3,"./call_get.js":5,"./cancel":6,"./catch_filter":7,"./context":8,"./debuggability":9,"./direct_resolve":10,"./each.js":11,"./errors":12,"./es5":13,"./filter.js":14,"./finally":15,"./generators.js":16,"./join":17,"./map.js":18,"./method":19,"./nodeback":20,"./nodeify.js":21,"./promise_array":23,"./promisify.js":24,"./props.js":25,"./race.js":27,"./reduce.js":28,"./settle.js":30,"./some.js":31,"./synchronous_inspection":32,"./thenables":33,"./timers.js":34,"./using.js":35,"./util":36}],'23':[function(xQ,xS,xR){A;xS.exports=function(yb,ya,yc,xU,xY){var xX=xQ(dt);var xT=xX.isArray;function xV(yd){switch(yd){case -2:return [];case -3:return {};};};function xW(ye){var yf=this._promise=new yb(ya);if(ye instanceof yb){yf._propagateFrom(ye,3);};yf._setOnCancel(this);this._values=ye;this._length=0;this._totalResolved=0;this._init(undefined,-2);};xX.inherits(xW,xY);xW.prototype.length=function(){return this._length;};xW.prototype.promise=function(){return this._promise;};xW.prototype._init=function yi(_,yk){var yj=yc(this._values,this._promise);if(yj instanceof yb){yj=yj._target();var yh=yj._bitField;;this._values=yj;if(((yh&50397184)===0)){this._promise._setAsyncGuaranteed();return yj._then(yi,this._reject,undefined,this,yk);}else if(((yh&33554432)!==0)){yj=yj._value();}else if(((yh&16777216)!==0)){return this._reject(yj._reason());}else {return this._cancel();};};yj=xX.asArray(yj);if(yj===null){var yg=xU(ei+xX.classString(yj)).reason();this._promise._rejectCallback(yg,false);return;};if(yj.length===0){if(yk===-5){this._resolveEmptyArray();}else {this._resolve(xV(yk));};return;};this._iterate(yj);};xW.prototype._iterate=function(yo){var yl=this.getActualLength(yo.length);this._length=yl;this._values=this.shouldCopyValues()?new Array(yl):this._values;var yp=this._promise;var yq=false;var ym=null;for(var i=0;i<yl; ++i){var yn=yc(yo[i],yp);if(yn instanceof yb){yn=yn._target();ym=yn._bitField;}else {ym=null;};if(yq){if(ym!==null){yn.suppressUnhandledRejections();};}else if(ym!==null){if(((ym&50397184)===0)){yn._proxy(this,i);this._values[i]=yn;}else if(((ym&33554432)!==0)){yq=this._promiseFulfilled(yn._value(),i);}else if(((ym&16777216)!==0)){yq=this._promiseRejected(yn._reason(),i);}else {yq=this._promiseCancelled(i);};}else {yq=this._promiseFulfilled(yn,i);};};if(!yq)yp._setAsyncGuaranteed();};xW.prototype._isResolved=function(){return this._values===null;};xW.prototype._resolve=function(yr){this._values=null;this._promise._fulfill(yr);};xW.prototype._cancel=function(){if(this._isResolved()||!this._promise._isCancellable())return;this._values=null;this._promise._cancel();};xW.prototype._reject=function(ys){this._values=null;this._promise._rejectCallback(ys,false);};xW.prototype._promiseFulfilled=function(yv,yt){this._values[yt]=yv;var yu= ++this._totalResolved;if(yu>=this._length){this._resolve(this._values);return true;};return false;};xW.prototype._promiseCancelled=function(){this._cancel();return true;};xW.prototype._promiseRejected=function(yw){this._totalResolved++ ;this._reject(yw);return true;};xW.prototype._resultCancelled=function(){if(this._isResolved())return;var yx=this._values;this._cancel();if(yx instanceof yb){yx.cancel();}else {for(var i=0;i<yx.length; ++i){if(yx[i] instanceof yb){yx[i].cancel();};};};};xW.prototype.shouldCopyValues=function(){return true;};xW.prototype.getActualLength=function(yy){return yy;};return xW;};},{"./util":36}],'24':[function(yz,yB,yA){A;yB.exports=function(ze,zd){var za={};var yU=yz(dt);var yJ=yz(cD);var yM=yU.withAppended;var yQ=yU.maybeWrapAsError;var yY=yU.canEvaluate;var TypeError=yz(dB).TypeError;var yI=ej;var yT={__vn:true};var yW=[bF,dX,dR,dd,h,bL,E,cv];var yO=new RegExp(ek+yW.join(dC)+dM);var yK=function(name){return yU.isIdentifier(name)&&name.charAt(0)!==dh&&name!==k;};function yD(zf){return !yO.test(zf);};function yC(zg){try{return zg.__vn===true;}catch(e){return false;};};function yN(zi,zh,zj){var zk=yU.getDataPropertyOrDefault(zi,zh+zj,yT);return zk?yC(zk):false;};function yF(zn,zl,zo){for(var i=0;i<zn.length;i+=2){var zp=zn[i];if(zo.test(zp)){var zm=zp.replace(zo,eq);for(var j=0;j<zn.length;j+=2){if(zn[j]===zm){throw new TypeError(cf.replace(es,zl));};};};};};function yR(zr,zs,zq,zv){var zt=yU.inheritedDataKeys(zr);var zu=[];for(var i=0;i<zt.length; ++i){var zx=zt[i];var zw=zr[zx];var zy=zv===yK?true:yK(zx,zw,zr);if(typeof zw===cz&&!yC(zw)&&!yN(zr,zx,zs)&&zv(zx,zw,zr,zy)){zu.push(zx,zw);};};yF(zu,zs,zq);return zu;};var yH=function(zz){return zz.replace(/([$])/,eN);};var yX;{var zb,yV,yS,yL;};function zc(zD,zF,_,zE,zA,zC){var zG=(function(){return this;})();var zH=zD;if(typeof zH===bI){zD=zE;};function zB(){var zI=zF;if(zF===za)zI=this;var zJ=new ze(zd);zJ._captureStackTrace();var zL=typeof zH===bI&&this!==zG?this[zH]:zD;var zK=yJ(zJ,zC);try{zL.apply(zI,yM(arguments,zK));}catch(e){zJ._rejectCallback(yQ(e),true,true);};if(!zJ._isFateSealed())zJ._setAsyncGuaranteed();return zJ;};yU.notEnumerableProp(zB,cv,true);return zB;};var yE=yY?yX:zc;function yG(zN,zO,zM,zS,zV){var zQ=new RegExp(yH(zO)+eo);var zX=yR(zN,zO,zQ,zM);for(var i=0,zP=zX.length;i<zP;i+=2){var zU=zX[i];var zT=zX[i+1];var zW=zU+zO;if(zS===yE){zN[zW]=yE(zU,za,zU,zT,zO,zV);}else {var zR=zS(zT,function(){return yE(zU,za,zU,zT,zO,zV);});yU.notEnumerableProp(zR,cv,true);zN[zW]=zR;};};yU.toFastProperties(zN);return zN;};function yP(zY,Ab,Aa){return yE(zY,Ab,undefined,zY,null,Aa);};ze.promisify=function(Ac,Ae){if(typeof Ac!==cz){throw new TypeError(cA+yU.classString(Ac));};if(yC(Ac)){return Ac;};Ae=Object(Ae);var Ag=Ae.context===undefined?za:Ae.context;var Ad=!!Ae.multiArgs;var Af=yP(Ac,Ag,Ad);yU.copyDescriptors(Ac,Af,yD);return Af;};ze.promisifyAll=function(Ao,Am){if(typeof Ao!==cz&&typeof Ao!==dO){throw new TypeError(db);};Am=Object(Am);var Ak=!!Am.multiArgs;var Ah=Am.suffix;if(typeof Ah!==bI)Ah=yI;var Al=Am.filter;if(typeof Al!==cz)Al=yK;var An=Am.promisifier;if(typeof An!==cz)An=yE;if(!yU.isIdentifier(Ah)){throw new RangeError(cO);};var Ai=yU.inheritedDataKeys(Ao);for(var i=0;i<Ai.length; ++i){var Aj=Ao[Ai[i]];if(Ai[i]!==k&&yU.isClass(Aj)){yG(Aj.prototype,Ah,Al,An,Ak);yG(Aj,Ah,Al,An,Ak);};};return yG(Ao,Ah,Al,An,Ak);};};},{"./errors":12,"./nodeback":20,"./util":36}],'25':[function(Ap,Ar,Aq){A;Ar.exports=function(Ay,At,Az,Ax){var Aw=Ap(dt);var AD=Aw.isObject;var As=Ap(eE);var AA;if(typeof Map===cz)AA=Map;var Av=(function(){var AE=0;var AF=0;function AG(AH,AI){this[AE]=AH;this[AE+AF]=AI;AE++ ;};return function AL(AJ){AF=AJ.size;AE=0;var AK=new Array(AJ.size*2);AJ.forEach(AG,AK);return AK;};})();var AC=function(AP){var AM=new AA();var length=AP.length/2|0;for(var i=0;i<length; ++i){var AO=AP[length+i];var AN=AP[i];AM.set(AO,AN);};return AM;};function Au(AQ){var AT=false;var AV;if(AA!==undefined&&AQ instanceof AA){AV=Av(AQ);AT=true;}else {var AR=As.keys(AQ);var AS=AR.length;AV=new Array(AS*2);for(var i=0;i<AS; ++i){var AU=AR[i];AV[i]=AQ[AU];AV[i+AS]=AU;};};this.constructor$(AV);this._isMap=AT;this._init$(undefined,-3);};Aw.inherits(Au,At);Au.prototype._init=function(){};Au.prototype._promiseFulfilled=function(Bb,AW){this._values[AW]=Bb;var AX= ++this._totalResolved;if(AX>=this._length){var AY;if(this._isMap){AY=AC(this._values);}else {AY={};var Bc=this.length();for(var i=0,Ba=this.length();i<Ba; ++i){AY[this._values[i+Bc]]=this._values[i];};};this._resolve(AY);return true;};return false;};Au.prototype.shouldCopyValues=function(){return false;};Au.prototype.getActualLength=function(Bd){return Bd>>1;};function AB(Be){var Bg;var Bf=Az(Be);if(!AD(Bf)){return Ax(q);}else if(Bf instanceof Ay){Bg=Bf._then(Ay.props,undefined,undefined,undefined,undefined);}else {Bg=new Au(Bf).promise();};if(Bf instanceof Ay){Bg._propagateFrom(Bf,2);};return Bg;};Ay.prototype.props=function(){return AB(this);};Ay.props=function(Bh){return AB(Bh);};};},{"./es5":13,"./util":36}],'26':[function(Bj,Bl,Bk){A;function Bm(Bn,Br,Bo,Bq,Bp){for(var j=0;j<Bp; ++j){Bo[j+Bq]=Bn[j+Br];Bn[j+Br]=void 0;};};function Bi(Bs){this._capacity=Bs;this._length=0;this._front=0;};Bi.prototype._willBeOverCapacity=function(Bt){return this._capacity<Bt;};Bi.prototype._pushOne=function(Bu){var length=this.length();this._checkCapacity(length+1);var i=(this._front+length)&(this._capacity-1);this[i]=Bu;this._length=length+1;};Bi.prototype._unshiftOne=function(Bx){var Bw=this._capacity;this._checkCapacity(this.length()+1);var Bv=this._front;var i=((((Bv-1)&(Bw-1))^Bw)-Bw);this[i]=Bx;this._front=i;this._length=this.length()+1;};Bi.prototype.unshift=function(Bz,By,BA){this._unshiftOne(BA);this._unshiftOne(By);this._unshiftOne(Bz);};Bi.prototype.push=function(BE,BC,BD){var length=this.length()+3;if(this._willBeOverCapacity(length)){this._pushOne(BE);this._pushOne(BC);this._pushOne(BD);return;};var j=this._front+length-3;this._checkCapacity(length);var BB=this._capacity-1;this[(j+0)&BB]=BE;this[(j+1)&BB]=BC;this[(j+2)&BB]=BD;this._length=length;};Bi.prototype.shift=function(){var BF=this._front,BG=this[BF];this[BF]=undefined;this._front=(BF+1)&(this._capacity-1);this._length-- ;return BG;};Bi.prototype.length=function(){return this._length;};Bi.prototype._checkCapacity=function(BH){if(this._capacity<BH){this._resizeTo(this._capacity<<1);};};Bi.prototype._resizeTo=function(BK){var BL=this._capacity;this._capacity=BK;var BI=this._front;var length=this._length;var BJ=(BI+length)&(BL-1);Bm(this,0,this,BL,BJ);};Bl.exports=Bi;},{}],'27':[function(BM,BO,BN){A;BO.exports=function(BT,BP,BU,BR){var BQ=BM(dt);var BV=function(BW){return BW.then(function(BX){return BS(BX,BW);});};function BS(BY,parent){var Cc=BU(BY);if(Cc instanceof BT){return BV(Cc);}else {BY=BQ.asArray(BY);if(BY===null)return BR(ei+BQ.classString(BY));};var Cb=new BT(BP);if(parent!==undefined){Cb._propagateFrom(parent,3);};var Cf=Cb._fulfill;var Ce=Cb._reject;for(var i=0,Cd=BY.length;i<Cd; ++i){var Ca=BY[i];if(Ca===undefined&&!(i in BY)){continue;};BT.cast(Ca)._then(Cf,Ce,undefined,Cb,null);};return Cb;};BT.race=function(Cg){return BS(Cg,undefined);};BT.prototype.race=function(){return BS(this,undefined);};};},{"./util":36}],'28':[function(Ch,Cj,Ci){A;Cj.exports=function(Cs,Cm,Cq,Ct,Cr,Cu){var Ck=Cs._getDomain;var Cp=Ch(dt);var Cv=Cp.tryCatch;function Cl(CC,Cy,CA,CB){this.constructor$(CC);var Cz=Ck();this._fn=Cz===null?Cy:Cp.domainBind(Cz,Cy);if(CA!==undefined){CA=Cs.resolve(CA);CA._attachCancellationCallback(this);};this._initialValue=CA;this._currentCancellable=null;if(CB===Cr){this._eachValues=Array(this._length);}else if(CB===0){this._eachValues=null;}else {this._eachValues=undefined;};this._promise._captureStackTrace();this._init$(undefined,-5);};Cp.inherits(Cl,Cm);Cl.prototype._gotAccum=function(CD){if(this._eachValues!==undefined&&this._eachValues!==null&&CD!==Cr){this._eachValues.push(CD);};};Cl.prototype._eachComplete=function(CE){if(this._eachValues!==null){this._eachValues.push(CE);};return this._eachValues;};Cl.prototype._init=function(){};Cl.prototype._resolveEmptyArray=function(){this._resolve(this._eachValues!==undefined?this._eachValues:this._initialValue);};Cl.prototype.shouldCopyValues=function(){return false;};Cl.prototype._resolve=function(CF){this._promise._resolveCallback(CF);this._values=null;};Cl.prototype._resultCancelled=function(CG){if(CG===this._initialValue)return this._cancel();if(this._isResolved())return;this._resultCancelled$();if(this._currentCancellable instanceof Cs){this._currentCancellable.cancel();};if(this._initialValue instanceof Cs){this._initialValue.cancel();};};Cl.prototype._iterate=function(CH){this._values=CH;var CJ;var i;var length=CH.length;if(this._initialValue!==undefined){CJ=this._initialValue;i=0;}else {CJ=Cs.resolve(CH[0]);i=1;};this._currentCancellable=CJ;if(!CJ.isRejected()){for(;i<length; ++i){var CI={accum:null,value:CH[i],index:i,length:length,array:this};CJ=CJ._then(Co,undefined,undefined,CI,undefined);};};if(this._eachValues!==undefined){CJ=CJ._then(this._eachComplete,undefined,undefined,this,undefined);};CJ._then(Cw,Cw,undefined,CJ,this);};Cs.prototype.reduce=function(CL,CK){return Cn(this,CL,CK,null);};Cs.reduce=function(CM,CP,CN,CO){return Cn(CM,CP,CN,CO);};function Cw(CQ,CR){if(this.isFulfilled()){CR._resolve(CQ);}else {CR._reject(CQ);};};function Cn(CS,CV,CT,CW){if(typeof CV!==cz){return Cq(cA+Cp.classString(CV));};var CU=new Cl(CS,CV,CT,CW);return CU.promise();};function Co(CX){this.accum=CX;this.array._gotAccum(CX);var CY=Ct(this.value,this.array._promise);if(CY instanceof Cs){this.array._currentCancellable=CY;return CY._then(Cx,undefined,undefined,this,undefined);}else {return Cx.call(this,CY);};};function Cx(Dd){var De=this.array;var Dc=De._promise;var Df=Cv(De._fn);Dc._pushContext();var Db;if(De._eachValues!==undefined){Db=Df.call(Dc._boundValue(),Dd,this.index,this.length);}else {Db=Df.call(Dc._boundValue(),this.accum,Dd,this.index,this.length);};if(Db instanceof Cs){De._currentCancellable=Db;};var Da=Dc._popContext();Cu.checkForgottenReturns(Db,Da,De._eachValues!==undefined?en:by,Dc);return Db;};};},{"./util":36}],'29':[function(Do,Dk,Dh){A;var Dg=Do(dt);var Dj;var Dm=function(){throw new Error(Y);};var Di=Dg.getNativePromise();if(Dg.isNode&&typeof MutationObserver===eR){var Dn=global.setImmediate;var Dl=process.nextTick;Dj=Dg.isRecentNode?function(Dq){Dn.call(global,Dq);}:function(Dr){Dl.call(process,Dr);};}else if(typeof Di===cz&&typeof Di.resolve===cz){var Dp=Di.resolve();Dj=function(Ds){Dp.then(Ds);};}else if((typeof MutationObserver!==eR)&&!(typeof window!==eR&&window.navigator&&(window.navigator.standalone||window.cordova))){Dj=(function(){var Dw=document.createElement(C);var Dy={attributes:true};var Dt=false;var Dx=document.createElement(C);var Du=new MutationObserver(function(){Dw.classList.toggle(cy);Dt=false;});Du.observe(Dx,Dy);var Dv=function(){if(Dt)return;Dt=true;Dx.classList.toggle(cy);};return function DA(Dz){var o=new MutationObserver(function(){o.disconnect();Dz();});o.observe(Dw,Dy);Dv();};})();}else if(typeof setImmediate!==eR){Dj=function(DB){setImmediate(DB);};}else if(typeof setTimeout!==eR){Dj=function(DC){setTimeout(DC,0);};}else {Dj=Dm;};Dk.exports=Dj;},{"./util":36}],'30':[function(DD,DF,DE){A;DF.exports=function(DK,DH,DL){var DG=DK.PromiseInspection;var DJ=DD(dt);function DI(DM){this.constructor$(DM);};DJ.inherits(DI,DH);DI.prototype._promiseResolved=function(DN,DP){this._values[DN]=DP;var DO= ++this._totalResolved;if(DO>=this._length){this._resolve(this._values);return true;};return false;};DI.prototype._promiseFulfilled=function(DR,DQ){var DS=new DG();DS._bitField=33554432;DS._settledValueField=DR;return this._promiseResolved(DQ,DS);};DI.prototype._promiseRejected=function(DU,DT){var DV=new DG();DV._bitField=16777216;DV._settledValueField=DU;return this._promiseResolved(DT,DV);};DK.settle=function(DW){DL.deprecated(cJ,cS);return new DI(DW).promise();};DK.prototype.settle=function(){return DK.settle(this);};};},{"./util":36}],'31':[function(DX,Ea,DY){A;Ea.exports=function(Eh,Ed,Eg){var Ef=DX(dt);var RangeError=DX(dB).RangeError;var Ec=DX(dB).AggregateError;var Eb=Ef.isArray;var Ei={};function Ej(Ek){this.constructor$(Ek);this._howMany=0;this._unwrap=false;this._initialized=false;};Ef.inherits(Ej,Ed);Ej.prototype._init=function(){if(!this._initialized){return;};if(this._howMany===0){this._resolve([]);return;};this._init$(undefined,-5);var El=Eb(this._values);if(!this._isResolved()&&El&&this._howMany>this._canPossiblyFulfill()){this._reject(this._getRangeError(this.length()));};};Ej.prototype.init=function(){this._initialized=true;this._init();};Ej.prototype.setUnwrap=function(){this._unwrap=true;};Ej.prototype.howMany=function(){return this._howMany;};Ej.prototype.setHowMany=function(Em){this._howMany=Em;};Ej.prototype._promiseFulfilled=function(En){this._addFulfilled(En);if(this._fulfilled()===this.howMany()){this._values.length=this.howMany();if(this.howMany()===1&&this._unwrap){this._resolve(this._values[0]);}else {this._resolve(this._values);};return true;};return false;};Ej.prototype._promiseRejected=function(Eo){this._addRejected(Eo);return this._checkOutcome();};Ej.prototype._promiseCancelled=function(){if(this._values instanceof Eh||this._values==null){return this._cancel();};this._addRejected(Ei);return this._checkOutcome();};Ej.prototype._checkOutcome=function(){if(this.howMany()>this._canPossiblyFulfill()){var e=new Ec();for(var i=this.length();i<this._values.length; ++i){if(this._values[i]!==Ei){e.push(this._values[i]);};};if(e.length>0){this._reject(e);}else {this._cancel();};return true;};return false;};Ej.prototype._fulfilled=function(){return this._totalResolved;};Ej.prototype._rejected=function(){return this._values.length-this.length();};Ej.prototype._addRejected=function(Ep){this._values.push(Ep);};Ej.prototype._addFulfilled=function(Eq){this._values[this._totalResolved++ ]=Eq;};Ej.prototype._canPossiblyFulfill=function(){return this.length()-this._rejected();};Ej.prototype._getRangeError=function(Er){var Es=bh+this._howMany+P+Er+N;return new RangeError(Es);};Ej.prototype._resolveEmptyArray=function(){this._reject(this._getRangeError(0));};function Ee(Eu,Et){if((Et|0)!==Et||Et<0){return Eg(dA);};var Ew=new Ej(Eu);var Ev=Ew.promise();Ew.setHowMany(Et);Ew.init();return Ev;};Eh.some=function(Ex,Ey){return Ee(Ex,Ey);};Eh.prototype.some=function(Ez){return Ee(this,Ez);};Eh._SomePromiseArray=Ej;};},{"./errors":12,"./util":36}],'32':[function(EA,EC,EB){A;EC.exports=function(EI){function ED(EL){if(EL!==undefined){EL=EL._target();this._bitField=EL._bitField;this._settledValueField=EL._isFateSealed()?EL._settledValue():undefined;}else {this._bitField=0;this._settledValueField=undefined;};};ED.prototype._settledValue=function(){return this._settledValueField;};var EF=ED.prototype.value=function(){if(!this.isFulfilled()){throw new TypeError(ev);};return this._settledValue();};var EG=ED.prototype.error=ED.prototype.reason=function(){if(!this.isRejected()){throw new TypeError(bK);};return this._settledValue();};var EJ=ED.prototype.isFulfilled=function(){return (this._bitField&33554432)!==0;};var EH=ED.prototype.isRejected=function(){return (this._bitField&16777216)!==0;};var EE=ED.prototype.isPending=function(){return (this._bitField&50397184)===0;};var EK=ED.prototype.isResolved=function(){return (this._bitField&50331648)!==0;};ED.prototype.isCancelled=function(){return (this._bitField&8454144)!==0;};EI.prototype.__vo=function(){return (this._bitField&65536)===65536;};EI.prototype._isCancelled=function(){return this._target().__vo();};EI.prototype.isCancelled=function(){return (this._target()._bitField&8454144)!==0;};EI.prototype.isPending=function(){return EE.call(this._target());};EI.prototype.isRejected=function(){return EH.call(this._target());};EI.prototype.isFulfilled=function(){return EJ.call(this._target());};EI.prototype.isResolved=function(){return EK.call(this._target());};EI.prototype.value=function(){return EF.call(this._target());};EI.prototype.reason=function(){var EM=this._target();EM._unsetRejectionIsUnhandled();return EG.call(EM);};EI.prototype._value=function(){return this._settledValue();};EI.prototype._reason=function(){this._unsetRejectionIsUnhandled();return this._settledValue();};EI.PromiseInspection=ED;};},{}],'33':[function(EN,EP,EO){A;EP.exports=function(Fa,EU){var ET=EN(dt);var EX=ET.errorObj;var Fb=ET.isObject;function EW(Fd,Fe){if(Fb(Fd)){if(Fd instanceof Fa)return Fd;var Fc=EQ(Fd);if(Fc===EX){if(Fe)Fe._pushContext();var Ff=Fa.reject(Fc.e);if(Fe)Fe._popContext();return Ff;}else if(typeof Fc===cz){if(ES(Fd)){var Ff=new Fa(EU);Fd._then(Ff._fulfill,Ff._reject,undefined,Ff,null);return Ff;};return EY(Fd,Fc,Fe);};};return Fd;};function ER(Fg){return Fg.then;};function EQ(Fh){try{return ER(Fh);}catch(e){EX.e=e;return EX;};};var EV={}.hasOwnProperty;function ES(Fi){try{return EV.call(Fi,dU);}catch(e){return false;};};function EY(x,Fj,Fp){var Fn=new Fa(EU);var Fm=Fn;if(Fp)Fp._pushContext();Fn._captureStackTrace();if(Fp)Fp._popContext();var Fl=true;var Fo=ET.tryCatch(Fj).call(x,Fk,Fq);Fl=false;if(Fn&&Fo===EX){Fn._rejectCallback(Fo.e,true,true);Fn=null;};function Fk(Fr){if(!Fn)return;Fn._resolveCallback(Fr);Fn=null;};function Fq(Fs){if(!Fn)return;Fn._rejectCallback(Fs,Fl,true);Fn=null;};return Fm;};return EW;};},{"./util":36}],'34':[function(Ft,Fv,Fu){A;Fv.exports=function(FD,FC,FB){var Fw=Ft(dt);var Fx=FD.TimeoutError;function Fy(FH){this.handle=FH;};Fy.prototype._resultCancelled=function(){clearTimeout(this.handle);};var Fz=function(FI){return FA(+this).thenReturn(FI);};var FA=FD.delay=function(FJ,FM){var FL;var FK;if(FM!==undefined){FL=FD.resolve(FM)._then(Fz,null,null,FJ,undefined);if(FB.cancellation()&&FM instanceof FD){FL._setOnCancel(FM);};}else {FL=new FD(FC);FK=setTimeout(function(){FL._fulfill();},+FJ);if(FB.cancellation()){FL._setOnCancel(new Fy(FK));};FL._captureStackTrace();};FL._setAsyncGuaranteed();return FL;};FD.prototype.delay=function(FN){return FA(FN,this);};var FF=function(FP,FO,parent){var FQ;if(typeof FO!==bI){if(FO instanceof Error){FQ=FO;}else {FQ=new Fx(dw);};}else {FQ=new Fx(FO);};Fw.markAsOriginatingFromRejection(FQ);FP._attachExtraTrace(FQ);FP._reject(FQ);if(parent!=null){parent.cancel();};};function FG(FR){clearTimeout(this.handle);return FR;};function FE(FS){clearTimeout(this.handle);throw FS;};FD.prototype.timeout=function(FT,FU){FT=+FT;var FW,parent;var FV=new Fy(setTimeout(function FX(){if(FW.isPending()){FF(FW,FU,parent);};},FT));if(FB.cancellation()){parent=this.then();FW=parent._then(FG,FE,undefined,FV,undefined);FW._setOnCancel(FV);}else {FW=this._then(FG,FE,undefined,FV,undefined);};return FW;};};},{"./util":36}],'35':[function(FY,Gb,Ga){A;Gb.exports=function(Gn,Gk,Go,Gc,Gm,Gg){var Gj=FY(dt);var TypeError=FY(dB).TypeError;var Gd=FY(dt).inherits;var Gq=Gj.errorObj;var Gt=Gj.tryCatch;var Ge={};function Gl(e){setTimeout(function(){throw e;},0);};function Gr(Gu){var Gv=Go(Gu);if(Gv!==Gu&&typeof Gu._isDisposable===cz&&typeof Gu._getDisposer===cz&&Gu._isDisposable()){Gv._setDisposable(Gu._getDisposer());};return Gv;};function Gi(GA,Gz){var i=0;var Gx=GA.length;var Gy=new Gn(Gm);function Gw(){if(i>=Gx)return Gy._fulfill();var GB=Gr(GA[i++ ]);if(GB instanceof Gn&&GB._isDisposable()){try{GB=Go(GB._getDisposer().tryDispose(Gz),GA.promise);}catch(e){return Gl(e);};if(GB instanceof Gn){return GB._then(Gw,Gl,null,null,null);};};Gw();};Gw();return Gy;};function Gs(GC,GD,GE){this._data=GC;this._promise=GD;this._context=GE;};Gs.prototype.data=function(){return this._data;};Gs.prototype.promise=function(){return this._promise;};Gs.prototype.resource=function(){if(this.promise().isFulfilled()){return this.promise().value();};return Ge;};Gs.prototype.tryDispose=function(GF){var GG=this.resource();var GH=this._context;if(GH!==undefined)GH._pushContext();var GI=GG!==Ge?this.doDispose(GG,GF):null;if(GH!==undefined)GH._popContext();this._promise._unsetDisposable();this._data=null;return GI;};Gs.isDisposer=function(d){return (d!=null&&typeof d.resource===cz&&typeof d.tryDispose===cz);};function Gh(GK,GJ,GL){this.constructor$(GK,GJ,GL);};Gd(Gh,Gs);Gh.prototype.doDispose=function(GM,GN){var GO=this.data();return GO.call(GM,GM,GN);};function Gf(GP){if(Gs.isDisposer(GP)){this.resources[this.index]._setDisposable(GP);return GP.promise();};return GP;};function Gp(length){this.length=length;this.promise=null;this[length-1]=null;};Gp.prototype._resultCancelled=function(){var GR=this.length;for(var i=0;i<GR; ++i){var GQ=this[i];if(GQ instanceof Gn){GQ.cancel();};};};Gn.using=function(){var GU=arguments.length;if(GU<2)return Gk(cj);var GX=arguments[GU-1];if(typeof GX!==cz){return Gk(cA+Gj.classString(GX));};var GY;var GT=true;if(GU===2&&Array.isArray(arguments[0])){GY=arguments[0];GU=GY.length;GT=false;}else {GY=arguments;GU-- ;};var Hc=new Gp(GU);for(var i=0;i<GU; ++i){var Ha=GY[i];if(Gs.isDisposer(Ha)){var Hb=Ha;Ha=Ha.promise();Ha._setDisposable(Hb);}else {var GV=Go(Ha);if(GV instanceof Gn){Ha=GV._then(Gf,null,null,{resources:Hc,index:i},undefined);};};Hc[i]=Ha;};var GS=new Array(Hc.length);for(var i=0;i<GS.length; ++i){GS[i]=Gn.resolve(Hc[i]).reflect();};var Hd=Gn.all(GS).then(function(He){for(var i=0;i<He.length; ++i){var Hg=He[i];if(Hg.isRejected()){Gq.e=Hg.error();return Gq;}else if(!Hg.isFulfilled()){Hd.cancel();return;};He[i]=Hg.value();};GW._pushContext();GX=Gt(GX);var Hh=GT?GX.apply(undefined,He):GX(He);var Hf=GW._popContext();Gg.checkForgottenReturns(Hh,Hf,bY,GW);return Hh;});var GW=Hd.lastly(function(){var Hi=new Gn.PromiseInspection(Hd);return Gi(Hc,Hi);});Hc.promise=GW;GW._setOnCancel(Hc);return GW;};Gn.prototype._setDisposable=function(Hj){this._bitField=this._bitField|131072;this._disposer=Hj;};Gn.prototype._isDisposable=function(){return (this._bitField&131072)>0;};Gn.prototype._getDisposer=function(){return this._disposer;};Gn.prototype._unsetDisposable=function(){this._bitField=this._bitField&-131073;this._disposer=undefined;};Gn.prototype.disposer=function(Hk){if(typeof Hk===cz){return new Gh(Hk,this,Gc());};throw new TypeError();};};},{"./errors":12,"./util":36}],'36':[function(_dereq_,module,exports){A;var es5=_dereq_(eE);var canEvaluate=typeof navigator==eR;var errorObj={e:{}};var tryCatchTarget;var globalObject=typeof self!==eR?self:typeof window!==eR?window:typeof global!==eR?global:this!==undefined?this:null;function tryCatcher(){try{var Hl=tryCatchTarget;tryCatchTarget=null;return Hl.apply(this,arguments);}catch(e){errorObj.e=e;return errorObj;};};function tryCatch(Hm){tryCatchTarget=Hm;return tryCatcher;};var inherits=function(Hp,Ho){var Hn={}.hasOwnProperty;function T(){this.constructor=Hp;this.constructor$=Ho;for(var Hq in Ho.prototype){if(Hn.call(Ho.prototype,Hq)&&Hq.charAt(Hq.length-1)!==eo){this[Hq+eo]=Ho.prototype[Hq];};};};T.prototype=Ho.prototype;Hp.prototype=new T();return Hp.prototype;};function isPrimitive(Hr){return Hr==null||Hr===true||Hr===false||typeof Hr===bI||typeof Hr===bb;};function isObject(Hs){return typeof Hs===cz||typeof Hs===dO&&Hs!==null;};function maybeWrapAsError(Ht){if(!isPrimitive(Ht))return Ht;return new Error(safeToString(Ht));};function withAppended(Hv,Hu){var Hw=Hv.length;var Hx=new Array(Hw+1);var i;for(i=0;i<Hw; ++i){Hx[i]=Hv[i];};Hx[i]=Hu;return Hx;};function getDataPropertyOrDefault(Hz,HA,Hy){if(es5.isES5){var HB=Object.getOwnPropertyDescriptor(Hz,HA);if(HB!=null){return HB.get==null&&HB.set==null?HB.value:Hy;};}else {return {}.hasOwnProperty.call(Hz,HA)?Hz[HA]:undefined;};};function notEnumerableProp(HD,name,HE){if(isPrimitive(HD))return HD;var HC={value:HE,configurable:true,enumerable:false,writable:true};es5.defineProperty(HD,name,HC);return HD;};function thrower(r){throw r;};var inheritedDataKeys=(function(){var HF=[Array.prototype,Object.prototype,Function.prototype];var HI=function(HJ){for(var i=0;i<HF.length; ++i){if(HF[i]===HJ){return true;};};return false;};if(es5.isES5){var HG=Object.getOwnPropertyNames;return function(HK){var HN=[];var HM=Object.create(null);while(HK!=null&&!HI(HK)){var HL;try{HL=HG(HK);}catch(e){return HN;};for(var i=0;i<HL.length; ++i){var HO=HL[i];if(HM[HO])continue;HM[HO]=true;var HP=Object.getOwnPropertyDescriptor(HK,HO);if(HP!=null&&HP.get==null&&HP.set==null){HN.push(HO);};};HK=es5.getPrototypeOf(HK);};return HN;};}else {var HH={}.hasOwnProperty;return function(HQ){if(HI(HQ))return [];var HR=[];enumeration:for(var HS in HQ){if(HH.call(HQ,HS)){HR.push(HS);}else {for(var i=0;i<HF.length; ++i){if(HH.call(HF[i],HS)){continue enumeration;};};HR.push(HS);};};return HR;};};})();var thisAssignmentPattern=/this\s*\.\s*\S+\s*=/;function isClass(HW){try{if(typeof HW===cz){var HT=es5.names(HW.prototype);var HU=es5.isES5&&HT.length>1;var HV=HT.length>0&&!(HT.length===1&&HT[0]===k);var HX=thisAssignmentPattern.test(HW+eq)&&es5.names(HW).length>0;if(HU||HV||HX){return true;};};return false;}catch(e){return false;};};function toFastProperties(obj){function FakeConstructor(){};FakeConstructor.prototype=obj;var l=8;while(l-- )new FakeConstructor();return obj;eval(obj);};var rident=/^[a-z$_][a-z$_0-9]*$/i;function isIdentifier(HY){return rident.test(HY);};function filledRange(Ia,Ib,Ic){var Id=new Array(Ia);for(var i=0;i<Ia; ++i){Id[i]=Ib+i+Ic;};return Id;};function safeToString(Ie){try{return Ie+eq;}catch(e){return bJ;};};function isError(If){return If!==null&&typeof If===dO&&typeof If.message===bI&&typeof If.name===bI;};function markAsOriginatingFromRejection(e){try{notEnumerableProp(e,eT,true);}catch(Ig){};};function originatesFromRejection(e){if(e==null)return false;return ((e instanceof Error[dF].OperationalError)||e[eT]===true);};function canAttachTrace(Ih){return isError(Ih)&&es5.propertyIsWritable(Ih,H);};var ensureErrorObject=(function(){if(!(H in new Error())){return function(Ii){if(canAttachTrace(Ii))return Ii;try{throw new Error(safeToString(Ii));}catch(Ij){return Ij;};};}else {return function(Ik){if(canAttachTrace(Ik))return Ik;return new Error(safeToString(Ik));};};})();function classString(Il){return {}.toString.call(Il);};function copyDescriptors(Im,In,Io){var Ip=es5.names(Im);for(var i=0;i<Ip.length; ++i){var Iq=Ip[i];if(Io(Iq)){try{es5.defineProperty(In,Iq,es5.getDescriptor(Im,Iq));}catch(Ir){};};};};var asArray=function(v){if(es5.isArray(v)){return v;};return null;};if(typeof Symbol!==eR&&Symbol.iterator){var ArrayFrom=typeof Array.from===cz?function(v){return Array.from(v);}:function(v){var Iu=[];var It=v[Symbol.iterator]();var Is;while(!((Is=It.next()).done)){Iu.push(Is.value);};return Iu;};asArray=function(v){if(es5.isArray(v)){return v;}else if(v!=null&&typeof v[Symbol.iterator]===cz){return ArrayFrom(v);};return null;};};var isNode=typeof process!==eR&&classString(process).toLowerCase()===dm;function env(Iv,Iw){return isNode?process.env[Iv]:Iw;};function getNativePromise(){if(typeof Promise===cz){try{var Ix=new Promise(function(){});if({}.toString.call(Ix)===cT){return Promise;};}catch(e){};};};function domainBind(self,Iy){return self.bind(Iy);};var ret={isClass:isClass,isIdentifier:isIdentifier,inheritedDataKeys:inheritedDataKeys,getDataPropertyOrDefault:getDataPropertyOrDefault,thrower:thrower,isArray:es5.isArray,asArray:asArray,notEnumerableProp:notEnumerableProp,isPrimitive:isPrimitive,isObject:isObject,isError:isError,canEvaluate:canEvaluate,errorObj:errorObj,tryCatch:tryCatch,inherits:inherits,withAppended:withAppended,maybeWrapAsError:maybeWrapAsError,toFastProperties:toFastProperties,filledRange:filledRange,toString:safeToString,canAttachTrace:canAttachTrace,ensureErrorObject:ensureErrorObject,originatesFromRejection:originatesFromRejection,markAsOriginatingFromRejection:markAsOriginatingFromRejection,classString:classString,copyDescriptors:copyDescriptors,hasDevTools:typeof chrome!==eR&&chrome&&typeof chrome.loadTimes===cz,isNode:isNode,env:env,global:globalObject,getNativePromise:getNativePromise,domainBind:domainBind};ret.isRecentNode=ret.isNode&&(function(){var Iz=process.versions.node.split(cg).map(Number);return (Iz[0]===0&&Iz[1]>10)||(Iz[0]>0);})();if(ret.isNode)ret.toFastProperties(process);try{throw new Error();}catch(e){ret.lastLineError=e;};module.exports=ret;},{"./es5":13}]},{},[4])(4);});})();})();(function(){var a='_get',b='String',c='-',d='',e='_applyExpression',f='kucken.date.RelativeDate',g=' ',h='_applyFormat',i='+';qx.Class.define(f,{extend:qx.core.Object,statics:{_extensionSet:{'now':1,'today0':1,'today1':1,'week0':1,'week1':1,'month0':1,'month1':1,'year0':1,'year1':1}},properties:{expression:{check:function(v){return qx.lang.Type.isString(v)||qx.lang.Type.isDate(v)||v instanceof this.constructor;},init:d,apply:e},format:{check:b,nullable:true,apply:h}},construct:function(j){qx.core.Object.call(this);if(j){this.setExpression(j);};},members:{_duration:null,_date:null,_format:null,_getNow:function(){return new Date();},_getToday0:function(){var k=this._getNow();k.setHours(0,0,0,0);return k;},_getToday1:function(){var l=this._getNow();l.setHours(23,59,59,999);return l;},_isMondayFirstDay:function(){return !qx.locale.Date.getWeekStart()?0:1;},_getWeek0:function(){var m=this._getNow();if(this._isMondayFirstDay()){m.setDate(m.getDate()-(m.getDay()||7)+1);}else {m.setDate(m.getDate()-m.getDay());};m.setHours(0,0,0,0);return m;},_getWeek1:function(){var n=this._getNow();if(this._isMondayFirstDay()){n.setDate(n.getDate()+(7-(n.getDay()||7)));}else {n.setDate(n.getDate()+(6-n.getDay()));};n.setHours(23,59,59,999);return n;},_getMonth0:function(){var o=this._getNow();return new Date(o.getFullYear(),o.getMonth(),1);},_getMonth1:function(){var p=this._getNow();return new Date(p.getFullYear(),p.getMonth()+1,0,23,59,59,999);},_getYear0:function(){return new Date(this._getNow().getFullYear(),0,1);},_getYear1:function(){return new Date(this._getNow().getFullYear(),11,31,23,59,59,999);},_applyExpression:function(s,q){if(s===this){return;};this._duration=this._date=null;if(qx.lang.Type.isDate(s)){this._date=s;this._date.toISOString();return;}else if(s instanceof this.constructor){this._date=s._date;this._duration=s._duration;this._format=s._format;return;};var w,u=s.lastIndexOf(c),t=s.substring(u).replace(g,d),x=s.lastIndexOf(i),r=s.substring(x).replace(g,d);if(kucken.date.Duration.isDuration(t)){w=s.substring(0,u).trim();this._duration=new kucken.date.Duration(t);}else if(kucken.date.Duration.isDuration(r)){w=s.substring(0,x).trim();this._duration=new kucken.date.Duration(r);}else {w=s;};if(w in this.self(arguments)._extensionSet){this._date=this[a+qx.lang.String.capitalize(w)];}else if(this._format){this._date=this._format.parse(w);}else {this._date=new Date(w);this._date.toISOString();};},_applyFormat:function(z,y){if(y){this._format.dispose();this._format=null;};if(z){this._format=new qx.util.format.DateFormat(z);};},toDate:function(){var A=this._date;if(qx.lang.Type.isFunction(A)){A=A.call(this);};if(this._duration){A=this._duration.asOf(A);};return A;},isAbsolute:function(){return !qx.lang.Type.isFunction(this._date)&&!this._duration;}}});})();(function(){var a='(?:(\\d+(?:[\\.,]\\d{1,3})?)M)?',b='(?:(\\d+(?:[\\.,]\\d{1,3})?)D)?',c='String',d='years',e='',f='seconds',g='(?:(\\d+(?:[\\.,]\\d{1,3})?)W)?',h='sign',i='hours',j='kucken.date.Duration',k='T?',l='minutes',m='Invalid duration string',n='P',o='_applyDuration',p='^(-|\\+)?',q='$',r='months',t='(?:(\\d+(?:[\\.,]\\d{1,3})?)Y)?',u='-',w='Number',x='(?:(\\d+(?:[\\.,]\\d{1,3})?)H)?',y='weeks',z='days',A='(?:(\\d+(?:[\\.,]\\d{1,3})?)S)?';qx.Class.define(j,{extend:qx.core.Object,statics:{_durationRegex:new RegExp([p,n,t,a,g,b,k,x,a,A,q].join(e)),_durationList:[h,d,r,y,z,i,l,f],_defaultAsOfDate:new Date(0),isDuration:function(s){return this._durationRegex.test(s);}},properties:{duration:{check:c,init:e,apply:o},sign:{check:[-1,1],init:1},years:{check:w,init:0},months:{check:w,init:0},weeks:{check:w,init:0},days:{check:w,init:0},hours:{check:w,init:0},minutes:{check:w,init:0},seconds:{check:w,init:0}},construct:function(B){qx.core.Object.call(this);if(B){this.setDuration(B);};},members:{_applyDuration:function(E,C){var D=this.self(arguments)._durationRegex.exec(E);if(!D){throw new Error(m);};this.setSign(D[1]==u?-1:1);this.set(kucken.lang.Object.dict(kucken.lang.Array.zip(this.self(arguments)._durationList.slice(1),D.slice(2).map(function(v){return parseFloat(v)||0;}))));},asOf:function(F){F=new Date(F.valueOf());var G=this.getSign();F.setFullYear(F.getFullYear()+G*this.getYears());F.setMonth(F.getMonth()+G*this.getMonths());F.setDate(F.getDate()+G*this.getWeeks()*7+G*this.getDays());F.setHours(F.getHours()+G*this.getHours());F.setMinutes(F.getMinutes()+G*this.getMinutes());F.setMilliseconds(F.getMilliseconds()+G*this.getSeconds()*1000);return F;},toSeconds:function(H){H=H||this.self(arguments)._defaultAsOfDate;return (this.asOf(H).valueOf()-H.valueOf())/1000;}}});})();(function(){var a='clui.bom.Timezone';qx.Class.define(a,{statics:{get:function(){return Intl.DateTimeFormat().resolvedOptions().timeZone;}}});})();(function(){var a="__vq",b="bottom",c="button",d="qx.event.type.Data",f="lastTab",g="barRight",h="beforeChangeSelection",j="close-button",k="changeSelection",m="bar",n="Index should be less than : ",o="tabview",p="vertical",q="page",r="close",s="_applyBarPosition",t="barLeft",u="top",v="horizontal",w="qx.ui.tabview.TabView",x="right",y="barTop",z="barBottom",A="pane",B="left",C="firstTab";qx.Class.define(w,{extend:qx.ui.core.Widget,implement:qx.ui.core.ISingleSelection,include:[qx.ui.core.MContentPadding],construct:function(E){qx.ui.core.Widget.call(this);this.__vp={top:y,right:g,bottom:z,left:t};this._createChildControl(m);this._createChildControl(A);var D=this.__vq=new qx.ui.form.RadioGroup;D.setWrap(false);D.addListener(k,this._onChangeSelection,this);if(E!=null){this.setBarPosition(E);}else {this.initBarPosition();};},events:{"changeSelection":d},properties:{appearance:{refine:true,init:o},barPosition:{check:[B,x,u,b],init:u,apply:s}},members:{__vq:null,_createChildControlImpl:function(H,G){var F;switch(H){case m:F=new qx.ui.container.SlideBar();F.setZIndex(10);this._add(F);break;case A:F=new qx.ui.container.Stack;F.setZIndex(5);this._add(F,{flex:1});break;};return F||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,H);},_getContentPaddingTarget:function(){return this.getChildControl(A);},add:function(M){{};var I=M.getButton();var J=this.getChildControl(m);var L=this.getChildControl(A);M.exclude();J.add(I);L.add(M);this.__vq.add(I);M.addState(this.__vp[this.getBarPosition()]);M.addState(f);var K=this.getChildren();if(K[0]==M){M.addState(C);}else {K[K.length-2].removeState(f);};M.addListener(r,this._onPageClose,this);},addAt:function(Q,N){{};var S=this.getChildren();if(!(N==null)&&N>S.length){throw new Error(n+S.length);};if(N==null){N=S.length;};var P=Q.getButton();var O=this.getChildControl(m);var R=this.getChildControl(A);Q.exclude();O.addAt(P,N);R.addAt(Q,N);this.__vq.add(P);Q.addState(this.__vp[this.getBarPosition()]);S=this.getChildren();if(N==S.length-1){Q.addState(f);};if(S[0]==Q){Q.addState(C);}else {S[S.length-2].removeState(f);};Q.addListener(r,this._onPageClose,this);},remove:function(W){var X=this.getChildControl(A);var U=this.getChildControl(m);var V=W.getButton();var Y=X.getChildren();if(this.getSelection()[0]==W){var T=Y.indexOf(W);if(T==0){if(Y[1]){this.setSelection([Y[1]]);}else {this.resetSelection();};}else {this.setSelection([Y[T-1]]);};};U.remove(V);X.remove(W);this.__vq.remove(V);W.removeState(this.__vp[this.getBarPosition()]);if(W.hasState(C)){W.removeState(C);if(Y[0]){Y[0].addState(C);};};if(W.hasState(f)){W.removeState(f);if(Y.length>0){Y[Y.length-1].addState(f);};};W.removeListener(r,this._onPageClose,this);},getChildren:function(){return this.getChildControl(A).getChildren();},indexOf:function(ba){return this.getChildControl(A).indexOf(ba);},__vp:null,_applyBarPosition:function(be,bg){var bb=this.getChildControl(m);var bh=this.getChildControl(A);var bj=be==B||be==x;var bk=be==x||be==b;var bi=bj?qx.ui.layout.HBox:qx.ui.layout.VBox;var bl=this._getLayout();if(bl&&bl instanceof bi){}else {this._setLayout(bl=new bi);};bl.setReversed(bk);bb.setOrientation(bj?p:v);var bf=this.getChildren();var i,l;if(bg){var bd=this.__vp[bg];bb.removeState(bd);bh.removeState(bd);for(i=0,l=bf.length;i<l;i++ ){bf[i].removeState(bd);};};if(be){var bc=this.__vp[be];bb.addState(bc);bh.addState(bc);for(i=0,l=bf.length;i<l;i++ ){bf[i].addState(bc);};};},getSelection:function(){var bm=this.__vq.getSelection();var bn=[];for(var i=0;i<bm.length;i++ ){bn.push(bm[i].getUserData(q));};return bn;},setSelection:function(bp){var bo=[];for(var i=0;i<bp.length;i++ ){bo.push(bp[i].getChildControl(c));};this.__vq.setSelection(bo);},resetSelection:function(){this.__vq.resetSelection();},isSelected:function(bq){var br=bq.getChildControl(c);return this.__vq.isSelected(br);},isSelectionEmpty:function(){return this.__vq.isSelectionEmpty();},getSelectables:function(bt){var bs=this.__vq.getSelectables(bt);var bu=[];for(var i=0;i<bs.length;i++ ){bu.push(bs[i].getUserData(q));};return bu;},_onChangeSelection:function(e){var bz=this.getChildControl(A);var bw=e.getData()[0];var by=e.getOldData()[0];var bx=[];var bv=[];if(bw){bx=[bw.getUserData(q)];bz.setSelection(bx);bw.focus();this.scrollChildIntoView(bw,null,null,false);}else {bz.resetSelection();};if(by){bv=[by.getUserData(q)];};this.fireDataEvent(k,bx,bv);},_onBeforeChangeSelection:function(e){if(!this.fireNonBubblingEvent(h,qx.event.type.Event,[false,true])){e.preventDefault();};},_onRadioChangeSelection:function(e){var bA=e.getData()[0];if(bA){this.setSelection([bA.getUserData(q)]);}else {this.resetSelection();};},_onPageClose:function(e){var bC=e.getTarget();var bB=bC.getButton().getChildControl(j);bB.reset();this.remove(bC);}},destruct:function(){this._disposeObjects(a);this.__vp=null;}});})();(function(){var a="__gs",b=" array contains ",c="qx.ui.core.MSingleSelectionHandling",d=" items!",f="changeSelection",g="changeSelected",h="Could only select one item, but the selection",i="qx.event.type.Data";qx.Mixin.define(c,{events:{"changeSelection":i},members:{__gs:null,getSelection:function(){var j=this.__qa().getSelected();if(j){return [j];}else {return [];};},setSelection:function(k){switch(k.length){case 0:this.resetSelection();break;case 1:this.__qa().setSelected(k[0]);break;default:throw new Error(h+b+k.length+d);};},resetSelection:function(){this.__qa().resetSelected();},isSelected:function(l){return this.__qa().isSelected(l);},isSelectionEmpty:function(){return this.__qa().isSelectionEmpty();},getSelectables:function(m){return this.__qa().getSelectables(m);},_onChangeSelected:function(e){var o=e.getData();var n=e.getOldData();o==null?o=[]:o=[o];n==null?n=[]:n=[n];this.fireDataEvent(f,o,n);},__qa:function(){if(this.__gs==null){var p=this;this.__gs=new qx.ui.core.SingleSelectionManager({getItems:function(){return p._getItems();},isItemSelectable:function(q){if(p._isItemSelectable){return p._isItemSelectable(q);}else {return q.isVisible();};}});this.__gs.addListener(g,this._onChangeSelected,this);};this.__gs.setAllowEmptySelection(this._isAllowEmptySelection());return this.__gs;}},destruct:function(){this._disposeObjects(a);}});})();(function(){var a=", because it is not a child element!",b="Boolean",c="__qc",d="qx.ui.core.SingleSelectionManager",e="__qb",f="__qd",g="Could not check if ",h=" is selected,",j="Could not select ",k="changeSelected",l=" because it is not a child element!",m="qx.event.type.Data";qx.Class.define(d,{extend:qx.core.Object,construct:function(n){qx.core.Object.call(this);{};this.__qb=n;},events:{"changeSelected":m},properties:{allowEmptySelection:{check:b,init:true,apply:f}},members:{__qc:null,__qb:null,getSelected:function(){return this.__qc;},setSelected:function(o){if(!this.__qf(o)){throw new Error(j+o+a);};this.__qe(o);},resetSelected:function(){this.__qe(null);},isSelected:function(p){if(!this.__qf(p)){throw new Error(g+p+h+l);};return this.__qc===p;},isSelectionEmpty:function(){return this.__qc==null;},getSelectables:function(r){var q=this.__qb.getItems();var s=[];for(var i=0;i<q.length;i++ ){if(this.__qb.isItemSelectable(q[i])){s.push(q[i]);};};if(!r){for(var i=s.length-1;i>=0;i-- ){if(!s[i].getEnabled()){s.splice(i,1);};};};return s;},__qd:function(u,t){if(!u){this.__qe(this.__qc);};},__qe:function(v){var y=this.__qc;var w=v;if(w!=null&&y===w){return;};if(!this.isAllowEmptySelection()&&w==null){var x=this.getSelectables(true)[0];if(x){w=x;};};this.__qc=w;this.fireDataEvent(k,w,y);},__qf:function(z){var A=this.__qb.getItems();for(var i=0;i<A.length;i++ ){if(A[i]===z){return true;};};return false;}},destruct:function(){if(this.__qb.toHashCode){this._disposeObjects(e);}else {this.__qb=null;};this._disposeObjects(c);}});})();(function(){var a="Could not set the model selection. Maybe your models are not unique? ",b="__qg",c="qx.ui.form.MModelSelection",d="change",f="changeSelection",g="qx.event.type.Data";qx.Mixin.define(c,{construct:function(){this.__qg=new qx.data.Array();this.__qg.addListener(d,this.__qj,this);this.addListener(f,this.__qi,this);},events:{changeModelSelection:g},members:{__qg:null,__qh:false,__qi:function(){if(this.__qh){return;};var l=this.getSelection();var m=[];for(var i=0;i<l.length;i++ ){var h=l[i];var k=h.getModel?h.getModel():null;if(k!==null){m.push(k);};};if(m.length===l.length){try{this.setModelSelection(m);}catch(e){throw new Error(a+e);};};},__qj:function(){this.__qh=true;var p=this.getSelectables(true);var q=[];var o=this.__qg.toArray();for(var i=0;i<o.length;i++ ){var s=o[i];for(var j=0;j<p.length;j++ ){var t=p[j];var n=t.getModel?t.getModel():null;if(s===n){q.push(t);break;};};};this.setSelection(q);this.__qh=false;var r=this.getSelection();if(!qx.lang.Array.equals(r,q)){this.__qi();};},getModelSelection:function(){return this.__qg;},setModelSelection:function(u){if(!u){this.__qg.removeAll();return;};{};u.unshift(this.__qg.getLength());u.unshift(0);var v=this.__qg.splice.apply(this.__qg,u);v.dispose();}},destruct:function(){this._disposeObjects(b);}});})();(function(){var a="__qk",b="_applyAllowEmptySelection",c="_applyInvalidMessage",d="qx.ui.form.RadioGroup",f="Boolean",g="_applyValid",h="",j="changeRequired",k="changeValid",m="changeEnabled",n="changeInvalidMessage",o="changeSelection",p="changeValue",q="_applyEnabled",r="String";qx.Class.define(d,{extend:qx.core.Object,implement:[qx.ui.core.ISingleSelection,qx.ui.form.IForm,qx.ui.form.IModelSelection],include:[qx.ui.core.MSingleSelectionHandling,qx.ui.form.MModelSelection],construct:function(s){qx.core.Object.call(this);this.__qk=[];this.addListener(o,this.__ql,this);if(s!=null){this.add.apply(this,arguments);};},properties:{enabled:{check:f,apply:q,event:m,init:true},wrap:{check:f,init:true},allowEmptySelection:{check:f,init:false,apply:b},valid:{check:f,init:true,apply:g,event:k},required:{check:f,init:false,event:j},invalidMessage:{check:r,init:h,event:n,apply:c},requiredInvalidMessage:{check:r,nullable:true,event:n}},members:{__qk:null,getItems:function(){return this.__qk;},add:function(u){var v=this.__qk;var t;for(var i=0,l=arguments.length;i<l;i++ ){t=arguments[i];if(qx.lang.Array.contains(v,t)){continue;};t.addListener(p,this._onItemChangeChecked,this);v.push(t);t.setGroup(this);if(t.getValue()){this.setSelection([t]);};};if(!this.isAllowEmptySelection()&&v.length>0&&!this.getSelection()[0]){this.setSelection([v[0]]);};},remove:function(w){var x=this.__qk;if(qx.lang.Array.contains(x,w)){qx.lang.Array.remove(x,w);if(w.getGroup()===this){w.resetGroup();};w.removeListener(p,this._onItemChangeChecked,this);if(w.getValue()){this.resetSelection();};};},getChildren:function(){return this.__qk;},_onItemChangeChecked:function(e){var y=e.getTarget();if(y.getValue()){this.setSelection([y]);}else if(this.getSelection()[0]==y){this.resetSelection();};},_applyInvalidMessage:function(A,z){for(var i=0;i<this.__qk.length;i++ ){this.__qk[i].setInvalidMessage(A);};},_applyValid:function(C,B){for(var i=0;i<this.__qk.length;i++ ){this.__qk[i].setValid(C);};},_applyEnabled:function(F,E){var D=this.__qk;if(F==null){for(var i=0,l=D.length;i<l;i++ ){D[i].resetEnabled();};}else {for(var i=0,l=D.length;i<l;i++ ){D[i].setEnabled(F);};};},_applyAllowEmptySelection:function(H,G){if(!H&&this.isSelectionEmpty()){this.resetSelection();};},selectNext:function(){var J=this.getSelection()[0];var K=this.__qk;var I=K.indexOf(J);if(I==-1){return;};var i=0;var length=K.length;if(this.getWrap()){I=(I+1)%length;}else {I=Math.min(I+1,length-1);};while(i<length&&!K[I].getEnabled()){I=(I+1)%length;i++ ;};this.setSelection([K[I]]);},selectPrevious:function(){var M=this.getSelection()[0];var N=this.__qk;var L=N.indexOf(M);if(L==-1){return;};var i=0;var length=N.length;if(this.getWrap()){L=(L-1+length)%length;}else {L=Math.max(L-1,0);};while(i<length&&!N[L].getEnabled()){L=(L-1+length)%length;i++ ;};this.setSelection([N[L]]);},_getItems:function(){return this.getItems();},_isAllowEmptySelection:function(){return this.isAllowEmptySelection();},_isItemSelectable:function(O){return this.__qk.indexOf(O)!=-1;},__ql:function(e){var Q=e.getData()[0];var P=e.getOldData()[0];if(P){P.setValue(false);};if(Q){Q.setValue(true);};}},destruct:function(){this._disposeArray(a);}});})();(function(){var a="qx.ui.container.SlideBar",b="scrollY",c="button-backward",d="horizontal",f="update",g="scrollX",h="_applyOrientation",i="button-forward",j="scrollAnimationEnd",k="content",l="mouse",m="qx.event.type.Event",n="scrollpane",o="vertical",p="Integer",q="slidebar",r="roll",s="execute";qx.Class.define(a,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.core.MRemoteLayoutHandling],construct:function(t){qx.ui.core.Widget.call(this);var u=this.getChildControl(n);this._add(u,{flex:1});if(t!=null){this.setOrientation(t);}else {this.initOrientation();};this.addListener(r,this._onRoll,this);},properties:{appearance:{refine:true,init:q},orientation:{check:[d,o],init:d,apply:h},scrollStep:{check:p,init:15,themeable:true}},events:{scrollAnimationEnd:m},members:{getChildrenContainer:function(){return this.getChildControl(k);},_createChildControlImpl:function(x,w){var v;switch(x){case i:v=new qx.ui.form.RepeatButton;v.addListener(s,this._onExecuteForward,this);v.setFocusable(false);this._addAt(v,2);break;case c:v=new qx.ui.form.RepeatButton;v.addListener(s,this._onExecuteBackward,this);v.setFocusable(false);this._addAt(v,0);break;case k:v=new qx.ui.container.Composite();this.getChildControl(n).add(v);break;case n:v=new qx.ui.core.scroll.ScrollPane();v.addListener(f,this._onResize,this);v.addListener(g,this._onScroll,this);v.addListener(b,this._onScroll,this);v.addListener(j,this._onScrollAnimationEnd,this);break;};return v||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,x);},_forwardStates:{barLeft:true,barTop:true,barRight:true,barBottom:true},scrollBy:function(A,y){var z=this.getChildControl(n);if(this.getOrientation()===d){z.scrollByX(A,y);}else {z.scrollByY(A,y);};},scrollTo:function(C,B){var D=this.getChildControl(n);if(this.getOrientation()===d){D.scrollToX(C,B);}else {D.scrollToY(C,B);};},_applyEnabled:function(F,E,name){qx.ui.core.Widget.prototype._applyEnabled.call(this,F,E,name);this._updateArrowsEnabled();},_applyOrientation:function(J,H){var I=[this.getLayout(),this._getLayout()];var K=this.getChildControl(i);var G=this.getChildControl(c);if(H==o&&J==d){K.removeState(o);G.removeState(o);K.addState(d);G.addState(d);}else if(H==d&&J==o){K.removeState(d);G.removeState(d);K.addState(o);G.addState(o);};if(J==d){this._setLayout(new qx.ui.layout.HBox());this.setLayout(new qx.ui.layout.HBox());}else {this._setLayout(new qx.ui.layout.VBox());this.setLayout(new qx.ui.layout.VBox());};if(I[0]){I[0].dispose();};if(I[1]){I[1].dispose();};},_onRoll:function(e){if(e.getPointerType()==l){return;};var O=0;var N=this.getChildControl(n);if(this.getOrientation()===d){O=e.getDelta().x;var P=N.getScrollX();var L=N.getScrollMaxX();var M=parseInt(O);if(!(M<0&&P<=0||M>0&&P>=L||O==0)){e.stop();}else {e.stopMomentum();};}else {O=e.getDelta().y;var P=N.getScrollY();var L=N.getScrollMaxY();var M=parseInt(O);if(!(M<0&&P<=0||M>0&&P>=L||O==0)){e.stop();}else {e.stopMomentum();};};this.scrollBy(parseInt(O,10));if(e.getMomentum()){e.stop();};},_onScroll:function(){this._updateArrowsEnabled();},_onScrollAnimationEnd:function(){this.fireEvent(j);},_onResize:function(e){var content=this.getChildControl(n).getChildren()[0];if(!content){return;};var Q=this.getInnerSize();var S=content.getBounds();var R=(this.getOrientation()===d)?S.width>Q.width:S.height>Q.height;if(R){this._showArrows();this._updateArrowsEnabled();}else {this._hideArrows();};},_onExecuteBackward:function(){this.scrollBy(-this.getScrollStep());},_onExecuteForward:function(){this.scrollBy(this.getScrollStep());},_updateArrowsEnabled:function(){if(!this.getEnabled()){this.getChildControl(c).setEnabled(false);this.getChildControl(i).setEnabled(false);return;};var U=this.getChildControl(n);if(this.getOrientation()===d){var T=U.getScrollX();var V=U.getScrollMaxX();}else {var T=U.getScrollY();var V=U.getScrollMaxY();};this.getChildControl(c).setEnabled(T>0);this.getChildControl(i).setEnabled(T<V);},_showArrows:function(){this._showChildControl(i);this._showChildControl(c);},_hideArrows:function(){this._excludeChildControl(i);this._excludeChildControl(c);this.scrollTo(0);}}});})();(function(){var a="press",b="hovered",c="qx.ui.form.RepeatButton",d="release",f="Enter",g="pressed",h="interval",i="__de",j="qx.event.type.Event",k="Space",l="abandoned",m="Integer",n="execute";qx.Class.define(c,{extend:qx.ui.form.Button,construct:function(o,p){qx.ui.form.Button.call(this,o,p);this.__de=new qx.event.AcceleratingTimer();this.__de.addListener(h,this._onInterval,this);},events:{"execute":j,"press":j,"release":j},properties:{interval:{check:m,init:100},firstInterval:{check:m,init:500},minTimer:{check:m,init:20},timerDecrease:{check:m,init:2}},members:{__pK:null,__de:null,press:function(){if(this.isEnabled()){if(!this.hasState(g)){this.__pL();};this.removeState(l);this.addState(g);};},release:function(q){if(!this.isEnabled()){return;};if(this.hasState(g)){if(!this.__pK){this.execute();};};this.removeState(g);this.removeState(l);this.__pM();},_applyEnabled:function(s,r){qx.ui.form.Button.prototype._applyEnabled.call(this,s,r);if(!s){if(this.isCapturing()){this.releaseCapture();};this.removeState(g);this.removeState(l);this.__pM();};},_onPointerOver:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};if(this.hasState(l)){this.removeState(l);this.addState(g);this.__de.start();};this.addState(b);},_onPointerOut:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};this.removeState(b);if(this.hasState(g)){this.removeState(g);this.addState(l);this.__de.stop();};},_onPointerDown:function(e){if(!e.isLeftPressed()){return;};this.capture();this.__pL();e.stopPropagation();},_onPointerUp:function(e){this.releaseCapture();if(!this.hasState(l)){this.addState(b);if(this.hasState(g)&&!this.__pK){this.execute();};};this.__pM();e.stopPropagation();},_onTap:function(e){},_onKeyUp:function(e){switch(e.getKeyIdentifier()){case f:case k:if(this.hasState(g)){if(!this.__pK){this.execute();};this.removeState(g);this.removeState(l);e.stopPropagation();this.__pM();};};},_onKeyDown:function(e){switch(e.getKeyIdentifier()){case f:case k:this.removeState(l);this.addState(g);e.stopPropagation();this.__pL();};},_onInterval:function(e){this.__pK=true;this.fireEvent(n);},__pL:function(){this.fireEvent(a);this.__pK=false;this.__de.set({interval:this.getInterval(),firstInterval:this.getFirstInterval(),minimum:this.getMinTimer(),decrease:this.getTimerDecrease()}).start();this.removeState(l);this.addState(g);},__pM:function(){this.fireEvent(d);this.__de.stop();this.removeState(l);this.removeState(g);}},destruct:function(){this._disposeObjects(i);}});})();(function(){var a="Integer",b="__de",c="interval",d="qx.event.type.Event",e="qx.event.AcceleratingTimer";qx.Class.define(e,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__de=new qx.event.Timer(this.getInterval());this.__de.addListener(c,this._onInterval,this);},events:{"interval":d},properties:{interval:{check:a,init:100},firstInterval:{check:a,init:500},minimum:{check:a,init:20},decrease:{check:a,init:2}},members:{__de:null,__pN:null,start:function(){this.__de.setInterval(this.getFirstInterval());this.__de.start();},stop:function(){this.__de.stop();this.__pN=null;},_onInterval:function(){this.__de.stop();if(this.__pN==null){this.__pN=this.getInterval();};this.__pN=Math.max(this.getMinimum(),this.__pN-this.getDecrease());this.__de.setInterval(this.__pN);this.__de.start();this.fireEvent(c);}},destruct:function(){this._disposeObjects(b);}});})();(function(){var a="resize",b="scrollY",c="scrollAnimationEnd",d="update",f="scrollX",g="_applyScrollX",h="_applyScrollY",i="frame",j="qx.lang.Type.isNumber(value)&&value>=0&&value<=this.getScrollMaxX()",k="appear",l="qx.lang.Type.isNumber(value)&&value>=0&&value<=this.getScrollMaxY()",m="qx.event.type.Event",n="qx.ui.core.scroll.ScrollPane",o="end",p="scroll";qx.Class.define(n,{extend:qx.ui.core.Widget,construct:function(){qx.ui.core.Widget.call(this);this.set({minWidth:0,minHeight:0});this._setLayout(new qx.ui.layout.Grow());this.addListener(a,this._onUpdate);var q=this.getContentElement();q.addListener(p,this._onScroll,this);q.addListener(k,this._onAppear,this);},events:{update:m,scrollAnimationEnd:m},properties:{scrollX:{check:j,apply:g,event:f,init:0},scrollY:{check:l,apply:h,event:b,init:0}},members:{__pO:null,add:function(r){var s=this._getChildren()[0];if(s){this._remove(s);s.removeListener(a,this._onUpdate,this);};if(r){this._add(r);r.addListener(a,this._onUpdate,this);};},remove:function(t){if(t){this._remove(t);t.removeListener(a,this._onUpdate,this);};},getChildren:function(){return this._getChildren();},_onUpdate:function(e){this.fireEvent(d);},_onScroll:function(e){var u=this.getContentElement();this.setScrollX(u.getScrollX());this.setScrollY(u.getScrollY());},_onAppear:function(e){var z=this.getContentElement();var v=this.getScrollX();var A=z.getScrollX();if(v!=A){z.scrollToX(v);};var w=this.getScrollY();var B=z.getScrollY();if(w!=B){z.scrollToY(w);};},getItemTop:function(C){var top=0;do {top+=C.getBounds().top;C=C.getLayoutParent();}while(C&&C!==this);return top;},getItemBottom:function(D){return this.getItemTop(D)+D.getBounds().height;},getItemLeft:function(E){var F=0;var parent;do {F+=E.getBounds().left;parent=E.getLayoutParent();if(parent){F+=parent.getInsets().left;};E=parent;}while(E&&E!==this);return F;},getItemRight:function(G){return this.getItemLeft(G)+G.getBounds().width;},getScrollSize:function(){return this.getChildren()[0].getBounds();},getScrollMaxX:function(){var I=this.getInnerSize();var H=this.getScrollSize();if(I&&H){return Math.max(0,H.width-I.width);};return 0;},getScrollMaxY:function(){var K=this.getInnerSize();var J=this.getScrollSize();if(K&&J){return Math.max(0,J.height-K.height);};return 0;},scrollToX:function(O,L){var M=this.getScrollMaxX();if(O<0){O=0;}else if(O>M){O=M;};this.stopScrollAnimation();if(L){var N=this.getScrollX();this.__pO=new qx.bom.AnimationFrame();this.__pO.on(o,function(){this.setScrollX(O);this.__pO=null;this.fireEvent(c);},this);this.__pO.on(i,function(Q){var P=parseInt(Q/L*(O-N)+N);this.setScrollX(P);},this);this.__pO.startSequence(L);}else {this.setScrollX(O);};},scrollToY:function(U,R){var S=this.getScrollMaxY();if(U<0){U=0;}else if(U>S){U=S;};this.stopScrollAnimation();if(R){var T=this.getScrollY();this.__pO=new qx.bom.AnimationFrame();this.__pO.on(o,function(){this.setScrollY(U);this.__pO=null;this.fireEvent(c);},this);this.__pO.on(i,function(W){var V=parseInt(W/R*(U-T)+T);this.setScrollY(V);},this);this.__pO.startSequence(R);}else {this.setScrollY(U);};},scrollByX:function(x,X){this.scrollToX(this.getScrollX()+x,X);},scrollByY:function(y,Y){this.scrollToY(this.getScrollY()+y,Y);},stopScrollAnimation:function(){if(this.__pO){this.__pO.cancelSequence();this.__pO=null;};},_applyScrollX:function(ba){this.getContentElement().scrollToX(ba);},_applyScrollY:function(bb){this.getContentElement().scrollToY(bb);}}});})();(function(){var a="_applyDynamic",b="changeSelection",c="Boolean",d="qx.ui.container.Stack";qx.Class.define(d,{extend:qx.ui.core.Widget,implement:qx.ui.core.ISingleSelection,include:[qx.ui.core.MSingleSelectionHandling,qx.ui.core.MChildrenHandling],construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.Grow);this.addListener(b,this.__ql,this);},properties:{dynamic:{check:c,init:false,apply:a}},members:{_applyDynamic:function(g){var j=this._getChildren();var f=this.getSelection()[0];var h;for(var i=0,l=j.length;i<l;i++ ){h=j[i];if(h!=f){if(g){j[i].exclude();}else {j[i].hide();};};};},_getItems:function(){return this.getChildren();},_isAllowEmptySelection:function(){return true;},_isItemSelectable:function(k){return true;},__ql:function(e){var m=e.getOldData()[0];var n=e.getData()[0];if(m){if(this.isDynamic()){m.exclude();}else {m.hide();};};if(n){n.show();};},_afterAddChild:function(p){var o=this.getSelection()[0];if(!o){this.setSelection([p]);}else if(o!==p){if(this.isDynamic()){p.exclude();}else {p.hide();};};},_afterRemoveChild:function(q){if(this.getSelection()[0]===q){var r=this._getChildren()[0];if(r){this.setSelection([r]);}else {this.resetSelection();};};},previous:function(){var u=this.getSelection()[0];var s=this._indexOf(u)-1;var v=this._getChildren();if(s<0){s=v.length-1;};var t=v[s];this.setSelection([t]);},next:function(){var x=this.getSelection()[0];var w=this._indexOf(x)+1;var y=this._getChildren();var z=y[w]||y[0];this.setSelection([z]);}}});})();(function(){var a='qx.event.type.Event',b='openTablePage',c='_applyOverviewPage',d='refresh',e='clui.view.TabView',f='clui.view.OverviewPage',g='refreshTimeline',h='open';qx.Class.define(e,{extend:qx.ui.tabview.TabView,properties:{overviewPage:{check:f,nullable:true,apply:c}},events:{openTablePage:a,refreshTimeline:a},construct:function(){qx.ui.tabview.TabView.call(this);this.setPadding(2);this.setContentPadding(0);},members:{_applyOverviewPage:function(j,i){this.add(j);j.addListener(h,this.fireEvent.bind(this,b));j.addListener(d,this.fireEvent.bind(this,g));},addTablePage:function(k){this.add(k);this.setSelection([k]);}}});})();(function(){var a="_applyIcon",b="",c="icon",d="page",e="close",f="qx.event.type.Event",g="_applyShowCloseButton",h="tabview-page",i="qx.ui.tabview.Page",j="_applyLabel",k="button",l="String",m="Boolean";qx.Class.define(i,{extend:qx.ui.container.Composite,construct:function(n,o){qx.ui.container.Composite.call(this);this._createChildControl(k);if(n!=null){this.setLabel(n);};if(o!=null){this.setIcon(o);};},events:{"close":f},properties:{appearance:{refine:true,init:h},label:{check:l,init:b,apply:j},icon:{check:l,init:b,apply:a,nullable:true},showCloseButton:{check:m,init:false,apply:g}},members:{_forwardStates:{barTop:1,barRight:1,barBottom:1,barLeft:1,firstTab:1,lastTab:1},_applyIcon:function(r,q){var p=this.getChildControl(k);if(r){p.setIcon(r);p._showChildControl(c);}else {p._excludeChildControl(c);};},_applyLabel:function(t,s){this.getChildControl(k).setLabel(t);},_applyEnabled:function(w,v){qx.ui.container.Composite.prototype._applyEnabled.call(this,w,v);var u=this.getChildControl(k);w==null?u.resetEnabled():u.setEnabled(w);},_createChildControlImpl:function(z,y){var x;switch(z){case k:x=new qx.ui.tabview.TabButton;x.setAllowGrowX(true);x.setAllowGrowY(true);x.setUserData(d,this);x.addListener(e,this._onButtonClose,this);break;};return x||qx.ui.container.Composite.prototype._createChildControlImpl.call(this,z);},_applyShowCloseButton:function(B,A){this.getChildControl(k).setShowCloseButton(B);},_onButtonClose:function(){this.fireEvent(e);},getButton:function(){return this.getChildControl(k);}}});})();(function(){var a="qx.ui.form.IRadioItem",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeValue":b},members:{setValue:function(c){},getValue:function(){},setGroup:function(d){this.assertInstance(d,qx.ui.form.RadioGroup);},getGroup:function(){}}});})();(function(){var a="qx.ui.form.IModel",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeModel":b},members:{setModel:function(c){},getModel:function(){},resetModel:function(){}}});})();(function(){var a="changeModel",b="_applyModel",c="qx.ui.form.MModelProperty";qx.Mixin.define(c,{properties:{model:{nullable:true,event:a,apply:b,dereference:true}},members:{_applyModel:function(e,d){}}});})();(function(){var a="qx.ui.form.IBooleanForm",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeValue":b},members:{setValue:function(c){return arguments.length==1;},resetValue:function(){},getValue:function(){}}});})();(function(){var a="keypress",b="Boolean",c="Right",d="label",f="Left",g="_applyValue",h="changeValue",i="Up",j="value",k="qx.ui.form.RadioButton",l="radiobutton",m="toolTipText",n="enabled",o="qx.ui.form.RadioGroup",p="Down",q="_applyGroup",r="checked",s="menu",t="execute";qx.Class.define(k,{extend:qx.ui.form.Button,include:[qx.ui.form.MForm,qx.ui.form.MModelProperty],implement:[qx.ui.form.IRadioItem,qx.ui.form.IForm,qx.ui.form.IBooleanForm,qx.ui.form.IModel],construct:function(u){{};qx.ui.form.Button.call(this,u);this.addListener(t,this._onExecute);this.addListener(a,this._onKeyPress);},properties:{group:{check:o,nullable:true,apply:q},value:{check:b,nullable:true,event:h,apply:g,init:false},appearance:{refine:true,init:l},allowGrowX:{refine:true,init:false}},members:{_forwardStates:{checked:true,focused:true,invalid:true,hovered:true},_bindableProperties:[n,d,m,j,s],_applyValue:function(w,v){w?this.addState(r):this.removeState(r);},_applyGroup:function(y,x){if(x){x.remove(this);};if(y){y.add(this);};},_onExecute:function(e){var z=this.getGroup();if(z&&z.getAllowEmptySelection()){this.toggleValue();}else {this.setValue(true);};},_onKeyPress:function(e){var A=this.getGroup();if(!A){return;};switch(e.getKeyIdentifier()){case f:case i:A.selectPrevious();break;case c:case p:A.selectNext();break;};}}});})();(function(){var a="Boolean",b="icon",c="label",d="bottom",e="qx.ui.tabview.TabButton",f="center",g="_applyShowCloseButton",h="close-button",i="top",j="left",k="tap",l="middle",m="close",n="right",o="qx.event.type.Data";qx.Class.define(e,{extend:qx.ui.form.RadioButton,implement:qx.ui.form.IRadioItem,construct:function(){qx.ui.form.RadioButton.call(this);var p=new qx.ui.layout.Grid(2,0);p.setRowAlign(0,j,l);p.setColumnAlign(0,n,l);this._getLayout().dispose();this._setLayout(p);this.initShowCloseButton();},events:{"close":o},properties:{showCloseButton:{check:a,init:false,apply:g}},members:{_forwardStates:{focused:true,checked:true},_applyIconPosition:function(s,q){var r={icon:this.getChildControl(b),label:this.getChildControl(c),closeButton:this.getShowCloseButton()?this.getChildControl(h):null};for(var t in r){if(r[t]){this._remove(r[t]);};};switch(s){case i:this._add(r.label,{row:3,column:2});this._add(r.icon,{row:1,column:2});if(r.closeButton){this._add(r.closeButton,{row:0,column:4});};break;case d:this._add(r.label,{row:1,column:2});this._add(r.icon,{row:3,column:2});if(r.closeButton){this._add(r.closeButton,{row:0,column:4});};break;case j:this._add(r.label,{row:0,column:2});this._add(r.icon,{row:0,column:0});if(r.closeButton){this._add(r.closeButton,{row:0,column:4});};break;case n:this._add(r.label,{row:0,column:0});this._add(r.icon,{row:0,column:2});if(r.closeButton){this._add(r.closeButton,{row:0,column:4});};break;};},_createChildControlImpl:function(w,v){var u;switch(w){case c:var u=new qx.ui.basic.Label(this.getLabel());u.setAnonymous(true);this._add(u,{row:0,column:2});this._getLayout().setColumnFlex(2,1);break;case b:u=new qx.ui.basic.Image(this.getIcon());u.setAnonymous(true);this._add(u,{row:0,column:0});break;case h:u=new qx.ui.form.Button();u.setFocusable(false);u.setKeepActive(true);u.addListener(k,this._onCloseButtonTap,this);this._add(u,{row:0,column:4});if(!this.getShowCloseButton()){u.exclude();};break;};return u||qx.ui.form.RadioButton.prototype._createChildControlImpl.call(this,w);},_onCloseButtonTap:function(){this.fireDataEvent(m,this);},_applyShowCloseButton:function(y,x){if(y){this._showChildControl(h);}else {this._excludeChildControl(h);};},_applyCenter:function(A){var z=this._getLayout();if(A){z.setColumnAlign(2,f,l);}else {z.setColumnAlign(2,j,l);};}}});})();(function(){var a='12px italic',b='Overview',c='changeSelection',d='Group by period in chart',e='before',f='From',g='after',h='main-dark',i='changeAfter',j='timeSeries',k='clui.view.OverviewPage',l='open',m='changeBefore',n='level',o='frame',p='refresh',q='group',r='execute',s='name',t='Open',u='Level',v='Custom range',w='series',x='qx.event.type.Event',y='today0/today1',z='middle',A='/',B='Name prefix',C='right',D='Refresh',E='Until';qx.Class.define(k,{extend:qx.ui.tabview.Page,events:{open:x,refresh:x},construct:function(G,F){qx.ui.tabview.Page.call(this,this.tr(b));this._controller=G;this._record=F;this._form=new qx.ui.form.Form();this.setLayout(new qx.ui.layout.VBox(4));this.setPadding(8);this.add(this._createToolbar());this.add(this._createTimeline());this.add(this._createForm());G.setTarget(this._form);},members:{_controller:null,_record:null,_form:null,_createToolbar:function(){var K=new qx.ui.container.Composite(new qx.ui.layout.HBox(4,C));var J=new qx.ui.form.ListItem(this.tr(v),null,null);J.setFont(qx.bom.Font.fromString(a));var H=new qx.ui.form.SelectBox();H.setMinWidth(160);H.add(J);kucken.ui.form.SelectBoxHelper.addFromMap(H,clui.model.form.Overview.quickRange);H.setModelSelection([y]);H.addListener(c,function(event){var M=event.getData()[0].getModel();if(M){var L=kucken.lang.Array.zip([g,e],M.split(A));this._controller.getModel().set(kucken.lang.Object.dict(L));};},this);this._controller.getModel().addListener(i,function(event){if(H.getModelSelection().getItem(0).split(A)[0]!=event.getData()){H.resetSelection();};});this._controller.getModel().addListener(m,function(event){if(H.getModelSelection().getItem(0).split(A)[1]!=event.getData()){H.resetSelection();};});K.add(H);var I=new qx.ui.form.SelectBox();I.setToolTipText(this.tr(d));kucken.ui.form.SelectBoxHelper.addFromMap(I,clui.model.form.Overview.groupBy);this._form.add(I,null,null,q);K.add(I);return K;},_createTimeline:function(){var N=new clui.view.Timeline();N.setHeight(200);this._record.bind(j,N,w);this._record.bind(q,N,q);var O=new qx.ui.container.Composite(new qx.ui.layout.VBox());O.setMarginTop(10);O.add(N);O.setDecorator(h);return O;},__vr:function(P,Q,R,S){R.setValid(P!=null);return R.getRelativeDate().getExpression();},_createForm:function(){var U=new qx.ui.container.Composite(new qx.ui.layout.VBox(8));var top=new qx.ui.container.Composite(new qx.ui.layout.HBox(8,C));U.add(top);var T=new qx.ui.layout.Grid(10,10);T.setColumnFlex(1,1);T.setColumnAlign(0,C,z);var bc=new qx.ui.groupbox.GroupBox();bc.setLayout(T);bc.setContentPadding(10);bc.getChildControl(o).setMarginTop(0);bc.setMinWidth(280);bc.add(new qx.ui.basic.Label(this.tr(f)),{'row':0,'column':0});var ba=new clui.view.widget.RelativeDateField(new Date(0,0,0,0,0,0,0));ba.setTabIndex(1);this._form.add(ba,null,null,g);bc.add(ba,{'row':0,'column':1});this._controller.addBindingOptions(g,null,{'converter':this.__vr.bind(this)});bc.add(new qx.ui.basic.Label(this.tr(E)),{'row':1,'column':0});var bd=new clui.view.widget.RelativeDateField(new Date(0,0,0,23,59,59,999));bd.setTabIndex(2);this._form.add(bd,null,null,e);bc.add(bd,{'row':1,'column':1});this._controller.addBindingOptions(e,null,{'converter':this.__vr.bind(this)});top.add(bc);var Y=new qx.ui.layout.Grid(10,10);Y.setColumnFlex(1,1);Y.setColumnAlign(0,C,z);var bb=new qx.ui.groupbox.GroupBox();bb.setLayout(Y);bb.setContentPadding(10);bb.getChildControl(o).setMarginTop(0);bb.setMarginTop(0);bb.setMinWidth(320);bb.add(new qx.ui.basic.Label(this.tr(B)),{'row':0,'column':0});var name=new qx.ui.form.TextField();name.setTabIndex(3);this._form.add(name,null,null,s);bb.add(name,{'row':0,'column':1});bb.add(new qx.ui.basic.Label(this.tr(u)),{'row':1,'column':0});var W=new qx.ui.form.SelectBox();W.setTabIndex(4);kucken.ui.form.SelectBoxHelper.addFromMap(W,clui.model.form.Record.levelMap);this._form.add(W,null,null,n);bb.add(W,{'row':1,'column':1});top.add(bb);var V=new qx.ui.container.Composite(new qx.ui.layout.HBox(8,C));V.setPaddingRight(5);U.add(V);var X=new qx.ui.form.Button(this.tr(D));X.addListener(r,this.fireEvent.bind(this,p));V.add(X);var open=new qx.ui.form.Button(this.tr(t));open.addListener(r,this.fireEvent.bind(this,l));V.add(open);return U;}}});})();(function(){var a="change",b="qx.ui.form.Form",c="qx.event.type.Event",d="";qx.Class.define(b,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__vs=[];this._buttons=[];this._buttonOptions=[];this._validationManager=this._createValidationManager();this._resetter=this._createResetter();},events:{"change":c},members:{__vs:null,_validationManager:null,_groupCounter:0,_buttons:null,_buttonOptions:null,_resetter:null,add:function(g,f,h,name,e,k){if(this.__vt()){this.__vs.push({title:null,items:[],labels:[],names:[],options:[],headerOptions:{}});};this.__vs[this._groupCounter].items.push(g);this.__vs[this._groupCounter].labels.push(f);this.__vs[this._groupCounter].options.push(k);if(name==null){name=f.replace(/\s+|&|-|\+|\*|\/|\||!|\.|,|:|\?|;|~|%|\{|\}|\(|\)|\[|\]|<|>|=|\^|@|\\/g,d);};this.__vs[this._groupCounter].names.push(name);this._validationManager.add(g,h,e);this._resetter.add(g);this.fireEvent(a);},addGroupHeader:function(m,l){if(!this.__vt()){this._groupCounter++ ;};this.__vs.push({title:m,items:[],labels:[],names:[],options:[],headerOptions:l});this.fireEvent(a);},addButton:function(n,o){this._buttons.push(n);this._buttonOptions.push(o||null);this.fireEvent(a);},__vt:function(){return this.__vs.length===0;},remove:function(p){for(var i=0;i<this.__vs.length;i++ ){var r=this.__vs[i];for(var j=0;j<r.items.length;j++ ){var q=r.items[j];if(q===p){r.items.splice(j,1);r.labels.splice(j,1);r.names.splice(j,1);r.options.splice(j,1);this._validationManager.remove(p);this._resetter.remove(p);this.fireEvent(a);return true;};};};return false;},removeGroupHeader:function(u){for(var i=0;i<this.__vs.length;i++ ){var t=this.__vs[i];if(t.title===u){var s;if(i==0){if(this.__vs.length==1){t.title=null;t.headerOptions={};this.fireEvent(a);return true;}else {s=this.__vs[i+1];};}else {s=this.__vs[i-1];};s.items=s.items.concat(t.items);s.labels=s.labels.concat(t.labels);s.names=s.names.concat(t.names);s.options=s.options.concat(t.options);this.__vs.splice(i,1);this._groupCounter-- ;this.fireEvent(a);return true;};};return false;},removeButton:function(w){for(var i=0;i<this._buttons.length;i++ ){var v=this._buttons[i];if(v===w){this._buttons.splice(i,1);this._buttonOptions.splice(i,1);this.fireEvent(a);return true;};};return false;},getItems:function(){var x={};for(var i=0;i<this.__vs.length;i++ ){var y=this.__vs[i];for(var j=0;j<y.names.length;j++ ){var name=y.names[j];x[name]=y.items[j];};};return x;},reset:function(){this._resetter.reset();this._validationManager.reset();},redefineResetter:function(){this._resetter.redefine();},redefineResetterItem:function(z){this._resetter.redefineItem(z);},validate:function(){return this._validationManager.validate();},getValidationManager:function(){return this._validationManager;},getGroups:function(){return this.__vs;},getButtons:function(){return this._buttons;},getButtonOptions:function(){return this._buttonOptions;},_createValidationManager:function(){return new qx.ui.form.validation.Manager();},_createResetter:function(){return new qx.ui.form.Resetter();}},destruct:function(){this.__vs=this._buttons=this._buttonOptions=null;this._validationManager.dispose();this._resetter.dispose();}});})();(function(){var a="Widgets supporting selection can only be validated ",b="Added widget not supported.",c="",d="in the form validator",f="mouse",g="changeValid",h="qx.event.type.Event",j="complete",k="value instanceof Function || qx.Class.isSubClassOf(value.constructor, qx.ui.form.validation.AsyncValidator)",l="qx.ui.form.validation.Manager",m="This field is required",n="String",o="qx.event.type.Data";qx.Class.define(l,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__vu=[];this.__vv={};this.setRequiredFieldMessage(qx.locale.Manager.tr(m));},events:{"changeValid":o,"complete":h},properties:{validator:{check:k,init:null,nullable:true},invalidMessage:{check:n,init:c},requiredFieldMessage:{check:n,init:c},context:{nullable:true}},members:{__vu:null,__vw:null,__vv:null,__vx:null,add:function(s,p,r){if(!this.__vC(s)){throw new Error(b);};if(this.__vD(s)&&!s.getValue){if(p!=null){throw new Error(a+d);};};var q={item:s,validator:p,valid:null,context:r};this.__vu.push(q);},remove:function(v){var t=this.__vu;for(var i=0,u=t.length;i<u;i++ ){if(v===t[i].item){t.splice(i,1);return v;};};return null;},getItems:function(){var w=[];for(var i=0;i<this.__vu.length;i++ ){w.push(this.__vu[i].item);};return w;},validate:function(){var B=true;this.__vx=true;var y=[];for(var i=0;i<this.__vu.length;i++ ){var z=this.__vu[i].item;var C=this.__vu[i].validator;y.push(z);if(C==null){var x=this.__vy(z);B=B&&x;this.__vx=x&&this.__vx;continue;};var x=this.__vz(this.__vu[i],z.getValue());B=x&&B;if(x!=null){this.__vx=x&&this.__vx;};};var A=this.__vA(y);if(qx.lang.Type.isBoolean(A)){this.__vx=A&&this.__vx;};B=A&&B;this._setValid(B);if(qx.lang.Object.isEmpty(this.__vv)){this.fireEvent(j);};return B;},__vy:function(E){if(E.getRequired()){if(this.__vD(E)){var D=!!E.getSelection()[0];}else {var G=E.getValue();var D=!!G||G===0;};E.setValid(D);var H=E.getRequiredInvalidMessage();var F=H?H:this.getRequiredFieldMessage();E.setInvalidMessage(F);return D;};return true;},__vz:function(K,L){var M=K.item;var O=K.context;var N=K.validator;if(this.__vB(N)){this.__vv[M.toHashCode()]=null;N.validate(M,M.getValue(),this,O);return null;};var I=null;try{var I=N.call(O||this,L,M);if(I===undefined){I=true;};}catch(e){if(e instanceof qx.core.ValidationError){I=false;if(e.message&&e.message!=qx.type.BaseError.DEFAULTMESSAGE){var J=e.message;}else {var J=e.getComment();};M.setInvalidMessage(J);}else {throw e;};};M.setValid(I);K.valid=I;return I;},__vA:function(Q){var R=this.getValidator();var S=this.getContext()||this;if(R==null){return true;};this.setInvalidMessage(c);if(this.__vB(R)){this.__vv[this.toHashCode()]=null;R.validateForm(Q,this,S);return null;};try{var T=R.call(S,Q,this);if(T===undefined){T=true;};}catch(e){if(e instanceof qx.core.ValidationError){T=false;if(e.message&&e.message!=qx.type.BaseError.DEFAULTMESSAGE){var P=e.message;}else {var P=e.getComment();};this.setInvalidMessage(P);}else {throw e;};};return T;},__vB:function(V){var U=false;if(!qx.lang.Type.isFunction(V)){U=qx.Class.isSubClassOf(V.constructor,qx.ui.form.validation.AsyncValidator);};return U;},__vC:function(W){var X=W.constructor;return qx.Class.hasInterface(X,qx.ui.form.IForm);},__vD:function(Y){var ba=Y.constructor;return qx.Class.hasInterface(ba,qx.ui.core.ISingleSelection);},_setValid:function(bb){this._showToolTip(bb);var bc=this.__vw;this.__vw=bb;if(bc!=bb){this.fireDataEvent(g,bb,bc);};},_showToolTip:function(bg){if(!qx.ui.tooltip||!qx.ui.tooltip.Manager){return;};var be=qx.ui.tooltip.Manager.getInstance().getSharedErrorTooltip();if(!bg){var bd;for(var i=0;i<this.__vu.length;i++ ){var bf=this.__vu[i].item;if(!bf.isValid()){bd=bf;if(!(bf.getContentLocation)){return;};if(bf.isSeeable()===false){continue;};be.setLabel(bf.getInvalidMessage());if(be.getPlaceMethod()==f){var location=bf.getContentLocation();var top=location.top-be.getOffsetTop();be.placeToPoint({left:location.right,top:top});}else {be.placeToWidget(bf);};be.show();return;};};}else {be.exclude();};},getValid:function(){return this.__vw;},isValid:function(){return this.getValid();},getInvalidMessages:function(){var bh=[];for(var i=0;i<this.__vu.length;i++ ){var bi=this.__vu[i].item;if(!bi.getValid()){bh.push(bi.getInvalidMessage());};};if(this.getInvalidMessage()!=c){bh.push(this.getInvalidMessage());};return bh;},getInvalidFormItems:function(){var bj=[];for(var i=0;i<this.__vu.length;i++ ){var bk=this.__vu[i].item;if(!bk.getValid()){bj.push(bk);};};return bj;},reset:function(){for(var i=0;i<this.__vu.length;i++ ){var bl=this.__vu[i];bl.item.setValid(true);};this.__vw=null;this._showToolTip(true);},setItemValid:function(bn,bm){this.__vv[bn.toHashCode()]=bm;bn.setValid(bm);this.__vE();},setFormValid:function(bo){this.__vv[this.toHashCode()]=bo;this.__vE();},__vE:function(){var bq=this.__vx;for(var br in this.__vv){var bp=this.__vv[br];bq=bp&&bq;if(bp==null){return;};};this._setValid(bq);this.__vv={};this.fireEvent(j);}},destruct:function(){this.__vu=null;}});})();(function(){var a="qx.ui.form.validation.AsyncValidator";qx.Class.define(a,{extend:qx.core.Object,construct:function(b){qx.core.Object.call(this);this.__vF=b;},members:{__vF:null,__vG:null,__gs:null,__vH:null,validate:function(c,e,d,f){this.__vH=false;this.__vG=c;this.__gs=d;this.__vF.call(f||this,this,e);},validateForm:function(g,h,i){this.__vH=true;this.__gs=h;this.__vF.call(i,g,this);},setValid:function(k,j){if(this.__vH){if(j!==undefined){this.__gs.setInvalidMessage(j);};this.__gs.setFormValid(k);}else {if(j!==undefined){this.__vG.setInvalidMessage(j);};this.__gs.setItemValid(this.__vG,k);};}},destruct:function(){this.__gs=this.__vG=null;}});})();(function(){var a="The given item has not been added.",b="qx.ui.form.Resetter",c=" not supported for reseting.",d="Item ";qx.Class.define(b,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__qk=[];},members:{__qk:null,add:function(e){if(this._supportsValue(e)){var f=e.getValue();}else if(this.__vD(e)){var f=e.getSelection();}else if(this.__vK(e)){var f=e.getSelection().concat();}else {throw new Error(d+e+c);};this.__qk.push({item:e,init:f});},remove:function(g){for(var i=0;i<this.__qk.length;i++ ){var h=this.__qk[i];if(h.item===g){this.__qk.splice(i,1);return true;};};return false;},reset:function(){for(var i=0;i<this.__qk.length;i++ ){var j=this.__qk[i];this.__vI(j.item,j.init);};},resetItem:function(k){var l;for(var i=0;i<this.__qk.length;i++ ){var m=this.__qk[i];if(m.item===k){l=m.init;break;};};if(l===undefined){throw new Error(a);};this.__vI(k,l);},__vI:function(n,o){if(this._supportsValue(n)){n.setValue(o);}else if(this.__vD(n)||this.__vK(n)){n.setSelection(o);};},redefine:function(){for(var i=0;i<this.__qk.length;i++ ){var p=this.__qk[i].item;this.__qk[i].init=this.__vJ(p);};},redefineItem:function(q){var r;for(var i=0;i<this.__qk.length;i++ ){if(this.__qk[i].item===q){r=this.__qk[i];break;};};if(r===undefined){throw new Error(a);};r.init=this.__vJ(r.item);},__vJ:function(s){if(this._supportsValue(s)){return s.getValue();}else if(this.__vD(s)||this.__vK(s)){return s.getSelection();};},__vD:function(t){var u=t.constructor;return qx.Class.hasInterface(u,qx.ui.core.ISingleSelection);},__vK:function(v){var w=v.constructor;return qx.Class.hasInterface(w,qx.data.controller.ISelection);},_supportsValue:function(x){var y=x.constructor;return (qx.Class.hasInterface(y,qx.ui.form.IBooleanForm)||qx.Class.hasInterface(y,qx.ui.form.IColorForm)||qx.Class.hasInterface(y,qx.ui.form.IDateForm)||qx.Class.hasInterface(y,qx.ui.form.INumberForm)||qx.Class.hasInterface(y,qx.ui.form.IStringForm));}},destruct:function(){this.__qk=null;}});})();(function(){var a="qx.data.controller.ISelection";qx.Interface.define(a,{members:{setSelection:function(b){},getSelection:function(){},resetSelection:function(){}}});})();(function(){var a="qx.ui.form.IColorForm",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeValue":b},members:{setValue:function(c){return arguments.length==1;},resetValue:function(){},getValue:function(){}}});})();(function(){var a="qx.ui.form.IDateForm",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeValue":b},members:{setValue:function(c){return arguments.length==1;},resetValue:function(){},getValue:function(){}}});})();(function(){var a="qx.ui.form.INumberForm",b="qx.event.type.Data";qx.Interface.define(a,{events:{"changeValue":b},members:{setValue:function(c){return arguments.length==1;},resetValue:function(){},getValue:function(){}}});})();(function(){var a="listitem",b="hovered",c="pointerover",d="qx.ui.form.ListItem",e="qx.event.type.Event",f="pointerout";qx.Class.define(d,{extend:qx.ui.basic.Atom,implement:[qx.ui.form.IModel],include:[qx.ui.form.MModelProperty],construct:function(h,i,g){qx.ui.basic.Atom.call(this,h,i);if(g!=null){this.setModel(g);};this.addListener(c,this._onPointerOver,this);this.addListener(f,this._onPointerOut,this);},events:{"action":e},properties:{appearance:{refine:true,init:a}},members:{_forwardStates:{focused:true,hovered:true,selected:true,dragover:true},_onPointerOver:function(){this.addState(b);},_onPointerOut:function(){this.removeState(b);}},destruct:function(){this.removeListener(c,this._onPointerOver,this);this.removeListener(f,this._onPointerOut,this);}});})();(function(){var a="popupOpen",b="PageUp",c="blur",d="one",f="Escape",g="_applyMaxListHeight",h="Function",i="",j="Abstract method: _onListPointerDown()",k="visible",l="changeSelection",m="middle",n="Abstract method: _onListChangeSelection()",o="changeVisibility",p="resize",q="list",r="qx.ui.form.AbstractSelectBox",s="pointerdown",t="keypress",u="PageDown",v="abstract",w="popup",x="Number",y="pane",z="tap";qx.Class.define(r,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.form.MForm],implement:[qx.ui.form.IForm],type:v,construct:function(){qx.ui.core.Widget.call(this);var A=new qx.ui.layout.HBox();this._setLayout(A);A.setAlignY(m);this.addListener(t,this._onKeyPress);this.addListener(c,this._onBlur,this);this.addListener(p,this._onResize,this);},properties:{focusable:{refine:true,init:true},width:{refine:true,init:120},maxListHeight:{check:x,apply:g,nullable:true,init:200},format:{check:h,init:function(B){return this._defaultFormat(B);},nullable:true}},members:{_createChildControlImpl:function(E,D){var C;switch(E){case q:C=new qx.ui.form.List().set({focusable:false,keepFocus:true,height:null,width:null,maxHeight:this.getMaxListHeight(),selectionMode:d,quickSelection:true});C.addListener(l,this._onListChangeSelection,this);C.addListener(s,this._onListPointerDown,this);C.getChildControl(y).addListener(z,this.close,this);break;case w:C=new qx.ui.popup.Popup(new qx.ui.layout.VBox());C.setAutoHide(false);C.setKeepActive(true);C.add(this.getChildControl(q));C.addListener(o,this._onPopupChangeVisibility,this);break;};return C||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,E);},_applyMaxListHeight:function(G,F){this.getChildControl(q).setMaxHeight(G);},getChildrenContainer:function(){return this.getChildControl(q);},open:function(){var H=this.getChildControl(w);H.placeToWidget(this,true);H.show();},close:function(){this.getChildControl(w).hide();},toggle:function(){var I=this.getChildControl(w).isVisible();if(I){this.close();}else {this.open();};},_defaultFormat:function(J){var L=J?J.getLabel():i;var K=J?J.getRich():false;if(K){L=L.replace(/<[^>]+?>/g,i);L=qx.bom.String.unescape(L);};return L;},_onBlur:function(e){this.close();},_onKeyPress:function(e){var M=e.getKeyIdentifier();var N=this.getChildControl(w);if(N.isHidden()&&(M==u||M==b)){e.stopPropagation();}else if(!N.isHidden()&&M==f){this.close();e.stop();}else {this.getChildControl(q).handleKeyPress(e);};},_onResize:function(e){this.getChildControl(w).setMinWidth(e.getData().width);},_onListChangeSelection:function(e){throw new Error(n);},_onListPointerDown:function(e){throw new Error(j);},_onPopupChangeVisibility:function(e){e.getData()==k?this.addState(a):this.removeState(a);}}});})();(function(){var c="os.name",d="Abstract method call: _getLastSelectable()",f="Could not select more than one items in mode: ",g="Boolean",h="one",j="Abstract method call: _getLocation()",k="Left",m="Abstract method call: _scrollBy()",n="The method getSelectedItem() is only supported in 'single' and 'one' selection mode!",o="Abstract method call: _scrollItemIntoView()",p="Escape",q="Abstract method call: _isSelectable()",r="Space",s="Abstract method call: _getPage()",t="right",u="lead",v="Down",w="Abstract method call: _getFirstSelectable()",x="Up",y="qx.event.type.Data",z="under",A="A",B="_applyMode",C="PageDown",D="Can not select multiple items in selection mode: ",E="osx",F="mouse",G="interval",H="Abstract method call: _styleSelectable()",I="anchor",J="Abstract method call: _capture()",K="Abstract method call: _getDimension()",L="The method invertSelection() is only supported in 'multi' and 'additive' selection mode!",M="!",N="Abstract method call: _getScroll()",O="Abstract method call: _getRelatedSelectable()",P="End",Q="quick",R="selected",S="key",T="Abstract method call: _getSelectableLocationX()",U="multi",V="left",W="Abstract method call: _selectableToHashCode()",X="Home",Y="Can not select all items in selection mode: ",bt="single",bu="Right",bv="Abstract method call: getSelectables()",bp="Abstract method call: _getSelectableLocationY()",bq="additive",br="abstract",bs="changeSelection",bA="above",bB="Abstract method call: _getSelectableRange()",bC="tap",bD="drag",bw="PageUp",bx="qx.ui.core.selection.Abstract",by="__ry",bz="Abstract method call: _releaseCapture()";qx.Class.define(bx,{type:br,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__gw={};},events:{"changeSelection":y},properties:{mode:{check:[bt,U,bq,h],init:bt,apply:B},drag:{check:g,init:false},quick:{check:g,init:false}},members:{__rw:0,__rx:0,__ry:null,__rz:null,__rA:null,__rB:null,__rC:null,__rD:null,__rE:null,__rF:null,__rG:null,__rH:null,__rI:null,__rJ:null,__rK:null,__rL:null,__rM:null,__gw:null,__rN:null,__rO:null,_userInteraction:false,__rP:null,getSelectionContext:function(){return this.__rL;},selectAll:function(){var bE=this.getMode();if(bE==bt||bE==h){throw new Error(Y+bE);};this._selectAllItems();this._fireChange();},selectItem:function(bF){this._setSelectedItem(bF);var bG=this.getMode();if(bG!==bt&&bG!==h){this._setLeadItem(bF);this._setAnchorItem(bF);};this._scrollItemIntoView(bF);this._fireChange();},addItem:function(bH){var bI=this.getMode();if(bI===bt||bI===h){this._setSelectedItem(bH);}else {if(this._getAnchorItem()==null){this._setAnchorItem(bH);};this._setLeadItem(bH);this._addToSelection(bH);};this._scrollItemIntoView(bH);this._fireChange();},removeItem:function(bJ){this._removeFromSelection(bJ);if(this.getMode()===h&&this.isSelectionEmpty()){var bK=this._applyDefaultSelection();if(bK==bJ){return;};};if(this.getLeadItem()==bJ){this._setLeadItem(null);};if(this._getAnchorItem()==bJ){this._setAnchorItem(null);};this._fireChange();},selectItemRange:function(bL,bM){var bN=this.getMode();if(bN==bt||bN==h){throw new Error(D+bN);};this._selectItemRange(bL,bM);this._setAnchorItem(bL);this._setLeadItem(bM);this._scrollItemIntoView(bM);this._fireChange();},clearSelection:function(){if(this.getMode()==h){var bO=this._applyDefaultSelection(true);if(bO!=null){return;};};this._clearSelection();this._setLeadItem(null);this._setAnchorItem(null);this._fireChange();},replaceSelection:function(bP){var bQ=this.getMode();if(bQ==h||bQ===bt){if(bP.length>1){throw new Error(f+bQ+M);};if(bP.length==1){this.selectItem(bP[0]);}else {this.clearSelection();};return;}else {this._replaceMultiSelection(bP);};},getSelectedItem:function(){var bR=this.getMode();if(bR===bt||bR===h){var bS=this._getSelectedItem();return bS!=undefined?bS:null;};throw new Error(n);},getSelection:function(){return Object.values(this.__gw);},getSortedSelection:function(){var bU=this.getSelectables();var bT=Object.values(this.__gw);bT.sort(function(a,b){return bU.indexOf(a)-bU.indexOf(b);});return bT;},isItemSelected:function(bV){var bW=this._selectableToHashCode(bV);return this.__gw[bW]!==undefined;},isSelectionEmpty:function(){return qx.lang.Object.isEmpty(this.__gw);},invertSelection:function(){var bY=this.getMode();if(bY===bt||bY===h){throw new Error(L);};var bX=this.getSelectables();for(var i=0;i<bX.length;i++ ){this._toggleInSelection(bX[i]);};this._fireChange();},_setLeadItem:function(cb){var ca=this.__rM;if(ca!==null){this._styleSelectable(ca,u,false);};if(cb!==null){this._styleSelectable(cb,u,true);};this.__rM=cb;},getLeadItem:function(){return this.__rM;},_setAnchorItem:function(cd){var cc=this.__rN;if(cc!=null){this._styleSelectable(cc,I,false);};if(cd!=null){this._styleSelectable(cd,I,true);};this.__rN=cd;},_getAnchorItem:function(){return this.__rN!==null?this.__rN:null;},_isSelectable:function(ce){throw new Error(q);},_getSelectableFromPointerEvent:function(event){var cf=event.getTarget();if(cf&&this._isSelectable(cf)){return cf;};return null;},_selectableToHashCode:function(cg){throw new Error(W);},_styleSelectable:function(ch,ci,cj){throw new Error(H);},_capture:function(){throw new Error(J);},_releaseCapture:function(){throw new Error(bz);},_getLocation:function(){throw new Error(j);},_getDimension:function(){throw new Error(K);},_getSelectableLocationX:function(ck){throw new Error(T);},_getSelectableLocationY:function(cl){throw new Error(bp);},_getScroll:function(){throw new Error(N);},_scrollBy:function(cm,cn){throw new Error(m);},_scrollItemIntoView:function(co){throw new Error(o);},getSelectables:function(cp){throw new Error(bv);},_getSelectableRange:function(cr,cq){throw new Error(bB);},_getFirstSelectable:function(){throw new Error(w);},_getLastSelectable:function(){throw new Error(d);},_getRelatedSelectable:function(cs,ct){throw new Error(O);},_getPage:function(cv,cu){throw new Error(s);},_applyMode:function(cx,cw){this._setLeadItem(null);this._setAnchorItem(null);this._clearSelection();if(cx===h){this._applyDefaultSelection(true);};this._fireChange();},handlePointerOver:function(event){if(this.__rP!=null&&this.__rP!=this._getScroll().top){this.__rP=null;return;};if(event.getPointerType()!=F){return;};this._userInteraction=true;if(!this.getQuick()){this._userInteraction=false;return;};var cz=this.getMode();if(cz!==h&&cz!==bt){this._userInteraction=false;return;};var cy=this._getSelectableFromPointerEvent(event);if(cy===null){this._userInteraction=false;return;};this._setSelectedItem(cy);this._fireChange(Q);this._userInteraction=false;},handlePointerDown:function(event){this._userInteraction=true;var cB=this._getSelectableFromPointerEvent(event);if(cB===null){this._userInteraction=false;return;};var cD=event.isCtrlPressed()||(qx.core.Environment.get(c)==E&&event.isMetaPressed());var cA=event.isShiftPressed();if(this.isItemSelected(cB)&&!cA&&!cD&&!this.getDrag()){this.__rO=cB;this._userInteraction=false;return;}else {this.__rO=null;};this._scrollItemIntoView(cB);var cC=this.getMode();if(this.getDrag()&&cC!==bt&&cC!==h&&!cA&&!cD&&event.getPointerType()==F){this._setAnchorItem(cB);this._setLeadItem(cB);this.__rC=this._getLocation();this.__rz=this._getScroll();this.__rD=event.getDocumentLeft()+this.__rz.left;this.__rE=event.getDocumentTop()+this.__rz.top;this.__rF=true;this._capture();};this._fireChange(bC);this._userInteraction=false;},handleTap:function(event){this._userInteraction=true;var cH=event.isCtrlPressed()||(qx.core.Environment.get(c)==E&&event.isMetaPressed());var cE=event.isShiftPressed();if(!cH&&!cE&&this.__rO!=null){this._userInteraction=false;var cF=this._getSelectableFromPointerEvent(event);if(cF===null||!this.isItemSelected(cF)){return;};};var cF=this._getSelectableFromPointerEvent(event);if(cF===null){this._userInteraction=false;return;};switch(this.getMode()){case bt:case h:this._setSelectedItem(cF);break;case bq:this._setLeadItem(cF);this._setAnchorItem(cF);this._toggleInSelection(cF);break;case U:this._setLeadItem(cF);if(cE){var cG=this._getAnchorItem();if(cG===null){cG=this._getFirstSelectable();this._setAnchorItem(cG);};this._selectItemRange(cG,cF,cH);}else if(cH){this._setAnchorItem(cF);this._toggleInSelection(cF);}else {this._setAnchorItem(cF);this._setSelectedItem(cF);};break;};this._cleanup();},handleLoseCapture:function(event){this._cleanup();},handlePointerMove:function(event){if(!this.__rF){return;};this.__rG=event.getDocumentLeft();this.__rH=event.getDocumentTop();this._userInteraction=true;var cI=this.__rG+this.__rz.left;if(cI>this.__rD){this.__rI=1;}else if(cI<this.__rD){this.__rI=-1;}else {this.__rI=0;};var cJ=this.__rH+this.__rz.top;if(cJ>this.__rE){this.__rJ=1;}else if(cJ<this.__rE){this.__rJ=-1;}else {this.__rJ=0;};var location=this.__rC;if(this.__rG<location.left){this.__rw=this.__rG-location.left;}else if(this.__rG>location.right){this.__rw=this.__rG-location.right;}else {this.__rw=0;};if(this.__rH<location.top){this.__rx=this.__rH-location.top;}else if(this.__rH>location.bottom){this.__rx=this.__rH-location.bottom;}else {this.__rx=0;};if(!this.__ry){this.__ry=new qx.event.Timer(100);this.__ry.addListener(G,this._onInterval,this);};this.__ry.start();this._autoSelect();event.stopPropagation();this._userInteraction=false;},handleAddItem:function(e){var cK=e.getData();if(this.getMode()===h&&this.isSelectionEmpty()){this.addItem(cK);};},handleRemoveItem:function(e){this.removeItem(e.getData());},_cleanup:function(){if(!this.getDrag()&&this.__rF){return;};if(this.__rK){this._fireChange(bC);};delete this.__rF;delete this.__rA;delete this.__rB;this._releaseCapture();if(this.__ry){this.__ry.stop();};},_onInterval:function(e){this._scrollBy(this.__rw,this.__rx);this.__rz=this._getScroll();this._autoSelect();},_autoSelect:function(){var cT=this._getDimension();var cM=Math.max(0,Math.min(this.__rG-this.__rC.left,cT.width))+this.__rz.left;var cL=Math.max(0,Math.min(this.__rH-this.__rC.top,cT.height))+this.__rz.top;if(this.__rA===cM&&this.__rB===cL){return;};this.__rA=cM;this.__rB=cL;var cQ=this._getAnchorItem();var cO=cQ;var cR=this.__rI;var cU,cN;while(cR!==0){cU=cR>0?this._getRelatedSelectable(cO,t):this._getRelatedSelectable(cO,V);if(cU!==null){cN=this._getSelectableLocationX(cU);if((cR>0&&cN.left<=cM)||(cR<0&&cN.right>=cM)){cO=cU;continue;};};break;};var cS=this.__rJ;var cV,cP;while(cS!==0){cV=cS>0?this._getRelatedSelectable(cO,z):this._getRelatedSelectable(cO,bA);if(cV!==null){cP=this._getSelectableLocationY(cV);if((cS>0&&cP.top<=cL)||(cS<0&&cP.bottom>=cL)){cO=cV;continue;};};break;};var cW=this.getMode();if(cW===U){this._selectItemRange(cQ,cO);}else if(cW===bq){if(this.isItemSelected(cQ)){this._selectItemRange(cQ,cO,true);}else {this._deselectItemRange(cQ,cO);};this._setAnchorItem(cO);};this._fireChange(bD);},__pC:{Home:1,Down:1,Right:1,PageDown:1,End:1,Up:1,Left:1,PageUp:1},handleKeyPress:function(event){this._userInteraction=true;var dd,dc;var df=event.getKeyIdentifier();var de=this.getMode();var cY=event.isCtrlPressed()||(qx.core.Environment.get(c)==E&&event.isMetaPressed());var da=event.isShiftPressed();var db=false;if(df===A&&cY){if(de!==bt&&de!==h){this._selectAllItems();db=true;};}else if(df===p){if(de!==bt&&de!==h){this._clearSelection();db=true;};}else if(df===r){var cX=this.getLeadItem();if(cX!=null&&!da){if(cY||de===bq){this._toggleInSelection(cX);}else {this._setSelectedItem(cX);};db=true;};}else if(this.__pC[df]){db=true;if(de===bt||de==h){dd=this._getSelectedItem();}else {dd=this.getLeadItem();};if(dd!==null){switch(df){case X:dc=this._getFirstSelectable();break;case P:dc=this._getLastSelectable();break;case x:dc=this._getRelatedSelectable(dd,bA);break;case v:dc=this._getRelatedSelectable(dd,z);break;case k:dc=this._getRelatedSelectable(dd,V);break;case bu:dc=this._getRelatedSelectable(dd,t);break;case bw:dc=this._getPage(dd,true);break;case C:dc=this._getPage(dd,false);break;};}else {switch(df){case X:case v:case bu:case C:dc=this._getFirstSelectable();break;case P:case x:case k:case bw:dc=this._getLastSelectable();break;};};if(dc!==null){switch(de){case bt:case h:this._setSelectedItem(dc);break;case bq:this._setLeadItem(dc);break;case U:if(da){var dg=this._getAnchorItem();if(dg===null){this._setAnchorItem(dg=this._getFirstSelectable());};this._setLeadItem(dc);this._selectItemRange(dg,dc,cY);}else {this._setAnchorItem(dc);this._setLeadItem(dc);if(!cY){this._setSelectedItem(dc);};};break;};this.__rP=this._getScroll().top;this._scrollItemIntoView(dc);};};if(db){event.stop();this._fireChange(S);};this._userInteraction=false;},_selectAllItems:function(){var dh=this.getSelectables();for(var i=0,l=dh.length;i<l;i++ ){this._addToSelection(dh[i]);};},_clearSelection:function(){var di=this.__gw;for(var dj in di){this._removeFromSelection(di[dj]);};this.__gw={};},_selectItemRange:function(dk,dp,dm){var dq=this._getSelectableRange(dk,dp);if(!dm){var dn=this.__gw;var dr=this.__rQ(dq);for(var dl in dn){if(!dr[dl]){this._removeFromSelection(dn[dl]);};};};for(var i=0,l=dq.length;i<l;i++ ){this._addToSelection(dq[i]);};},_deselectItemRange:function(du,ds){var dt=this._getSelectableRange(du,ds);for(var i=0,l=dt.length;i<l;i++ ){this._removeFromSelection(dt[i]);};},__rQ:function(dw){var dx={};var dv;for(var i=0,l=dw.length;i<l;i++ ){dv=dw[i];dx[this._selectableToHashCode(dv)]=dv;};return dx;},_getSelectedItem:function(){for(var dy in this.__gw){return this.__gw[dy];};return null;},_setSelectedItem:function(dA){if(this._isSelectable(dA)){var dz=this.__gw;var dB=this._selectableToHashCode(dA);if(!dz[dB]||(dz.length>=2)){this._clearSelection();this._addToSelection(dA);};};},_addToSelection:function(dC){var dD=this._selectableToHashCode(dC);if(this.__gw[dD]==null&&this._isSelectable(dC)){this.__gw[dD]=dC;this._styleSelectable(dC,R,true);this.__rK=true;};},_toggleInSelection:function(dE){var dF=this._selectableToHashCode(dE);if(this.__gw[dF]==null){this.__gw[dF]=dE;this._styleSelectable(dE,R,true);}else {delete this.__gw[dF];this._styleSelectable(dE,R,false);};this.__rK=true;},_removeFromSelection:function(dG){var dH=this._selectableToHashCode(dG);if(this.__gw[dH]!=null){delete this.__gw[dH];this._styleSelectable(dG,R,false);this.__rK=true;};},_replaceMultiSelection:function(dK){if(dK.length===0){this.clearSelection();return;};var dL=false;var dO,dN;var dJ={};for(var i=0,l=dK.length;i<l;i++ ){dO=dK[i];if(this._isSelectable(dO)){dN=this._selectableToHashCode(dO);dJ[dN]=dO;};};var dP=dK[0];var dI=dO;var dM=this.__gw;for(var dN in dM){if(dJ[dN]){delete dJ[dN];}else {dO=dM[dN];delete dM[dN];this._styleSelectable(dO,R,false);dL=true;};};for(var dN in dJ){dO=dM[dN]=dJ[dN];this._styleSelectable(dO,R,true);dL=true;};if(!dL){return false;};this._scrollItemIntoView(dI);this._setLeadItem(dP);this._setAnchorItem(dP);this.__rK=true;this._fireChange();},_fireChange:function(dQ){if(this.__rK){this.__rL=dQ||null;this.fireDataEvent(bs,this.getSelection());delete this.__rK;};},_applyDefaultSelection:function(dR){if(dR===true||this.getMode()===h&&this.isSelectionEmpty()){var dS=this._getFirstSelectable();if(dS!=null){this.selectItem(dS);};return dS;};return null;}},destruct:function(){this._disposeObjects(by);this.__gw=this.__rO=this.__rN=null;this.__rM=null;}});})();(function(){var a="vertical",b="under",c="above",d="qx.ui.core.selection.Widget",e="left",f="right";qx.Class.define(d,{extend:qx.ui.core.selection.Abstract,construct:function(g){qx.ui.core.selection.Abstract.call(this);this.__lf=g;},members:{__lf:null,_isSelectable:function(h){return this._isItemSelectable(h)&&h.getLayoutParent()===this.__lf;},_selectableToHashCode:function(j){return j.$$hash;},_styleSelectable:function(k,m,n){n?k.addState(m):k.removeState(m);},_capture:function(){this.__lf.capture();},_releaseCapture:function(){this.__lf.releaseCapture();},_isItemSelectable:function(o){if(this._userInteraction){return o.isVisible()&&o.isEnabled();}else {return o.isVisible();};},_getWidget:function(){return this.__lf;},_getLocation:function(){var p=this.__lf.getContentElement().getDomElement();return p?qx.bom.element.Location.get(p):null;},_getDimension:function(){return this.__lf.getInnerSize();},_getSelectableLocationX:function(q){var r=q.getBounds();if(r){return {left:r.left,right:r.left+r.width};};},_getSelectableLocationY:function(s){var t=s.getBounds();if(t){return {top:t.top,bottom:t.top+t.height};};},_getScroll:function(){return {left:0,top:0};},_scrollBy:function(u,v){},_scrollItemIntoView:function(w){this.__lf.scrollChildIntoView(w);},getSelectables:function(x){var y=false;if(!x){y=this._userInteraction;this._userInteraction=true;};var B=this.__lf.getChildren();var z=[];var A;for(var i=0,l=B.length;i<l;i++ ){A=B[i];if(this._isItemSelectable(A)){z.push(A);};};this._userInteraction=y;return z;},_getSelectableRange:function(C,D){if(C===D){return [C];};var H=this.__lf.getChildren();var E=[];var G=false;var F;for(var i=0,l=H.length;i<l;i++ ){F=H[i];if(F===C||F===D){if(G){E.push(F);break;}else {G=true;};};if(G&&this._isItemSelectable(F)){E.push(F);};};return E;},_getFirstSelectable:function(){var I=this.__lf.getChildren();for(var i=0,l=I.length;i<l;i++ ){if(this._isItemSelectable(I[i])){return I[i];};};return null;},_getLastSelectable:function(){var J=this.__lf.getChildren();for(var i=J.length-1;i>0;i-- ){if(this._isItemSelectable(J[i])){return J[i];};};return null;},_getRelatedSelectable:function(N,O){var L=this.__lf.getOrientation()===a;var P=this.__lf.getChildren();var K=P.indexOf(N);var M;if((L&&O===c)||(!L&&O===e)){for(var i=K-1;i>=0;i-- ){M=P[i];if(this._isItemSelectable(M)){return M;};};}else if((L&&O===b)||(!L&&O===f)){for(var i=K+1;i<P.length;i++ ){M=P[i];if(this._isItemSelectable(M)){return M;};};};return null;},_getPage:function(R,Q){if(Q){return this._getFirstSelectable();}else {return this._getLastSelectable();};}},destruct:function(){this.__lf=null;}});})();(function(){var a="Invalid lead item: ",b="qx.ui.core.selection.ScrollArea";qx.Class.define(b,{extend:qx.ui.core.selection.Widget,members:{_isSelectable:function(c){return this._isItemSelectable(c)&&c.getLayoutParent()===this._getWidget().getChildrenContainer();},_getDimension:function(){return this._getWidget().getPaneSize();},_getScroll:function(){var d=this._getWidget();return {left:d.getScrollX(),top:d.getScrollY()};},_scrollBy:function(f,g){var e=this._getWidget();e.scrollByX(f);e.scrollByY(g);},_getPage:function(k,o){var q=this.getSelectables();var length=q.length;var p=q.indexOf(k);if(p===-1){throw new Error(a+k);};var h=this._getWidget();var r=h.getScrollY();var innerHeight=h.getInnerSize().height;var top,l,s;if(o){var n=r;var i=p;while(1){for(;i>=0;i-- ){top=h.getItemTop(q[i]);if(top<n){s=i+1;break;};};if(s==null){var t=this._getFirstSelectable();return t==k?null:t;};if(s>=p){n-=innerHeight+r-h.getItemBottom(k);s=null;continue;};return q[s];};}else {var m=innerHeight+r;var i=p;while(1){for(;i<length;i++ ){l=h.getItemBottom(q[i]);if(l>m){s=i-1;break;};};if(s==null){var j=this._getLastSelectable();return j==k?null:j;};if(s<=p){m+=h.getItemTop(k)-r;s=null;continue;};return q[s];};};}}});})();(function(){var a="Boolean",b="one",c="pointerover",d="qx.event.type.Data",f=", because it is not a child element!",g="_applyDragSelection",h="Could not add + ",j=" from selection, because it is not a child element!",k="changeSelection",l="Could not test if ",m="Could not remove ",n="addItem",o="multi",p="_applyQuickSelection",q="single",r="qx.ui.core.MMultiSelectionHandling",s="pointermove",t=" is selected, because it is not a child element!",u="_applySelectionMode",v="additive",w="__gs",x="keypress",y="losecapture",z="Could not select ",A="removeItem",B="tap",C="pointerdown",D=" to selection, because it is not a child element!";qx.Mixin.define(r,{construct:function(){var F=this.SELECTION_MANAGER;var E=this.__gs=new F(this);this.addListener(C,E.handlePointerDown,E);this.addListener(B,E.handleTap,E);this.addListener(c,E.handlePointerOver,E);this.addListener(s,E.handlePointerMove,E);this.addListener(y,E.handleLoseCapture,E);this.addListener(x,E.handleKeyPress,E);this.addListener(n,E.handleAddItem,E);this.addListener(A,E.handleRemoveItem,E);E.addListener(k,this._onSelectionChange,this);},events:{"changeSelection":d},properties:{selectionMode:{check:[q,o,v,b],init:q,apply:u},dragSelection:{check:a,init:false,apply:g},quickSelection:{check:a,init:false,apply:p}},members:{__gs:null,selectAll:function(){this.__gs.selectAll();},isSelected:function(G){if(!qx.ui.core.Widget.contains(this,G)){throw new Error(l+G+t);};return this.__gs.isItemSelected(G);},addToSelection:function(H){if(!qx.ui.core.Widget.contains(this,H)){throw new Error(h+H+D);};this.__gs.addItem(H);},removeFromSelection:function(I){if(!qx.ui.core.Widget.contains(this,I)){throw new Error(m+I+j);};this.__gs.removeItem(I);},selectRange:function(J,K){this.__gs.selectItemRange(J,K);},resetSelection:function(){this.__gs.clearSelection();},setSelection:function(L){for(var i=0;i<L.length;i++ ){if(!qx.ui.core.Widget.contains(this,L[i])){throw new Error(z+L[i]+f);};};if(L.length===0){this.resetSelection();}else {var M=this.getSelection();if(!qx.lang.Array.equals(M,L)){this.__gs.replaceSelection(L);};};},getSelection:function(){return this.__gs.getSelection();},getSortedSelection:function(){return this.__gs.getSortedSelection();},isSelectionEmpty:function(){return this.__gs.isSelectionEmpty();},getSelectionContext:function(){return this.__gs.getSelectionContext();},_getManager:function(){return this.__gs;},getSelectables:function(N){return this.__gs.getSelectables(N);},invertSelection:function(){this.__gs.invertSelection();},_getLeadItem:function(){var O=this.__gs.getMode();if(O===q||O===b){return this.__gs.getSelectedItem();}else {return this.__gs.getLeadItem();};},_applySelectionMode:function(Q,P){this.__gs.setMode(Q);},_applyDragSelection:function(S,R){this.__gs.setDrag(S);},_applyQuickSelection:function(U,T){this.__gs.setQuick(U);},_onSelectionChange:function(e){this.fireDataEvent(k,e.getData());}},destruct:function(){this._disposeObjects(w);}});})();(function(){var a="qx.ui.core.IMultiSelection";qx.Interface.define(a,{extend:qx.ui.core.ISingleSelection,members:{selectAll:function(){return true;},addToSelection:function(b){return arguments.length==1;},removeFromSelection:function(c){return arguments.length==1;}}});})();(function(){var a="mouse",b="scrollbar-y",c="qx.ui.core.scroll.MRoll",d="pointerdown",f="scrollbar-x",g="roll";qx.Mixin.define(c,{members:{__qm:null,_addRollHandling:function(){this.addListener(g,this._onRoll,this);this.addListener(d,this._onPointerDownForRoll,this);},_removeRollHandling:function(){this.removeListener(g,this._onRoll,this);this.removeListener(d,this._onPointerDownForRoll,this);},_onPointerDownForRoll:function(e){this.__qm=e.getPointerId();},_onRoll:function(e){if(e.getPointerType()==a){return;};if(this.__qm&&e.getMomentum()){e.stopMomentum();this.__qm=null;return;};this.__qm=null;var k=this._isChildControlVisible(f);var l=this._isChildControlVisible(b);var q=l?this.getChildControl(b,true):null;var p=k?this.getChildControl(f,true):null;var m=e.getDelta().y;var h=e.getDelta().x;var j=!l;var o=!k;if(q){if(m!==0){q.scrollBy(parseInt(m,10));};var n=q.getPosition();var i=q.getMaximum();if(m<0&&n<=0||m>0&&n>=i){j=true;};};if(p){if(h!==0){p.scrollBy(parseInt(h,10));};var n=p.getPosition();var i=p.getMaximum();if(h<0&&n<=0||h>0&&n>=i){o=true;};};if(o&&j){e.stopMomentum();};if((!j&&h===0)||(!o&&m===0)||((!o||!j)&&h!==0&&m!==0)){e.stop();};}}});})();(function(){var a="x",b="Float",c="qx.ui.core.MDragDropScrolling",d="",f="). Must be: 'left', 'right', 'top' or 'bottom'",g="bottom",h="interval",i="dragend",j="scrollbar-",k="drag",l="Invalid edge type given (",m="top",n="left",o="right",p="Integer",q="y";qx.Mixin.define(c,{construct:function(){var r=this;if(this instanceof qx.ui.core.DragDropScrolling){r=this._getWidget();};r.addListener(k,this.__qq,this);r.addListener(i,this.__qr,this);this.__qn=[n,o];this.__qo=[m,g];},properties:{dragScrollThresholdX:{check:p,init:30},dragScrollThresholdY:{check:p,init:30},dragScrollSlowDownFactor:{check:b,init:0.1}},members:{__qp:null,__qn:null,__qo:null,_findScrollableParent:function(s){var t=s;if(t===null){return null;};while(t.getLayoutParent()){t=t.getLayoutParent();if(this._isScrollable(t)){return t;};};return null;},_isScrollable:function(u){return qx.Class.hasMixin(u.constructor,qx.ui.core.scroll.MScrollBarFactory);},_getBounds:function(v){var w=v.getContentLocation();if(v.getScrollAreaContainer){w=v.getScrollAreaContainer().getContentLocation();};return w;},_getEdgeType:function(y,z,x){if((y.left*-1)<=z&&y.left<0){return n;}else if((y.top*-1)<=x&&y.top<0){return m;}else if(y.right<=z&&y.right>0){return o;}else if(y.bottom<=x&&y.bottom>0){return g;}else {return null;};},_getAxis:function(A){if(this.__qn.indexOf(A)!==-1){return a;}else if(this.__qo.indexOf(A)!==-1){return q;}else {throw new Error(l+A+f);};},_getThresholdByEdgeType:function(B){if(this.__qn.indexOf(B)!==-1){return this.getDragScrollThresholdX();}else if(this.__qo.indexOf(B)!==-1){return this.getDragScrollThresholdY();};},_isScrollbarVisible:function(C,D){if(C&&C._isChildControlVisible){return C._isChildControlVisible(j+D);}else {return false;};},_isScrollbarExceedingMaxPos:function(F,H,E){var G=0;if(!F){return true;};G=F.getPosition()+E;return (G>F.getMaximum()||G<0);},_calculateThresholdExceedance:function(J,I){var K=I-Math.abs(J);return J<0?(K*-1):K;},_calculateScrollAmount:function(L,M){return Math.floor(((L/100)*M)*this.getDragScrollSlowDownFactor());},_scrollBy:function(N,T,Q){var S=N.getChildControl(j+T,true);if(!S){return;};var P=S.getBounds(),O=T===a?P.width:P.height,R=this._calculateScrollAmount(O,Q);if(this._isScrollbarExceedingMaxPos(S,T,R)){this.__qp.stop();};S.scrollBy(R);},__qq:function(e){if(this.__qp){this.__qp.stop();};var W=e.getOriginalTarget();if(!W){return;};var U;if(this._isScrollable(W)){U=W;}else {U=this._findScrollableParent(W);};while(U){var Y=this._getBounds(U),V=e.getDocumentLeft(),ba=e.getDocumentTop(),bc={"left":Y.left-V,"right":Y.right-V,"top":Y.top-ba,"bottom":Y.bottom-ba},X=null,bd=d,bb=0;X=this._getEdgeType(bc,this.getDragScrollThresholdX(),this.getDragScrollThresholdY());if(!X){U=this._findScrollableParent(U);continue;};bd=this._getAxis(X);if(this._isScrollbarVisible(U,bd)){bb=this._calculateThresholdExceedance(bc[X],this._getThresholdByEdgeType(X));if(this.__qp){this.__qp.dispose();};this.__qp=new qx.event.Timer(50);this.__qp.addListener(h,function(be,bg,bf){this._scrollBy(be,bg,bf);}.bind(this,U,bd,bb));this.__qp.start();e.stopPropagation();return;}else {U=this._findScrollableParent(U);};};},__qr:function(e){if(this.__qp){this.__qp.stop();};}},destruct:function(){if(this.__qp){this.__qp.dispose();};}});})();(function(){var a="qx.ui.core.DragDropScrolling";qx.Class.define(a,{extend:qx.core.Object,include:[qx.ui.core.MDragDropScrolling],construct:function(b){qx.core.Object.call(this);this._widget=b;},members:{_widget:null,_getWidget:function(){return this._widget||qx.core.Init.getApplication().getRoot();}}});})();(function(){var a="qx.nativeScrollBars",b="qx.ui.core.scroll.MScrollBarFactory";qx.core.Environment.add(a,false);qx.Mixin.define(b,{members:{_createScrollBar:function(c){if(qx.core.Environment.get(a)){return new qx.ui.core.scroll.NativeScrollBar(c);}else {return new qx.ui.core.scroll.ScrollBar(c);};}}});})();(function(){var a='qx.event.type.Event',b="qx.ui.core.scroll.IScrollBar",c="qx.event.type.Data";qx.Interface.define(b,{events:{"scroll":c,"scrollAnimationEnd":a},properties:{orientation:{},maximum:{},position:{},knobFactor:{}},members:{scrollTo:function(e,d){this.assertNumber(e);},scrollBy:function(g,f){this.assertNumber(g);},scrollBySteps:function(i,h){this.assertNumber(i);}}});})();(function(){var a="qx.ui.core.scroll.NativeScrollBar",b="px",c="PositiveNumber",d="frame",f="end",g="box-sizing",h="Integer",i="track",j="browser.name",k="hidden",l="content-box",m="pointerup",n="vertical",o="_applyOrientation",p="scrollAnimationEnd",q="appear",r="pointerdown",s="PositiveInteger",t='qx.event.type.Event',u="mshtml",v="engine.name",w="horizontal",x="Number",y="edge",z="_applyPosition",A="scrollbar",B="_applyMaximum",C="__qs",D="pointermove",E="native",F="scroll";qx.Class.define(a,{extend:qx.ui.core.Widget,implement:qx.ui.core.scroll.IScrollBar,construct:function(G){qx.ui.core.Widget.call(this);this.addState(E);this.getContentElement().addListener(F,this._onScroll,this);this.addListener(r,this._stopPropagation,this);this.addListener(m,this._stopPropagation,this);this.addListener(D,this._stopPropagation,this);this.addListener(q,this._onAppear,this);this.getContentElement().add(this._getScrollPaneElement());this.getContentElement().setStyle(g,l);if(G!=null){this.setOrientation(G);}else {this.initOrientation();};this.addListener(i,function(e){e.stopPropagation();},this);},events:{scrollAnimationEnd:t},properties:{appearance:{refine:true,init:A},orientation:{check:[w,n],init:w,apply:o},maximum:{check:s,apply:B,init:100},position:{check:x,init:0,apply:z,event:F},singleStep:{check:h,init:20},knobFactor:{check:c,nullable:true}},members:{__pg:null,__qs:null,__kp:null,__qt:null,_getScrollPaneElement:function(){if(!this.__qs){this.__qs=new qx.html.Element();};return this.__qs;},renderLayout:function(I,top,H,K){var J=qx.ui.core.Widget.prototype.renderLayout.call(this,I,top,H,K);this._updateScrollBar();return J;},_getContentHint:function(){var L=qx.bom.element.Scroll.getScrollbarWidth();return {width:this.__pg?100:L,maxWidth:this.__pg?null:L,minWidth:this.__pg?null:L,height:this.__pg?L:100,maxHeight:this.__pg?L:null,minHeight:this.__pg?L:null};},_applyEnabled:function(N,M){qx.ui.core.Widget.prototype._applyEnabled.call(this,N,M);this._updateScrollBar();},_applyMaximum:function(O){this._updateScrollBar();},_applyPosition:function(P){var content=this.getContentElement();if(this.__pg){content.scrollToX(P);}else {content.scrollToY(P);};},_applyOrientation:function(S,Q){var R=this.__pg=S===w;this.set({allowGrowX:R,allowShrinkX:R,allowGrowY:!R,allowShrinkY:!R});if(R){this.replaceState(n,w);}else {this.replaceState(w,n);};this.getContentElement().setStyles({overflowX:R?F:k,overflowY:R?k:F});qx.ui.core.queue.Layout.add(this);},_updateScrollBar:function(){var U=this.__pg;var V=this.getBounds();if(!V){return;};if(this.isEnabled()){var W=U?V.width:V.height;var T=this.getMaximum()+W;}else {T=0;};if(qx.core.Environment.get(v)==u||qx.core.Environment.get(j)==y){var V=this.getBounds();this.getContentElement().setStyles({left:(U?V.left:(V.left-1))+b,top:(U?(V.top-1):V.top)+b,width:(U?V.width:V.width+1)+b,height:(U?V.height+1:V.height)+b});};this._getScrollPaneElement().setStyles({left:0,top:0,width:(U?T:1)+b,height:(U?1:T)+b});this.updatePosition(this.getPosition());},scrollTo:function(Y,X){this.stopScrollAnimation();if(X){var ba=this.getPosition();this.__qt=new qx.bom.AnimationFrame();this.__qt.on(d,function(bc){var bb=parseInt(bc/X*(Y-ba)+ba);this.updatePosition(bb);},this);this.__qt.on(f,function(){this.setPosition(Math.max(0,Math.min(this.getMaximum(),Y)));this.__qt=null;this.fireEvent(p);},this);this.__qt.startSequence(X);}else {this.updatePosition(Y);};},updatePosition:function(bd){this.setPosition(Math.max(0,Math.min(this.getMaximum(),bd)));},scrollBy:function(bf,be){this.scrollTo(this.getPosition()+bf,be);},scrollBySteps:function(bh,bg){var bi=this.getSingleStep();this.scrollBy(bh*bi,bg);},stopScrollAnimation:function(){if(this.__qt){this.__qt.cancelSequence();this.__qt=null;};},_onScroll:function(e){var bj=this.getContentElement();var bk=this.__pg?bj.getScrollX():bj.getScrollY();this.setPosition(bk);},_onAppear:function(e){this._applyPosition(this.getPosition());},_stopPropagation:function(e){e.stopPropagation();}},destruct:function(){this._disposeObjects(C);}});})();(function(){var a="slider",b="slideAnimationEnd",c="PositiveNumber",d="changeValue",f="Integer",g="execute",h="track",i="qx.lang.Type.isNumber(value)&&value>=0&&value<=this.getMaximum()",j="_applyKnobFactor",k="visible",l="qx.event.type.Event",m="knob",n="button-begin",o="hidden",p="qx.ui.core.scroll.ScrollBar",q="resize",r="vertical",s="_applyOrientation",t="scrollAnimationEnd",u="_applyPageStep",v="right",w="PositiveInteger",x="horizontal",y="up",z="_applyPosition",A="scrollbar",B="_applyMaximum",C="left",D="button-end",E="down",F="scroll";qx.Class.define(p,{extend:qx.ui.core.Widget,implement:qx.ui.core.scroll.IScrollBar,construct:function(G){qx.ui.core.Widget.call(this);this._createChildControl(n);this._createChildControl(a).addListener(q,this._onResizeSlider,this);this._createChildControl(D);if(G!=null){this.setOrientation(G);}else {this.initOrientation();};this.addListener(h,function(e){e.stopPropagation();},this);},events:{"scrollAnimationEnd":l},properties:{appearance:{refine:true,init:A},orientation:{check:[x,r],init:x,apply:s},maximum:{check:w,apply:B,init:100},position:{check:i,init:0,apply:z,event:F},singleStep:{check:f,init:20},pageStep:{check:f,init:10,apply:u},knobFactor:{check:c,apply:j,nullable:true}},members:{__qu:2,__qv:0,_computeSizeHint:function(){var H=qx.ui.core.Widget.prototype._computeSizeHint.call(this);if(this.getOrientation()===x){this.__qv=H.minWidth;H.minWidth=0;}else {this.__qv=H.minHeight;H.minHeight=0;};return H;},renderLayout:function(M,top,J,I){var L=qx.ui.core.Widget.prototype.renderLayout.call(this,M,top,J,I);var K=this.getOrientation()===x;if(this.__qv>=(K?J:I)){this.getChildControl(n).setVisibility(o);this.getChildControl(D).setVisibility(o);}else {this.getChildControl(n).setVisibility(k);this.getChildControl(D).setVisibility(k);};return L;},_createChildControlImpl:function(P,O){var N;switch(P){case a:N=new qx.ui.core.scroll.ScrollSlider();N.setPageStep(100);N.setFocusable(false);N.addListener(d,this._onChangeSliderValue,this);N.addListener(b,this._onSlideAnimationEnd,this);this._add(N,{flex:1});break;case n:N=new qx.ui.form.RepeatButton();N.setFocusable(false);N.addListener(g,this._onExecuteBegin,this);this._add(N);break;case D:N=new qx.ui.form.RepeatButton();N.setFocusable(false);N.addListener(g,this._onExecuteEnd,this);this._add(N);break;};return N||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,P);},_applyMaximum:function(Q){this.getChildControl(a).setMaximum(Q);},_applyPosition:function(R){this.getChildControl(a).setValue(R);},_applyKnobFactor:function(S){this.getChildControl(a).setKnobFactor(S);},_applyPageStep:function(T){this.getChildControl(a).setPageStep(T);},_applyOrientation:function(W,U){var V=this._getLayout();if(V){V.dispose();};if(W===x){this._setLayout(new qx.ui.layout.HBox());this.setAllowStretchX(true);this.setAllowStretchY(false);this.replaceState(r,x);this.getChildControl(n).replaceState(y,C);this.getChildControl(D).replaceState(E,v);}else {this._setLayout(new qx.ui.layout.VBox());this.setAllowStretchX(false);this.setAllowStretchY(true);this.replaceState(x,r);this.getChildControl(n).replaceState(C,y);this.getChildControl(D).replaceState(v,E);};this.getChildControl(a).setOrientation(W);},scrollTo:function(Y,X){this.getChildControl(a).slideTo(Y,X);},scrollBy:function(bb,ba){this.getChildControl(a).slideBy(bb,ba);},scrollBySteps:function(bd,bc){var be=this.getSingleStep();this.getChildControl(a).slideBy(bd*be,bc);},updatePosition:function(bf){this.getChildControl(a).updatePosition(bf);},stopScrollAnimation:function(){this.getChildControl(a).stopSlideAnimation();},_onExecuteBegin:function(e){this.scrollBy(-this.getSingleStep(),50);},_onExecuteEnd:function(e){this.scrollBy(this.getSingleStep(),50);},_onSlideAnimationEnd:function(){this.fireEvent(t);},_onChangeSliderValue:function(e){this.setPosition(e.getData());},_onResizeSlider:function(e){var bg=this.getChildControl(a).getChildControl(m);var bj=bg.getSizeHint();var bh=false;var bi=this.getChildControl(a).getInnerSize();if(this.getOrientation()==r){if(bi.height<bj.minHeight+this.__qu){bh=true;};}else {if(bi.width<bj.minWidth+this.__qu){bh=true;};};if(bh){bg.exclude();}else {bg.show();};}}});})();(function(){var a="qx.ui.form.IRange";qx.Interface.define(a,{members:{setMinimum:function(b){return arguments.length==1;},getMinimum:function(){},setMaximum:function(c){return arguments.length==1;},getMaximum:function(){},setSingleStep:function(d){return arguments.length==1;},getSingleStep:function(){},setPageStep:function(e){return arguments.length==1;},getPageStep:function(){}}});})();(function(){var a="slider",b="hovered",c="pressed",d="px",f="pointerover",g="PageUp",h="changeValue",i="frame",j="end",k='qx.event.type.Data',l="Left",m="Down",n="Integer",o="roll",p="qx.ui.form.Slider",q="PageDown",r="interval",s="_applyValue",t="Up",u="_applyKnobFactor",v="End",w="pointermove",x="height",y="y",z="dbltap",A="resize",B="pointerup",C="vertical",D="Right",E="width",F="_applyOrientation",G="left",H="Home",I="floor",J="_applyMinimum",K="pointerdown",L="top",M="changeMaximum",N="horizontal",O="slideAnimationEnd",P="knob",Q="ceil",R='qx.event.type.Event',S="x",T="keypress",U="losecapture",V="contextmenu",W="wheel",X="_applyMaximum",Y="Number",bf="tap",bg="typeof value==='number'&&value>=this.getMinimum()&&value<=this.getMaximum()",bh="changeMinimum",be="pointerout";qx.Class.define(p,{extend:qx.ui.core.Widget,implement:[qx.ui.form.IForm,qx.ui.form.INumberForm,qx.ui.form.IRange],include:[qx.ui.form.MForm],construct:function(bi){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.Canvas());this.addListener(T,this._onKeyPress);this.addListener(o,this._onRoll);this.addListener(K,this._onPointerDown);this.addListener(B,this._onPointerUp);this.addListener(U,this._onPointerUp);this.addListener(A,this._onUpdate);this.addListener(V,this._onStopEvent);this.addListener(bf,this._onStopEvent);this.addListener(z,this._onStopEvent);if(bi!=null){this.setOrientation(bi);}else {this.initOrientation();};},events:{changeValue:k,slideAnimationEnd:R},properties:{appearance:{refine:true,init:a},focusable:{refine:true,init:true},orientation:{check:[N,C],init:N,apply:F},value:{check:bg,init:0,apply:s,nullable:true},minimum:{check:n,init:0,apply:J,event:bh},maximum:{check:n,init:100,apply:X,event:M},singleStep:{check:n,init:1},pageStep:{check:n,init:10},knobFactor:{check:Y,apply:u,nullable:true}},members:{__qw:null,__qx:null,__qy:null,__qz:null,__qA:null,__qB:null,__qC:null,__qD:null,__de:null,__qE:null,__qF:null,__qG:null,__qt:null,_forwardStates:{invalid:true},renderLayout:function(bk,top,bj,bl){qx.ui.core.Widget.prototype.renderLayout.call(this,bk,top,bj,bl);this._updateKnobPosition();},_createChildControlImpl:function(bo,bn){var bm;switch(bo){case P:bm=new qx.ui.core.Widget();bm.addListener(A,this._onUpdate,this);bm.addListener(f,this._onPointerOver);bm.addListener(be,this._onPointerOut);this._add(bm);break;};return bm||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,bo);},_onPointerOver:function(e){this.addState(b);},_onPointerOut:function(e){this.removeState(b);},_onRoll:function(e){if(e.getPointerType()!=W){return;};var bq=this.getOrientation()===N?S:y;var br=e.getDelta()[bq];var bp=br>0?1:br<0?-1:0;this.slideBy(bp*this.getSingleStep());e.stop();},_onKeyPress:function(e){var bt=this.getOrientation()===N;var bs=bt?l:t;var forward=bt?D:m;switch(e.getKeyIdentifier()){case forward:this.slideForward();break;case bs:this.slideBack();break;case q:this.slidePageForward(100);break;case g:this.slidePageBack(100);break;case H:this.slideToBegin(200);break;case v:this.slideToEnd(200);break;default:return;};e.stop();},_onPointerDown:function(e){if(this.__qz){return;};var bw=this.__pg;var bu=this.getChildControl(P);var bv=bw?G:L;var bA=bw?e.getDocumentLeft():e.getDocumentTop();var bC=this.getDecorator();bC=qx.theme.manager.Decoration.getInstance().resolve(bC);if(bw){var bz=bC?bC.getInsets().left:0;var by=(this.getPaddingLeft()||0)+bz;}else {var bz=bC?bC.getInsets().top:0;var by=(this.getPaddingTop()||0)+bz;};var bB=this.__qw=qx.bom.element.Location.get(this.getContentElement().getDomElement())[bv];bB+=by;var bx=this.__qx=qx.bom.element.Location.get(bu.getContentElement().getDomElement())[bv];if(e.getTarget()===bu){this.__qz=true;if(!this.__qE){this.__qE=new qx.event.Timer(100);this.__qE.addListener(r,this._fireValue,this);};this.__qE.start();this.__qA=bA+bB-bx;bu.addState(c);}else {this.__qB=true;this.__qC=bA<=bx?-1:1;this.__qI(e);this._onInterval();if(!this.__de){this.__de=new qx.event.Timer(100);this.__de.addListener(r,this._onInterval,this);};this.__de.start();};this.addListener(w,this._onPointerMove);this.capture();e.stopPropagation();},_onPointerUp:function(e){if(this.__qz){this.releaseCapture();delete this.__qz;this.__qE.stop();this._fireValue();delete this.__qA;this.getChildControl(P).removeState(c);if(e.getType()===B){var bE;var bF;var bD;if(this.__pg){bE=e.getDocumentLeft()-(this._valueToPosition(this.getValue())+this.__qw);bD=qx.bom.element.Location.get(this.getContentElement().getDomElement())[L];bF=e.getDocumentTop()-(bD+this.getChildControl(P).getBounds().top);}else {bE=e.getDocumentTop()-(this._valueToPosition(this.getValue())+this.__qw);bD=qx.bom.element.Location.get(this.getContentElement().getDomElement())[G];bF=e.getDocumentLeft()-(bD+this.getChildControl(P).getBounds().left);};if(bF<0||bF>this.__qy||bE<0||bE>this.__qy){this.getChildControl(P).removeState(b);};};}else if(this.__qB){this.__de.stop();this.releaseCapture();delete this.__qB;delete this.__qC;delete this.__qD;};this.removeListener(w,this._onPointerMove);if(e.getType()===B){e.stopPropagation();};},_onPointerMove:function(e){if(this.__qz){var bH=this.__pg?e.getDocumentLeft():e.getDocumentTop();var bG=bH-this.__qA;this.slideTo(this._positionToValue(bG));}else if(this.__qB){this.__qI(e);};e.stopPropagation();},_onInterval:function(e){var bI=this.getValue()+(this.__qC*this.getPageStep());if(bI<this.getMinimum()){bI=this.getMinimum();}else if(bI>this.getMaximum()){bI=this.getMaximum();};var bJ=this.__qC==-1;if((bJ&&bI<=this.__qD)||(!bJ&&bI>=this.__qD)){bI=this.__qD;};this.slideTo(bI);},_onUpdate:function(e){var bL=this.getInnerSize();var bM=this.getChildControl(P).getBounds();var bK=this.__pg?E:x;this._updateKnobSize();this.__qH=bL[bK]-bM[bK];this.__qy=bM[bK];this._updateKnobPosition();},__pg:false,__qH:0,__qI:function(e){var bN=this.__pg;var bU=bN?e.getDocumentLeft():e.getDocumentTop();var bX=this.__qw;var bO=this.__qx;var bY=this.__qy;var bV=bU-bX;if(bU>=bO){bV-=bY;};var bR=this._positionToValue(bV);var bP=this.getMinimum();var bQ=this.getMaximum();if(bR<bP){bR=bP;}else if(bR>bQ){bR=bQ;}else {var bW=this.getValue();var bT=this.getPageStep();var bS=this.__qC<0?I:Q;bR=bW+(Math[bS]((bR-bW)/bT)*bT);};if(this.__qD==null||(this.__qC==-1&&bR<=this.__qD)||(this.__qC==1&&bR>=this.__qD)){this.__qD=bR;};},_positionToValue:function(cb){var ca=this.__qH;if(ca==null||ca==0){return 0;};var cd=cb/ca;if(cd<0){cd=0;}else if(cd>1){cd=1;};var cc=this.getMaximum()-this.getMinimum();return this.getMinimum()+Math.round(cc*cd);},_valueToPosition:function(ch){var ce=this.__qH;if(ce==null){return 0;};var cf=this.getMaximum()-this.getMinimum();if(cf==0){return 0;};var ch=ch-this.getMinimum();var cg=ch/cf;if(cg<0){cg=0;}else if(cg>1){cg=1;};return Math.round(ce*cg);},_updateKnobPosition:function(){this._setKnobPosition(this._valueToPosition(this.getValue()));},_setKnobPosition:function(ck){var ci=this.getChildControl(P);var cj=this.getDecorator();cj=qx.theme.manager.Decoration.getInstance().resolve(cj);var content=ci.getContentElement();if(this.__pg){if(cj&&cj.getPadding()){ck+=cj.getPadding().left;};ck+=this.getPaddingLeft()||0;content.setStyle(G,ck+d,true);}else {if(cj&&cj.getPadding()){ck+=cj.getPadding().top;};ck+=this.getPaddingTop()||0;content.setStyle(L,ck+d,true);};},_updateKnobSize:function(){var cm=this.getKnobFactor();if(cm==null){return;};var cl=this.getInnerSize();if(cl==null){return;};if(this.__pg){this.getChildControl(P).setWidth(Math.round(cm*cl.width));}else {this.getChildControl(P).setHeight(Math.round(cm*cl.height));};},slideToBegin:function(cn){this.slideTo(this.getMinimum(),cn);},slideToEnd:function(co){this.slideTo(this.getMaximum(),co);},slideForward:function(){this.slideBy(this.getSingleStep());},slideBack:function(){this.slideBy(-this.getSingleStep());},slidePageForward:function(cp){this.slideBy(this.getPageStep(),cp);},slidePageBack:function(cq){this.slideBy(-this.getPageStep(),cq);},slideBy:function(cs,cr){this.slideTo(this.getValue()+cs,cr);},slideTo:function(cu,ct){this.stopSlideAnimation();if(ct){this.__qK(cu,ct);}else {this.updatePosition(cu);};},updatePosition:function(cv){this.setValue(this.__qJ(cv));},stopSlideAnimation:function(){if(this.__qt){this.__qt.cancelSequence();this.__qt=null;};},__qJ:function(cw){if(cw<this.getMinimum()){cw=this.getMinimum();}else if(cw>this.getMaximum()){cw=this.getMaximum();}else {cw=this.getMinimum()+Math.round((cw-this.getMinimum())/this.getSingleStep())*this.getSingleStep();};return cw;},__qK:function(cy,cx){cy=this.__qJ(cy);var cz=this.getValue();this.__qt=new qx.bom.AnimationFrame();this.__qt.on(i,function(cA){this.setValue(parseInt(cA/cx*(cy-cz)+cz));},this);this.__qt.on(j,function(){this.setValue(cy);this.__qt=null;this.fireEvent(O);},this);this.__qt.startSequence(cx);},_applyOrientation:function(cD,cC){var cB=this.getChildControl(P);this.__pg=cD===N;if(this.__pg){this.removeState(C);cB.removeState(C);this.addState(N);cB.addState(N);cB.setLayoutProperties({top:0,right:null,bottom:0});}else {this.removeState(N);cB.removeState(N);this.addState(C);cB.addState(C);cB.setLayoutProperties({right:0,bottom:null,left:0});};this._updateKnobPosition();},_applyKnobFactor:function(cF,cE){if(cF!=null){this._updateKnobSize();}else {if(this.__pg){this.getChildControl(P).resetWidth();}else {this.getChildControl(P).resetHeight();};};},_applyValue:function(cH,cG){if(cH!=null){this._updateKnobPosition();if(this.__qz){this.__qG=[cH,cG];}else {this.fireEvent(h,qx.event.type.Data,[cH,cG]);};}else {this.resetValue();};},_fireValue:function(){if(!this.__qG){return;};var cI=this.__qG;this.__qG=null;this.fireEvent(h,qx.event.type.Data,cI);},_applyMinimum:function(cK,cJ){if(this.getValue()<cK){this.setValue(cK);};this._updateKnobPosition();},_applyMaximum:function(cM,cL){if(this.getValue()>cM){this.setValue(cM);};this._updateKnobPosition();}}});})();(function(){var a="dblclick",b="qx.ui.core.scroll.ScrollSlider",c="horizontal",d="keypress",f="roll",g="knob";qx.Class.define(b,{extend:qx.ui.form.Slider,construct:function(h){qx.ui.form.Slider.call(this,h);this.removeListener(d,this._onKeyPress);this.removeListener(f,this._onRoll);},members:{_createChildControlImpl:function(k,j){var i;switch(k){case g:i=qx.ui.form.Slider.prototype._createChildControlImpl.call(this,k);i.addListener(a,function(e){e.stopPropagation();});};return i||qx.ui.form.Slider.prototype._createChildControlImpl.call(this,k);},getSizeHint:function(l){var m=qx.ui.form.Slider.prototype.getSizeHint.call(this);if(this.getOrientation()===c){m.width=0;}else {m.height=0;};return m;}}});})();(function(){var a="scrollY",b="_computeScrollbars",c="X",d="scrollbar-y",f="scrollAnimation",g="scrollbarX",h="auto",i="End",j="corner",k="os.scrollBarOverlayed",l="scrollarea",m="changeVisibility",n="vertical",o="scrollX",p="scrollAnimationEnd",q="off",r="horizontal",s="scrollbar-x",t="Y",u='qx.event.type.Event',v="qx.ui.core.scroll.AbstractScrollArea",w="abstract",x="update",y="scrollbarY",z="pane",A="on",B="scroll";qx.Class.define(v,{extend:qx.ui.core.Widget,include:[qx.ui.core.scroll.MScrollBarFactory,qx.ui.core.scroll.MRoll,qx.ui.core.MDragDropScrolling],type:w,statics:{DEFAULT_SCROLLBAR_WIDTH:14},construct:function(){qx.ui.core.Widget.call(this);if(qx.core.Environment.get(k)){this._setLayout(new qx.ui.layout.Canvas());}else {var C=new qx.ui.layout.Grid();C.setColumnFlex(0,1);C.setRowFlex(0,1);this._setLayout(C);};this._addRollHandling();},events:{scrollAnimationXEnd:u,scrollAnimationYEnd:u},properties:{appearance:{refine:true,init:l},width:{refine:true,init:100},height:{refine:true,init:200},scrollbarX:{check:[h,A,q],init:h,themeable:true,apply:b},scrollbarY:{check:[h,A,q],init:h,themeable:true,apply:b},scrollbar:{group:[g,y]}},members:{_createChildControlImpl:function(F,E){var D;switch(F){case z:D=new qx.ui.core.scroll.ScrollPane();D.addListener(x,this._computeScrollbars,this);D.addListener(o,this._onScrollPaneX,this);D.addListener(a,this._onScrollPaneY,this);if(qx.core.Environment.get(k)){this._add(D,{edge:0});}else {this._add(D,{row:0,column:0});};break;case s:D=this._createScrollBar(r);D.setMinWidth(0);D.exclude();D.addListener(B,this._onScrollBarX,this);D.addListener(m,this._onChangeScrollbarXVisibility,this);D.addListener(p,this._onScrollAnimationEnd.bind(this,c));if(qx.core.Environment.get(k)){D.setMinHeight(qx.ui.core.scroll.AbstractScrollArea.DEFAULT_SCROLLBAR_WIDTH);this._add(D,{bottom:0,right:0,left:0});}else {this._add(D,{row:1,column:0});};break;case d:D=this._createScrollBar(n);D.setMinHeight(0);D.exclude();D.addListener(B,this._onScrollBarY,this);D.addListener(m,this._onChangeScrollbarYVisibility,this);D.addListener(p,this._onScrollAnimationEnd.bind(this,t));if(qx.core.Environment.get(k)){D.setMinWidth(qx.ui.core.scroll.AbstractScrollArea.DEFAULT_SCROLLBAR_WIDTH);this._add(D,{right:0,bottom:0,top:0});}else {this._add(D,{row:0,column:1});};break;case j:D=new qx.ui.core.Widget();D.setWidth(0);D.setHeight(0);D.exclude();if(!qx.core.Environment.get(k)){this._add(D,{row:1,column:1});};break;};return D||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,F);},getPaneSize:function(){return this.getChildControl(z).getInnerSize();},getItemTop:function(G){return this.getChildControl(z).getItemTop(G);},getItemBottom:function(H){return this.getChildControl(z).getItemBottom(H);},getItemLeft:function(I){return this.getChildControl(z).getItemLeft(I);},getItemRight:function(J){return this.getChildControl(z).getItemRight(J);},scrollToX:function(L,K){qx.ui.core.queue.Manager.flush();this.getChildControl(s).scrollTo(L,K);},scrollByX:function(N,M){qx.ui.core.queue.Manager.flush();this.getChildControl(s).scrollBy(N,M);},getScrollX:function(){var O=this.getChildControl(s,true);return O?O.getPosition():0;},scrollToY:function(Q,P){qx.ui.core.queue.Manager.flush();this.getChildControl(d).scrollTo(Q,P);},scrollByY:function(S,R){qx.ui.core.queue.Manager.flush();this.getChildControl(d).scrollBy(S,R);},getScrollY:function(){var T=this.getChildControl(d,true);return T?T.getPosition():0;},stopScrollAnimationX:function(){var U=this.getChildControl(s,true);if(U){U.stopScrollAnimation();};},stopScrollAnimationY:function(){var V=this.getChildControl(d,true);if(V){V.stopScrollAnimation();};},_onScrollAnimationEnd:function(W){this.fireEvent(f+W+i);},_onScrollBarX:function(e){this.getChildControl(z).scrollToX(e.getData());},_onScrollBarY:function(e){this.getChildControl(z).scrollToY(e.getData());},_onScrollPaneX:function(e){var X=this.getChildControl(s);if(X){X.updatePosition(e.getData());};},_onScrollPaneY:function(e){var Y=this.getChildControl(d);if(Y){Y.updatePosition(e.getData());};},_onChangeScrollbarXVisibility:function(e){var ba=this._isChildControlVisible(s);var bb=this._isChildControlVisible(d);if(!ba){this.scrollToX(0);};ba&&bb?this._showChildControl(j):this._excludeChildControl(j);},_onChangeScrollbarYVisibility:function(e){var bc=this._isChildControlVisible(s);var bd=this._isChildControlVisible(d);if(!bd){this.scrollToY(0);};bc&&bd?this._showChildControl(j):this._excludeChildControl(j);},_computeScrollbars:function(){var bk=this.getChildControl(z);var content=bk.getChildren()[0];if(!content){this._excludeChildControl(s);this._excludeChildControl(d);return;};var be=this.getInnerSize();var bj=bk.getInnerSize();var bh=bk.getScrollSize();if(!bj||!bh){return;};var bl=this.getScrollbarX();var bm=this.getScrollbarY();if(bl===h&&bm===h){var bi=bh.width>be.width;var bn=bh.height>be.height;if((bi||bn)&&!(bi&&bn)){if(bi){bn=bh.height>bj.height;}else if(bn){bi=bh.width>bj.width;};};}else {var bi=bl===A;var bn=bm===A;if(bh.width>(bi?bj.width:be.width)&&bl===h){bi=true;};if(bh.height>(bi?bj.height:be.height)&&bm===h){bn=true;};};if(bi){var bg=this.getChildControl(s);bg.show();bg.setMaximum(Math.max(0,bh.width-bj.width));bg.setKnobFactor((bh.width===0)?0:bj.width/bh.width);}else {this._excludeChildControl(s);};if(bn){var bf=this.getChildControl(d);bf.show();bf.setMaximum(Math.max(0,bh.height-bj.height));bf.setKnobFactor((bh.height===0)?0:bj.height/bh.height);}else {this._excludeChildControl(d);};}}});})();(function(){var a="os.version",b="os.name",c="qx.mobile.nativescroll",d="osx",e="qx.nativeScrollBars",f="event.mspointer",g="android",h="firefox",i="os.scrollBarOverlayed",j="browser.version",k="ios",l=".",m="browser.name",n="qx.bom.client.Scroll";qx.Bootstrap.define(n,{statics:{scrollBarOverlayed:function(){var o=qx.bom.element.Scroll.getScrollbarWidth();var q=qx.bom.client.OperatingSystem.getName()===d;var p=qx.core.Environment.get(e);return o===0&&q&&p;},getNativeScroll:function(){if(qx.core.Environment.get(b)==k&&parseInt(qx.core.Environment.get(j),10)>7){return true;};if(qx.core.Environment.get(m)==h){return true;};if(qx.core.Environment.get(b)==g){var s=qx.core.Environment.get(a);var r=s.split(l);if(r[0]>4||(r.length>1&&r[0]>3&&r[1]>3)){return true;};};if(qx.core.Environment.get(f)){return true;};return false;}},defer:function(t){qx.core.Environment.add(i,t.scrollBarOverlayed);qx.core.Environment.add(c,t.getNativeScroll);}});})();(function(){var a="qx.ui.form.List",b="text",c="Boolean",d="one",f="addChildWidget",g="_applySpacing",h="Enter",j="Integer",k="action",m="keyinput",n="qx.event.type.Data",o="addItem",p="vertical",q="removeChildWidget",r="",s="_applyOrientation",t="single",u="keypress",v="list",w="horizontal",x="label",y="__vL",z="pane",A="removeItem";qx.Class.define(a,{extend:qx.ui.core.scroll.AbstractScrollArea,implement:[qx.ui.core.IMultiSelection,qx.ui.form.IForm,qx.ui.form.IModelSelection],include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.core.MMultiSelectionHandling,qx.ui.form.MForm,qx.ui.form.MModelSelection],construct:function(B){qx.ui.core.scroll.AbstractScrollArea.call(this);this.__vL=this._createListItemContainer();this.__vL.addListener(f,this._onAddChild,this);this.__vL.addListener(q,this._onRemoveChild,this);this.getChildControl(z).add(this.__vL);if(B){this.setOrientation(w);}else {this.initOrientation();};this.addListener(u,this._onKeyPress);this.addListener(m,this._onKeyInput);this.__vM=r;},events:{addItem:n,removeItem:n},properties:{appearance:{refine:true,init:v},focusable:{refine:true,init:true},orientation:{check:[w,p],init:p,apply:s},spacing:{check:j,init:0,apply:g,themeable:true},enableInlineFind:{check:c,init:true}},members:{__vM:null,__vN:null,__vL:null,SELECTION_MANAGER:qx.ui.core.selection.ScrollArea,getChildrenContainer:function(){return this.__vL;},_onAddChild:function(e){this.fireDataEvent(o,e.getData());},_onRemoveChild:function(e){this.fireDataEvent(A,e.getData());},handleKeyPress:function(e){if(!this._onKeyPress(e)){this._getManager().handleKeyPress(e);};},_createListItemContainer:function(){return new qx.ui.container.Composite;},_applyOrientation:function(E,C){var content=this.__vL;var D=content.getLayout();var G=E===w;var F=G?new qx.ui.layout.HBox():new qx.ui.layout.VBox();content.setLayout(F);content.setAllowGrowX(!G);content.setAllowGrowY(G);this._applySpacing(this.getSpacing());if(D){D.dispose();};},_applySpacing:function(I,H){this.__vL.getLayout().setSpacing(I);},_onKeyPress:function(e){if(e.getKeyIdentifier()==h&&!e.isAltPressed()){var J=this.getSelection();for(var i=0;i<J.length;i++ ){J[i].fireEvent(k);};return true;};return false;},_onKeyInput:function(e){if(!this.getEnableInlineFind()){return;};var K=this.getSelectionMode();if(!(K===t||K===d)){return;};if(((new Date).valueOf()-this.__vN)>1000){this.__vM=r;};this.__vM+=e.getChar();var L=this.findItemByLabelFuzzy(this.__vM);if(L){this.setSelection([L]);};this.__vN=(new Date).valueOf();},findItemByLabelFuzzy:function(N){N=N.toLowerCase();var M=this.getChildren();for(var i=0,l=M.length;i<l;i++ ){var O=M[i].getLabel();if(O&&O.toLowerCase().indexOf(N)==0){return M[i];};};return null;},findItem:function(Q,U){if(U!==false){Q=Q.toLowerCase();};var S=this.getChildren();var V;for(var i=0,l=S.length;i<l;i++ ){V=S[i];var T;if(V.isRich()){var P=V.getChildControl(x,true);if(P){var R=P.getContentElement().getDomElement();if(R){T=qx.bom.element.Attribute.get(R,b);};};}else {T=V.getLabel();};if(T!=null){if(T.translate){T=T.translate();};if(U!==false){T=T.toLowerCase();};if(T.toString()==Q.toString()){return V;};};};return null;}},destruct:function(){this._disposeObjects(y);}});})();(function(){var a="<br",b="",c=" &nbsp;",d="<br>",e=" ",f="\n",g="qx.bom.String";qx.Bootstrap.define(g,{statics:{TO_CHARCODE:{"quot":34,"amp":38,"lt":60,"gt":62,"nbsp":160,"iexcl":161,"cent":162,"pound":163,"curren":164,"yen":165,"brvbar":166,"sect":167,"uml":168,"copy":169,"ordf":170,"laquo":171,"not":172,"shy":173,"reg":174,"macr":175,"deg":176,"plusmn":177,"sup2":178,"sup3":179,"acute":180,"micro":181,"para":182,"middot":183,"cedil":184,"sup1":185,"ordm":186,"raquo":187,"frac14":188,"frac12":189,"frac34":190,"iquest":191,"Agrave":192,"Aacute":193,"Acirc":194,"Atilde":195,"Auml":196,"Aring":197,"AElig":198,"Ccedil":199,"Egrave":200,"Eacute":201,"Ecirc":202,"Euml":203,"Igrave":204,"Iacute":205,"Icirc":206,"Iuml":207,"ETH":208,"Ntilde":209,"Ograve":210,"Oacute":211,"Ocirc":212,"Otilde":213,"Ouml":214,"times":215,"Oslash":216,"Ugrave":217,"Uacute":218,"Ucirc":219,"Uuml":220,"Yacute":221,"THORN":222,"szlig":223,"agrave":224,"aacute":225,"acirc":226,"atilde":227,"auml":228,"aring":229,"aelig":230,"ccedil":231,"egrave":232,"eacute":233,"ecirc":234,"euml":235,"igrave":236,"iacute":237,"icirc":238,"iuml":239,"eth":240,"ntilde":241,"ograve":242,"oacute":243,"ocirc":244,"otilde":245,"ouml":246,"divide":247,"oslash":248,"ugrave":249,"uacute":250,"ucirc":251,"uuml":252,"yacute":253,"thorn":254,"yuml":255,"fnof":402,"Alpha":913,"Beta":914,"Gamma":915,"Delta":916,"Epsilon":917,"Zeta":918,"Eta":919,"Theta":920,"Iota":921,"Kappa":922,"Lambda":923,"Mu":924,"Nu":925,"Xi":926,"Omicron":927,"Pi":928,"Rho":929,"Sigma":931,"Tau":932,"Upsilon":933,"Phi":934,"Chi":935,"Psi":936,"Omega":937,"alpha":945,"beta":946,"gamma":947,"delta":948,"epsilon":949,"zeta":950,"eta":951,"theta":952,"iota":953,"kappa":954,"lambda":955,"mu":956,"nu":957,"xi":958,"omicron":959,"pi":960,"rho":961,"sigmaf":962,"sigma":963,"tau":964,"upsilon":965,"phi":966,"chi":967,"psi":968,"omega":969,"thetasym":977,"upsih":978,"piv":982,"bull":8226,"hellip":8230,"prime":8242,"Prime":8243,"oline":8254,"frasl":8260,"weierp":8472,"image":8465,"real":8476,"trade":8482,"alefsym":8501,"larr":8592,"uarr":8593,"rarr":8594,"darr":8595,"harr":8596,"crarr":8629,"lArr":8656,"uArr":8657,"rArr":8658,"dArr":8659,"hArr":8660,"forall":8704,"part":8706,"exist":8707,"empty":8709,"nabla":8711,"isin":8712,"notin":8713,"ni":8715,"prod":8719,"sum":8721,"minus":8722,"lowast":8727,"radic":8730,"prop":8733,"infin":8734,"ang":8736,"and":8743,"or":8744,"cap":8745,"cup":8746,"int":8747,"there4":8756,"sim":8764,"cong":8773,"asymp":8776,"ne":8800,"equiv":8801,"le":8804,"ge":8805,"sub":8834,"sup":8835,"sube":8838,"supe":8839,"oplus":8853,"otimes":8855,"perp":8869,"sdot":8901,"lceil":8968,"rceil":8969,"lfloor":8970,"rfloor":8971,"lang":9001,"rang":9002,"loz":9674,"spades":9824,"clubs":9827,"hearts":9829,"diams":9830,"OElig":338,"oelig":339,"Scaron":352,"scaron":353,"Yuml":376,"circ":710,"tilde":732,"ensp":8194,"emsp":8195,"thinsp":8201,"zwnj":8204,"zwj":8205,"lrm":8206,"rlm":8207,"ndash":8211,"mdash":8212,"lsquo":8216,"rsquo":8217,"sbquo":8218,"ldquo":8220,"rdquo":8221,"bdquo":8222,"dagger":8224,"Dagger":8225,"permil":8240,"lsaquo":8249,"rsaquo":8250,"euro":8364},escape:function(h){return qx.util.StringEscape.escape(h,qx.bom.String.FROM_CHARCODE);},unescape:function(i){return qx.util.StringEscape.unescape(i,qx.bom.String.TO_CHARCODE);},fromText:function(j){return qx.bom.String.escape(j).replace(/(  |\n)/g,function(l){var k={"  ":c,"\n":d};return k[l]||l;});},toText:function(m){return qx.bom.String.unescape(m.replace(/\s+|<([^>])+>/gi,function(n){if(n.indexOf(a)===0){return f;}else if(n.length>0&&n.replace(/^\s*/,b).replace(/\s*$/,b)==b){return e;}else {return b;};}));}},defer:function(o){o.FROM_CHARCODE=qx.lang.Object.invert(o.TO_CHARCODE);}});})();(function(){var a="&",b='X',c="",d='#',e="&#",f=";",g="qx.util.StringEscape";qx.Bootstrap.define(g,{statics:{escape:function(o,m){var j,n=c;for(var i=0,l=o.length;i<l;i++ ){var k=o.charAt(i);var h=k.charCodeAt(0);if(m[h]){j=a+m[h]+f;}else {if(h>0x7F){j=e+h+f;}else {j=k;};};n+=j;};return n;},unescape:function(p,q){return p.replace(/&[#\w]+;/gi,function(t){var r=t;var t=t.substring(1,t.length-1);var s=q[t];if(s){r=String.fromCharCode(s);}else {if(t.charAt(0)==d){if(t.charAt(1).toUpperCase()==b){s=t.substring(2);if(s.match(/^[0-9A-Fa-f]+$/gi)){r=String.fromCharCode(parseInt(s,16));};}else {s=t.substring(1);if(s.match(/^\d+$/gi)){r=String.fromCharCode(parseInt(s,10));};};};};return r;});}}});})();(function(){var a="hovered",b="Enter",c="pressed",d="one",f="pointerover",g="changeLabel",h="changeIcon",i="Space",j="abandoned",k="key",l="list",m="keyinput",n="arrow",o="changeSelection",p="quick",q="",r="qx.ui.form.SelectBox",s="spacer",t="selectbox",u="popup",v=" ",w="tap",x="pointerout",y="atom";qx.Class.define(r,{extend:qx.ui.form.AbstractSelectBox,implement:[qx.ui.core.ISingleSelection,qx.ui.form.IModelSelection],include:[qx.ui.core.MSingleSelectionHandling,qx.ui.form.MModelSelection],construct:function(){qx.ui.form.AbstractSelectBox.call(this);this._createChildControl(y);this._createChildControl(s);this._createChildControl(n);this.addListener(f,this._onPointerOver,this);this.addListener(x,this._onPointerOut,this);this.addListener(w,this._onTap,this);this.addListener(m,this._onKeyInput,this);this.addListener(o,this.__ql,this);},properties:{appearance:{refine:true,init:t}},members:{__vO:null,_createChildControlImpl:function(B,A){var z;switch(B){case s:z=new qx.ui.core.Spacer();this._add(z,{flex:1});break;case y:z=new qx.ui.basic.Atom(v);z.setCenter(false);z.setAnonymous(true);this._add(z,{flex:1});break;case n:z=new qx.ui.basic.Image();z.setAnonymous(true);this._add(z);break;};return z||qx.ui.form.AbstractSelectBox.prototype._createChildControlImpl.call(this,B);},_forwardStates:{focused:true},_getItems:function(){return this.getChildrenContainer().getChildren();},_isAllowEmptySelection:function(){return this.getChildrenContainer().getSelectionMode()!==d;},__ql:function(e){var D=e.getData()[0];var C=this.getChildControl(l);if(C.getSelection()[0]!=D){if(D){C.setSelection([D]);}else {C.resetSelection();};};this.__vP();this.__vQ();},__vP:function(){var F=this.getChildControl(l).getSelection()[0];var E=this.getChildControl(y);var G=F?F.getIcon():q;G==null?E.resetIcon():E.setIcon(G);},__vQ:function(){var J=this.getChildControl(l).getSelection()[0];var H=this.getChildControl(y);var I=J?J.getLabel():q;var K=this.getFormat();if(K!=null){I=K.call(this,J);};if(I&&I.translate){I=I.translate();};I==null?H.resetLabel():H.setLabel(I);},_onPointerOver:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};if(this.hasState(j)){this.removeState(j);this.addState(c);};this.addState(a);},_onPointerOut:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};this.removeState(a);if(this.hasState(c)){this.removeState(c);this.addState(j);};},_onTap:function(e){this.toggle();},_onKeyPress:function(e){var L=e.getKeyIdentifier();if(L==b||L==i){if(this.__vO){this.setSelection([this.__vO]);this.__vO=null;};this.toggle();}else {qx.ui.form.AbstractSelectBox.prototype._onKeyPress.call(this,e);};},_onKeyInput:function(e){var M=e.clone();M.setTarget(this._list);M.setBubbles(false);this.getChildControl(l).dispatchEvent(M);},_onListPointerDown:function(e){if(this.__vO){this.setSelection([this.__vO]);this.__vO=null;};},_onListChangeSelection:function(e){var Q=e.getData();var O=e.getOldData();if(O&&O.length>0){O[0].removeListener(h,this.__vP,this);O[0].removeListener(g,this.__vQ,this);};if(Q.length>0){var N=this.getChildControl(u);var P=this.getChildControl(l);var R=P.getSelectionContext();if(N.isVisible()&&(R==p||R==k)){this.__vO=Q[0];}else {this.setSelection([Q[0]]);this.__vO=null;};Q[0].addListener(h,this.__vP,this);Q[0].addListener(g,this.__vQ,this);}else {this.resetSelection();};},_onPopupChangeVisibility:function(e){qx.ui.form.AbstractSelectBox.prototype._onPopupChangeVisibility.call(this,e);var T=this.getChildControl(u);if(!T.isVisible()){var V=this.getChildControl(l);if(V.hasChildren()){V.setSelection(this.getSelection());};}else {var S=T.getLayoutLocation(this);var X=qx.bom.Viewport.getHeight();var W=S.top;var Y=X-S.bottom;var U=W>Y?W:Y;var ba=this.getMaxListHeight();var V=this.getChildControl(l);if(ba==null||ba>U){V.setMaxHeight(U);}else if(ba<U){V.setMaxHeight(ba);};};}},destruct:function(){this.__vO=null;}});})();(function(){var a='kucken.ui.form.SelectBoxHelper',b='',c='Unsupported list widget';qx.Class.define(a,{statics:{_validate:function(d){if(!(d instanceof qx.ui.form.AbstractSelectBox)){throw new Error(c);};},allowEmpty:function(f,e,name){this._validate(e);e.add(new qx.ui.form.ListItem(b,null,-1));f.addBindingOptions(name,{'converter':function(g){return g===null?-1:g;}},{'converter':function(h){return h===-1?null:h;}});},addFromMap:function(j,i){this._validate(j);kucken.Fix.fix5443(i);kucken.lang.Object.items(i).forEach(function(k){j.add(new qx.ui.form.ListItem(k[1],null,k[0]));});}}});})();(function(){var a='translate(0, {0})',b='bar-container',c='y axis',e='_applyCompact',f='.x.axis',g='<div>{{ count }} {{ unit }}</div>',h='</div>',i='hour',j='translate({0}, {1})',k='',l='Boolean',m='resize',n='line',o='transform',p='.y.axis',q='100%',r='.bar-container',s='_timeFormatter',t='brushend',u='.x.axis *',v='y2',w='x axis',x='mouseout',y='timeline',z='left',A='y1',B='+PT23H59M',C='x brush',D='width',E='<div>[{{ time0 }}; {{ time1 }}]</div>',F='changeZoomRange',G='height',H='x2',I='bottom',J='count',K='_applyZoomEnabled',L='date',M='.x.brush *',N='translate({0}, -1)',O='+PT59M',P='.x.highlight line',Q='svg',R='quad-in-out',S='Array',T='record(s)',U='opacity',V='<div>{{ date }}</div>',W='appear',X='_applyHighlightDate',Y='day',bB='g',bC='short',bD='class',bx='bottom-center',by='popup',bz='x1',bA='<div style="width: 190px; text-align: center;">',bH='rect',bI='_applySeries',bJ='Date',bP='mouseover',bE='x highlight',bF='.bar',bG='.x.brush',bv='_numberFormatter',bL='clui.view.Timeline',bw='s',bM='bar',bN='_dateFormatter',bO='_barToolTip',bK='full';qx.Class.define(bL,{extend:qx.ui.container.Composite,statics:{xAxisMarginTop:5,yAxisMarginRight:5,transitionDuration:333},properties:{series:{check:S,init:[],apply:bI},group:{check:[Y,i],nullable:true},compact:{check:l,apply:e},zoomEnabled:{check:l,init:false,apply:K},zoomRange:{check:S,nullable:true,event:F},highlightDate:{check:bJ,nullable:true,apply:X}},construct:function(){qx.ui.container.Composite.call(this);this._d3=kucken.lib.D3.get();this.setLayout(new qx.ui.layout.VBox());this.setMinHeight(75);this.addListenerOnce(W,this._createBarChart,this);this._barToolTip=new qx.ui.tooltip.ToolTip();this._barToolTip.set({'appearance':by,'rich':true,'autoHide':false,'position':bx,'padding':8});this._numberFormatter=new qx.util.format.NumberFormat();this._numberFormatter.setMaximumFractionDigits(0);this._dateFormatter=new qx.util.format.DateFormat(qx.locale.Date.getDateFormat(bK));this._timeFormatter=new qx.util.format.DateFormat(qx.locale.Date.getTimeFormat(bC));this.setCompact(false);},destruct:function(){this._disposeObjects(bO,bv,bN,s);},members:{_d3:null,_barToolTip:null,_numberFormatter:null,_dateFormatter:null,_timeFormatter:null,_chartXAxis:null,_chartYAxis:null,_chartSvg:null,_zoomBrush:null,_chartMargin:null,_zoomSeries:null,_applySeries:function(bR,bQ){this._update();},_applyCompact:function(bT,bS){if(bT){this._chartMargin={'top':9,'right':21,'bottom':6,'left':60};this._barToolTip.setOffsetTop(0);if(this._chartSvg){this._chartSvg.selectAll(u).remove();};}else {this._chartMargin={'top':20,'right':50,'bottom':40,'left':80};this._barToolTip.setOffsetTop(-27);};this._update();},_applyZoomEnabled:function(bV,bU){if(this._chartSvg&&!bV){this._zoomBrush.clear();this._chartSvg.selectAll(M).remove();};this._zoomSeries=bV?this.getSeries():null;this._update();},_applyHighlightDate:function(ca,bX){if(!this._chartSvg){return;};var bW=this._chartSvg.select(P);if(!ca&&!this._zoomSeries){bW.style(U,0);}else if(ca){var bY=this._chartYAxis.scale().domain();bW.attr(A,this._chartYAxis.scale()(bY[0])).attr(v,this._chartYAxis.scale()(bY[1])).attr(bz,this._chartXAxis.scale()(ca)).attr(H,this._chartXAxis.scale()(ca)).style(U,1);};},_getToolTipLabel:function(cc){var cf=[bA,V,E,g,h].join(k);var cd=this.getGroup();var ce=cc[L];var cb=new kucken.date.RelativeDate();if(cd==Y){cb.setExpression(ce.toISOString()+B);ce=cb.toDate();}else if(cd==i){cb.setExpression(ce.toISOString()+O);ce=cb.toDate();};return qx.bom.Template.render(cf,{'date':this._dateFormatter.format(cc[L]),'time0':this._timeFormatter.format(cc[L]),'time1':this._timeFormatter.format(ce),'count':this._numberFormatter.format(cc[J]),'unit':this.tr(T)});},_onBarMouseOver:function(ci){var ch=this.getContentElement().getDomElement();var location=qx.bom.element.Location.get(ch);var cg=qx.bom.element.Dimension.getSize(ch);var cj={'left':location.left+this._chartMargin.left+Math.floor(this._chartXAxis.scale()(ci.date)),'top':location.top+cg.height};this._barToolTip.placeToPoint(cj);this._barToolTip.setLabel(this._getToolTipLabel(ci));this._barToolTip.show();},_onBarMouseOut:function(ck){this._barToolTip.hide();},_update:function(cw){if(!this._chartSvg){return;};var cv=this._chartMargin;this._chartSvg.attr(o,j.format(cv.left,cv.top));if(!cw){var cr=this.getContentElement().getDomElement();cw=qx.bom.element.Dimension.getSize(cr);};cw.width-=cv.left+cv.right;cw.height-=cv.top+cv.bottom;var co=this._zoomSeries||this.getSeries();var cl=co.map(kucken.lang.Object.select.bind(null,L));var cu=this._d3.time.scale().range([0,cw.width]).domain(this._d3.extent(cl));this._chartXAxis.scale(cu);var cn=this._d3.scale.linear().range([cw.height,0]).domain([0,qx.lang.Array.max(co.map(kucken.lang.Object.select.bind(null,J)))]);this._chartYAxis.scale(cn);var cq=this._d3.scale.ordinal().domain(cl).rangeRoundBands(cu.range(),0.1).rangeBand();cq=Math.min(cq,Math.floor(cv.left/2));if(!this.getCompact()){var cp=this.self(arguments).xAxisMarginTop;this._chartSvg.select(f).transition().duration(this.self(arguments).transitionDuration).attr(o,a.format(cw.height+cp)).call(this._chartXAxis);};var cm=this.self(arguments).yAxisMarginRight;this._chartSvg.select(p).transition().duration(this.self(arguments).transitionDuration).attr(o,N.format(-cq/2-cm)).call(this._chartYAxis.ticks(2,bw));var cs={'x':function(d){return cu(d[L])-cq/2+1;},'y':function(d){return cn(d[J]);},'width':cq,'height':function(d){return cw.height-cn(d[J]);}};var ct=this._chartSvg.select(r).selectAll(bF).data(co,kucken.lang.Object.select.bind(null,L));ct.transition().duration(this.self(arguments).transitionDuration).ease(R).attr(cs);ct.exit().remove();ct.enter().append(bH).attr(bD,bM).attr(cs).on(bP,this._onBarMouseOver.bind(this)).on(x,this._onBarMouseOut.bind(this));if(this.getZoomEnabled()){this._zoomBrush.x(cu);this._chartSvg.select(bG).call(this._zoomBrush).selectAll(bH).attr(G,cw.height);};},_onZoom:function(){this.setZoomRange(this._zoomBrush.empty()?null:this._zoomBrush.extent());},_createBarChart:function(){this._chartXAxis=this._d3.svg.axis().orient(I);this._chartYAxis=this._d3.svg.axis().orient(z).ticks(2);this._zoomBrush=this._d3.svg.brush().on(t,this._onZoom.bind(this));var cx=this.getContentElement().getDomElement();this._chartSvg=this._d3.select(cx).append(Q).attr(bD,y).attr(D,q).attr(G,q).append(bB);this._chartSvg.append(bB).attr(bD,b);this._chartSvg.append(bB).attr(bD,c);this._chartSvg.append(bB).attr(bD,w);this._chartSvg.append(bB).attr(bD,C);this._chartSvg.append(bB).attr(bD,bE).append(n);this._update();this.addListener(m,function(event){this._update(event.getData());},this);}}});})();(function(){var a="-",b="Boolean",c='{0,1}[0-9]{3}){0,}){0,1}',d=")?$",e="Number string '",f="' does not match the number format",g="Wrong argument type. String is expected.",h="0",i="^(",j="changeLocale",k=')?([-+]){0,1}',l='(',m="-Infinity",n="String",o="",p='\\d+){0,1}(',q='([0-9]{1,3}(?:',r="g",s="qx.util.format.NumberFormat",t="locale",u="Wrong number of arguments.",v="Number",w="NaN",x="changeNumberFormat",y=".",z="Infinity";qx.Class.define(s,{extend:qx.core.Object,implement:qx.util.format.IFormat,construct:function(A){qx.core.Object.call(this);if(arguments.length>0){if(arguments.length===1){if(qx.lang.Type.isString(A)){this.setLocale(A);}else {throw new Error(g);};}else {throw new Error(u);};};if(!A){this.setLocale(qx.locale.Manager.getInstance().getLocale());{qx.locale.Manager.getInstance().bind(t,this,t);};};},properties:{minimumIntegerDigits:{check:v,init:0},maximumIntegerDigits:{check:v,nullable:true},minimumFractionDigits:{check:v,init:0},maximumFractionDigits:{check:v,nullable:true},groupingUsed:{check:b,init:true},prefix:{check:n,init:o,event:x},postfix:{check:n,init:o,event:x},locale:{check:n,init:null,event:j}},members:{format:function(G){if(isNaN(G)){return w;};switch(G){case Infinity:return z;case -Infinity:return m;};var E=(G<0);if(E){G=-G;};if(this.getMaximumFractionDigits()!=null){var M=Math.pow(10,this.getMaximumFractionDigits());G=Math.round(G*M)/M;};var K=String(Math.floor(G)).length;var B=o+G;var I=B.substring(0,K);while(I.length<this.getMinimumIntegerDigits()){I=h+I;};if(this.getMaximumIntegerDigits()!=null&&I.length>this.getMaximumIntegerDigits()){I=I.substring(I.length-this.getMaximumIntegerDigits());};var H=B.substring(K+1);while(H.length<this.getMinimumFractionDigits()){H+=h;};if(this.getMaximumFractionDigits()!=null&&H.length>this.getMaximumFractionDigits()){H=H.substring(0,this.getMaximumFractionDigits());};if(this.getGroupingUsed()){var D=I;I=o;var L;for(L=D.length;L>3;L-=3){I=o+qx.locale.Number.getGroupSeparator(this.getLocale())+D.substring(L-3,L)+I;};I=D.substring(0,L)+I;};var F=this.getPrefix()?this.getPrefix():o;var C=this.getPostfix()?this.getPostfix():o;var J=F+(E?a:o)+I;if(H.length>0){J+=o+qx.locale.Number.getDecimalSeparator(this.getLocale())+H;};J+=C;return J;},parse:function(V){var R=qx.lang.String.escapeRegexpChars(qx.locale.Number.getGroupSeparator(this.getLocale())+o);var P=qx.lang.String.escapeRegexpChars(qx.locale.Number.getDecimalSeparator(this.getLocale())+o);var N=new RegExp(i+qx.lang.String.escapeRegexpChars(this.getPrefix())+k+q+R+c+l+P+p+qx.lang.String.escapeRegexpChars(this.getPostfix())+d);var Q=N.exec(V);if(Q==null){throw new Error(e+V+f);};var S=(Q[2]==a);var U=Q[3]||h;var T=Q[4];U=U.replace(new RegExp(R,r),o);var O=(S?a:o)+U;if(T!=null&&T.length!=0){T=T.replace(new RegExp(P),o);O+=y+T;};return parseFloat(O);}},destruct:function(){{qx.locale.Manager.getInstance().removeRelatedBindings(this);};}});})();(function(){var a='&#x60;',b='}}',c='" was given as the first ',d='',e='argument for mustache#render(template, view, partials)',f='&amp;',g='&#39;',h='Unclosed tag at ',k='object',l="div",m='2.2.1',n='\\$&',o='Cannot use higher-order sections without the original template',p='function',q='^',r='array',t='&gt;',u='exports',v='&lt;',w='mustache.js',x='.',y="qx.bom.Template",z='Invalid tags: ',A='Unopened section "',B='Invalid template! Template should be a "string" ',C='>',D='\\s*',E='but "',F='{',G='number',H='{{',I='" at ',J='name',K='[object Array]',L='&#x2F;',M='\n',N='&',O='text',P='#',Q='string',R='=',S='/',T='Unclosed section "',U='&quot;',V='&#x3D;',W='}';qx.Bootstrap.define(y,{statics:{version:null,render:null,renderToNode:function(ba,bb,X){var Y=this.render(ba,bb,X);return this._createNodeFromTemplate(Y);},get:function(bd,bf,bc){var be=document.getElementById(bd);return this.renderToNode(be.innerHTML,bf,bc);},_createNodeFromTemplate:function(bg){if(bg.search(/<|>/)===-1){return document.createTextNode(bg);};var bh=qx.dom.Element.create(l);bh.innerHTML=bg;return bh.children[0];}}});(function(){var bi;var bj;(function bk(bl,bm){if(typeof bi===k&&bi&&typeof bi.nodeName!==Q){bm(bi);}else if(typeof bj===p&&bj.amd){bj([u],bm);}else {bl.Mustache={};bm(bl.Mustache);};}(this,function bz(bM){var bv=Object.prototype.toString;var by=Array.isArray||function bO(bN){return bv.call(bN)===K;};function bt(bP){return typeof bP===p;};function bL(bQ){return by(bQ)?r:typeof bQ;};function bH(bR){return bR.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,n);};function bu(bS,bT){return bS!=null&&typeof bS===k&&(bT in bS);};var bA=RegExp.prototype.test;function bC(bU,bV){return bA.call(bU,bV);};var bs=/\S/;function bx(bW){return !bC(bs,bW);};var bD={'&':f,'<':v,'>':t,'"':U,"'":g,'/':L,'`':a,'=':V};function bn(bX){return String(bX).replace(/[&<>"'`=\/]/g,function bY(s){return bD[s];});};var bw=/\s*/;var bK=/\s+/;var bJ=/\s*=/;var bE=/\s*\}/;var bB=/#|\^|\/|>|\{|&|=|!/;function bo(co,cc){if(!co)return [];var cd=[];var cj=[];var cm=[];var ct=false;var cg=false;function ce(){if(ct&&!cg){while(cm.length)delete cj[cm.pop()];}else {cm=[];};ct=false;cg=false;};var ci,ca,cq;function cf(cu){if(typeof cu===Q)cu=cu.split(bK,2);if(!by(cu)||cu.length!==2)throw new Error(z+cu);ci=new RegExp(bH(cu[0])+D);ca=new RegExp(D+bH(cu[1]));cq=new RegExp(D+bH(W+cu[1]));};cf(cc||bM.tags);var cb=new bI(co);var ck,cr,cn,cl,cs,ch;while(!cb.eos()){ck=cb.pos;cn=cb.scanUntil(ci);if(cn){for(var i=0,cp=cn.length;i<cp; ++i){cl=cn.charAt(i);if(bx(cl)){cm.push(cj.length);}else {cg=true;};cj.push([O,cl,ck,ck+1]);ck+=1;if(cl===M)ce();};};if(!cb.scan(ci))break;ct=true;cr=cb.scan(bB)||J;cb.scan(bw);if(cr===R){cn=cb.scanUntil(bJ);cb.scan(bJ);cb.scanUntil(ca);}else if(cr===F){cn=cb.scanUntil(cq);cb.scan(bE);cb.scanUntil(ca);cr=N;}else {cn=cb.scanUntil(ca);};if(!cb.scan(ca))throw new Error(h+cb.pos);cs=[cr,cn,ck,cb.pos];cj.push(cs);if(cr===P||cr===q){cd.push(cs);}else if(cr===S){ch=cd.pop();if(!ch)throw new Error(A+cn+I+ck);if(ch[1]!==cn)throw new Error(T+ch[1]+I+ck);}else if(cr===J||cr===F||cr===N){cg=true;}else if(cr===R){cf(cn);};};ch=cd.pop();if(ch)throw new Error(T+ch[1]+I+cb.pos);return br(bp(cj));};function bp(cx){var cv=[];var cy,cz;for(var i=0,cw=cx.length;i<cw; ++i){cy=cx[i];if(cy){if(cy[0]===O&&cz&&cz[0]===O){cz[1]+=cy[1];cz[3]=cy[3];}else {cv.push(cy);cz=cy;};};};return cv;};function br(cE){var cA=[];var cG=cA;var cB=[];var cF,cC;for(var i=0,cD=cE.length;i<cD; ++i){cF=cE[i];switch(cF[0]){case P:case q:cG.push(cF);cB.push(cF);cG=cF[4]=[];break;case S:cC=cB.pop();cC[5]=cF[2];cG=cB.length>0?cB[cB.length-1][4]:cA;break;default:cG.push(cF);};};return cA;};function bI(cH){this.string=cH;this.tail=cH;this.pos=0;};bI.prototype.eos=function cI(){return this.tail===d;};bI.prototype.scan=function cM(cJ){var cL=this.tail.match(cJ);if(!cL||cL.index!==0)return d;var cK=cL[0];this.tail=this.tail.substring(cK.length);this.pos+=cK.length;return cK;};bI.prototype.scanUntil=function cN(cO){var cQ=this.tail.search(cO),cP;switch(cQ){case -1:cP=this.tail;this.tail=d;break;case 0:cP=d;break;default:cP=this.tail.substring(0,cQ);this.tail=this.tail.substring(cQ);};this.pos+=cP.length;return cP;};function bF(cS,cR){this.view=cS;this.cache={'.':this.view};this.parent=cR;};bF.prototype.push=function cT(cU){return new bF(cU,this);};bF.prototype.lookup=function da(name){var cX=this.cache;var cY;if(cX.hasOwnProperty(name)){cY=cX[name];}else {var dc=this,db,cV,cW=false;while(dc){if(name.indexOf(x)>0){cY=dc.view;db=name.split(x);cV=0;while(cY!=null&&cV<db.length){if(cV===db.length-1)cW=bu(cY,db[cV]);cY=cY[db[cV++ ]];};}else {cY=dc.view[name];cW=bu(dc.view,name);};if(cW)break;dc=dc.parent;};cX[name]=cY;};if(bt(cY))cY=cY.call(this.view);return cY;};function bq(){this.cache={};};bq.prototype.clearCache=function dd(){this.cache={};};bq.prototype.parse=function df(dh,di){var dg=this.cache;var de=dg[dh];if(de==null)de=dg[dh]=bo(dh,di);return de;};bq.prototype.render=function dk(dj,dp,dm){var dl=this.parse(dj);var dn=(dp instanceof bF)?dp:new bF(dp);return this.renderTokens(dl,dn,dm,dj);};bq.prototype.renderTokens=function dy(dv,dx,ds,dz){var dq=d;var dw,dr,dt;for(var i=0,du=dv.length;i<du; ++i){dt=undefined;dw=dv[i];dr=dw[0];if(dr===P)dt=this.renderSection(dw,dx,ds,dz);else if(dr===q)dt=this.renderInverted(dw,dx,ds,dz);else if(dr===C)dt=this.renderPartial(dw,dx,ds,dz);else if(dr===N)dt=this.unescapedValue(dw,dx);else if(dr===J)dt=this.escapedValue(dw,dx);else if(dr===O)dt=this.rawValue(dw);if(dt!==undefined)dq+=dt;};return dq;};bq.prototype.renderSection=function dA(dD,dG,dF,dI){var self=this;var dB=d;var dE=dG.lookup(dD[1]);function dC(dJ){return self.render(dJ,dG,dF);};if(!dE)return;if(by(dE)){for(var j=0,dH=dE.length;j<dH; ++j){dB+=this.renderTokens(dD[4],dG.push(dE[j]),dF,dI);};}else if(typeof dE===k||typeof dE===Q||typeof dE===G){dB+=this.renderTokens(dD[4],dG.push(dE),dF,dI);}else if(bt(dE)){if(typeof dI!==Q)throw new Error(o);dE=dE.call(dG.view,dI.slice(dD[3],dD[5]),dC);if(dE!=null)dB+=dE;}else {dB+=this.renderTokens(dD[4],dG,dF,dI);};return dB;};bq.prototype.renderInverted=function dK(dL,dO,dN,dP){var dM=dO.lookup(dL[1]);if(!dM||(by(dM)&&dM.length===0))return this.renderTokens(dL[4],dO,dN,dP);};bq.prototype.renderPartial=function dQ(dT,dS,dR){if(!dR)return;var dU=bt(dR)?dR(dT[1]):dR[dT[1]];if(dU!=null)return this.renderTokens(this.parse(dU),dS,dR,dU);};bq.prototype.unescapedValue=function dX(dW,dV){var dY=dV.lookup(dW[1]);if(dY!=null)return dY;};bq.prototype.escapedValue=function eb(ec,ea){var ed=ea.lookup(ec[1]);if(ed!=null)return bM.escape(ed);};bq.prototype.rawValue=function ef(ee){return ee[1];};bM.name=w;bM.version=m;bM.tags=[H,b];var bG=new bq();bM.clearCache=function eg(){return bG.clearCache();};bM.parse=function eh(ei,ej){return bG.parse(ei,ej);};bM.render=function el(em,en,ek){if(typeof em!==Q){throw new TypeError(B+E+bL(em)+c+e);};return bG.render(em,en,ek);};bM.to_html=function eo(es,et,eq,ep){var er=bM.render(es,et,eq);if(bt(ep)){ep(er);}else {return er;};};bM.escape=bn;bM.Scanner=bI;bM.Context=bF;bM.Writer=bq;}));qx.bom.Template.version=this.Mustache.version;qx.bom.Template.render=this.Mustache.render;}).call({});})();(function(){var a="resize",b="qx.ui.groupbox.GroupBox",c="groupbox",d="frame",f="legend",g="top",h="middle",i="_applyLegendPosition";qx.Class.define(b,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.core.MRemoteLayoutHandling,qx.ui.core.MContentPadding,qx.ui.form.MForm],implement:[qx.ui.form.IForm],construct:function(j,k){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.Canvas);this._createChildControl(d);this._createChildControl(f);if(j!=null){this.setLegend(j);};if(k!=null){this.setIcon(k);};},properties:{appearance:{refine:true,init:c},legendPosition:{check:[g,h],init:h,apply:i,themeable:true}},members:{_forwardStates:{invalid:true},_createChildControlImpl:function(n,m){var l;switch(n){case d:l=new qx.ui.container.Composite();this._add(l,{left:0,top:6,right:0,bottom:0});break;case f:l=new qx.ui.basic.Atom();l.addListener(a,this._repositionFrame,this);this._add(l,{left:0,right:0});break;};return l||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,n);},_getContentPaddingTarget:function(){return this.getChildControl(d);},_applyLegendPosition:function(e){if(this.getChildControl(f).getBounds()){this._repositionFrame();};},_repositionFrame:function(){var p=this.getChildControl(f);var o=this.getChildControl(d);var q=p.getBounds().height;if(this.getLegendPosition()==h){o.setLayoutProperties({"top":Math.round(q/2)});}else if(this.getLegendPosition()==g){o.setLayoutProperties({"top":q});};},getChildrenContainer:function(){return this.getChildControl(d);},setLegend:function(s){var r=this.getChildControl(f);if(s!==null){r.setLabel(s);r.show();}else {r.exclude();};},getLegend:function(){return this.getChildControl(f).getLabel();},setIcon:function(t){this.getChildControl(f).setIcon(t);},getIcon:function(){return this.getChildControl(f).getIcon();}}});})();(function(){var a="popupOpen",b="blur",c="qx.util.format.DateFormat",d="Escape",f="changeValue",g="Left",h="Down",i="button",j="Up",k="execute",l="qx.event.type.Data",m="inner",n="list",o="changeLocale",p="visible",q="middle",r="String",s="_applyDateFormat",t="pointerup",u="",v="changeVisibility",w="textfield",x="medium",y="focusin",z="popup",A="qx.ui.form.DateField",B="focusout",C="datefield",D="_applyPlaceholder",E="hidden",F="tap",G="Right";qx.Class.define(A,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling,qx.ui.form.MForm],implement:[qx.ui.form.IForm,qx.ui.form.IDateForm],construct:function(){qx.ui.core.Widget.call(this);var I=new qx.ui.layout.HBox();this._setLayout(I);I.setAlignY(q);var H=this._createChildControl(w);this._createChildControl(i);this.addListener(F,this._onTap,this);this.addListener(b,this._onBlur,this);this.addListener(y,function(e){H.fireNonBubblingEvent(y,qx.event.type.Focus);},this);this.addListener(B,function(e){H.fireNonBubblingEvent(B,qx.event.type.Focus);},this);this._setDefaultDateFormat();this._addLocaleChangeListener();},events:{"changeValue":l},properties:{dateFormat:{check:c,apply:s},placeholder:{check:r,nullable:true,apply:D},appearance:{refine:true,init:C},focusable:{refine:true,init:true},width:{refine:true,init:120}},statics:{__vR:null,__vS:null,getDefaultDateFormatter:function(){var J=qx.locale.Date.getDateFormat(x).toString();if(J==this.__vR){return this.__vS;};if(this.__vS){this.__vS.dispose();};this.__vS=new qx.util.format.DateFormat(J,qx.locale.Manager.getInstance().getLocale());this.__vR=J;return this.__vS;}},members:{__vT:null,_forwardStates:{focused:true,invalid:true},_setDefaultDateFormat:function(){this.setDateFormat(qx.ui.form.DateField.getDefaultDateFormatter());},_addLocaleChangeListener:function(){{this.__vT=qx.locale.Manager.getInstance().addListener(o,function(){this._setDefaultDateFormat();},this);};},setValue:function(M){var K=this.getChildControl(w);K.setValue(this.getDateFormat().format(M));var L=this.getChildControl(n);L.setValue(M);},getValue:function(){var N=this.getChildControl(w).getValue();try{return this.getDateFormat().parse(N);}catch(O){return null;};},resetValue:function(){var P=this.getChildControl(w);P.setValue(u);var Q=this.getChildControl(n);Q.setValue(null);},open:function(){var R=this.getChildControl(z);R.placeToWidget(this,true);R.show();},close:function(){this.getChildControl(z).hide();},toggle:function(){var S=this.getChildControl(z).isVisible();if(S){this.close();}else {this.open();};},_applyDateFormat:function(X,V){if(!V){return;};try{var U=this.getChildControl(w);var W=U.getValue();var T=V.parse(W);U.setValue(X.format(T));}catch(Y){};},_applyPlaceholder:function(bb,ba){this.getChildControl(w).setPlaceholder(bb);},_createChildControlImpl:function(be,bd){var bc;switch(be){case w:bc=new qx.ui.form.TextField();bc.setFocusable(false);bc.addState(m);bc.addListener(f,this._onTextFieldChangeValue,this);bc.addListener(b,this.close,this);this._add(bc,{flex:1});break;case i:bc=new qx.ui.form.Button();bc.setFocusable(false);bc.setKeepActive(true);bc.addState(m);bc.addListener(k,this.toggle,this);this._add(bc);break;case n:bc=new qx.ui.control.DateChooser();bc.setFocusable(false);bc.setKeepFocus(true);bc.addListener(k,this._onChangeDate,this);break;case z:bc=new qx.ui.popup.Popup(new qx.ui.layout.VBox);bc.setAutoHide(false);bc.add(this.getChildControl(n));bc.addListener(t,this._onChangeDate,this);bc.addListener(v,this._onPopupChangeVisibility,this);break;};return bc||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,be);},_onChangeDate:function(e){var bf=this.getChildControl(w);var bg=this.getChildControl(n).getValue();bf.setValue(this.getDateFormat().format(bg));this.close();},_onTap:function(e){this.close();},_onBlur:function(e){this.close();},_onKeyPress:function(e){var bh=e.getKeyIdentifier();if(bh==h&&e.isAltPressed()){this.toggle();e.stopPropagation();return;};var bi=this.getChildControl(z);if(bi.getVisibility()==E){return;};if(bh==d){this.close();e.stopPropagation();return;};if(bh===g||bh===G||bh===h||bh===j){e.preventDefault();};this.getChildControl(n).handleKeyPress(e);},_onPopupChangeVisibility:function(e){e.getData()==p?this.addState(a):this.removeState(a);var bk=this.getChildControl(z);if(bk.isVisible()){var bl=this.getChildControl(n);var bj=this.getValue();bl.setValue(bj);};},_onTextFieldChangeValue:function(e){var bm=this.getValue();if(bm!=null){var bn=this.getChildControl(n);bn.setValue(bm);};this.fireDataEvent(f,this.getValue());},isEmpty:function(){var bo=this.getChildControl(w).getValue();return bo==null||bo==u;},focus:function(){qx.ui.core.Widget.prototype.focus.call(this);this.getChildControl(w).getFocusElement().focus();}},destruct:function(){{if(this.__vT){qx.locale.Manager.getInstance().removeListenerById(this.__vT);};};}});})();(function(){var a="PageUp",b="day",c="lastMonth",d="yyyyMMMM",f="Next month",g="Escape",h="Left",j="last-month-button",k="default",l="today",m="weekday",n="changeValue",o="Space",p="selected",q="Down",r="Integer",s="qx.ui.control.DateChooser",t="Up",u="Enter",v="PageDown",w="day#",z="changeLocale",A="Next year",B="ww",C="_applyValue",D="next-month-button",E="next-month-button-tooltip",F="weekday#",G="last-month-button-tooltip",H="datechooser",I="header",J="week",K="lastYear",L="pointerup",M="otherMonth",N="month-year-label",O="nextYear",P="last-year-button",Q="changeShownYear",R="week#",S="pointerdown",T="next-year-button",U="Last month",V="Last year",W="MMMM yyyy",X="EE",Y="week#0",br="keypress",bs="",bt="navigation-bar",bn="nextMonth",bo="last-year-button-tooltip",bp="next-year-button-tooltip",bq="Date",bw="tap",bx="Right",by="date-pane",bz="dbltap",bu="weekend",bv="changeShownMonth";qx.Class.define(s,{extend:qx.ui.core.Widget,include:[qx.ui.core.MExecutable,qx.ui.form.MForm],implement:[qx.ui.form.IExecutable,qx.ui.form.IForm,qx.ui.form.IDateForm],construct:function(bA){qx.ui.core.Widget.call(this);var bD=new qx.ui.layout.VBox();this._setLayout(bD);this._createChildControl(bt);this._createChildControl(by);this.addListener(br,this._onKeyPress);var bB=qx.ui.control.DateChooser;if(!bB.MONTH_YEAR_FORMAT){bB.MONTH_YEAR_FORMAT=qx.locale.Date.getDateTimeFormat(d,W);};var bC=(bA!=null)?bA:new Date();this.showMonth(bC.getMonth(),bC.getFullYear());{qx.locale.Manager.getInstance().addListener(z,this._updateDatePane,this);};this.addListener(S,this._onPointerUpDown,this);this.addListener(L,this._onPointerUpDown,this);},statics:{MONTH_YEAR_FORMAT:null,WEEKDAY_FORMAT:X,WEEK_FORMAT:B},properties:{appearance:{refine:true,init:H},width:{refine:true,init:200},height:{refine:true,init:150},shownMonth:{check:r,init:null,nullable:true,event:bv},shownYear:{check:r,init:null,nullable:true,event:Q},value:{check:bq,init:null,nullable:true,event:n,apply:C}},members:{__vU:null,__vV:null,__vW:null,_forwardStates:{invalid:true},_createChildControlImpl:function(bI,bF){var bE;switch(bI){case bt:bE=new qx.ui.container.Composite(new qx.ui.layout.HBox());bE.add(this.getChildControl(P));bE.add(this.getChildControl(j));bE.add(this.getChildControl(N),{flex:1});bE.add(this.getChildControl(D));bE.add(this.getChildControl(T));this._add(bE);break;case bo:bE=new qx.ui.tooltip.ToolTip(this.tr(V));break;case P:bE=new qx.ui.toolbar.Button();bE.addState(K);bE.setFocusable(false);bE.setToolTip(this.getChildControl(bo));bE.addListener(bw,this._onNavButtonTap,this);break;case G:bE=new qx.ui.tooltip.ToolTip(this.tr(U));break;case j:bE=new qx.ui.toolbar.Button();bE.addState(c);bE.setFocusable(false);bE.setToolTip(this.getChildControl(G));bE.addListener(bw,this._onNavButtonTap,this);break;case E:bE=new qx.ui.tooltip.ToolTip(this.tr(f));break;case D:bE=new qx.ui.toolbar.Button();bE.addState(bn);bE.setFocusable(false);bE.setToolTip(this.getChildControl(E));bE.addListener(bw,this._onNavButtonTap,this);break;case bp:bE=new qx.ui.tooltip.ToolTip(this.tr(A));break;case T:bE=new qx.ui.toolbar.Button();bE.addState(O);bE.setFocusable(false);bE.setToolTip(this.getChildControl(bp));bE.addListener(bw,this._onNavButtonTap,this);break;case N:bE=new qx.ui.basic.Label();bE.setAllowGrowX(true);bE.setAnonymous(true);break;case J:bE=new qx.ui.basic.Label();bE.setAllowGrowX(true);bE.setAllowGrowY(true);bE.setSelectable(false);bE.setAnonymous(true);bE.setCursor(k);break;case m:bE=new qx.ui.basic.Label();bE.setAllowGrowX(true);bE.setAllowGrowY(true);bE.setSelectable(false);bE.setAnonymous(true);bE.setCursor(k);break;case b:bE=new qx.ui.basic.Label();bE.setAllowGrowX(true);bE.setAllowGrowY(true);bE.setCursor(k);bE.addListener(S,this._onDayTap,this);bE.addListener(bz,this._onDayDblTap,this);break;case by:var bH=new qx.ui.layout.Grid();bE=new qx.ui.container.Composite(bH);for(var i=0;i<8;i++ ){bH.setColumnFlex(i,1);};for(var i=0;i<7;i++ ){bH.setRowFlex(i,1);};var bG=this.getChildControl(Y);bG.addState(I);bE.add(bG,{column:0,row:0});this.__vU=[];for(var i=0;i<7;i++ ){bG=this.getChildControl(F+i);bE.add(bG,{column:i+1,row:0});this.__vU.push(bG);};this.__vV=[];this.__vW=[];for(var y=0;y<6;y++ ){var bG=this.getChildControl(R+(y+1));bE.add(bG,{column:0,row:y+1});this.__vW.push(bG);for(var x=0;x<7;x++ ){var bG=this.getChildControl(w+((y*7)+x));bE.add(bG,{column:x+1,row:y+1});this.__vV.push(bG);};};this._add(bE);break;};return bE||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,bI);},_applyValue:function(bL,bK){if((bL!=null)&&(this.getShownMonth()!=bL.getMonth()||this.getShownYear()!=bL.getFullYear())){this.showMonth(bL.getMonth(),bL.getFullYear());}else {var bJ=(bL==null)?-1:bL.getDate();for(var i=0;i<42;i++ ){var bM=this.__vV[i];if(bM.hasState(M)){if(bM.hasState(p)){bM.removeState(p);};}else {var bN=parseInt(bM.getValue(),10);if(bN==bJ){bM.addState(p);}else if(bM.hasState(p)){bM.removeState(p);};};};};},_onPointerUpDown:function(e){var bO=e.getTarget();if(bO==this.getChildControl(bt)||bO==this.getChildControl(by)){e.stopPropagation();return;};},_onNavButtonTap:function(bQ){var bP=this.getShownYear();var bR=this.getShownMonth();switch(bQ.getCurrentTarget()){case this.getChildControl(P):bP-- ;break;case this.getChildControl(j):bR-- ;if(bR<0){bR=11;bP-- ;};break;case this.getChildControl(D):bR++ ;if(bR>=12){bR=0;bP++ ;};break;case this.getChildControl(T):bP++ ;break;};this.showMonth(bR,bP);},_onDayTap:function(bS){var bT=bS.getCurrentTarget().dateTime;this.setValue(new Date(bT));},_onDayDblTap:function(){this.execute();},_onKeyPress:function(bW){var bX=null;var bY=null;var bV=null;if(bW.getModifiers()==0){switch(bW.getKeyIdentifier()){case h:bX=-1;break;case bx:bX=1;break;case t:bX=-7;break;case q:bX=7;break;case a:bY=-1;break;case v:bY=1;break;case g:if(this.getValue()!=null){this.setValue(null);return;};break;case u:case o:if(this.getValue()!=null){this.execute();};return;};}else if(bW.isShiftPressed()){switch(bW.getKeyIdentifier()){case a:bV=-1;break;case v:bV=1;break;};};if(bX!=null||bY!=null||bV!=null){var bU=this.getValue();if(bU!=null){bU=new Date(bU.getTime());};if(bU==null){bU=new Date();}else {if(bX!=null){bU.setDate(bU.getDate()+bX);};if(bY!=null){bU.setMonth(bU.getMonth()+bY);};if(bV!=null){bU.setFullYear(bU.getFullYear()+bV);};};this.setValue(bU);};},showMonth:function(ca,cb){if((ca!=null&&ca!=this.getShownMonth())||(cb!=null&&cb!=this.getShownYear())){if(ca!=null){this.setShownMonth(ca);};if(cb!=null){this.setShownYear(cb);};this._updateDatePane();};},handleKeyPress:function(e){this._onKeyPress(e);},_updateDatePane:function(){var cr=qx.ui.control.DateChooser;var co=new Date();var cg=co.getFullYear();var cm=co.getMonth();var cj=co.getDate();var cs=this.getValue();var cv=(cs==null)?-1:cs.getFullYear();var cC=(cs==null)?-1:cs.getMonth();var cl=(cs==null)?-1:cs.getDate();var ck=this.getShownMonth();var cz=this.getShownYear();var ch=qx.locale.Date.getWeekStart();var ct=new Date(this.getShownYear(),this.getShownMonth(),1);var cq=new qx.util.format.DateFormat(cr.MONTH_YEAR_FORMAT);this.getChildControl(N).setValue(cq.format(ct));var cB=ct.getDay();var cn=1+((7-cB)%7);var cu=new qx.util.format.DateFormat(cr.WEEKDAY_FORMAT);for(var i=0;i<7;i++ ){var cw=(i+ch)%7;var cy=this.__vU[i];ct.setDate(cn+cw);cy.setValue(cu.format(ct));if(qx.locale.Date.isWeekend(cw)){cy.addState(bu);}else {cy.removeState(bu);};};ct=new Date(cz,ck,1,12,0,0);var cd=(7+cB-ch)%7;ct.setDate(ct.getDate()-cd);var cx=new qx.util.format.DateFormat(cr.WEEK_FORMAT);for(var cp=0;cp<6;cp++ ){this.__vW[cp].setValue(cx.format(ct));for(var i=0;i<7;i++ ){var cy=this.__vV[cp*7+i];var cf=ct.getFullYear();var ce=ct.getMonth();var ci=ct.getDate();var cc=(cv==cf&&cC==ce&&cl==ci);if(cc){cy.addState(p);}else {cy.removeState(p);};if(ce!=ck){cy.addState(M);}else {cy.removeState(M);};var cA=(cf==cg&&ce==cm&&ci==cj);if(cA){cy.addState(l);}else {cy.removeState(l);};cy.setValue(bs+ci);cy.dateTime=ct.getTime();ct.setDate(ct.getDate()+1);};};cq.dispose();cu.dispose();cx.dispose();}},destruct:function(){{qx.locale.Manager.getInstance().removeListener(z,this._updateDatePane,this);};this.__vU=this.__vV=this.__vW=null;}});})();(function(){var a="inherit",b="toolbar-button",c="keydown",d="qx.ui.toolbar.Button",e="keyup";qx.Class.define(d,{extend:qx.ui.form.Button,construct:function(f,h,g){qx.ui.form.Button.call(this,f,h,g);this.removeListener(c,this._onKeyDown);this.removeListener(e,this._onKeyUp);},properties:{appearance:{refine:true,init:b},show:{refine:true,init:a},focusable:{refine:true,init:false}},members:{_applyVisibility:function(j,i){qx.ui.form.Button.prototype._applyVisibility.call(this,j,i);var parent=this.getLayoutParent();if(parent&&parent instanceof qx.ui.toolbar.PartContainer){qx.ui.core.queue.Appearance.add(parent);};}}});})();(function(){var a="toolbar/part/container",b="icon",c="label",d="qx.ui.toolbar.PartContainer",e="qx.event.type.Event",f="changeShow",g="both",h="changeChildren";qx.Class.define(d,{extend:qx.ui.container.Composite,construct:function(){qx.ui.container.Composite.call(this);this._setLayout(new qx.ui.layout.HBox);},events:{changeChildren:e},properties:{appearance:{refine:true,init:a},show:{init:g,check:[g,c,b],inheritable:true,event:f}},members:{_afterAddChild:function(i){this.fireEvent(h);},_afterRemoveChild:function(j){this.fireEvent(h);}}});})();(function(){var a='list',b='clui.view.widget.RelativeDateField',c='Date',d='{0} {1}',e='kucken.date.RelativeDate',f='textfield',g='medium',h='Invalid date';qx.Class.define(b,{extend:qx.ui.form.DateField,properties:{relativeDate:{check:e,nullable:true},defaultTime:{check:c,nullable:true}},construct:function(i){qx.ui.form.DateField.call(this);if(i){this.setDefaultTime(i);};},members:{_setDefaultDateFormat:function(){var k=d.format(qx.locale.Date.getDateFormat(g),qx.locale.Date.getTimeFormat(g));this.setDateFormat(new qx.util.format.DateFormat(k));var j=new kucken.date.RelativeDate();j.setFormat(k);this.setRelativeDate(j);},_onChangeDate:function(event){var m=this.getDefaultTime();if(m){var l=this.getChildControl(a).getValue();l.setHours(m.getHours());l.setMinutes(m.getMinutes());l.setSeconds(m.getSeconds());l.setMilliseconds(m.getMilliseconds());};qx.ui.form.DateField.prototype._onChangeDate.call(this,event);},getValue:function(){var n=this.getChildControl(f).getValue();var o=this.getRelativeDate();try{o.setExpression(n);return o.toDate();}catch(p){this.debug(h,n);return null;};},setValue:function(q){if(qx.lang.Type.isString(q)){this.getChildControl(f).setValue(q);var r=this.getRelativeDate();r.setExpression(q);this.getChildControl(a).setValue(r.toDate());}else {return qx.ui.form.DateField.prototype.setValue.call(this,q);};}}});})();(function(){var a='Invalid log level',b='before',c='query',d='name',e='after',f='clui.model.form.TableQuery',g='level';qx.Class.define(f,{extend:kucken.ui.form.mvc.Model,members:{_createFormModel:function(){var h={'after':this._item[e]||null,'before':this._item[b]||null,'level':this._item[g]||null,'name':this._item[d]||null,'query':this._item[c]||null};this.setFormModel(qx.data.marshal.Json.createModel(h,true));},toString:function(){var i=qx.util.Serializer.toNativeObject(this.getFormModel());i[e]=this.getFormModel().getAfter().getExpression();if(qx.lang.Type.isDate(i[e])){i[e]=i[e].toISOString();};i[b]=this.getFormModel().getBefore().getExpression();if(qx.lang.Type.isDate(i[b])){i[b]=i[b].toISOString();};if(i[e]){i[e]=i[e];};if(i[b]){i[b]=i[b];};if(i[g]){i[g]=clui.model.form.Record.levelMap[i[g]];};kucken.lang.Object.items(i).forEach(function(j){if(j[1]===null){delete i[j[0]];};});return clui.util.QueryParser.dumpConjunctionDict(i);},updateFrom:function(l){var m=clui.util.QueryParser.loadConjunctionDict(l);if(m[e]){m[e]=new kucken.date.RelativeDate(m[e]);};if(m[b]){m[b]=new kucken.date.RelativeDate(m[b]);};if(m[g]){m[g]=qx.lang.Object.invert(clui.model.form.Record.levelMap)[m[g]];if(!m[g]){throw new Error(a);};};Object.keys(this.save()).forEach(function(k){this.getFormModel().set(k,m[k]||null);},this);},save:function(){var n=qx.util.Serializer.toNativeObject(this.getFormModel());n[e]=this.getFormModel().getAfter();n[b]=this.getFormModel().getBefore();return n;}}});})();(function(){var c="-",d="\"-\"",e="[^ \\t\\r\\n\\f{}()\"\\/\\^~[\\]]",f='~',g='clui.util.QueryParser',h="\".\"",j='\\\\',k=" found.",l="end of input",m='parenthesized',n="\")\"",o="[0-9]",q="||",r='(',t="{",u="\"TO\"",v="Can't start parsing from rule \"",w="\"{\"",x=':',y="OR NOT",z="\"AND NOT\"",A="[",B="\"||\"",C="SyntaxError",D="OR",E='\\u',F='\\b',G="AND NOT",H="\\",I="\"'\"",J="[ \\t\\r\\n\\f]",K="end",L=' TO ',M="+",N="startRule",O='\\',P="\u2029",Q="\"AND\"",R='"',S="0.",T='\\x0',U='^',V="\"OR NOT\"",W="\r",X=":",Y="\"^\"",cG="<implicit>",cH="\"|\"",cI="\"NOT\"",cC="(",cD='{',cE="\u2028",cF="\"~\"",cN="~",cO="\"?\"",cU="\"]\"",cP="\"!\"",cJ="any character",cK='boost',cL="\"0.\"",cM="^",cT=")",dy="\"OR\"",ee='\\f',cV="\"&\"",cQ=" or ",cR='none',eb='left',cS="\"}\"",cW="class",cX="!",cY="\":\"",de="\"+\"",df="AND",dg="\".",da="any",db='\\r',dc="\"\\\"\"",dd="literal",dk=", ",dl="&",dm="\n",dn="\"&&\"",dh='[',di="|",ec='\\u0',dj='\\n',dt="NOT",du='right',ed='prefix',dv='<implicit>',dp=".",dq='}',dr='similarity',ds='operator',dw="\"",dx='\\x',dI="\"\\\\\"",dH='',dG="&&",dM="\"/\"",dL=']',dK="'",dJ="\"[\"",dB='\\"',dA="}",dz='field',dF='\\t',dE="/",dD='both',dC="other",dT="[:]",dS='proximity',dR="Expected ",dQ="]",dX="whitespace",dW=' ',dV="[^: \\t\\r\\n\\f{}()\"\\/\\^~[\\]]",dU="?",dP="TO",dO=')',dN='AND',ea=" but ",dY="\"(\"";qx.Class.define(g,{statics:{__uz:null,parse:function(ef){return this.__uz.parse(ef);},toString:function(eg){return this.__uz.toString(eg);},_flatten:function(eh){if(eh.operator){qx.core.Assert.assertInArray(eh.operator,[dv,dN]);return kucken.lang.Object.merge(this._flatten(eh.left),this._flatten(eh.right));}else if(eh.field){return kucken.lang.Object.dict([[eh.field,eh.term]]);}else if(eh.left){return this._flatten(eh.left);}else {return {};};},loadConjunctionDict:function(ei){return this._flatten(this.parse(ei));},_createTermNode:function(ej){var ek=ej[1];if(!qx.lang.Type.isString(ek)){ek=String(ek);};if([x,R,dW].some(qx.lang.String.contains.bind(null,ek))){ek=qx.lang.String.quote(ek);};return {'field':ej[0],'term':ek,'quoted':false};},_nest:function(el,em){if(el.term){el={'left':el,'operator':dv,'right':this._createTermNode(em)};}else if(!el.left){el.left=this._createTermNode(em);}else if(!el.right){el.operator=dv;el.right=this._createTermNode(em);}else {el.right=this._nest(el.right,em);};return el;},dumpConjunctionDict:function(en){var eo=kucken.lang.Object.items(en).reduce(this._nest.bind(this),{});return this.toString(eo);}}});(function(ep,eq){ep.__uz=eq();})(clui.util.QueryParser,function(){function er(ex,parent){function ew(){this.constructor=ex;};ew.prototype=parent.prototype;ex.prototype=new ew();};function SyntaxError(eC,eA,eB,ez,eD,ey){this.message=eC;this.expected=eA;this.found=eB;this.offset=ez;this.line=eD;this.column=ey;this.name=C;};er(SyntaxError,Error);function es(eR){var gd=arguments.length>1?arguments[1]:{},eF={},gJ={start:hB},gs=hB,hb=eF,ha=[],gY=function(hC){return hC[0];},gX=function(){return {};},hf=function(hD){return {'operator':hD};},he=function(hF,hI,hE,hG){var hH={'start':hF,'left':hI};var hG=hG.length==0?null:hG[0][du]==null?hG[0][eb]:hG[0];if(hG!=null){hH[ds]=hE==dH?dv:hE[0];hH[du]=hG;};return hH;},hd=function(hJ,hK){return hK;},hc=function(hO,hL,hN){var hM={'left':hO};var hN=hN.length==0?null:hN[0][du]==null?hN[0][eb]:hN[0];if(hN!=null){hM[ds]=hL==dH?dv:hL[0];hM[du]=hN;};return hM;},hh=function(hP){return hP;},hg=cC,hr={type:dd,value:cC,description:dY},hq=cT,hp={type:dd,value:cT,description:n},gc=function(hQ){hQ[0][m]=true;return hQ[0];},hv=null,hu=function(hS,hR){hR[dz]=hS==dH||hS==null?cG:hS;return hR;},ht=function(hU,hT){hT[dz]=hU;return hT;},hs=function(hX,hW){var hV={'field':hX==dH||hX==null?cG:hX};for(var hY in hW)hV[hY]=hW[hY];return hV;},hm=/^[:]/,hl={type:cW,value:dT,description:dT},fu=function(ia){return ia;},fv=function(ig,ib,ie,ic){var id={'term':ib,'quoted':true};if(dH!=ie){id[dS]=ie;};if(dH!=ic){id[cK]=ic;};if(dH!=ig){id[ed]=ig;};return id;},fs=function(ii,ih,il,ij){var ik={'term':ih,'quoted':false};if(dH!=il){ik[dr]=il;};if(dH!=ij){ik[cK]=ij;};if(dH!=ii){ik[ed]=ii;};return ik;},ft=dp,fy={type:dd,value:dp,description:h},fz=/^[^ \t\r\n\f{}()"\/\^~[\]]/,fw={type:cW,value:e,description:e},fx=function(im){return im.join(dH);},fA=/^[^: \t\r\n\f{}()"\/\^~[\]]/,fB={type:cW,value:dV,description:dV},fa=dw,eY={type:dd,value:dw,description:dc},fc=function(io){return io.join(dH);},fb=void 0,eV=H,eU={type:dd,value:H,description:dI},eX={type:da,description:cJ},eW=function(ip){return ip;},ff=function(iq){return iq;},fe=M,gk={type:dd,value:M,description:de},gl=c,gm={type:dd,value:c,description:d},gn=cX,fh={type:dd,value:cX,description:cP},gh=t,gi={type:dd,value:t,description:w},gj=dA,go={type:dd,value:dA,description:cS},fG=A,gf={type:dd,value:A,description:dJ},fT=dQ,fS={type:dd,value:dQ,description:cU},fR=cM,fQ={type:dd,value:cM,description:Y},fP=dU,fO={type:dd,value:dU,description:cO},fN=X,fW={type:dd,value:X,description:cY},fV=dl,gV={type:dd,value:dl,description:cV},gW=di,gT={type:dd,value:di,description:cH},gU=dK,gR={type:dd,value:dK,description:I},gS=dE,gP={type:dd,value:dE,description:dM},gQ=cN,gN={type:dd,value:cN,description:cF},gO=function(ir){return ir;},gz=function(is){return is;},gy=function(it){return it==dH||it==null?0.5:it;},gB=S,gA={type:dd,value:S,description:cL},gD=/^[0-9]/,gC={type:cW,value:o,description:o},gF=function(iu){return parseFloat(S+iu.join(dH));},gE=function(iv){return parseInt(iv.join(dH));},gH=dP,eG={type:dd,value:dP,description:u},fC=function(iw,ix){return {'term_min':iw,'term_max':ix,'inclusive':dD};},fj=function(iy,iz){return {'term_min':iy,'term_max':iz,'inclusive':cR};},fk=function(iA,iB){return {'term_min':iA,'term_max':iB,'inclusive':eb};},fl=function(iC,iD){return {'term_min':iC,'term_max':iD,'inclusive':du};},fJ=function(iE){return iE;},fn=y,fo={type:dd,value:y,description:V},fp=G,fq={type:dd,value:G,description:z},fr=D,eM={type:dd,value:D,description:dy},eL=df,eK={type:dd,value:df,description:Q},eJ=dt,eQ={type:dd,value:dt,description:cI},eP=q,eO={type:dd,value:q,description:B},eN=dG,eT={type:dd,value:dG,description:dn},eS={type:dC,description:dX},fE=/^[ \t\r\n\f]/,fF={type:cW,value:J,description:J},hj=0,hk=0,gM=0,fD={line:1,column:1,seenCR:false},eH=0,gt=[],fY=0,gb;if(N in gd){if(!(gd.startRule in gJ)){throw new Error(v+gd.startRule+dg);};gs=gJ[gd.startRule];};function hz(){return eR.substring(hk,hj);};function fU(){return hk;};function gI(){return eE(hk).line;};function fX(){return eE(hk).column;};function gw(iF){throw fg(null,[{type:dC,description:iF}],hk);};function gL(iG){throw fg(iG,null,hk);};function eE(iI){function iH(iL,iJ,iM){var p,iK;for(p=iJ;p<iM;p++ ){iK=eR.charAt(p);if(iK===dm){if(!iL.seenCR){iL.line++ ;};iL.column=1;iL.seenCR=false;}else if(iK===W||iK===cE||iK===P){iL.line++ ;iL.column=1;iL.seenCR=true;}else {iL.column++ ;iL.seenCR=false;};};};if(gM!==iI){if(gM>iI){gM=0;fD={line:1,column:1,seenCR:false};};iH(fD,gM,iI);gM=iI;};return fD;};function fi(iN){if(hj<eH){return;};if(hj>eH){eH=hj;gt=[];};gt.push(iN);};function fg(iU,iS,iR){function iQ(iV){var i=1;iV.sort(function(a,b){if(a.description<b.description){return -1;}else if(a.description>b.description){return 1;}else {return 0;};});while(i<iV.length){if(iV[i-1]===iV[i]){iV.splice(i,1);}else {i++ ;};};};function iO(ja,jb){function iY(s){function jd(je){return je.charCodeAt(0).toString(16).toUpperCase();};return s.replace(/\\/g,j).replace(/"/g,dB).replace(/\x08/g,F).replace(/\t/g,dF).replace(/\n/g,dj).replace(/\f/g,ee).replace(/\r/g,db).replace(/[\x00-\x07\x0B\x0E\x0F]/g,function(jf){return T+jd(jf);}).replace(/[\x10-\x1F\x80-\xFF]/g,function(jg){return dx+jd(jg);}).replace(/[\u0180-\u0FFF]/g,function(jh){return ec+jd(jh);}).replace(/[\u1080-\uFFFF]/g,function(ji){return E+jd(ji);});};var jc=new Array(ja.length),iW,iX,i;for(i=0;i<ja.length;i++ ){jc[i]=ja[i].description;};iW=ja.length>1?jc.slice(0,-1).join(dk)+cQ+jc[ja.length-1]:jc[0];iX=jb?dw+iY(jb)+dw:l;return dR+iW+ea+iX+k;};var iP=eE(iR),iT=iR<eR.length?eR.charAt(iR):null;if(iS!==null){iQ(iS);};return new SyntaxError(iU!==null?iU:iO(iS,iT),iS,iT,iR,iP.line,iP.column);};function hB(){var jm,jl,jk,jj;jm=hj;jl=[];jk=gq();while(jk!==eF){jl.push(jk);jk=gq();};if(jl!==eF){jk=[];jj=ga();if(jj!==eF){while(jj!==eF){jk.push(jj);jj=ga();};}else {jk=hb;};if(jk!==eF){hk=jm;jl=gY(jk);jm=jl;}else {hj=jm;jm=hb;};}else {hj=jm;jm=hb;};if(jm===eF){jm=hj;jl=[];jk=gq();while(jk!==eF){jl.push(jk);jk=gq();};if(jl!==eF){hk=jm;jl=gX();};jm=jl;if(jm===eF){jm=hj;jl=eI();if(jl!==eF){hk=jm;jl=gX();};jm=jl;};};return jm;};function ga(){var jq,jp,jo,jn,js,jr;jq=hj;jp=fI();if(jp!==eF){jo=eI();if(jo!==eF){hk=jq;jp=hf(jp);jq=jp;}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};if(jq===eF){jq=hj;jp=fI();if(jp!==eF){jo=gg();if(jo!==eF){jn=[];js=fI();while(js!==eF){jn.push(js);js=fI();};if(jn!==eF){js=[];jr=ga();while(jr!==eF){js.push(jr);jr=ga();};if(js!==eF){hk=jq;jp=he(jp,jo,jn,js);jq=jp;}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};if(jq===eF){jq=hj;jp=fI();if(jp!==eF){jo=ga();if(jo!==eF){hk=jq;jp=hd(jp,jo);jq=jp;}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};if(jq===eF){jq=hj;jp=gg();if(jp!==eF){jo=[];jn=fI();while(jn!==eF){jo.push(jn);jn=fI();};if(jo!==eF){jn=[];js=ga();while(js!==eF){jn.push(js);js=ga();};if(jn!==eF){hk=jq;jp=hc(jp,jo,jn);jq=jp;}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};}else {hj=jq;jq=hb;};};};};return jq;};function gg(){var jw,jv,ju,jt;jw=hj;jv=fL();if(jv!==eF){ju=[];jt=gq();while(jt!==eF){ju.push(jt);jt=gq();};if(ju!==eF){hk=jw;jv=hh(jv);jw=jv;}else {hj=jw;jw=hb;};}else {hj=jw;jw=hb;};if(jw===eF){jw=gK();};return jw;};function gK(){var jA,jz,jy,jx,jC,jB;jA=hj;if(eR.charCodeAt(hj)===40){jz=hg;hj++ ;}else {jz=eF;if(fY===0){fi(hr);};};if(jz!==eF){jy=[];jx=ga();if(jx!==eF){while(jx!==eF){jy.push(jx);jx=ga();};}else {jy=hb;};if(jy!==eF){if(eR.charCodeAt(hj)===41){jx=hq;hj++ ;}else {jx=eF;if(fY===0){fi(hp);};};if(jx!==eF){jC=[];jB=gq();while(jB!==eF){jC.push(jB);jB=gq();};if(jC!==eF){hk=jA;jz=gc(jy);jA=jz;}else {hj=jA;jA=hb;};}else {hj=jA;jA=hb;};}else {hj=jA;jA=hb;};}else {hj=jA;jA=hb;};return jA;};function fL(){var jF,jE,jD;jF=hj;jE=fd();if(jE===eF){jE=hv;};if(jE!==eF){jD=ho();if(jD!==eF){hk=jF;jE=hu(jE,jD);jF=jE;}else {hj=jF;jF=hb;};}else {hj=jF;jF=hb;};if(jF===eF){jF=hj;jE=fd();if(jE!==eF){jD=gK();if(jD!==eF){hk=jF;jE=ht(jE,jD);jF=jE;}else {hj=jF;jF=hb;};}else {hj=jF;jF=hb;};if(jF===eF){jF=hj;jE=fd();if(jE===eF){jE=hv;};if(jE!==eF){jD=hw();if(jD!==eF){hk=jF;jE=hs(jE,jD);jF=jE;}else {hj=jF;jF=hb;};}else {hj=jF;jF=hb;};};};return jF;};function fd(){var jJ,jI,jH,jG,jK;jJ=hj;jI=hy();if(jI!==eF){if(hm.test(eR.charAt(hj))){jH=eR.charAt(hj);hj++ ;}else {jH=eF;if(fY===0){fi(hl);};};if(jH!==eF){jG=[];jK=gq();while(jK!==eF){jG.push(jK);jK=gq();};if(jG!==eF){hk=jJ;jI=fu(jI);jJ=jI;}else {hj=jJ;jJ=hb;};}else {hj=jJ;jJ=hb;};}else {hj=jJ;jJ=hb;};return jJ;};function hw(){var jO,jN,jM,jL,jR,jQ,jP;jO=hj;jN=fm();if(jN===eF){jN=hv;};if(jN!==eF){jM=gu();if(jM!==eF){jL=gx();if(jL===eF){jL=hv;};if(jL!==eF){jR=hx();if(jR===eF){jR=hv;};if(jR!==eF){jQ=[];jP=gq();while(jP!==eF){jQ.push(jP);jP=gq();};if(jQ!==eF){hk=jO;jN=fv(jN,jM,jL,jR);jO=jN;}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};if(jO===eF){jO=hj;jN=fm();if(jN===eF){jN=hv;};if(jN!==eF){jM=hy();if(jM!==eF){jL=gr();if(jL===eF){jL=hv;};if(jL!==eF){jR=hx();if(jR===eF){jR=hv;};if(jR!==eF){jQ=[];jP=gq();while(jP!==eF){jQ.push(jP);jP=gq();};if(jQ!==eF){hk=jO;jN=fs(jN,jM,jL,jR);jO=jN;}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};}else {hj=jO;jO=hb;};};return jO;};function ge(){var jS;if(eR.charCodeAt(hj)===46){jS=ft;hj++ ;}else {jS=eF;if(fY===0){fi(fy);};};if(jS===eF){if(fz.test(eR.charAt(hj))){jS=eR.charAt(hj);hj++ ;}else {jS=eF;if(fY===0){fi(fw);};};};return jS;};function gp(){var jV,jU,jT;jV=hj;jU=[];jT=ge();if(jT!==eF){while(jT!==eF){jU.push(jT);jT=ge();};}else {jU=hb;};if(jU!==eF){hk=jV;jU=fx(jU);};jV=jU;return jV;};function hy(){var jY,jX,jW;jY=hj;jX=[];jW=gG();if(jW!==eF){while(jW!==eF){jX.push(jW);jW=gG();};}else {jX=hb;};if(jX!==eF){hk=jY;jX=fx(jX);};jY=jX;return jY;};function gG(){var ka;if(eR.charCodeAt(hj)===46){ka=ft;hj++ ;}else {ka=eF;if(fY===0){fi(fy);};};if(ka===eF){if(fA.test(eR.charAt(hj))){ka=eR.charAt(hj);hj++ ;}else {ka=eF;if(fY===0){fi(fB);};};};return ka;};function gu(){var ke,kd,kc,kb;ke=hj;if(eR.charCodeAt(hj)===34){kd=fa;hj++ ;}else {kd=eF;if(fY===0){fi(eY);};};if(kd!==eF){kc=[];kb=fM();while(kb!==eF){kc.push(kb);kb=fM();};if(kc!==eF){if(eR.charCodeAt(hj)===34){kb=fa;hj++ ;}else {kb=eF;if(fY===0){fi(eY);};};if(kb!==eF){hk=ke;kd=fc(kc);ke=kd;}else {hj=ke;ke=hb;};}else {hj=ke;ke=hb;};}else {hj=ke;ke=hb;};return ke;};function fM(){var kh,kg,kf;kh=hj;kg=hj;fY++ ;if(eR.charCodeAt(hj)===34){kf=fa;hj++ ;}else {kf=eF;if(fY===0){fi(eY);};};if(kf===eF){if(eR.charCodeAt(hj)===92){kf=eV;hj++ ;}else {kf=eF;if(fY===0){fi(eU);};};};fY-- ;if(kf===eF){kg=fb;}else {hj=kg;kg=hb;};if(kg!==eF){if(eR.length>hj){kf=eR.charAt(hj);hj++ ;}else {kf=eF;if(fY===0){fi(eX);};};if(kf!==eF){hk=kh;kg=eW(kf);kh=kg;}else {hj=kh;kh=hb;};}else {hj=kh;kh=hb;};if(kh===eF){kh=hj;if(eR.charCodeAt(hj)===92){kg=eV;hj++ ;}else {kg=eF;if(fY===0){fi(eU);};};if(kg!==eF){kf=hA();if(kf!==eF){hk=kh;kg=ff(kf);kh=kg;}else {hj=kh;kh=hb;};}else {hj=kh;kh=hb;};};return kh;};function hA(){var ki;if(eR.charCodeAt(hj)===43){ki=fe;hj++ ;}else {ki=eF;if(fY===0){fi(gk);};};if(ki===eF){if(eR.charCodeAt(hj)===45){ki=gl;hj++ ;}else {ki=eF;if(fY===0){fi(gm);};};if(ki===eF){if(eR.charCodeAt(hj)===33){ki=gn;hj++ ;}else {ki=eF;if(fY===0){fi(fh);};};if(ki===eF){if(eR.charCodeAt(hj)===40){ki=hg;hj++ ;}else {ki=eF;if(fY===0){fi(hr);};};if(ki===eF){if(eR.charCodeAt(hj)===41){ki=hq;hj++ ;}else {ki=eF;if(fY===0){fi(hp);};};if(ki===eF){if(eR.charCodeAt(hj)===123){ki=gh;hj++ ;}else {ki=eF;if(fY===0){fi(gi);};};if(ki===eF){if(eR.charCodeAt(hj)===125){ki=gj;hj++ ;}else {ki=eF;if(fY===0){fi(go);};};if(ki===eF){if(eR.charCodeAt(hj)===91){ki=fG;hj++ ;}else {ki=eF;if(fY===0){fi(gf);};};if(ki===eF){if(eR.charCodeAt(hj)===93){ki=fT;hj++ ;}else {ki=eF;if(fY===0){fi(fS);};};if(ki===eF){if(eR.charCodeAt(hj)===94){ki=fR;hj++ ;}else {ki=eF;if(fY===0){fi(fQ);};};if(ki===eF){if(eR.charCodeAt(hj)===34){ki=fa;hj++ ;}else {ki=eF;if(fY===0){fi(eY);};};if(ki===eF){if(eR.charCodeAt(hj)===63){ki=fP;hj++ ;}else {ki=eF;if(fY===0){fi(fO);};};if(ki===eF){if(eR.charCodeAt(hj)===58){ki=fN;hj++ ;}else {ki=eF;if(fY===0){fi(fW);};};if(ki===eF){if(eR.charCodeAt(hj)===92){ki=eV;hj++ ;}else {ki=eF;if(fY===0){fi(eU);};};if(ki===eF){if(eR.charCodeAt(hj)===38){ki=fV;hj++ ;}else {ki=eF;if(fY===0){fi(gV);};};if(ki===eF){if(eR.charCodeAt(hj)===124){ki=gW;hj++ ;}else {ki=eF;if(fY===0){fi(gT);};};if(ki===eF){if(eR.charCodeAt(hj)===39){ki=gU;hj++ ;}else {ki=eF;if(fY===0){fi(gR);};};if(ki===eF){if(eR.charCodeAt(hj)===47){ki=gS;hj++ ;}else {ki=eF;if(fY===0){fi(gP);};};};};};};};};};};};};};};};};};};};return ki;};function gx(){var kl,kk,kj;kl=hj;if(eR.charCodeAt(hj)===126){kk=gQ;hj++ ;}else {kk=eF;if(fY===0){fi(gN);};};if(kk!==eF){kj=hn();if(kj!==eF){hk=kl;kk=gO(kj);kl=kk;}else {hj=kl;kl=hb;};}else {hj=kl;kl=hb;};return kl;};function hx(){var ko,kn,km;ko=hj;if(eR.charCodeAt(hj)===94){kn=fR;hj++ ;}else {kn=eF;if(fY===0){fi(fQ);};};if(kn!==eF){km=hi();if(km!==eF){hk=ko;kn=gz(km);ko=kn;}else {hj=ko;ko=hb;};}else {hj=ko;ko=hb;};return ko;};function gr(){var kr,kq,kp;kr=hj;if(eR.charCodeAt(hj)===126){kq=gQ;hj++ ;}else {kq=eF;if(fY===0){fi(gN);};};if(kq!==eF){kp=gv();if(kp===eF){kp=hv;};if(kp!==eF){hk=kr;kq=gy(kp);kr=kq;}else {hj=kr;kr=hb;};}else {hj=kr;kr=hb;};return kr;};function hi(){var ks;ks=gv();if(ks===eF){ks=hn();};return ks;};function gv(){var kw,kv,ku,kt;kw=hj;if(eR.substr(hj,2)===gB){kv=gB;hj+=2;}else {kv=eF;if(fY===0){fi(gA);};};if(kv!==eF){ku=[];if(gD.test(eR.charAt(hj))){kt=eR.charAt(hj);hj++ ;}else {kt=eF;if(fY===0){fi(gC);};};if(kt!==eF){while(kt!==eF){ku.push(kt);if(gD.test(eR.charAt(hj))){kt=eR.charAt(hj);hj++ ;}else {kt=eF;if(fY===0){fi(gC);};};};}else {ku=hb;};if(ku!==eF){hk=kw;kv=gF(ku);kw=kv;}else {hj=kw;kw=hb;};}else {hj=kw;kw=hb;};return kw;};function hn(){var kz,ky,kx;kz=hj;ky=[];if(gD.test(eR.charAt(hj))){kx=eR.charAt(hj);hj++ ;}else {kx=eF;if(fY===0){fi(gC);};};if(kx!==eF){while(kx!==eF){ky.push(kx);if(gD.test(eR.charAt(hj))){kx=eR.charAt(hj);hj++ ;}else {kx=eF;if(fY===0){fi(gC);};};};}else {ky=hb;};if(ky!==eF){hk=kz;ky=gE(ky);};kz=ky;return kz;};function ho(){var kD,kC,kB,kA,kH,kG,kF,kE;kD=hj;if(eR.charCodeAt(hj)===91){kC=fG;hj++ ;}else {kC=eF;if(fY===0){fi(gf);};};if(kC!==eF){kB=gp();if(kB!==eF){kA=[];kH=gq();while(kH!==eF){kA.push(kH);kH=gq();};if(kA!==eF){if(eR.substr(hj,2)===gH){kH=gH;hj+=2;}else {kH=eF;if(fY===0){fi(eG);};};if(kH!==eF){kG=[];kF=gq();if(kF!==eF){while(kF!==eF){kG.push(kF);kF=gq();};}else {kG=hb;};if(kG!==eF){kF=gp();if(kF!==eF){if(eR.charCodeAt(hj)===93){kE=fT;hj++ ;}else {kE=eF;if(fY===0){fi(fS);};};if(kE!==eF){hk=kD;kC=fC(kB,kF);kD=kC;}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};if(kD===eF){kD=hj;if(eR.charCodeAt(hj)===123){kC=gh;hj++ ;}else {kC=eF;if(fY===0){fi(gi);};};if(kC!==eF){kB=gp();if(kB!==eF){kA=[];kH=gq();while(kH!==eF){kA.push(kH);kH=gq();};if(kA!==eF){if(eR.substr(hj,2)===gH){kH=gH;hj+=2;}else {kH=eF;if(fY===0){fi(eG);};};if(kH!==eF){kG=[];kF=gq();if(kF!==eF){while(kF!==eF){kG.push(kF);kF=gq();};}else {kG=hb;};if(kG!==eF){kF=gp();if(kF!==eF){if(eR.charCodeAt(hj)===125){kE=gj;hj++ ;}else {kE=eF;if(fY===0){fi(go);};};if(kE!==eF){hk=kD;kC=fj(kB,kF);kD=kC;}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};if(kD===eF){kD=hj;if(eR.charCodeAt(hj)===91){kC=fG;hj++ ;}else {kC=eF;if(fY===0){fi(gf);};};if(kC!==eF){kB=gp();if(kB!==eF){kA=[];kH=gq();while(kH!==eF){kA.push(kH);kH=gq();};if(kA!==eF){if(eR.substr(hj,2)===gH){kH=gH;hj+=2;}else {kH=eF;if(fY===0){fi(eG);};};if(kH!==eF){kG=[];kF=gq();if(kF!==eF){while(kF!==eF){kG.push(kF);kF=gq();};}else {kG=hb;};if(kG!==eF){kF=gp();if(kF!==eF){if(eR.charCodeAt(hj)===125){kE=gj;hj++ ;}else {kE=eF;if(fY===0){fi(go);};};if(kE!==eF){hk=kD;kC=fk(kB,kF);kD=kC;}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};if(kD===eF){kD=hj;if(eR.charCodeAt(hj)===123){kC=gh;hj++ ;}else {kC=eF;if(fY===0){fi(gi);};};if(kC!==eF){kB=gp();if(kB!==eF){kA=[];kH=gq();while(kH!==eF){kA.push(kH);kH=gq();};if(kA!==eF){if(eR.substr(hj,2)===gH){kH=gH;hj+=2;}else {kH=eF;if(fY===0){fi(eG);};};if(kH!==eF){kG=[];kF=gq();if(kF!==eF){while(kF!==eF){kG.push(kF);kF=gq();};}else {kG=hb;};if(kG!==eF){kF=gp();if(kF!==eF){if(eR.charCodeAt(hj)===93){kE=fT;hj++ ;}else {kE=eF;if(fY===0){fi(fS);};};if(kE!==eF){hk=kD;kC=fl(kB,kF);kD=kC;}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};}else {hj=kD;kD=hb;};};};};return kD;};function fI(){var kL,kK,kJ,kI,kM;kL=hj;kK=[];kJ=gq();while(kJ!==eF){kK.push(kJ);kJ=gq();};if(kK!==eF){kJ=fK();if(kJ!==eF){kI=[];kM=gq();if(kM!==eF){while(kM!==eF){kI.push(kM);kM=gq();};}else {kI=hb;};if(kI!==eF){hk=kL;kK=fJ(kJ);kL=kK;}else {hj=kL;kL=hb;};}else {hj=kL;kL=hb;};}else {hj=kL;kL=hb;};if(kL===eF){kL=hj;kK=[];kJ=gq();while(kJ!==eF){kK.push(kJ);kJ=gq();};if(kK!==eF){kJ=fK();if(kJ!==eF){kI=eI();if(kI!==eF){hk=kL;kK=fJ(kJ);kL=kK;}else {hj=kL;kL=hb;};}else {hj=kL;kL=hb;};}else {hj=kL;kL=hb;};};return kL;};function fK(){var kN;if(eR.substr(hj,6)===fn){kN=fn;hj+=6;}else {kN=eF;if(fY===0){fi(fo);};};if(kN===eF){if(eR.substr(hj,7)===fp){kN=fp;hj+=7;}else {kN=eF;if(fY===0){fi(fq);};};if(kN===eF){if(eR.substr(hj,2)===fr){kN=fr;hj+=2;}else {kN=eF;if(fY===0){fi(eM);};};if(kN===eF){if(eR.substr(hj,3)===eL){kN=eL;hj+=3;}else {kN=eF;if(fY===0){fi(eK);};};if(kN===eF){if(eR.substr(hj,3)===eJ){kN=eJ;hj+=3;}else {kN=eF;if(fY===0){fi(eQ);};};if(kN===eF){if(eR.substr(hj,2)===eP){kN=eP;hj+=2;}else {kN=eF;if(fY===0){fi(eO);};};if(kN===eF){if(eR.substr(hj,2)===eN){kN=eN;hj+=2;}else {kN=eF;if(fY===0){fi(eT);};};if(kN===eF){if(eR.charCodeAt(hj)===33){kN=gn;hj++ ;}else {kN=eF;if(fY===0){fi(fh);};};};};};};};};};return kN;};function fm(){var kQ,kP,kO;kQ=hj;kP=[];kO=gq();while(kO!==eF){kP.push(kO);kO=gq();};if(kP!==eF){kO=fH();if(kO!==eF){hk=kQ;kP=fJ(kO);kQ=kP;}else {hj=kQ;kQ=hb;};}else {hj=kQ;kQ=hb;};return kQ;};function fH(){var kR;if(eR.charCodeAt(hj)===43){kR=fe;hj++ ;}else {kR=eF;if(fY===0){fi(gk);};};if(kR===eF){if(eR.charCodeAt(hj)===45){kR=gl;hj++ ;}else {kR=eF;if(fY===0){fi(gm);};};};return kR;};function gq(){var kT,kS;fY++ ;kT=[];if(fE.test(eR.charAt(hj))){kS=eR.charAt(hj);hj++ ;}else {kS=eF;if(fY===0){fi(fF);};};if(kS!==eF){while(kS!==eF){kT.push(kS);if(fE.test(eR.charAt(hj))){kS=eR.charAt(hj);hj++ ;}else {kS=eF;if(fY===0){fi(fF);};};};}else {kT=hb;};fY-- ;if(kT===eF){kS=eF;if(fY===0){fi(eS);};};return kT;};function eI(){var kV,kU;kV=hj;fY++ ;if(eR.length>hj){kU=eR.charAt(hj);hj++ ;}else {kU=eF;if(fY===0){fi(eX);};};fY-- ;if(kU===eF){kV=fb;}else {hj=kV;kV=hb;};return kV;};gb=gs();if(gb!==eF&&hj===eR.length){return gb;}else {if(gb!==eF&&hj<eR.length){fi({type:K,description:l});};throw fg(null,gt,eH);};};function et(kW){return O+kW;};function ev(s){return s.replace(/"/g,et);};function eu(kX){if(!kX){return dH;};var la=dH;var kY=dv;if(kX.start!=null){la+=kX.start+dW;};if(kX.field&&kX.field!==kY){la+=kX.field+x;};if(kX.left){if(kX.parenthesized){la+=r;};la+=eu(kX.left);if(kX.parenthesized&&!kX.right){la+=dO;};};if(kX.operator){if(kX.left){la+=dW;};if(kX.operator!==kY){la+=kX.operator;};};if(kX.right){if(kX.operator&&kX.operator!==kY){la+=dW;};la+=eu(kX.right);if(kX.parenthesized){la+=dO;};};if(kX.term){if(kX.prefix){la+=kX.prefix;};if(kX.quoted){la+=R;la+=ev(kX.term);la+=R;}else {la+=kX.term;};if(kX.proximity!=null){la+=f+kX.proximity;};if(kX.boost!=null){la+=U+kX.boost;};};if(kX.term_min){if(kX.inclusive===dD||kX.inclusive===eb){la+=dh;}else {la+=cD;};la+=kX.term_min;la+=L;la+=kX.term_max;if(kX.inclusive===dD||kX.inclusive===du){la+=dL;}else {la+=dq;};};if(kX.similarity){la+=f;if(kX.similarity!==0.5){la+=kX.similarity;};};return la;};return {SyntaxError:SyntaxError,parse:es,toString:eu};});})();(function(){var a='beforeRequest',b='afterRequest',c='requestData',d='timeSeries',e='_desktop',f='group',g='open',h='clone',i='Log',j='data',k='changeBubble',l='_formController',m='filter',n='clui.model.form.TableQuery',o='timezone',p='refresh',q='clui.controller.RecordTable',r='changeGroup',s='_listView';qx.Class.define(q,{extend:qx.core.Object,include:qx.locale.MTranslation,properties:{tableQueryModel:{check:n,nullable:true}},construct:function(t,u){qx.core.Object.call(this);this.setTableQueryModel(t);this._tabView=u;this._desktop=new qx.ui.window.Desktop(new qx.ui.window.Manager());this._formController=new kucken.ui.form.mvc.Controller(this._desktop,clui.view.form.Record,clui.model.form.Record);},destruct:function(){this._disposeObjects(e,s,l);},members:{_desktop:null,_listView:null,_formController:null,_tabView:null,_reload:qx.util.Function.debounce(function(){this._listView.getTable().getTableModel().reloadData();},50),_onOpen:function(event){var v=event.getData();var w=this._listView.getTable().getTableModel().getRowData(v);if(w){this._formController.open(w);};},_onClone:function(){var x=new clui.model.form.TableQuery();x.load(this.getTableQueryModel().save());var y=new clui.controller.RecordTable(x,this._tabView);this._tabView.addTablePage(new clui.view.TablePage(y));},_onBeforeDataModelRequest:function(){this._listView.getToolbar().setEnabled(false);},_onAfterDataModelRequest:function(event){if(event.getData() instanceof qx.event.type.Rest&&event.getData().getRequest().getStatus()==400){this._listView.setValidQuery(false);};var z=this._listView.getTable();z.clearFocusedRowHighlight();z.getSelectionModel().resetSelection();this._listView.getToolbar().setEnabled(true);},_onRequestData:function(event){var A=event.getData()[j];A[m]=this.getTableQueryModel().save();A[f]=this._listView.getGroup();A[o]=clui.bom.Timezone.get();},_initDataModel:function(){var B=new clui.model.RemoteRecordTable();B.addListener(a,this._onBeforeDataModelRequest,this);B.addListener(b,this._onAfterDataModelRequest,this);B.addListener(c,this._onRequestData,this);this._listView.setTableModel(B);B.bind(d,this._listView,d);this._listView.addListener(r,this._reload,this);this.getTableQueryModel().getFormModel().addListener(k,this._reload,this);},createWidget:function(){this._listView=new clui.view.list.RecordTable(this.tr(i),null,this.getTableQueryModel());this._listView.addListener(p,this._reload,this);this._listView.addListener(g,this._onOpen,this);this._listView.addListener(h,this._onClone,this);this._initDataModel();this._desktop.add(this._listView,{'left':20,'top':20});this._listView.open();return this._desktop;}}});})();(function(){var a="qx.ui.window.Desktop";qx.Class.define(a,{extend:qx.ui.core.Widget,include:[qx.ui.core.MChildrenHandling,qx.ui.window.MDesktop,qx.ui.core.MBlocker],implement:qx.ui.window.IDesktop,construct:function(b){qx.ui.core.Widget.call(this);b=b||new qx.ui.window.Window.DEFAULT_MANAGER_CLASS();this.getContentElement().disableScrolling();this._setLayout(new qx.ui.layout.Canvas().set({desktop:true}));this.setWindowManager(b);}});})();(function(){var a='kucken.ui.form.mvc.View',b='Cancel',c='kucken/image/loading16.gif',d='failed',e='_form',f='_applyModel',g='appear',h='OK',i='changeActive',j='loaded',k='Boolean',l='kucken.ui.form.mvc.Model',m='_blocker',n='execute',o='_controller',p='gray',q='preload',r='abstract';qx.Class.define(a,{extend:qx.ui.window.Window,type:r,properties:{isCanceled:{check:k,init:false},model:{check:l,apply:f,init:null,nullable:true}},construct:function(){qx.ui.window.Window.call(this);this.set({'layout':new qx.ui.layout.VBox(),'showMinimize':false,'showMaximize':false});this.addListener(g,this.center,this);this.addListener(i,function(event){if(event.getData()){this.activate();};},this);this._form=new qx.ui.form.Form();this._controller=new qx.data.controller.Form(null,this._form);this._blocker=new qx.ui.core.Blocker(this.getChildrenContainer());this._blocker.set({'opacity':0.4,'color':p});},destruct:function(){this._disposeObjects(e,m,o);},members:{_form:null,_controller:null,_blocker:null,_windowHeading:null,_okButton:null,_cancelButton:null,_blockedIcon:null,_block:function(){if(!this._blocker.isBlocked()){this._blocker.block();this._blockedIcon=this.getIcon();this.setIcon(c);};},_unblock:function(){if(this._blocker.isBlocked()){this._blocker.unblock();this.setIcon(this._blockedIcon);};},_onModelLoaded:function(){this._controller.setModel(this.getModel().getFormModel());this._unblock();},_createButtons:function(){this._okButton=new qx.ui.form.Button(this.tr(h));this._okButton.setWidth(70);this._okButton.addListener(n,this._onOk,this);this._form.addButton(this._okButton);this._cancelButton=new qx.ui.form.Button(this.tr(b));this._cancelButton.setWidth(70);this._cancelButton.addListener(n,this._onCancel,this);this._form.addButton(this._cancelButton);},_createForm:function(){this._createButtons();},_onOk:function(){if(this._form.validate()){this.getModel().save();this.close();};},_onCancel:function(){this.setIsCanceled(true);this.close();},_renderForm:function(){var s=new qx.ui.form.renderer.Single(this._form);s.getLayout().setColumnFlex(0,0);s.getLayout().setColumnFlex(1,1);this.add(s,{'flex':1});return s;},_applyModel:function(t,u){if(u){u.removeListener(q,this._block,this);u.removeListener(j,this._onModelLoaded,this);u.removeListener(d,this._unblock,this);};if(t){t.addListener(q,this._block,this);t.addListener(j,this._onModelLoaded,this);t.addListener(d,this._unblock,this);};this._createForm();this._renderForm();},load:function(v){this._form.reset();this.getModel().load(v);}}});})();(function(){var a="qx.ui.form.renderer.IFormRenderer";qx.Interface.define(a,{members:{addItems:function(b,f,d,c,e){},addButton:function(g,h){}}});})();(function(){var a=" <span style='color:red'>*</span> ",b="Abstract method call",c="abstract",d="",f="changeLocale",g="change",h="visibility",j="qx.ui.form.renderer.AbstractRenderer",k=" :";qx.Class.define(j,{type:c,extend:qx.ui.core.Widget,implement:qx.ui.form.renderer.IFormRenderer,construct:function(l){qx.ui.core.Widget.call(this);this._labels=[];{qx.locale.Manager.getInstance().addListener(f,this._onChangeLocale,this);this._names=[];};this._form=l;this._render();l.addListener(g,this._onFormChange,this);},members:{_names:null,_form:null,_labels:null,_render:function(){var p=this._form.getGroups();for(var i=0;i<p.length;i++ ){var o=p[i];this.addItems(o.items,o.labels,o.title,o.options,o.headerOptions);};var m=this._form.getButtons();var n=this._form.getButtonOptions();for(var i=0;i<m.length;i++ ){this.addButton(m[i],n[i]);};},_onFormChange:function(){this._removeAll();for(var i=0;i<this._labels.length;i++ ){this._labels[i].dispose();};this._labels=[];this._render();},_connectVisibility:function(q,r){q.bind(h,r,h);},_onChangeLocale:function(e){for(var i=0;i<this._names.length;i++ ){var t=this._names[i];if(t.name&&t.name.translate){t.name=t.name.translate();};var s=this._createLabelText(t.name,t.item);t.label.setValue(s);};},_createLabelText:function(name,u){var v=d;if(u.getRequired()){v=a;};var w=name.length>0||u.getRequired()?k:d;return name+v+w;},addItems:function(x,y,z){throw new Error(b);},addButton:function(A){throw new Error(b);}},destruct:function(){{qx.locale.Manager.getInstance().removeListener(f,this._onChangeLocale,this);};this._names=null;}});})();(function(){var a="bold",b="_buttonRow",c="qx.ui.form.renderer.Single",d="form-renderer-label",e="top",f="left",g="right";qx.Class.define(c,{extend:qx.ui.form.renderer.AbstractRenderer,construct:function(j){var h=new qx.ui.layout.Grid();h.setSpacing(6);h.setColumnFlex(1,1);h.setColumnAlign(0,g,e);this._setLayout(h);qx.ui.form.renderer.AbstractRenderer.call(this,j);},members:{_row:0,_buttonRow:null,_onFormChange:function(){if(this._buttonRow){this._buttonRow.destroy();this._buttonRow=null;};this._row=0;qx.ui.form.renderer.AbstractRenderer.prototype._onFormChange.call(this);},addItems:function(l,o,k){if(k!=null){this._add(this._createHeader(k),{row:this._row,column:0,colSpan:2});this._row++ ;};for(var i=0;i<l.length;i++ ){var m=this._createLabel(o[i],l[i]);this._add(m,{row:this._row,column:0});var n=l[i];m.setBuddy(n);this._add(n,{row:this._row,column:1});this._row++ ;this._connectVisibility(n,m);{this._names.push({name:o[i],label:m,item:l[i]});};};},addButton:function(p){if(this._buttonRow==null){this._buttonRow=new qx.ui.container.Composite();this._buttonRow.setMarginTop(5);var q=new qx.ui.layout.HBox();q.setAlignX(g);q.setSpacing(5);this._buttonRow.setLayout(q);this._add(this._buttonRow,{row:this._row,column:0,colSpan:2});this._row++ ;};this._buttonRow.add(p);},getLayout:function(){return this._getLayout();},_createLabel:function(name,r){var s=new qx.ui.basic.Label(this._createLabelText(name,r));this._labels.push(s);s.setRich(true);s.setAppearance(d);return s;},_createHeader:function(u){var t=new qx.ui.basic.Label(u);this._labels.push(t);t.setFont(a);if(this._row!=0){t.setMarginTop(10);};t.setAlignX(f);return t;}},destruct:function(){if(this._buttonRow){this._buttonRow.removeAll();this._disposeObjects(b);};}});})();(function(){var a='',b=' ',c='preload',d='_dateFormatter',e='clui.view.form.Record',f='icon/16/apps/utilities-log-viewer.png',g='HHmmssSSSzz',h='Log record %1',i='HH:mm:ss.SSS zz',j='...',k='full';qx.Class.define(e,{extend:kucken.ui.form.mvc.View,construct:function(){kucken.ui.form.mvc.View.call(this);this.setCaption(this.tr(h,j));this.setIcon(f);this.setContentPadding(0);this.setWidth(480);var l=[qx.locale.Date.getDateFormat(k),qx.locale.Date.getDateTimeFormat(g,i)].join(b);this._dateFormatter=new qx.util.format.DateFormat(l);},destruct:function(){this._disposeObjects(d);},members:{_codeViewer:null,_dateFormatter:null,_cleanStrings:function(m){if(qx.lang.Type.isObject(m)){kucken.lang.Object.items(m).forEach(function(n){if(qx.lang.Type.isString(n[1])){m[n[0]]=n[1].replace(clui.util.String.nonPrintableRegexp,a);}else {this._cleanStrings(n[1]);};},this);};return m;},_createForm:function(){kucken.ui.form.mvc.View.prototype._createForm.call(this);this._codeViewer=new clui.view.widget.CodeViewer();this._codeViewer.set({'readOnly':true,'height':240});this.add(this._codeViewer,{'flex':1});this.getModel().addListener(c,this._codeViewer.resetValue,this._codeViewer);},_onModelLoaded:function(){kucken.ui.form.mvc.View.prototype._onModelLoaded.call(this);var o=this.getModel().getFormModel();var p={'id':o.getId(),'name':o.getName(),'message':o.getMessage(),'level':clui.model.form.Record.levelMap[o.getLevel()],'ts':this._dateFormatter.format(o.getTs()),'logrec':this._cleanStrings(qx.lang.Json.parse(o.getLogrec()))};var q=kucken.util.Yaml.stringify(p,{'sortKeys':true});this._codeViewer.setValue(q);this.setCaption(this.tr(h,o.getId()));},_renderForm:function(){}}});})();(function(){var a='[\\x00-\\x09\\x0B-\\x1F\\x7F-\\x9F\\xAD\\u0378\\u0379\\u037F-\\u0383\\u038B',b='\\u23F4-\\u23FF\\u2427-\\u243F\\u244B-\\u245F\\u2700\\u2B4D-\\u2B4F',c='\\u1715-\\u171F\\u1737-\\u173F\\u1754-\\u175F\\u176D\\u1771\\u1774-\\u177F',d='\\u0D65\\u0D76-\\u0D78\\u0D80\\u0D81\\u0D84\\u0D97-\\u0D99\\u0DB2\\u0DBC',e='\\u1878-\\u187F\\u18AB-\\u18AF\\u18F6-\\u18FF\\u191D-\\u191F',f='\\u192C-\\u192F\\u193C-\\u193F\\u1941-\\u1943\\u196E\\u196F\\u1975-\\u197F',g='\\u0D11\\u0D3B\\u0D3C\\u0D45\\u0D49\\u0D4F-\\u0D56\\u0D58-\\u0D5F\\u0D64',h='\\u038D\\u03A2\\u0528-\\u0530\\u0557\\u0558\\u0560\\u0588\\u058B-\\u058E',i='\\u12C6\\u12C7\\u12D7\\u1311\\u1316\\u1317\\u135B\\u135C\\u137D-\\u137F',j='\\u0ACE\\u0ACF\\u0AD1-\\u0ADF\\u0AE4\\u0AE5\\u0AF2-\\u0B00\\u0B04\\u0B0D',k='\\u2B5A-\\u2BFF\\u2C2F\\u2C5F\\u2CF4-\\u2CF8\\u2D26\\u2D28-\\u2D2C\\u2D2E',l='\\u083F\\u085C\\u085D\\u085F-\\u089F\\u08A1\\u08AD-\\u08E3\\u08FF\\u0978',m='\\uFFE7\\uFFEF-\\uFFFB\\uFFFE\\uFFFF]',n='\\uA8FC-\\uA8FF\\uA954-\\uA95E\\uA97D-\\uA97F\\uA9CE\\uA9DA-\\uA9DD',o='\\u0980\\u0984\\u098D\\u098E\\u0991\\u0992\\u09A9\\u09B1\\u09B3-\\u09B5',p='\\u2D2F\\u2D68-\\u2D6E\\u2D71-\\u2D7E\\u2D97-\\u2D9F\\u2DA7\\u2DAF\\u2DB7',q='\\u1C80-\\u1CBF\\u1CC8-\\u1CCF\\u1CF7-\\u1CFF\\u1DE7-\\u1DFB\\u1F16',r='\\u1FF5\\u1FFF\\u200B-\\u200F\\u202A-\\u202E\\u2060-\\u206F\\u2072\\u2073',s='\\uA82C-\\uA82F\\uA83A-\\uA83F\\uA878-\\uA87F\\uA8C5-\\uA8CD\\uA8DA-\\uA8DF',t='\\u0B78-\\u0B81\\u0B84\\u0B8B-\\u0B8D\\u0B91\\u0B96-\\u0B98\\u0B9B\\u0B9D',u='\\u1F17\\u1F1E\\u1F1F\\u1F46\\u1F47\\u1F4E\\u1F4F\\u1F58\\u1F5A\\u1F5C',v='\\u0DF5-\\u0E00\\u0E3B-\\u0E3E\\u0E5C-\\u0E80\\u0E83\\u0E85\\u0E86\\u0E89',w='\\u0E8B\\u0E8C\\u0E8E-\\u0E93\\u0E98\\u0EA0\\u0EA4\\u0EA6\\u0EA8\\u0EA9',x='\\u312E-\\u3130\\u318F\\u31BB-\\u31BF\\u31E4-\\u31EF\\u321F\\u32FF',y='\\uA9E0-\\uA9FF\\uAA37-\\uAA3F\\uAA4E\\uAA4F\\uAA5A\\uAA5B\\uAA7C-\\uAA7F',z='\\u2FD6-\\u2FEF\\u2FFC-\\u2FFF\\u3040\\u3097\\u3098\\u3100-\\u3104',A='\\u19AC-\\u19AF\\u19CA-\\u19CF\\u19DB-\\u19DD\\u1A1C\\u1A1D\\u1A5F\\u1A7D',B='\\u0B49\\u0B4A\\u0B4E-\\u0B55\\u0B58-\\u0B5B\\u0B5E\\u0B64\\u0B65',C='\\u10C6\\u10C8-\\u10CC\\u10CE\\u10CF\\u1249\\u124E\\u124F\\u1257\\u1259',D='\\u208F\\u209D-\\u209F\\u20BB-\\u20CF\\u20F1-\\u20FF\\u218A-\\u218F',E='\\uAAC3-\\uAADA\\uAAF7-\\uAB00\\uAB07\\uAB08\\uAB0F\\uAB10\\uAB17-\\uAB1F',F='\\u0B0E\\u0B11\\u0B12\\u0B29\\u0B31\\u0B34\\u0B3A\\u0B3B\\u0B45\\u0B46',G='\\uFD40-\\uFD4F\\uFD90\\uFD91\\uFDC8-\\uFDEF\\uFDFE\\uFDFF\\uFE1A-\\uFE1F',H='\\u4DB6-\\u4DBF\\u9FCD-\\u9FFF\\uA48D-\\uA48F\\uA4C7-\\uA4CF\\uA62C-\\uA63F',I='\\uFE27-\\uFE2F\\uFE53\\uFE67\\uFE6C-\\uFE6F\\uFE75\\uFEFD-\\uFF00',J='\\uD7C7-\\uD7CA\\uD7FC-\\uF8FF\\uFA6E\\uFA6F\\uFADA-\\uFAFF\\uFB07-\\uFB12',K='\\u0A4A\\u0A4E-\\u0A50\\u0A52-\\u0A58\\u0A5D\\u0A5F-\\u0A65\\u0A76-\\u0A80',L='\\u0BC9\\u0BCE\\u0BCF\\u0BD1-\\u0BD6\\u0BD8-\\u0BE5\\u0BFB-\\u0C00\\u0C04',M='\\u0C8D\\u0C91\\u0CA9\\u0CB4\\u0CBA\\u0CBB\\u0CC5\\u0CC9\\u0CCE-\\u0CD4',N='\\u1F5E\\u1F7E\\u1F7F\\u1FB5\\u1FC5\\u1FD4\\u1FD5\\u1FDC\\u1FF0\\u1FF1',O='\\u0A84\\u0A8E\\u0A92\\u0AA9\\u0AB1\\u0AB4\\u0ABA\\u0ABB\\u0AC6\\u0ACA',P='\\u139A-\\u139F\\u13F5-\\u13FF\\u169D-\\u169F\\u16F1-\\u16FF\\u170D',Q='g',R='\\u17DE\\u17DF\\u17EA-\\u17EF\\u17FA-\\u17FF\\u180F\\u181A-\\u181F',S='\\u2DBF\\u2DC7\\u2DCF\\u2DD7\\u2DDF\\u2E3C-\\u2E7F\\u2E9A\\u2EF4-\\u2EFF',T='\\u0A29\\u0A31\\u0A34\\u0A37\\u0A3A\\u0A3B\\u0A3D\\u0A43-\\u0A46\\u0A49',U='\\u1B7D-\\u1B7F\\u1BF4-\\u1BFB\\u1C38-\\u1C3A\\u1C4A-\\u1C4C',V='\\u0BA0-\\u0BA2\\u0BA5-\\u0BA7\\u0BAB-\\u0BAD\\u0BBA-\\u0BBD\\u0BC3-\\u0BC5',W='\\u0C57\\u0C5A-\\u0C5F\\u0C64\\u0C65\\u0C70-\\u0C77\\u0C80\\u0C81\\u0C84',X='\\u070E\\u070F\\u074B\\u074C\\u07B2-\\u07BF\\u07FB-\\u07FF\\u082E\\u082F',Y='\\u0590\\u05C8-\\u05CF\\u05EB-\\u05EF\\u05F5-\\u0605\\u061C\\u061D\\u06DD',bs='\\u0DBE\\u0DBF\\u0DC7-\\u0DC9\\u0DCB-\\u0DCE\\u0DD5\\u0DD7\\u0DE0-\\u0DF1',bt='\\u125E\\u125F\\u1289\\u128E\\u128F\\u12B1\\u12B6\\u12B7\\u12BF\\u12C1',bu='\\u0EE0-\\u0EFF\\u0F48\\u0F6D-\\u0F70\\u0F98\\u0FBD\\u0FCD\\u0FDB-\\u0FFF',bo='\\uFFBF-\\uFFC1\\uFFC8\\uFFC9\\uFFD0\\uFFD1\\uFFD8\\uFFD9\\uFFDD-\\uFFDF',bp='clui.util.String',bq='\\uAB27\\uAB2F-\\uABBF\\uABEE\\uABEF\\uABFA-\\uABFF\\uD7A4-\\uD7AF',br='\\u09BA\\u09BB\\u09C5\\u09C6\\u09C9\\u09CA\\u09CF-\\u09D6\\u09D8-\\u09DB',by='\\u1A7E\\u1A8A-\\u1A8F\\u1A9A-\\u1A9F\\u1AAE-\\u1AFF\\u1B4C-\\u1B4F',bz='\\u0C0D\\u0C11\\u0C29\\u0C34\\u0C3A-\\u0C3C\\u0C45\\u0C49\\u0C4E-\\u0C54',bA='\\u0EAC\\u0EBA\\u0EBE\\u0EBF\\u0EC5\\u0EC7\\u0ECE\\u0ECF\\u0EDA\\u0EDB',bB='\\uFB18-\\uFB1C\\uFB37\\uFB3D\\uFB3F\\uFB42\\uFB45\\uFBC2-\\uFBD2',bv='\\uA698-\\uA69E\\uA6F8-\\uA6FF\\uA78F\\uA794-\\uA79F\\uA7AB-\\uA7F7',bw='\\u09DE\\u09E4\\u09E5\\u09FC-\\u0A00\\u0A04\\u0A0B-\\u0A0E\\u0A11\\u0A12',bx='\\u0CD7-\\u0CDD\\u0CDF\\u0CE4\\u0CE5\\u0CF0\\u0CF3-\\u0D01\\u0D04\\u0D0D';qx.Class.define(bp,{statics:{nonPrintableRegexp:new RegExp(a+h+Y+X+l+o+br+bw+T+K+O+j+F+B+t+V+L+bz+W+M+bx+g+d+bs+v+w+bA+bu+C+bt+i+P+c+R+e+f+A+by+U+q+u+N+r+D+b+k+p+S+z+x+H+bv+s+n+y+E+bq+J+bB+G+I+bo+m,Q)}});})();(function(){var a='ace/mode/yaml',b='clui/image/loading66.gif',c='center',d='middle',e='changeValue',f='appear',g='{0}/ace/ace.js',h='clui.view.widget.CodeViewer',i='',j='Boolean',k='change',l='Failed to load ace',m='qx.event.type.Data',n='ace/theme/textmate',o='resourceUri',p='resize',q='Cannot load ace',r='clui',s='success',t='_applyReadOnly';qx.Class.define(h,{extend:qx.ui.core.Widget,implement:[qx.ui.form.IForm,qx.ui.form.IStringForm],include:qx.ui.form.MForm,events:{changeValue:m},properties:{readOnly:{check:j,init:false,apply:t}},construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.VBox(0,d));this.setMinWidth(320);this.setMinHeight(240);this.addListener(f,this._onAppear,this);this.addListener(p,this._onResize,this);},destruct:function(){if(this._editor){this._editor.destroy();this._editor=null;};},statics:{_ace:null},members:{_editor:null,_tempValue:i,_loadEditor:function(){var u=qx.util.LibraryManager.getInstance().get(r,o);var v=g.format(u);var w=new kucken.io.ScriptLoader();var self=this.self(arguments);return new kucken.Promise(function(x,y){if(self._ace){x();}else {w.load(v,function(status){if(status==s||!window.ace){self._ace=window.ace;x();}else {y(new Error(q));};},this);};},this);},_applyReadOnly:function(A,z){if(this._editor){this._editor.setReadOnly(A);};},_onEditorValueChange:function(){if(this._editor){this.fireDataEvent(e,this._editor.getValue());};},_createEditor:function(){if(this._editor){return;};var B=new qx.ui.core.Widget();this._add(B,{'flex':1});qx.ui.core.queue.Manager.flush();this._editor=this.self(arguments)._ace.edit(B.getContentElement().getDomElement());this._editor.setTheme(n);this._editor.setShowPrintMargin(false);this._editor.getSession().setMode(a);this._editor.$blockScrolling=Infinity;this._editor.on(k,this._onEditorValueChange.bind(this));this._applyReadOnly(this.getReadOnly());if(this._tempValue){this.setValue(this._tempValue);this._tempValue=null;};},_onResize:function(){if(this._editor){qx.event.Timer.once(this._editor.resize,this._editor,0);};},_onAppear:function(){var C=new qx.ui.basic.Image(b);C.setAlignX(c);this._add(C,{'flex':1});this._loadEditor().then(this._createEditor,this).caught(function(D){this.error(l,D);},this).lastly(C.destroy.bind(C));},getValue:function(){return this._editor?this._editor.getValue():this._tempValue;},resetValue:function(){this.setValue(i);},setValue:function(E){if(this._editor){return this._editor.setValue(E||i,-1);}else {this._tempValue=E||i;return E;};}}});})();(function(){var a="mshtml",b="readystatechange",c="head",d="complete",f="load",g="webkit",h="script",i="kucken.io.ScriptLoader",j="fail",k="opera",l="abort",m="text/javascript",n="Another request is still running!",o="success",p="loaded",q="error";qx.Class.define(i,{extend:qx.core.Object,statics:{TIMEOUT:15},construct:function(){this.__vX=qx.Bootstrap.bind(this.__wb,this);this.__vY=document.createElement(h);},members:{__wa:null,__nl:null,__A:null,__C:null,__vX:null,__vY:null,load:function(t,u,v){if(this.__wa){throw new Error(n);};this.__wa=true;this.__nl=false;var r=document.getElementsByTagName(c)[0];var s=this.__vY;this.__A=u||null;this.__C=v||window;s.type=m;s.onerror=s.onload=s.onreadystatechange=this.__vX;var self=this;if(qx.bom.client.Engine.getName()===k&&this._getTimeout()>0){setTimeout(function(){self.dispose(j);},this._getTimeout()*1000);};s.src=t;setTimeout(function(){r.appendChild(s);},0);},abort:function(){if(this.__wa){this.dispose(l);};},dispose:function(status){if(this.__nl){return;};this.__nl=true;var y=this.__vY;y.onerror=y.onload=y.onreadystatechange=null;var x=y.parentNode;if(x){x.removeChild(y);};delete this.__wa;if(this.__A){var w=qx.bom.client.Engine.getName();if(w==a||w==g){var self=this;setTimeout(qx.event.GlobalError.observeMethod(function(){self.__A.call(self.__C,status);delete self.__A;}),0);}else {this.__A.call(this.__C,status);delete this.__A;};};},_getTimeout:function(){return this.self(arguments).TIMEOUT;},__wb:qx.event.GlobalError.observeMethod(function(e){var z=qx.bom.client.Engine.getName();if(z===a){var A=this.__vY.readyState;if(A===p||A===d||(e&&e.type===f)){this.dispose(o);}else if(e&&e.type===q){this.dispose(j);}else {return;};}else if(z===k){if(qx.Bootstrap.isString(e)||e.type===q){return this.dispose(j);}else if(e.type===f){return this.dispose(o);}else {return;};}else {if(qx.Bootstrap.isString(e)||e.type===q){this.dispose(j);}else if(e.type===f){this.dispose(o);}else if(e.type===b&&(e.target.readyState===d||e.target.readyState===p)){this.dispose(o);}else {return;};};})}});})();(function(){var b='\0',g='.NaN',h=': ',j='sequence',k=' ... ',m='^([0-9][0-9][0-9][0-9])',p='addConstructor',q='ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r',w='directive name must not be less than one character in length',x='0b',y='tag:yaml.org,2002:null',z='Null',A='tag:yaml.org,2002:float',B='NO',C='OFF',D='no',E='lowercase',F='([0-9][0-9]?)',G='../type/js/undefined',H='~',I='> ',J='i',K='ExpressionStatement',L='./js-yaml/schema/default_safe',M='function',N='./js-yaml/schema/failsafe',O='../common',P='-.inf',Q='FALSE',R='../type/merge',S='tag:yaml.org,2002:js/function',T='*ref_',U='(?:\\.([0-9]*))?',V='false',W='./js-yaml/loader',X='(',Y='!!',ba='unexpected end of the document within a single quoted scalar',bb='\\r',bc='No',bd='-([0-9][0-9])$',be='kucken.util.Yaml',bf='1',bg='y',bh='dec',bi='_',bj='ON',bk='end of the stream or a document separator is expected',bl='bad indentation of a mapping entry',bm='tag:yaml.org,2002:binary',bn=' is deprecated and cannot be used.',bo='scan',bp='cannot merge mappings; the provided source object is unacceptable',bq='tag:yaml.org,2002:merge',br='../schema',bs='(?:[Tt]|[ \\t]+)',bt='unexpected end of the stream within a verbatim tag',bu='|[-+]?\\.(?:inf|Inf|INF)',bv='\\e',bw='Unknown kind "',bx='filename',by='<<',bz='condenseFlow',bA='\x08',bB='schema',bC='unexpected end of the stream within a double quoted scalar',bD='null',bE=', ',bF='" YAML type.',bG='../type/js/regexp',bH='\\b',bI='../type',bJ='tag:yaml.org,2002:bool',bK='code point within a string may not be greater than 0xFFFFFFFF',bL='a line break is expected',bM='" is specified for "',bN='named tag handle cannot contain such characters',bO='flowLevel',bP='predicate',bQ='n',bR='./json',bS='./mark',bT='|\\.(?:nan|NaN|NAN))$',bU='+',bV='a whitespace character is expected after the key-value separator within a block mapping',bW='x',bX='esprima',bY='\x09',ca='Date resolve error',cb=':([0-9][0-9])',cc='tag:yaml.org,2002:timestamp',cd='repeat of a chomping mode identifier',ce='YES',cf='indent',cg='object',ci='\\',cj='\x0C',ck='represent',cl='- ',cm='sortKeys',cn='compose',co='./js-yaml/schema/default_full',cp='\\t',cq='\\f',cr='expected a single document in the stream, but found more',cs='duplication of an anchor property',ct='False',cu='bin',cv='[object RegExp]',cw='\x0D',cx='decimal',cy='\x00',cz='../type/set',cA='yes',cB='../type/js/function',cC='tag:yaml.org,2002:map',cD='lineWidth',cE='tag:yaml.org,2002:str',cF='open',cG='\x0A',cH='parse',cI='\u2029',cJ='../type/null',cK='[object Boolean]',cL='[object Number]',cM='unacceptable kind of an object to dump ',cN='0x',cO='impossible error: invalid scalar style',cP='non-ASCII line breaks are interpreted as content',cQ='resolve',cR='unidentified alias "',cS='{',cT='noRefs',cU='Specified list of super schemas (or a single Schema object) contains a non-Schema object.',cV='-.Inf',cW='Yes',cX='On',cY='tag suffix cannot contain exclamation marks',da='./lib/js-yaml.js',db='Off',dc='the stream contains non-printable characters',dd='\x0B',de='", not "',df='../type/int',dg='\x1B',dh='Y',di='../type/pairs',dj='.Inf',dk='implicit',dl='explicit',dm='NULL',dn='" tag handle',dp='repeat of an indentation width identifier',dq='construct',dr='-',ds='\\0',dt='./common',du='.inf',dv='legacy',dw='./default_safe',dx='TAG directive accepts exactly two arguments',dy='alias node should not have any properties',dz='\x07',dA='../type/seq',dB='hex',dC='.e',dD='ill-formed tag prefix (second argument) of the TAG directive',dE=',',dF="function",dG='on',dH='duplication of a tag property',dI='+-',dJ='tag:yaml.org,2002:seq',dK='../type/str',dL='\\L',dM='" ',dN='incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line',dO='../type/timestamp',dP='onWarning',dQ='[object Array]',dR='cannot resolve a node with !<',dS='skipInvalid',dT='> tag; it should be "',dU='./type',dV='unknown escape sequence',dW='unexpected end of the document within a double quoted scalar',dX='? ',dY='defaultStyle',ea="MODULE_NOT_FOUND",eb='\\_',ec='tag:yaml.org,2002:js/regexp',ed='undefined',ee='kind',ef='Program',eg='[]',eh='../type/float',ei='\x00\r\n\x85\u2028\u2029',ej='\\v',ek='tag:yaml.org,2002:omap',el='can not read a block mapping entry; a multiline key may not be an implicit key',em='./js-yaml/exception',en='> explicit tag',eo='scalar',ep='../../type',eq='^(?:[-+]?(?:0|[1-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?',er='./schema/default_full',es='use strict',et='ill-formed tag handle (first argument) of the TAG directive',eu='(unknown reason)',ev='" is met in definition of "',ew='b',ex='unknown tag !<',ey='&ref_',ez='\x5C',eA='>',eB='unexpected end of the stream within a single quoted scalar',eC='../type/map',eD='camelcase',eE='uppercase',eF='|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*',eG='directives end mark is expected',eH=', column ',eI='./js-yaml/schema',eJ='\x85',eK='e',eL=':\n',eM=':',eN='[object String]',eO='-0.0',eP='\xA0',eQ='unexpected end of the stream within a flow collection',eR='?',eS='\\a',eT='(?::([0-9][0-9]))?))?$',eU='Failed to resolve function',eV='../type/binary',eW='json',eX='-([0-9][0-9])',eY='u',fa='unsupported YAML version of the document',fb='undeclared tag handle "',fc='/',fd='./failsafe',fe='bad indentation of a sequence entry',ff='[',fg='FunctionExpression',fh='\\n',fi='buffer',fj='\\"',fk='TRUE',fl='./js-yaml/schema/json',fm='mapping',fn='}',fo='at line ',fp='N',fq='tag:yaml.org,2002:int',fr='tag:yaml.org,2002:js/undefined',fs='styleAliases',ft='U',fu='oct',fv='can not read an implicit mapping pair; a colon is missed',fw='Specified list of YAML types (or a single Type object) contains a non-Type object.',fx='\u2028',fy='tag suffix cannot contain flow indicator characters',fz='YAMLException',fA='',fB='./schema/default_safe',fC='name of an anchor node must contain at least one character',fD='\\N',fE='\\\\',fF='ill-formed argument of the YAML directive',fG='!',fH='tag:yaml.org,2002:',fI='.NAN',fJ=']',fK='True',fL='Unknown option "',fM='There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.',fN="'",fO='YAML directive accepts exactly one argument',fP='../type/bool',fQ='{}',fR='./js-yaml/schema/core',fS='|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?',fT='listener',fU='unacceptable node kind for !<',fV='m',fW='missed comma between flow collection entries',fX='[object Function]',fY='.INF',ga='styles',gb='there is a previously declared suffix for "',gc='close',gd='unacceptable YAML version of the document',ge='fallback',gf='Function ',gg='off',gh='[object Object]',gi="/",gj='../type/omap',gk="Cannot find module '",gl='|',gm='> tag resolver accepts not "',gn='./js-yaml/type',go='instanceOf',gp='tag:yaml.org,2002:pairs',gq='"',gr='bad explicit indentation width of a block scalar; it cannot be less than one',gs="''",gt='deficient indentation',gu='\\P',gv='name of an alias node must contain at least one character',gw='sortKeys must be a boolean or a function',gx='g',gy='!<',gz='unknown document directive "',gA='in "',gB='./js-yaml/dumper',gC='tag name cannot contain such characters: ',gD=' ',gE='\n',gF='" style',gG='^',gH='tag:yaml.org,2002:set',gI='.nan',gJ='-([0-9][0-9]?)',gK='expected valid JSON character',gL='(?:[ \\t]*(Z|([-+])([0-9][0-9]?)',gM='\x22',gN='./exception',gO='expected hexadecimal character',gP='0',gQ='-.INF',gR='./core',gS=')',gT='Wrong number of arguments for Schema.create function',gU='true',gV='duplication of %YAML directive',gW='duplicated mapping key',gX='noCompatMode';qx.Class.define(be,{statics:{__uz:null,parse:function(s,gY){return this.__uz.safeLoad(s,gY);},stringify:function(ha,hb){return this.__uz.safeDump(ha,hb);}}});(function(f){kucken.util.Yaml.__uz=f();})(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require==dF&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error(gk+o+fN);throw f.code=ea,f;};var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e);},l,l.exports,e,t,n,r);};return n[o].exports;};var i=typeof require==dF&&require;for(var o=0;o<r.length;o++ )s(r[o]);return s;})({'1':[function(he,hf,hc){es;var hg=he(W);var hh=he(gB);function hd(name){return function(){throw new Error(gf+name+bn);};};hf.exports.Type=he(gn);hf.exports.Schema=he(eI);hf.exports.FAILSAFE_SCHEMA=he(N);hf.exports.JSON_SCHEMA=he(fl);hf.exports.CORE_SCHEMA=he(fR);hf.exports.DEFAULT_SAFE_SCHEMA=he(L);hf.exports.DEFAULT_FULL_SCHEMA=he(co);hf.exports.load=hg.load;hf.exports.loadAll=hg.loadAll;hf.exports.safeLoad=hg.safeLoad;hf.exports.safeLoadAll=hg.safeLoadAll;hf.exports.dump=hh.dump;hf.exports.safeDump=hh.safeDump;hf.exports.YAMLException=he(em);hf.exports.MINIMAL_SCHEMA=he(N);hf.exports.SAFE_SCHEMA=he(L);hf.exports.DEFAULT_SCHEMA=he(co);hf.exports.scan=hd(bo);hf.exports.parse=hd(cH);hf.exports.compose=hd(cn);hf.exports.addConstructor=hd(p);},{"./js-yaml/dumper":3,"./js-yaml/exception":4,"./js-yaml/loader":5,"./js-yaml/schema":7,"./js-yaml/schema/core":8,"./js-yaml/schema/default_full":9,"./js-yaml/schema/default_safe":10,"./js-yaml/schema/failsafe":11,"./js-yaml/schema/json":12,"./js-yaml/type":13}],'2':[function(hm,hp,hj){es;function ho(hr){return (typeof hr===ed)||(hr===null);};function hq(hs){return (typeof hs===cg)&&(hs!==null);};function hi(ht){if(Array.isArray(ht))return ht;else if(ho(ht))return [];return [ht];};function hl(hv,hw){var hu,length,hx,hy;if(hw){hy=Object.keys(hw);for(hu=0,length=hy.length;hu<length;hu+=1){hx=hy[hu];hv[hx]=hw[hx];};};return hv;};function hk(hB,hz){var hA=fA,hC;for(hC=0;hC<hz;hC+=1){hA+=hB;};return hA;};function hn(hD){return (hD===0)&&(Number.NEGATIVE_INFINITY===1/hD);};hp.exports.isNothing=ho;hp.exports.isObject=hq;hp.exports.toArray=hi;hp.exports.repeat=hk;hp.exports.isNegativeZero=hn;hp.exports.extend=hl;},{}],'3':[function(iQ,hJ,ii){es;var iM=iQ(dt);var is=iQ(gN);var iv=iQ(er);var hS=iQ(fB);var id=Object.prototype.toString;var iq=Object.prototype.hasOwnProperty;var iC=0x09;var ip=0x0A;var iu=0x20;var iL=0x21;var hO=0x22;var iy=0x23;var iR=0x25;var iz=0x26;var ih=0x27;var hU=0x2A;var iS=0x2C;var hF=0x2D;var ib=0x3A;var ij=0x3E;var it=0x3F;var hM=0x40;var io=0x5B;var ik=0x5D;var ig=0x60;var hW=0x7B;var hP=0x7C;var iG=0x7D;var im={};im[0x00]=ds;im[0x07]=eS;im[0x08]=bH;im[0x09]=cp;im[0x0A]=fh;im[0x0B]=ej;im[0x0C]=cq;im[0x0D]=bb;im[0x1B]=bv;im[0x22]=fj;im[0x5C]=fE;im[0x85]=fD;im[0xA0]=eb;im[0x2028]=dL;im[0x2029]=gu;var hG=[bg,dh,cA,cW,ce,dG,cX,bj,bQ,fp,D,bc,B,gg,db,C];function hY(jb,iT){var iY,iW,iV,length,iX,iU,ja;if(iT===null)return {};iY={};iW=Object.keys(iT);for(iV=0,length=iW.length;iV<length;iV+=1){iX=iW[iV];iU=String(iT[iX]);if(iX.slice(0,2)===Y){iX=fH+iX.slice(2);};ja=jb.compiledTypeMap[ge][iX];if(ja&&iq.call(ja.styleAliases,iU)){iU=ja.styleAliases[iU];};iY[iX]=iU;};return iY;};function hT(jc){var je,jd,length;je=jc.toString(16).toUpperCase();if(jc<=0xFF){jd=bW;length=2;}else if(jc<=0xFFFF){jd=eY;length=4;}else if(jc<=0xFFFFFFFF){jd=ft;length=8;}else {throw new is(bK);};return ci+jd+iM.repeat(gP,length-je.length)+je;};function hL(jf){this.schema=jf[bB]||iv;this.indent=Math.max(1,(jf[cf]||2));this.skipInvalid=jf[dS]||false;this.flowLevel=(iM.isNothing(jf[bO])?-1:jf[bO]);this.styleMap=hY(this.schema,jf[ga]||null);this.sortKeys=jf[cm]||false;this.lineWidth=jf[cD]||80;this.noRefs=jf[cT]||false;this.noCompatMode=jf[gX]||false;this.condenseFlow=jf[bz]||false;this.implicitTypes=this.schema.compiledImplicit;this.explicitTypes=this.schema.compiledExplicit;this.tag=null;this.result=fA;this.duplicates=[];this.usedDuplicates=null;};function ir(jg,ji){var jk=iM.repeat(gD,ji),jl=0,jh=-1,jj=fA,jm,length=jg.length;while(jl<length){jh=jg.indexOf(gE,jl);if(jh===-1){jm=jg.slice(jl);jl=length;}else {jm=jg.slice(jl,jh+1);jl=jh+1;};if(jm.length&&jm!==gE)jj+=jk;jj+=jm;};return jj;};function iP(jn,jo){return gE+iM.repeat(gD,jn.indent*jo);};function il(jq,js){var jp,length,jr;for(jp=0,length=jq.implicitTypes.length;jp<length;jp+=1){jr=jq.implicitTypes[jp];if(jr.resolve(js)){return true;};};return false;};function ie(c){return c===iu||c===iC;};function hE(c){return (0x00020<=c&&c<=0x00007E)||((0x000A1<=c&&c<=0x00D7FF)&&c!==0x2028&&c!==0x2029)||((0x0E000<=c&&c<=0x00FFFD)&&c!==0xFEFF)||(0x10000<=c&&c<=0x10FFFF);};function iK(c){return hE(c)&&c!==0xFEFF&&c!==iS&&c!==io&&c!==ik&&c!==hW&&c!==iG&&c!==ib&&c!==iy;};function hQ(c){return hE(c)&&c!==0xFEFF&&!ie(c)&&c!==hF&&c!==it&&c!==ib&&c!==iS&&c!==io&&c!==ik&&c!==hW&&c!==iG&&c!==iy&&c!==iz&&c!==hU&&c!==iL&&c!==hP&&c!==ij&&c!==ih&&c!==hO&&c!==iR&&c!==hM&&c!==ig;};var ic=1,iA=2,ia=3,iJ=4,hX=5;function ix(jt,ju,jx,jA,jC){var i;var jz;var jv=false;var jB=false;var jy=jA!==-1;var jD=-1;var jw=hQ(jt.charCodeAt(0))&&!ie(jt.charCodeAt(jt.length-1));if(ju){for(i=0;i<jt.length;i++ ){jz=jt.charCodeAt(i);if(!hE(jz)){return hX;};jw=jw&&iK(jz);};}else {for(i=0;i<jt.length;i++ ){jz=jt.charCodeAt(i);if(jz===ip){jv=true;if(jy){jB=jB||(i-jD-1>jA&&jt[jD+1]!==gD);jD=i;};}else if(!hE(jz)){return hX;};jw=jw&&iK(jz);};jB=jB||(jy&&(i-jD-1>jA&&jt[jD+1]!==gD));};if(!jv&&!jB){return jw&&!jC(jt)?ic:iA;};if(jt[0]===gD&&jx>9){return hX;};return jB?iJ:ia;};function iE(jF,jG,jH,jE){jF.dump=(function(){if(jG.length===0){return gs;};if(!jF.noCompatMode&&hG.indexOf(jG)!==-1){return fN+jG+fN;};var jJ=jF.indent*Math.max(1,jH);var jI=jF.lineWidth===-1?-1:Math.max(Math.min(jF.lineWidth,40),jF.lineWidth-jJ);var jK=jE||(jF.flowLevel>-1&&jH>=jF.flowLevel);function jL(jM){return il(jF,jM);};switch(ix(jG,jK,jF.indent,jI,jL)){case ic:return jG;case iA:return fN+jG.replace(/'/g,gs)+fN;case ia:return gl+hV(jG,jF.indent)+iN(ir(jG,jJ));case iJ:return eA+hV(jG,jF.indent)+iN(ir(hR(jG,jI),jJ));case hX:return gq+iw(jG,jI)+gq;default:throw new is(cO);};}());};function hV(jN,jR){var jS=(jN[0]===gD)?String(jR):fA;var jO=jN[jN.length-1]===gE;var jQ=jO&&(jN[jN.length-2]===gE||jN===gE);var jP=jQ?bU:(jO?fA:dr);return jS+jP+gE;};function iN(jT){return jT[jT.length-1]===gE?jT.slice(0,-1):jT;};function hR(jU,jV){var kb=/(\n+)([^\n]*)/g;var kd=(function(){var ke=jU.indexOf(gE);ke=ke!==-1?ke:jU.length;kb.lastIndex=ke;return hN(jU.slice(0,ke),jV);}());var jX=jU[0]===gE||jU[0]===gD;var jY;var kc;while((kc=kb.exec(jU))){var jW=kc[1],ka=kc[2];jY=(ka[0]===gD);kd+=jW+(!jX&&!jY&&ka!==fA?gE:fA)+hN(ka,jV);jX=jY;};return kd;};function hN(km,kh){if(km===fA||km[0]===gD)return km;var kg=/ [^ ]/g;var kn;var kj=0,kf,kl=0,ki=0;var kk=fA;while((kn=kg.exec(km))){ki=kn.index;if(ki-kj>kh){kf=(kl>kj)?kl:ki;kk+=gE+km.slice(kj,kf);kj=kf+1;};kl=ki;};kk+=gE;if(km.length-kj>kh&&kl>kj){kk+=km.slice(kj,kl)+gE+km.slice(kl+1);}else {kk+=km.slice(kj);};return kk.slice(1);};function iw(ko){var kq=fA;var kp,ks;var kr;for(var i=0;i<ko.length;i++ ){kp=ko.charCodeAt(i);if(kp>=0xD800&&kp<=0xDBFF){ks=ko.charCodeAt(i+1);if(ks>=0xDC00&&ks<=0xDFFF){kq+=hT((kp-0xD800)*0x400+ks-0xDC00+0x10000);i++ ;continue;};};kr=im[kp];kq+=!kr&&hE(kp)?ko[i]:kr||hT(kp);};return kq;};function hK(ky,kv,kw){var ku=fA,kx=ky.tag,kt,length;for(kt=0,length=kw.length;kt<length;kt+=1){if(hH(ky,kv,kw[kt],false,false)){if(kt!==0)ku+=dE+(!ky.condenseFlow?gD:fA);ku+=ky.dump;};};ky.tag=kx;ky.dump=ff+ku+fJ;};function iI(kF,kC,kD,kz){var kB=fA,kE=kF.tag,kA,length;for(kA=0,length=kD.length;kA<length;kA+=1){if(hH(kF,kC+1,kD[kA],true,true)){if(!kz||kA!==0){kB+=iP(kF,kC);};if(kF.dump&&ip===kF.dump.charCodeAt(0)){kB+=dr;}else {kB+=cl;};kB+=kF.dump;};};kF.tag=kE;kF.dump=kB||eg;};function iD(kM,kJ,kK){var kI=fA,kL=kM.tag,kN=Object.keys(kK),kH,length,kO,kP,kG;for(kH=0,length=kN.length;kH<length;kH+=1){kG=kM.condenseFlow?gq:fA;if(kH!==0)kG+=bE;kO=kN[kH];kP=kK[kO];if(!hH(kM,kJ,kO,false,false)){continue;};if(kM.dump.length>1024)kG+=dX;kG+=kM.dump+(kM.condenseFlow?gq:fA)+eM+(kM.condenseFlow?fA:gD);if(!hH(kM,kJ,kP,false,false)){continue;};kG+=kM.dump;kI+=kG;};kM.tag=kL;kM.dump=cS+kI+fn;};function iO(kX,kT,kU,kQ){var kS=fA,kW=kX.tag,kY=Object.keys(kU),kR,length,la,ld,lb,kV;if(kX.sortKeys===true){kY.sort();}else if(typeof kX.sortKeys===M){kY.sort(kX.sortKeys);}else if(kX.sortKeys){throw new is(gw);};for(kR=0,length=kY.length;kR<length;kR+=1){kV=fA;if(!kQ||kR!==0){kV+=iP(kX,kT);};la=kY[kR];ld=kU[la];if(!hH(kX,kT+1,la,true,true,true)){continue;};lb=(kX.tag!==null&&kX.tag!==eR)||(kX.dump&&kX.dump.length>1024);if(lb){if(kX.dump&&ip===kX.dump.charCodeAt(0)){kV+=eR;}else {kV+=dX;};};kV+=kX.dump;if(lb){kV+=iP(kX,kT);};if(!hH(kX,kT+1,ld,true,lb)){continue;};if(kX.dump&&ip===kX.dump.charCodeAt(0)){kV+=eM;}else {kV+=h;};kV+=kX.dump;kS+=kV;};kX.tag=kW;kX.dump=kS||fQ;};function hI(lk,li,lj){var lg,lh,le,length,ll,lf;lh=lj?lk.explicitTypes:lk.implicitTypes;for(le=0,length=lh.length;le<length;le+=1){ll=lh[le];if((ll.instanceOf||ll.predicate)&&(!ll.instanceOf||((typeof li===cg)&&(li instanceof ll.instanceOf)))&&(!ll.predicate||ll.predicate(li))){lk.tag=lj?ll.tag:eR;if(ll.represent){lf=lk.styleMap[ll.tag]||ll.defaultStyle;if(id.call(ll.represent)===fX){lg=ll.represent(li,lf);}else if(iq.call(ll.represent,lf)){lg=ll.represent[lf](li,lf);}else {throw new is(gy+ll.tag+gm+lf+gF);};lk.dump=lg;};return true;};};return false;};function hH(ls,lp,lr,lv,lm,lq){ls.tag=null;ls.dump=lr;if(!hI(ls,lr,false)){hI(ls,lr,true);};var lu=id.call(ls.dump);if(lv){lv=(ls.flowLevel<0||ls.flowLevel>lp);};var ln=lu===gh||lu===dQ,lo,lt;if(ln){lo=ls.duplicates.indexOf(lr);lt=lo!==-1;};if((ls.tag!==null&&ls.tag!==eR)||lt||(ls.indent!==2&&lp>0)){lm=false;};if(lt&&ls.usedDuplicates[lo]){ls.dump=T+lo;}else {if(ln&&lt&&!ls.usedDuplicates[lo]){ls.usedDuplicates[lo]=true;};if(lu===gh){if(lv&&(Object.keys(ls.dump).length!==0)){iO(ls,lp,ls.dump,lm);if(lt){ls.dump=ey+lo+ls.dump;};}else {iD(ls,lp,ls.dump);if(lt){ls.dump=ey+lo+gD+ls.dump;};};}else if(lu===dQ){if(lv&&(ls.dump.length!==0)){iI(ls,lp,ls.dump,lm);if(lt){ls.dump=ey+lo+ls.dump;};}else {hK(ls,lp,ls.dump);if(lt){ls.dump=ey+lo+gD+ls.dump;};};}else if(lu===eN){if(ls.tag!==eR){iE(ls,ls.dump,lp,lq);};}else {if(ls.skipInvalid)return false;throw new is(cM+lu);};if(ls.tag!==null&&ls.tag!==eR){ls.dump=gy+ls.tag+I+ls.dump;};};return true;};function iB(lx,ly){var lz=[],lA=[],lw,length;iF(lx,lz,lA);for(lw=0,length=lA.length;lw<length;lw+=1){ly.duplicates.push(lz[lA[lw]]);};ly.usedDuplicates=new Array(length);};function iF(lD,lE,lF){var lC,lB,length;if(lD!==null&&typeof lD===cg){lB=lE.indexOf(lD);if(lB!==-1){if(lF.indexOf(lB)===-1){lF.push(lB);};}else {lE.push(lD);if(Array.isArray(lD)){for(lB=0,length=lD.length;lB<length;lB+=1){iF(lD[lB],lE,lF);};}else {lC=Object.keys(lD);for(lB=0,length=lC.length;lB<length;lB+=1){iF(lD[lC[lB]],lE,lF);};};};};};function dump(lG,lI){lI=lI||{};var lH=new hL(lI);if(!lH.noRefs)iB(lG,lH);if(hH(lH,0,lG,true,true))return lH.dump+gE;return fA;};function iH(lJ,lK){return dump(lJ,iM.extend({schema:hS},lK));};hJ.exports.dump=dump;hJ.exports.safeDump=iH;},{"./common":2,"./exception":4,"./schema/default_full":9,"./schema/default_safe":10}],'4':[function(lM,lN,lL){es;function lO(lP,lQ){Error.call(this);this.name=fz;this.reason=lP;this.mark=lQ;this.message=(this.reason||eu)+(this.mark?gD+this.mark.toString():fA);if(Error.captureStackTrace){Error.captureStackTrace(this,this.constructor);}else {this.stack=(new Error()).stack||fA;};};lO.prototype=Object.create(Error.prototype);lO.prototype.constructor=lO;lO.prototype.toString=function lS(lR){var lT=this.name+h;lT+=this.reason||eu;if(!lR&&this.mark){lT+=gD+this.mark.toString();};return lT;};lN.exports=lO;},{}],'5':[function(mP,mb,mO){es;var mX=mP(dt);var mG=mP(gN);var mc=mP(bS);var mx=mP(fB);var mJ=mP(er);var mK=Object.prototype.hasOwnProperty;var mn=1;var lV=2;var mS=3;var nd=4;var mt=1;var mR=2;var mH=3;var mi=/[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/;var mo=/[\x85\u2028\u2029]/;var mh=/[,\[\]\{\}]/;var lY=/^(?:!|!!|![a-z\-]+!)$/i;var nc=/^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;function mq(c){return (c===0x0A)||(c===0x0D);};function mF(c){return (c===0x09)||(c===0x20);};function mE(c){return (c===0x09)||(c===0x20)||(c===0x0A)||(c===0x0D);};function mf(c){return c===0x2C||c===0x5B||c===0x5D||c===0x7B||c===0x7D;};function mm(c){var nf;if((0x30<=c)&&(c<=0x39)){return c-0x30;};nf=c|0x20;if((0x61<=nf)&&(nf<=0x66)){return nf-0x61+10;};return -1;};function mp(c){if(c===0x78){return 2;};if(c===0x75){return 4;};if(c===0x55){return 8;};return 0;};function ma(c){if((0x30<=c)&&(c<=0x39)){return c-0x30;};return -1;};function mI(c){return (c===0x30)?cy:(c===0x61)?dz:(c===0x62)?bA:(c===0x74)?bY:(c===0x09)?bY:(c===0x6E)?cG:(c===0x76)?dd:(c===0x66)?cj:(c===0x72)?cw:(c===0x65)?dg:(c===0x20)?gD:(c===0x22)?gM:(c===0x2F)?fc:(c===0x5C)?ez:(c===0x4E)?eJ:(c===0x5F)?eP:(c===0x4C)?fx:(c===0x50)?cI:fA;};function mB(c){if(c<=0xFFFF){return String.fromCharCode(c);};return String.fromCharCode(((c-0x010000)>>10)+0xD800,((c-0x010000)&0x03FF)+0xDC00);};var mw=new Array(256);var ms=new Array(256);for(var i=0;i<256;i++ ){mw[i]=mI(i)?1:0;ms[i]=mI(i);};function md(ng,nh){this.input=ng;this.filename=nh[bx]||null;this.schema=nh[bB]||mJ;this.onWarning=nh[dP]||null;this.legacy=nh[dv]||false;this.json=nh[eW]||false;this.listener=nh[fT]||null;this.implicitTypes=this.schema.compiledImplicit;this.typeMap=this.schema.compiledTypeMap;this.length=ng.length;this.position=0;this.line=0;this.lineStart=0;this.lineIndent=0;this.documents=[];};function mY(ni,nj){return new mG(nj,new mc(ni.filename,ni.input,ni.position,ni.line,(ni.position-ni.lineStart)));};function mg(nk,nl){throw mY(nk,nl);};function lU(nm,nn){if(nm.onWarning){nm.onWarning.call(null,mY(nm,nn));};};var mj={YAML:function ns(nq,name,np){var nr,no,nt;if(nq.version!==null){mg(nq,gV);};if(np.length!==1){mg(nq,fO);};nr=/^([0-9]+)\.([0-9]+)$/.exec(np[0]);if(nr===null){mg(nq,fF);};no=parseInt(nr[1],10);nt=parseInt(nr[2],10);if(no!==1){mg(nq,gd);};nq.version=np[0];nq.checkLineBreaks=(nt<2);if(nt!==1&&nt!==2){lU(nq,fa);};},TAG:function nu(nx,name,nw){var nv,ny;if(nw.length!==2){mg(nx,dx);};nv=nw[0];ny=nw[1];if(!lY.test(nv)){mg(nx,et);};if(mK.call(nx.tagMap,nv)){mg(nx,gb+nv+dn);};if(!nc.test(ny)){mg(nx,dD);};nx.tagMap[nv]=ny;}};function mL(nB,nC,nA,nE){var nG,nF,nD,nz;if(nC<nA){nz=nB.input.slice(nC,nA);if(nE){for(nG=0,nF=nz.length;nG<nF;nG+=1){nD=nz.charCodeAt(nG);if(!(nD===0x09||(0x20<=nD&&nD<=0x10FFFF))){mg(nB,gK);};};}else if(mi.test(nz)){mg(nB,dc);};nB.result+=nz;};};function mW(nM,nJ,nL,nK){var nI,nN,nH,nO;if(!mX.isObject(nL)){mg(nM,bp);};nI=Object.keys(nL);for(nH=0,nO=nI.length;nH<nO;nH+=1){nN=nI[nH];if(!mK.call(nJ,nN)){nJ[nN]=nL[nN];nK[nN]=true;};};};function mC(nT,nQ,nU,nP,nV,nS,nW,nX){var nR,nY;nV=String(nV);if(nQ===null){nQ={};};if(nP===bq){if(Array.isArray(nS)){for(nR=0,nY=nS.length;nR<nY;nR+=1){mW(nT,nQ,nS[nR],nU);};}else {mW(nT,nQ,nS,nU);};}else {if(!nT.json&&!mK.call(nU,nV)&&mK.call(nQ,nV)){nT.line=nW||nT.line;nT.position=nX||nT.position;mg(nT,gW);};nQ[nV]=nS;delete nU[nV];};return nQ;};function mv(oa){var ob;ob=oa.input.charCodeAt(oa.position);if(ob===0x0A){oa.position++ ;}else if(ob===0x0D){oa.position++ ;if(oa.input.charCodeAt(oa.position)===0x0A){oa.position++ ;};}else {mg(oa,bL);};oa.line+=1;oa.lineStart=oa.position;};function lW(oe,og,od){var oc=0,of=oe.input.charCodeAt(oe.position);while(of!==0){while(mF(of)){of=oe.input.charCodeAt( ++oe.position);};if(og&&of===0x23){do {of=oe.input.charCodeAt( ++oe.position);}while(of!==0x0A&&of!==0x0D&&of!==0);};if(mq(of)){mv(oe);of=oe.input.charCodeAt(oe.position);oc++ ;oe.lineIndent=0;while(of===0x20){oe.lineIndent++ ;of=oe.input.charCodeAt( ++oe.position);};}else {break;};};if(od!==-1&&oc!==0&&oe.lineIndent<od){lU(oe,gt);};return oc;};function mu(oh){var oj=oh.position,oi;oi=oh.input.charCodeAt(oj);if((oi===0x2D||oi===0x2E)&&oi===oh.input.charCodeAt(oj+1)&&oi===oh.input.charCodeAt(oj+2)){oj+=3;oi=oh.input.charCodeAt(oj);if(oi===0||mE(oi)){return true;};};return false;};function mA(ol,ok){if(ok===1){ol.result+=gD;}else if(ok>1){ol.result+=mX.repeat(gE,ok-1);};};function mr(ov,op,ox){var or,oy,on,ou,oz,om,ot,oq,os=ov.kind,oo=ov.result,ow;ow=ov.input.charCodeAt(ov.position);if(mE(ow)||mf(ow)||ow===0x23||ow===0x26||ow===0x2A||ow===0x21||ow===0x7C||ow===0x3E||ow===0x27||ow===0x22||ow===0x25||ow===0x40||ow===0x60){return false;};if(ow===0x3F||ow===0x2D){oy=ov.input.charCodeAt(ov.position+1);if(mE(oy)||ox&&mf(oy)){return false;};};ov.kind=eo;ov.result=fA;on=ou=ov.position;oz=false;while(ow!==0){if(ow===0x3A){oy=ov.input.charCodeAt(ov.position+1);if(mE(oy)||ox&&mf(oy)){break;};}else if(ow===0x23){or=ov.input.charCodeAt(ov.position-1);if(mE(or)){break;};}else if((ov.position===ov.lineStart&&mu(ov))||ox&&mf(ow)){break;}else if(mq(ow)){om=ov.line;ot=ov.lineStart;oq=ov.lineIndent;lW(ov,false,-1);if(ov.lineIndent>=op){oz=true;ow=ov.input.charCodeAt(ov.position);continue;}else {ov.position=ou;ov.line=om;ov.lineStart=ot;ov.lineIndent=oq;break;};};if(oz){mL(ov,on,ou,false);mA(ov,ov.line-om);on=ou=ov.position;oz=false;};if(!mF(ow)){ou=ov.position+1;};ow=ov.input.charCodeAt( ++ov.position);};mL(ov,on,ou,false);if(ov.result){return true;};ov.kind=os;ov.result=oo;return false;};function mk(oA,oC){var oB,oD,oE;oB=oA.input.charCodeAt(oA.position);if(oB!==0x27){return false;};oA.kind=eo;oA.result=fA;oA.position++ ;oD=oE=oA.position;while((oB=oA.input.charCodeAt(oA.position))!==0){if(oB===0x27){mL(oA,oD,oA.position,true);oB=oA.input.charCodeAt( ++oA.position);if(oB===0x27){oD=oA.position;oA.position++ ;oE=oA.position;}else {return true;};}else if(mq(oB)){mL(oA,oD,oE,true);mA(oA,lW(oA,false,oC));oD=oE=oA.position;}else if(oA.position===oA.lineStart&&mu(oA)){mg(oA,ba);}else {oA.position++ ;oE=oA.position;};};mg(oA,eB);};function my(oL,oI){var oG,oK,oJ,oM,oF,oH;oH=oL.input.charCodeAt(oL.position);if(oH!==0x22){return false;};oL.kind=eo;oL.result=fA;oL.position++ ;oG=oK=oL.position;while((oH=oL.input.charCodeAt(oL.position))!==0){if(oH===0x22){mL(oL,oG,oL.position,true);oL.position++ ;return true;}else if(oH===0x5C){mL(oL,oG,oL.position,true);oH=oL.input.charCodeAt( ++oL.position);if(mq(oH)){lW(oL,false,oI);}else if(oH<256&&mw[oH]){oL.result+=ms[oH];oL.position++ ;}else if((oF=mp(oH))>0){oJ=oF;oM=0;for(;oJ>0;oJ-- ){oH=oL.input.charCodeAt( ++oL.position);if((oF=mm(oH))>=0){oM=(oM<<4)+oF;}else {mg(oL,gO);};};oL.result+=mB(oM);oL.position++ ;}else {mg(oL,dV);};oG=oK=oL.position;}else if(mq(oH)){mL(oL,oG,oK,true);mA(oL,lW(oL,false,oI));oG=oK=oL.position;}else if(oL.position===oL.lineStart&&mu(oL)){mg(oL,dW);}else {oL.position++ ;oK=oL.position;};};mg(oL,bC);};function mU(oP,oR){var oT=true,oN,oX=oP.tag,oQ,oU=oP.anchor,pd,pc,pa,oS,pe,oY={},oW,oO,oV,pb;pb=oP.input.charCodeAt(oP.position);if(pb===0x5B){pc=0x5D;pe=false;oQ=[];}else if(pb===0x7B){pc=0x7D;pe=true;oQ={};}else {return false;};if(oP.anchor!==null){oP.anchorMap[oP.anchor]=oQ;};pb=oP.input.charCodeAt( ++oP.position);while(pb!==0){lW(oP,true,oR);pb=oP.input.charCodeAt(oP.position);if(pb===pc){oP.position++ ;oP.tag=oX;oP.anchor=oU;oP.kind=pe?fm:j;oP.result=oQ;return true;}else if(!oT){mg(oP,fW);};oO=oW=oV=null;pa=oS=false;if(pb===0x3F){pd=oP.input.charCodeAt(oP.position+1);if(mE(pd)){pa=oS=true;oP.position++ ;lW(oP,true,oR);};};oN=oP.line;me(oP,oR,mn,false,true);oO=oP.tag;oW=oP.result;lW(oP,true,oR);pb=oP.input.charCodeAt(oP.position);if((oS||oP.line===oN)&&pb===0x3A){pa=true;pb=oP.input.charCodeAt( ++oP.position);lW(oP,true,oR);me(oP,oR,mn,false,true);oV=oP.result;};if(pe){mC(oP,oQ,oY,oO,oW,oV);}else if(pa){oQ.push(mC(oP,null,oY,oO,oW,oV));}else {oQ.push(oW);};lW(oP,true,oR);pb=oP.input.charCodeAt(oP.position);if(pb===0x2C){oT=true;pb=oP.input.charCodeAt( ++oP.position);}else {oT=false;};};mg(oP,eQ);};function lX(pl,pp){var pg,pi,pk=mt,pj=false,pq=false,po=pp,pn=0,ph=false,pf,pm;pm=pl.input.charCodeAt(pl.position);if(pm===0x7C){pi=false;}else if(pm===0x3E){pi=true;}else {return false;};pl.kind=eo;pl.result=fA;while(pm!==0){pm=pl.input.charCodeAt( ++pl.position);if(pm===0x2B||pm===0x2D){if(mt===pk){pk=(pm===0x2B)?mH:mR;}else {mg(pl,cd);};}else if((pf=ma(pm))>=0){if(pf===0){mg(pl,gr);}else if(!pq){po=pp+pf-1;pq=true;}else {mg(pl,dp);};}else {break;};};if(mF(pm)){do {pm=pl.input.charCodeAt( ++pl.position);}while(mF(pm));if(pm===0x23){do {pm=pl.input.charCodeAt( ++pl.position);}while(!mq(pm)&&(pm!==0));};};while(pm!==0){mv(pl);pl.lineIndent=0;pm=pl.input.charCodeAt(pl.position);while((!pq||pl.lineIndent<po)&&(pm===0x20)){pl.lineIndent++ ;pm=pl.input.charCodeAt( ++pl.position);};if(!pq&&pl.lineIndent>po){po=pl.lineIndent;};if(mq(pm)){pn++ ;continue;};if(pl.lineIndent<po){if(pk===mH){pl.result+=mX.repeat(gE,pj?1+pn:pn);}else if(pk===mt){if(pj){pl.result+=gE;};};break;};if(pi){if(mF(pm)){ph=true;pl.result+=mX.repeat(gE,pj?1+pn:pn);}else if(ph){ph=false;pl.result+=mX.repeat(gE,pn+1);}else if(pn===0){if(pj){pl.result+=gD;};}else {pl.result+=mX.repeat(gE,pn);};}else {pl.result+=mX.repeat(gE,pj?1+pn:pn);};pj=true;pq=true;pn=0;pg=pl.position;while(!mq(pm)&&(pm!==0)){pm=pl.input.charCodeAt( ++pl.position);};mL(pl,pg,pl.position,false);};return true;};function mT(pw,pt){var pr,pv=pw.tag,pu=pw.anchor,px=[],pz,py=false,ps;if(pw.anchor!==null){pw.anchorMap[pw.anchor]=px;};ps=pw.input.charCodeAt(pw.position);while(ps!==0){if(ps!==0x2D){break;};pz=pw.input.charCodeAt(pw.position+1);if(!mE(pz)){break;};py=true;pw.position++ ;if(lW(pw,true,-1)){if(pw.lineIndent<=pt){px.push(null);ps=pw.input.charCodeAt(pw.position);continue;};};pr=pw.line;me(pw,pt,mS,false,true);px.push(pw.result);lW(pw,true,-1);ps=pw.input.charCodeAt(pw.position);if((pw.line===pr||pw.lineIndent>pt)&&(ps!==0)){mg(pw,fe);}else if(pw.lineIndent<pt){break;};};if(py){pw.tag=pv;pw.anchor=pu;pw.kind=j;pw.result=px;return true;};return false;};function mD(pE,pD,pN){var pM,pH,pA,pO,pG=pE.tag,pF=pE.anchor,pK={},pI={},pB=null,pJ=null,pP=null,pQ=false,pL=false,pC;if(pE.anchor!==null){pE.anchorMap[pE.anchor]=pK;};pC=pE.input.charCodeAt(pE.position);while(pC!==0){pM=pE.input.charCodeAt(pE.position+1);pA=pE.line;pO=pE.position;if((pC===0x3F||pC===0x3A)&&mE(pM)){if(pC===0x3F){if(pQ){mC(pE,pK,pI,pB,pJ,null);pB=pJ=pP=null;};pL=true;pQ=true;pH=true;}else if(pQ){pQ=false;pH=true;}else {mg(pE,dN);};pE.position+=1;pC=pM;}else if(me(pE,pN,lV,false,true)){if(pE.line===pA){pC=pE.input.charCodeAt(pE.position);while(mF(pC)){pC=pE.input.charCodeAt( ++pE.position);};if(pC===0x3A){pC=pE.input.charCodeAt( ++pE.position);if(!mE(pC)){mg(pE,bV);};if(pQ){mC(pE,pK,pI,pB,pJ,null);pB=pJ=pP=null;};pL=true;pQ=false;pH=false;pB=pE.tag;pJ=pE.result;}else if(pL){mg(pE,fv);}else {pE.tag=pG;pE.anchor=pF;return true;};}else if(pL){mg(pE,el);}else {pE.tag=pG;pE.anchor=pF;return true;};}else {break;};if(pE.line===pA||pE.lineIndent>pD){if(me(pE,pD,nd,true,pH)){if(pQ){pJ=pE.result;}else {pP=pE.result;};};if(!pQ){mC(pE,pK,pI,pB,pJ,pP,pA,pO);pB=pJ=pP=null;};lW(pE,true,-1);pC=pE.input.charCodeAt(pE.position);};if(pE.lineIndent>pD&&(pC!==0)){mg(pE,bl);}else if(pE.lineIndent<pD){break;};};if(pQ){mC(pE,pK,pI,pB,pJ,null);};if(pL){pE.tag=pG;pE.anchor=pF;pE.kind=fm;pE.result=pK;};return pL;};function mM(pS){var pX,pW=false,pU=false,pV,pT,pR;pR=pS.input.charCodeAt(pS.position);if(pR!==0x21)return false;if(pS.tag!==null){mg(pS,dH);};pR=pS.input.charCodeAt( ++pS.position);if(pR===0x3C){pW=true;pR=pS.input.charCodeAt( ++pS.position);}else if(pR===0x21){pU=true;pV=Y;pR=pS.input.charCodeAt( ++pS.position);}else {pV=fG;};pX=pS.position;if(pW){do {pR=pS.input.charCodeAt( ++pS.position);}while(pR!==0&&pR!==0x3E);if(pS.position<pS.length){pT=pS.input.slice(pX,pS.position);pR=pS.input.charCodeAt( ++pS.position);}else {mg(pS,bt);};}else {while(pR!==0&&!mE(pR)){if(pR===0x21){if(!pU){pV=pS.input.slice(pX-1,pS.position+1);if(!lY.test(pV)){mg(pS,bN);};pU=true;pX=pS.position+1;}else {mg(pS,cY);};};pR=pS.input.charCodeAt( ++pS.position);};pT=pS.input.slice(pX,pS.position);if(mh.test(pT)){mg(pS,fy);};};if(pT&&!nc.test(pT)){mg(pS,gC+pT);};if(pW){pS.tag=pT;}else if(mK.call(pS.tagMap,pV)){pS.tag=pS.tagMap[pV]+pT;}else if(pV===fG){pS.tag=fG+pT;}else if(pV===Y){pS.tag=fH+pT;}else {mg(pS,fb+pV+gq);};return true;};function nb(pY){var qb,qa;qa=pY.input.charCodeAt(pY.position);if(qa!==0x26)return false;if(pY.anchor!==null){mg(pY,cs);};qa=pY.input.charCodeAt( ++pY.position);qb=pY.position;while(qa!==0&&!mE(qa)&&!mf(qa)){qa=pY.input.charCodeAt( ++pY.position);};if(pY.position===qb){mg(pY,fC);};pY.anchor=pY.input.slice(qb,pY.position);return true;};function na(qd){var qf,qc,qe;qe=qd.input.charCodeAt(qd.position);if(qe!==0x2A)return false;qe=qd.input.charCodeAt( ++qd.position);qf=qd.position;while(qe!==0&&!mE(qe)&&!mf(qe)){qe=qd.input.charCodeAt( ++qd.position);};if(qd.position===qf){mg(qd,gv);};qc=qd.input.slice(qf,qd.position);if(!qd.anchorMap.hasOwnProperty(qc)){mg(qd,cR+qc+gq);};qd.result=qd.anchorMap[qc];lW(qd,true,-1);return true;};function me(qk,qr,qq,qt,qn){var qg,qp,qh,qi=1,qm=false,qj=false,qv,qo,qu,qs,ql;if(qk.listener!==null){qk.listener(cF,qk);};qk.tag=null;qk.anchor=null;qk.kind=null;qk.result=null;qg=qp=qh=nd===qq||mS===qq;if(qt){if(lW(qk,true,-1)){qm=true;if(qk.lineIndent>qr){qi=1;}else if(qk.lineIndent===qr){qi=0;}else if(qk.lineIndent<qr){qi=-1;};};};if(qi===1){while(mM(qk)||nb(qk)){if(lW(qk,true,-1)){qm=true;qh=qg;if(qk.lineIndent>qr){qi=1;}else if(qk.lineIndent===qr){qi=0;}else if(qk.lineIndent<qr){qi=-1;};}else {qh=false;};};};if(qh){qh=qm||qn;};if(qi===1||nd===qq){if(mn===qq||lV===qq){qs=qr;}else {qs=qr+1;};ql=qk.position-qk.lineStart;if(qi===1){if(qh&&(mT(qk,ql)||mD(qk,ql,qs))||mU(qk,qs)){qj=true;}else {if((qp&&lX(qk,qs))||mk(qk,qs)||my(qk,qs)){qj=true;}else if(na(qk)){qj=true;if(qk.tag!==null||qk.anchor!==null){mg(qk,dy);};}else if(mr(qk,qs,mn===qq)){qj=true;if(qk.tag===null){qk.tag=eR;};};if(qk.anchor!==null){qk.anchorMap[qk.anchor]=qk.result;};};}else if(qi===0){qj=qh&&mT(qk,ql);};};if(qk.tag!==null&&qk.tag!==fG){if(qk.tag===eR){for(qv=0,qo=qk.implicitTypes.length;qv<qo;qv+=1){qu=qk.implicitTypes[qv];if(qu.resolve(qk.result)){qk.result=qu.construct(qk.result);qk.tag=qu.tag;if(qk.anchor!==null){qk.anchorMap[qk.anchor]=qk.result;};break;};};}else if(mK.call(qk.typeMap[qk.kind||ge],qk.tag)){qu=qk.typeMap[qk.kind||ge][qk.tag];if(qk.result!==null&&qu.kind!==qk.kind){mg(qk,fU+qk.tag+dT+qu.kind+de+qk.kind+gq);};if(!qu.resolve(qk.result)){mg(qk,dR+qk.tag+en);}else {qk.result=qu.construct(qk.result);if(qk.anchor!==null){qk.anchorMap[qk.anchor]=qk.result;};};}else {mg(qk,ex+qk.tag+eA);};};if(qk.listener!==null){qk.listener(gc,qk);};return qk.tag!==null||qk.anchor!==null||qj;};function mQ(qz){var qA=qz.position,qD,qB,qy,qC=false,qw;qz.version=null;qz.checkLineBreaks=qz.legacy;qz.tagMap={};qz.anchorMap={};while((qw=qz.input.charCodeAt(qz.position))!==0){lW(qz,true,-1);qw=qz.input.charCodeAt(qz.position);if(qz.lineIndent>0||qw!==0x25){break;};qC=true;qw=qz.input.charCodeAt( ++qz.position);qD=qz.position;while(qw!==0&&!mE(qw)){qw=qz.input.charCodeAt( ++qz.position);};qB=qz.input.slice(qD,qz.position);qy=[];if(qB.length<1){mg(qz,w);};while(qw!==0){while(mF(qw)){qw=qz.input.charCodeAt( ++qz.position);};if(qw===0x23){do {qw=qz.input.charCodeAt( ++qz.position);}while(qw!==0&&!mq(qw));break;};if(mq(qw))break;qD=qz.position;while(qw!==0&&!mE(qw)){qw=qz.input.charCodeAt( ++qz.position);};qy.push(qz.input.slice(qD,qz.position));};if(qw!==0)mv(qz);if(mK.call(mj,qB)){mj[qB](qz,qB,qy);}else {lU(qz,gz+qB+gq);};};lW(qz,true,-1);if(qz.lineIndent===0&&qz.input.charCodeAt(qz.position)===0x2D&&qz.input.charCodeAt(qz.position+1)===0x2D&&qz.input.charCodeAt(qz.position+2)===0x2D){qz.position+=3;lW(qz,true,-1);}else if(qC){mg(qz,eG);};me(qz,qz.lineIndent-1,nd,false,true);lW(qz,true,-1);if(qz.checkLineBreaks&&mo.test(qz.input.slice(qA,qz.position))){lU(qz,cP);};qz.documents.push(qz.result);if(qz.position===qz.lineStart&&mu(qz)){if(qz.input.charCodeAt(qz.position)===0x2E){qz.position+=3;lW(qz,true,-1);};return;};if(qz.position<(qz.length-1)){mg(qz,bk);}else {return;};};function mV(qE,qG){qE=String(qE);qG=qG||{};if(qE.length!==0){if(qE.charCodeAt(qE.length-1)!==0x0A&&qE.charCodeAt(qE.length-1)!==0x0D){qE+=gE;};if(qE.charCodeAt(0)===0xFEFF){qE=qE.slice(1);};};var qF=new md(qE,qG);qF.input+=b;while(qF.input.charCodeAt(qF.position)===0x20){qF.lineIndent+=1;qF.position+=1;};while(qF.position<(qF.length-1)){mQ(qF);};return qF.documents;};function mz(qK,qJ,qL){var qI=mV(qK,qL),qH,length;if(typeof qJ!==M){return qI;};for(qH=0,length=qI.length;qH<length;qH+=1){qJ(qI[qH]);};};function ml(qM,qO){var qN=mV(qM,qO);if(qN.length===0){return undefined;}else if(qN.length===1){return qN[0];};throw new mG(cr);};function ne(qP,qR,qQ){if(typeof qR===M){mz(qP,qR,mX.extend({schema:mx},qQ));}else {return mz(qP,mX.extend({schema:mx},qQ));};};function mN(qS,qT){return ml(qS,mX.extend({schema:mx},qT));};mb.exports.loadAll=mz;mb.exports.load=ml;mb.exports.safeLoadAll=ne;mb.exports.safeLoad=mN;},{"./common":2,"./exception":4,"./mark":6,"./schema/default_full":9,"./schema/default_safe":10}],'6':[function(qV,qX,qW){es;var qU=qV(dt);function qY(name,ra,rd,rc,rb){this.name=name;this.buffer=ra;this.position=rd;this.line=rc;this.column=rb;};qY.prototype.getSnippet=function re(rg,rk){var rf,ri,rj,rl,rh;if(!this.buffer)return null;rg=rg||4;rk=rk||75;rf=fA;ri=this.position;while(ri>0&&ei.indexOf(this.buffer.charAt(ri-1))===-1){ri-=1;if(this.position-ri>(rk/2-1)){rf=k;ri+=5;break;};};rj=fA;rl=this.position;while(rl<this.buffer.length&&ei.indexOf(this.buffer.charAt(rl))===-1){rl+=1;if(rl-this.position>(rk/2-1)){rj=k;rl-=5;break;};};rh=this.buffer.slice(ri,rl);return qU.repeat(gD,rg)+rf+rh+rj+gE+qU.repeat(gD,rg+this.position-ri+rf.length)+gG;};qY.prototype.toString=function ro(rm){var rn,rp=fA;if(this.name){rp+=gA+this.name+dM;};rp+=fo+(this.line+1)+eH+(this.column+1);if(!rm){rn=this.getSnippet();if(rn){rp+=eL+rn;};};return rp;};qX.exports=qY;},{"./common":2}],'7':[function(rs,rt,rq){es;var rr=rs(dt);var rw=rs(gN);var rx=rs(dU);function ru(rA,name,rB){var rz=[];rA.include.forEach(function(rC){rB=ru(rC,name,rB);});rA[name].forEach(function(rD){rB.forEach(function(rE,rF){if(rE.tag===rD.tag&&rE.kind===rD.kind){rz.push(rF);};});rB.push(rD);});return rB.filter(function(rH,rG){return rz.indexOf(rG)===-1;});};function rv(){var rJ={scalar:{},sequence:{},mapping:{},fallback:{}},rI,length;function rK(rL){rJ[rL.kind][rL.tag]=rJ[ge][rL.tag]=rL;};for(rI=0,length=arguments.length;rI<length;rI+=1){arguments[rI].forEach(rK);};return rJ;};function ry(rM){this.include=rM.include||[];this.implicit=rM.implicit||[];this.explicit=rM.explicit||[];this.implicit.forEach(function(rN){if(rN.loadKind&&rN.loadKind!==eo){throw new rw(fM);};});this.compiledImplicit=ru(this,dk,[]);this.compiledExplicit=ru(this,dl,[]);this.compiledTypeMap=rv(this.compiledImplicit,this.compiledExplicit);};ry.DEFAULT=null;ry.create=function rO(){var rQ,rP;switch(arguments.length){case 1:rQ=ry.DEFAULT;rP=arguments[0];break;case 2:rQ=arguments[0];rP=arguments[1];break;default:throw new rw(gT);};rQ=rr.toArray(rQ);rP=rr.toArray(rP);if(!rQ.every(function(rR){return rR instanceof ry;})){throw new rw(cU);};if(!rP.every(function(rS){return rS instanceof rx;})){throw new rw(fw);};return new ry({include:rQ,explicit:rP});};rt.exports=ry;},{"./common":2,"./exception":4,"./type":13}],'8':[function(rT,rV,rU){es;var rW=rT(br);rV.exports=new rW({include:[rT(bR)]});},{"../schema":7,"./json":12}],'9':[function(rX,sa,rY){es;var sb=rX(br);sa.exports=sb.DEFAULT=new sb({include:[rX(dw)],explicit:[rX(G),rX(bG),rX(cB)]});},{"../schema":7,"../type/js/function":18,"../type/js/regexp":19,"../type/js/undefined":20,"./default_safe":10}],'10':[function(sc,se,sd){es;var sf=sc(br);se.exports=new sf({include:[sc(gR)],implicit:[sc(dO),sc(R)],explicit:[sc(eV),sc(gj),sc(di),sc(cz)]});},{"../schema":7,"../type/binary":14,"../type/merge":22,"../type/omap":24,"../type/pairs":25,"../type/set":27,"../type/timestamp":29,"./core":8}],'11':[function(sg,si,sh){es;var sj=sg(br);si.exports=new sj({explicit:[sg(dK),sg(dA),sg(eC)]});},{"../schema":7,"../type/map":21,"../type/seq":26,"../type/str":28}],'12':[function(sk,sm,sl){es;var sn=sk(br);sm.exports=new sn({include:[sk(fd)],implicit:[sk(cJ),sk(fP),sk(df),sk(eh)]});},{"../schema":7,"../type/bool":15,"../type/float":16,"../type/int":17,"../type/null":23,"./failsafe":11}],'13':[function(sp,ss,sr){es;var st=sp(gN);var so=[ee,cQ,dq,go,bP,ck,dY,fs];var sq=[eo,j,fm];function sv(sw){var sx={};if(sw!==null){Object.keys(sw).forEach(function(sy){sw[sy].forEach(function(sz){sx[String(sz)]=sy;});});};return sx;};function su(sA,sB){sB=sB||{};Object.keys(sB).forEach(function(name){if(so.indexOf(name)===-1){throw new st(fL+name+ev+sA+bF);};});this.tag=sA;this.kind=sB[ee]||null;this.resolve=sB[cQ]||function(){return true;};this.construct=sB[dq]||function(sC){return sC;};this.instanceOf=sB[go]||null;this.predicate=sB[bP]||null;this.represent=sB[ck]||null;this.defaultStyle=sB[dY]||null;this.styleAliases=sv(sB[fs]||null);if(sq.indexOf(this.kind)===-1){throw new st(bw+this.kind+bM+sA+bF);};};ss.exports=su;},{"./exception":4}],'14':[function(sG,sI,sD){es;var sM;try{var sN=sG;sM=sN(fi).Buffer;}catch(sO){};var sF=sG(bI);var sJ=q;function sE(sU){if(sU===null)return false;var sQ,sR,sT=0,sS=sU.length,sP=sJ;for(sR=0;sR<sS;sR++ ){sQ=sP.indexOf(sU.charAt(sR));if(sQ>64)continue;if(sQ<0)return false;sT+=6;};return (sT%8)===0;};function sK(sY){var sW,tb,tc=sY.replace(/[\r\n=]/g,fA),sX=tc.length,sV=sJ,td=0,ta=[];for(sW=0;sW<sX;sW++ ){if((sW%4===0)&&sW){ta.push((td>>16)&0xFF);ta.push((td>>8)&0xFF);ta.push(td&0xFF);};td=(td<<6)|sV.indexOf(tc.charAt(sW));};tb=(sX%4)*6;if(tb===0){ta.push((td>>16)&0xFF);ta.push((td>>8)&0xFF);ta.push(td&0xFF);}else if(tb===18){ta.push((td>>10)&0xFF);ta.push((td>>2)&0xFF);}else if(tb===12){ta.push((td>>4)&0xFF);};if(sM){return sM.from?sM.from(ta):new sM(ta);};return ta;};function sH(th){var tj=fA,tk=0,tf,ti,tg=th.length,te=sJ;for(tf=0;tf<tg;tf++ ){if((tf%3===0)&&tf){tj+=te[(tk>>18)&0x3F];tj+=te[(tk>>12)&0x3F];tj+=te[(tk>>6)&0x3F];tj+=te[tk&0x3F];};tk=(tk<<8)+th[tf];};ti=tg%3;if(ti===0){tj+=te[(tk>>18)&0x3F];tj+=te[(tk>>12)&0x3F];tj+=te[(tk>>6)&0x3F];tj+=te[tk&0x3F];}else if(ti===2){tj+=te[(tk>>10)&0x3F];tj+=te[(tk>>4)&0x3F];tj+=te[(tk<<2)&0x3F];tj+=te[64];}else if(ti===1){tj+=te[(tk>>2)&0x3F];tj+=te[(tk<<4)&0x3F];tj+=te[64];tj+=te[64];};return tj;};function sL(tl){return sM&&sM.isBuffer(tl);};sI.exports=new sF(bm,{kind:eo,resolve:sE,construct:sK,predicate:sL,represent:sH});},{"../type":13}],'15':[function(tq,tr,tn){es;var ts=tq(bI);function tm(tu){if(tu===null)return false;var tt=tu.length;return (tt===4&&(tu===gU||tu===fK||tu===fk))||(tt===5&&(tu===V||tu===ct||tu===Q));};function tp(tv){return tv===gU||tv===fK||tv===fk;};function to(tw){return Object.prototype.toString.call(tw)===cK;};tr.exports=new ts(bJ,{kind:eo,resolve:tm,construct:tp,predicate:to,represent:{lowercase:function(tx){return tx?gU:V;},uppercase:function(ty){return ty?fk:Q;},camelcase:function(tz){return tz?fK:ct;}},defaultStyle:E});},{"../type":13}],'16':[function(tE,tF,tB){es;var tH=tE(O);var tI=tE(bI);var tD=new RegExp(eq+fS+eF+bu+bT);function tK(tL){if(tL===null)return false;if(!tD.test(tL)||tL[tL.length-1]===bi){return false;};return true;};function tJ(tO){var tP,tQ,tN,tM;tP=tO.replace(/_/g,fA).toLowerCase();tQ=tP[0]===dr?-1:1;tM=[];if(dI.indexOf(tP[0])>=0){tP=tP.slice(1);};if(tP===du){return (tQ===1)?Number.POSITIVE_INFINITY:Number.NEGATIVE_INFINITY;}else if(tP===gI){return NaN;}else if(tP.indexOf(eM)>=0){tP.split(eM).forEach(function(v){tM.unshift(parseFloat(v,10));});tP=0.0;tN=1;tM.forEach(function(d){tP+=d*tN;tN*=60;});return tQ*tP;};return tQ*parseFloat(tP,10);};var tC=/^[-+]?[0-9]+e/;function tG(tT,tS){var tR;if(isNaN(tT)){switch(tS){case E:return gI;case eE:return fI;case eD:return g;};}else if(Number.POSITIVE_INFINITY===tT){switch(tS){case E:return du;case eE:return fY;case eD:return dj;};}else if(Number.NEGATIVE_INFINITY===tT){switch(tS){case E:return P;case eE:return gQ;case eD:return cV;};}else if(tH.isNegativeZero(tT)){return eO;};tR=tT.toString(10);return tC.test(tR)?tR.replace(eK,dC):tR;};function tA(tU){return (Object.prototype.toString.call(tU)===cL)&&(tU%1!==0||tH.isNegativeZero(tU));};tF.exports=new tI(A,{kind:eo,resolve:tK,construct:tJ,predicate:tA,represent:tG,defaultStyle:E});},{"../common":2,"../type":13}],'17':[function(tY,ub,tV){es;var ud=tY(O);var uc=tY(bI);function tW(c){return ((0x30<=c)&&(c<=0x39))||((0x41<=c)&&(c<=0x46))||((0x61<=c)&&(c<=0x66));};function ue(c){return ((0x30<=c)&&(c<=0x37));};function uf(c){return ((0x30<=c)&&(c<=0x39));};function ua(uj){if(uj===null)return false;var uh=uj.length,uk=0,ul=false,ui;if(!uh)return false;ui=uj[uk];if(ui===dr||ui===bU){ui=uj[ ++uk];};if(ui===gP){if(uk+1===uh)return true;ui=uj[ ++uk];if(ui===ew){uk++ ;for(;uk<uh;uk++ ){ui=uj[uk];if(ui===bi)continue;if(ui!==gP&&ui!==bf)return false;ul=true;};return ul&&ui!==bi;};if(ui===bW){uk++ ;for(;uk<uh;uk++ ){ui=uj[uk];if(ui===bi)continue;if(!tW(uj.charCodeAt(uk)))return false;ul=true;};return ul&&ui!==bi;};for(;uk<uh;uk++ ){ui=uj[uk];if(ui===bi)continue;if(!ue(uj.charCodeAt(uk)))return false;ul=true;};return ul&&ui!==bi;};if(ui===bi)return false;for(;uk<uh;uk++ ){ui=uj[uk];if(ui===bi)continue;if(ui===eM)break;if(!uf(uj.charCodeAt(uk))){return false;};ul=true;};if(!ul||ui===bi)return false;if(ui!==eM)return true;return /^(:[0-5]?[0-9])+$/.test(uj.slice(uk));};function tX(ur){var uo=ur,up=1,un,uq,um=[];if(uo.indexOf(bi)!==-1){uo=uo.replace(/_/g,fA);};un=uo[0];if(un===dr||un===bU){if(un===dr)up=-1;uo=uo.slice(1);un=uo[0];};if(uo===gP)return 0;if(un===gP){if(uo[1]===ew)return up*parseInt(uo.slice(2),2);if(uo[1]===bW)return up*parseInt(uo,16);return up*parseInt(uo,8);};if(uo.indexOf(eM)!==-1){uo.split(eM).forEach(function(v){um.unshift(parseInt(v,10));});uo=0;uq=1;um.forEach(function(d){uo+=(d*uq);uq*=60;});return up*uo;};return up*parseInt(uo,10);};function ug(us){return (Object.prototype.toString.call(us))===cL&&(us%1===0&&!ud.isNegativeZero(us));};ub.exports=new uc(fq,{kind:eo,resolve:ua,construct:tX,predicate:ug,represent:{binary:function(ut){return x+ut.toString(2);},octal:function(uu){return gP+uu.toString(8);},decimal:function(uv){return uv.toString(10);},hexadecimal:function(uw){return cN+uw.toString(16).toUpperCase();}},defaultStyle:cx,styleAliases:{binary:[2,cu],octal:[8,fu],decimal:[10,bh],hexadecimal:[16,dB]}});},{"../common":2,"../type":13}],'18':[function(require,module,exports){es;var esprima;try{var _require=require;esprima=_require(bX);}catch(_){if(typeof window!==ed)esprima=window.esprima;};var Type=require(ep);function resolveJavascriptFunction(uy){if(uy===null)return false;try{var ux=X+uy+gS,uz=esprima.parse(ux,{range:true});if(uz.type!==ef||uz.body.length!==1||uz.body[0].type!==K||uz.body[0].expression.type!==fg){return false;};return true;}catch(uA){return false;};};function constructJavascriptFunction(data){var source=X+data+gS,ast=esprima.parse(source,{range:true}),params=[],body;if(ast.type!==ef||ast.body.length!==1||ast.body[0].type!==K||ast.body[0].expression.type!==fg){throw new Error(eU);};ast.body[0].expression.params.forEach(function(uB){params.push(uB.name);});body=ast.body[0].expression.body.range;return new Function(params,source.slice(body[0]+1,body[1]-1));};function representJavascriptFunction(uC){return uC.toString();};function isFunction(uD){return Object.prototype.toString.call(uD)===fX;};module.exports=new Type(S,{kind:eo,resolve:resolveJavascriptFunction,construct:constructJavascriptFunction,predicate:isFunction,represent:representJavascriptFunction});},{"../../type":13}],'19':[function(uH,uI,uE){es;var uK=uH(ep);function uJ(uP){if(uP===null)return false;if(uP.length===0)return false;var uM=uP,uN=/\/([gim]*)$/.exec(uP),uO=fA;if(uM[0]===fc){if(uN)uO=uN[1];if(uO.length>3)return false;if(uM[uM.length-uO.length-1]!==fc)return false;};return true;};function uG(uT){var uQ=uT,uR=/\/([gim]*)$/.exec(uT),uS=fA;if(uQ[0]===fc){if(uR)uS=uR[1];uQ=uQ.slice(1,uQ.length-uS.length-1);};return new RegExp(uQ,uS);};function uF(uU){var uV=fc+uU.source+fc;if(uU.global)uV+=gx;if(uU.multiline)uV+=fV;if(uU.ignoreCase)uV+=J;return uV;};function uL(uW){return Object.prototype.toString.call(uW)===cv;};uI.exports=new uK(ec,{kind:eo,resolve:uJ,construct:uG,predicate:uL,represent:uF});},{"../../type":13}],'20':[function(va,vb,uX){es;var ve=va(ep);function uY(){return true;};function vc(){return undefined;};function vd(){return fA;};function vf(vg){return typeof vg===ed;};vb.exports=new ve(fr,{kind:eo,resolve:uY,construct:vc,predicate:vf,represent:vd});},{"../../type":13}],'21':[function(vh,vk,vj){es;var vi=vh(bI);vk.exports=new vi(cC,{kind:fm,construct:function(vl){return vl!==null?vl:{};}});},{"../type":13}],'22':[function(vm,vq,vp){es;var vo=vm(bI);function vn(vr){return vr===by||vr===null;};vq.exports=new vo(bq,{kind:eo,resolve:vn});},{"../type":13}],'23':[function(vt,vu,vs){es;var vy=vt(bI);function vx(vA){if(vA===null)return true;var vz=vA.length;return (vz===1&&vA===H)||(vz===4&&(vA===bD||vA===z||vA===dm));};function vw(){return null;};function vv(vB){return vB===null;};vu.exports=new vy(y,{kind:eo,resolve:vx,construct:vw,predicate:vv,represent:{canonical:function(){return H;},lowercase:function(){return bD;},uppercase:function(){return dm;},camelcase:function(){return z;}},defaultStyle:E});},{"../type":13}],'24':[function(vE,vF,vC){es;var vJ=vE(bI);var vG=Object.prototype.hasOwnProperty;var vI=Object.prototype.toString;function vD(vQ){if(vQ===null)return true;var vO=[],vK,length,vP,vN,vL,vM=vQ;for(vK=0,length=vM.length;vK<length;vK+=1){vP=vM[vK];vL=false;if(vI.call(vP)!==gh)return false;for(vN in vP){if(vG.call(vP,vN)){if(!vL)vL=true;else return false;};};if(!vL)return false;if(vO.indexOf(vN)===-1)vO.push(vN);else return false;};return true;};function vH(vR){return vR!==null?vR:[];};vF.exports=new vJ(ek,{kind:j,resolve:vD,construct:vH});},{"../type":13}],'25':[function(vT,vU,vS){es;var vX=vT(bI);var vV=Object.prototype.toString;function vW(wf){if(wf===null)return true;var wa,length,we,wb,wd,wc=wf;wd=new Array(wc.length);for(wa=0,length=wc.length;wa<length;wa+=1){we=wc[wa];if(vV.call(we)!==gh)return false;wb=Object.keys(we);if(wb.length!==1)return false;wd[wa]=[wb[0],we[wb[0]]];};return true;};function vY(wl){if(wl===null)return [];var wg,length,wk,wh,wj,wi=wl;wj=new Array(wi.length);for(wg=0,length=wi.length;wg<length;wg+=1){wk=wi[wg];wh=Object.keys(wk);wj[wg]=[wh[0],wk[wh[0]]];};return wj;};vU.exports=new vX(gp,{kind:j,resolve:vW,construct:vY});},{"../type":13}],'26':[function(wm,wp,wo){es;var wn=wm(bI);wp.exports=new wn(dJ,{kind:j,construct:function(wq){return wq!==null?wq:[];}});},{"../type":13}],'27':[function(ws,wu,wt){es;var wx=ws(bI);var wv=Object.prototype.hasOwnProperty;function ww(wz){if(wz===null)return true;var wA,wy=wz;for(wA in wy){if(wv.call(wy,wA)){if(wy[wA]!==null)return false;};};return true;};function wr(wB){return wB!==null?wB:{};};wu.exports=new wx(gH,{kind:fm,resolve:ww,construct:wr});},{"../type":13}],'28':[function(wC,wF,wE){es;var wD=wC(bI);wF.exports=new wD(cE,{kind:eo,construct:function(wG){return wG!==null?wG:fA;}});},{"../type":13}],'29':[function(wK,wL,wH){es;var wP=wK(bI);var wO=new RegExp(m+eX+bd);var wN=new RegExp(m+gJ+gJ+bs+F+cb+cb+U+gL+eT);function wJ(wQ){if(wQ===null)return false;if(wO.exec(wQ)!==null)return true;if(wN.exec(wQ)!==null)return true;return false;};function wI(xc){var wX,wS,wU,xd,wR,xe,wV,wY=0,xa=null,wT,wW,xb;wX=wO.exec(xc);if(wX===null)wX=wN.exec(xc);if(wX===null)throw new Error(ca);wS=+(wX[1]);wU=+(wX[2])-1;xd=+(wX[3]);if(!wX[4]){return new Date(Date.UTC(wS,wU,xd));};wR=+(wX[4]);xe=+(wX[5]);wV=+(wX[6]);if(wX[7]){wY=wX[7].slice(0,3);while(wY.length<3){wY+=gP;};wY=+wY;};if(wX[9]){wT=+(wX[10]);wW=+(wX[11]||0);xa=(wT*60+wW)*60000;if(wX[9]===dr)xa=-xa;};xb=new Date(Date.UTC(wS,wU,xd,wR,xe,wV,wY));if(xa)xb.setTime(xb.getTime()-xa);return xb;};function wM(xf){return xf.toISOString();};wL.exports=new wP(cc,{kind:eo,resolve:wJ,construct:wI,instanceOf:Date,represent:wM});},{"../type":13}],"/":[function(xh,xj,xi){es;var xg=xh(da);xj.exports=xg;},{"./lib/js-yaml.js":1}]},{},[])(gi);});})();(function(){var a='qx.event.type.Event',b='Invalid editor view supplied',c='kucken.ui.form.mvc.Controller',d='canceled',e='close',f='saved',g='qx.event.type.Data',h='failed',i='No editor view supplied',j='completed',k='No model supplied';qx.Class.define(c,{extend:qx.core.Object,construct:function(m,n,l){qx.core.Object.call(this);this._pool=new qx.util.ObjectPool(2);this._desktop=m;this._view=n;this._model=l;},events:{completed:g,failed:a,canceled:a},members:{_desktop:null,_pool:null,_view:null,_model:null,_createView:function(o){var q;if(qx.Class.isSubClassOf(this._view,kucken.ui.form.mvc.View)){q=this._view;}else if(qx.lang.Type.isFunction(this._view)){q=this._view.call(this,o);if(!qx.Class.isSubClassOf(q,kucken.ui.form.mvc.View)){throw new Error(b);};}else {throw new Error(i);};var r=this._pool.getObject(q);var p=r.getModel();if(!p){r.addListener(e,function(){if(r.getIsCanceled()){this.fireEvent(d);};this._pool.poolObject(r);},this);p=this._createModel();p.addListener(f,function(event){this.fireDataEvent(j,event.getData());},this);p.addListener(h,function(event){this.fireDataEvent(h,event.getData());r.open();},this);r.setModel(p);};return r;},_createModel:function(){var s;if(qx.Class.isSubClassOf(this._model,kucken.ui.form.mvc.Model)){s=this._model;}else {throw new Error(k);};return new s();},open:function(t){var u=this._createView(t);this._desktop.add(u);u.load(t);u.open();}}});})();(function(){var a='clui.view.TablePage',b='short',c='%1, %2 - %3',d='medium',e='_dateFormatter',f='_timeFormatter',g='%1 - %2',h='changeBubble';qx.Class.define(a,{extend:qx.ui.tabview.Page,construct:function(i){qx.ui.tabview.Page.call(this);this._dateFormatter=new qx.util.format.DateFormat(qx.locale.Date.getDateFormat(d));this._timeFormatter=new qx.util.format.DateFormat(qx.locale.Date.getTimeFormat(b));this._tableQueryModelFormModel=i.getTableQueryModel().getFormModel();this._tableQueryModelFormModel.addListener(h,this._onBubbleChange,this);this.setShowCloseButton(true);this.setLayout(new qx.ui.layout.VBox(4));this.setPadding(0);this.add(i.createWidget(),{'flex':1});this._onBubbleChange();},destruct:function(){this._disposeObjects(e,f);},members:{_dateFormatter:null,_timeFormatter:null,_tableQueryModelFormModel:null,_onBubbleChange:function(){this.setLabel(this._getLabel());},_getLabel:function(){var k=this._tableQueryModelFormModel.getAfter();var j=this._tableQueryModelFormModel.getBefore();if(k.isAbsolute()&&j.isAbsolute()){var l=this._dateFormatter.format(k.toDate());var m=this._dateFormatter.format(j.toDate());if(l==m){return this.tr(c,l,this._timeFormatter.format(k.toDate()),this._timeFormatter.format(j.toDate()));}else {return this.tr(g,l,m);};}else if(k.isAbsolute()){var l=this._dateFormatter.format(k.toDate());return this.tr(g,l,j.getExpression());}else if(j.isAbsolute()){var m=this._dateFormatter.format(j.toDate());return this.tr(g,k.getExpression(),m);}else {return this.tr(g,k.getExpression(),j.getExpression());};}}});})();(function(){var a="qx.event.type.Event",b="qx.ui.table.ITableModel",c="qx.event.type.Data";qx.Interface.define(b,{events:{"dataChanged":c,"metaDataChanged":a,"sorted":c},members:{getRowCount:function(){},getRowData:function(d){},getColumnCount:function(){},getColumnId:function(e){},getColumnIndexById:function(f){},getColumnName:function(g){},isColumnEditable:function(h){},isColumnSortable:function(i){},sortByColumn:function(j,k){},getSortColumnIndex:function(){},isSortAscending:function(){},prefetchRows:function(m,l){},getValue:function(o,n){},getValueById:function(q,p){},setValue:function(s,r,t){},setValueById:function(v,u,w){}}});})();(function(){var a=" != ",b="abstract",c="metaDataChanged",d="columnIdArr and columnNameArr have different length: ",e="getValue is abstract",f="qx.ui.table.model.Abstract",g="qx.event.type.Event",h="this.__columnIdArr and columnNameArr have different length: ",j="setValue is abstract",k="getRowCount is abstract",l="qx.event.type.Data";qx.Class.define(f,{type:b,extend:qx.core.Object,implement:qx.ui.table.ITableModel,events:{"dataChanged":l,"metaDataChanged":g,"sorted":l},construct:function(){qx.core.Object.call(this);this.__wc=[];this.__wd=[];this.__we={};},members:{__wc:null,__wd:null,__we:null,__wf:null,init:function(m){},getRowCount:function(){throw new Error(k);},getRowData:function(n){return null;},isColumnEditable:function(o){return false;},isColumnSortable:function(p){return false;},sortByColumn:function(q,r){},getSortColumnIndex:function(){return -1;},isSortAscending:function(){return true;},prefetchRows:function(t,s){},getValue:function(v,u){throw new Error(e);},getValueById:function(x,w){return this.getValue(this.getColumnIndexById(x),w);},setValue:function(z,y,A){throw new Error(j);},setValueById:function(C,B,D){this.setValue(this.getColumnIndexById(C),B,D);},getColumnCount:function(){return this.__wc.length;},getColumnIndexById:function(E){return this.__we[E];},getColumnId:function(F){return this.__wc[F];},getColumnName:function(G){return this.__wd[G];},setColumnIds:function(H){this.__wc=H;this.__we={};for(var i=0;i<H.length;i++ ){this.__we[H[i]]=i;};this.__wd=new Array(H.length);if(!this.__wf){this.fireEvent(c);};},setColumnNamesByIndex:function(I){if(this.__wc.length!=I.length){throw new Error(h+this.__wc.length+a+I.length);};this.__wd=I;this.fireEvent(c);},setColumnNamesById:function(J){this.__wd=new Array(this.__wc.length);for(var i=0;i<this.__wc.length; ++i){this.__wd[i]=J[this.__wc[i]];};},setColumns:function(K,L){var M=this.__wc.length==0||L;if(L==null){if(this.__wc.length==0){L=K;}else {L=this.__wc;};};if(L.length!=K.length){throw new Error(d+L.length+a+K.length);};if(M){this.__wf=true;this.setColumnIds(L);this.__wf=false;};this.setColumnNamesByIndex(K);}},destruct:function(){this.__wc=this.__wd=this.__we=null;}});})();(function(){var a="Integer",b="Boolean",c="metaDataChanged",d="qx.ui.table.model.Remote",e="_loadRowData is abstract",f="dataChanged",g="_loadRowCount is abstract";qx.Class.define(d,{extend:qx.ui.table.model.Abstract,construct:function(){qx.ui.table.model.Abstract.call(this);this._sortColumnIndex=-1;this._sortAscending=true;this._rowCount=-1;this._lruCounter=0;this._firstLoadingBlock=-1;this._firstRowToLoad=-1;this._lastRowToLoad=-1;this._ignoreCurrentRequest=false;this._rowBlockCache={};this._rowBlockCount=0;this._sortableColArr=null;this._editableColArr=null;},properties:{blockSize:{check:a,init:50},maxCachedBlockCount:{check:a,init:15},clearCacheOnRemove:{check:b,init:false},blockConcurrentLoadRowCount:{check:b,init:true}},members:{_rowCount:null,_ignoreCurrentRequest:null,_lruCounter:null,_firstLoadingBlock:null,_firstRowToLoad:null,_lastRowToLoad:null,_rowBlockCache:null,_rowBlockCount:null,_sortColumnIndex:null,_sortAscending:null,_editableColArr:null,_sortableColArr:null,_loadRowCountRequestRunning:false,_clearCache:false,_getIgnoreCurrentRequest:function(){return this._ignoreCurrentRequest;},getRowCount:function(){if(this._rowCount==-1){if(!this._loadRowCountRequestRunning||!this.getBlockConcurrentLoadRowCount()){this._loadRowCountRequestRunning=true;this._loadRowCount();};return (this._rowCount==-1)?0:this._rowCount;}else {return this._rowCount;};},_loadRowCount:function(){throw new Error(g);},_onRowCountLoaded:function(h){if(this.getBlockConcurrentLoadRowCount()){this._loadRowCountRequestRunning=false;};if(h==null||h<0){h=0;};this._rowCount=Number(h);var j={firstRow:0,lastRow:h-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,j);},reloadData:function(){if(this._firstLoadingBlock!=-1){var k=this._cancelCurrentRequest();if(k){this._firstLoadingBlock=-1;this._ignoreCurrentRequest=false;}else {this._ignoreCurrentRequest=true;};};this._clearCache=true;this._firstRowToLoad=-1;this._lastRowToLoad=-1;this._loadRowCountRequestRunning=true;this._loadRowCount();},clearCache:function(){this._rowBlockCache={};this._rowBlockCount=0;},getCacheContent:function(){return {sortColumnIndex:this._sortColumnIndex,sortAscending:this._sortAscending,rowCount:this._rowCount,lruCounter:this._lruCounter,rowBlockCache:this._rowBlockCache,rowBlockCount:this._rowBlockCount};},restoreCacheContent:function(m){if(this._firstLoadingBlock!=-1){var n=this._cancelCurrentRequest();if(n){this._firstLoadingBlock=-1;this._ignoreCurrentRequest=false;}else {this._ignoreCurrentRequest=true;};};this._sortColumnIndex=m.sortColumnIndex;this._sortAscending=m.sortAscending;this._rowCount=m.rowCount;this._lruCounter=m.lruCounter;this._rowBlockCache=m.rowBlockCache;this._rowBlockCount=m.rowBlockCount;var l={firstRow:0,lastRow:this._rowCount-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,l);},_cancelCurrentRequest:function(){return false;},iterateCachedRows:function(p,t){var r=this.getBlockSize();var o=Math.ceil(this.getRowCount()/r);for(var y=0;y<=o;y++ ){var u=this._rowBlockCache[y];if(u!=null){var s=y*r;var q=u.rowDataArr;for(var w=0;w<q.length;w++ ){var v=q[w];var x=p.call(t,s+w,v);if(x!=null){q[w]=x;};};};};},prefetchRows:function(H,B){if(this._firstLoadingBlock==-1){var z=this.getBlockSize();var F=Math.ceil(this._rowCount/z);var E=parseInt(H/z,10)-1;if(E<0){E=0;};var C=parseInt(B/z,10)+1;if(C>=F){C=F-1;};var D=-1;var A=-1;for(var G=E;G<=C;G++ ){if((this._clearCache&&!this._loadRowCountRequestRunning)||this._rowBlockCache[G]==null||this._rowBlockCache[G].isDirty){if(D==-1){D=G;};A=G;};};if(D!=-1){this._firstRowToLoad=-1;this._lastRowToLoad=-1;this._firstLoadingBlock=D;this._loadRowData(D*z,(A+1)*z-1);};}else {this._firstRowToLoad=H;this._lastRowToLoad=B;};},_loadRowData:function(J,I){throw new Error(e);},_onRowDataLoaded:function(P){if(this._clearCache){this.clearCache();this._clearCache=false;};if(P!=null&&!this._ignoreCurrentRequest){var M=this.getBlockSize();var K=Math.ceil(P.length/M);if(K==1){this._setRowBlockData(this._firstLoadingBlock,P);}else {for(var i=0;i<K;i++ ){var N=i*M;var O=[];var L=Math.min(M,P.length-N);for(var R=0;R<L;R++ ){O.push(P[N+R]);};this._setRowBlockData(this._firstLoadingBlock+i,O);};};var Q={firstRow:this._firstLoadingBlock*M,lastRow:(this._firstLoadingBlock+K+1)*M-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,Q);};this._firstLoadingBlock=-1;this._ignoreCurrentRequest=false;if(this._firstRowToLoad!=-1){this.prefetchRows(this._firstRowToLoad,this._lastRowToLoad);};},_setRowBlockData:function(X,W){if(this._rowBlockCache[X]==null){this._rowBlockCount++ ;while(this._rowBlockCount>this.getMaxCachedBlockCount()){var T;var S=this._lruCounter;for(var V in this._rowBlockCache){var U=this._rowBlockCache[V].lru;if(U<S&&V>1){S=U;T=V;};};delete this._rowBlockCache[T];this._rowBlockCount-- ;};};this._rowBlockCache[X]={lru: ++this._lruCounter,rowDataArr:W};},removeRow:function(bb){if(this.getClearCacheOnRemove()){this.clearCache();var bg={firstRow:0,lastRow:this.getRowCount()-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,bg);}else {var bc=this.getBlockSize();var Y=Math.ceil(this.getRowCount()/bc);var bd=parseInt(bb/bc,10);for(var bh=bd;bh<=Y;bh++ ){var bf=this._rowBlockCache[bh];if(bf!=null){var ba=0;if(bh==bd){ba=bb-bh*bc;};bf.rowDataArr.splice(ba,1);if(bh==Y-1){if(bf.rowDataArr.length==0){delete this._rowBlockCache[bh];};}else {var be=this._rowBlockCache[bh+1];if(be!=null){bf.rowDataArr.push(be.rowDataArr[0]);}else {bf.isDirty=true;};};};};if(this._rowCount!=-1){this._rowCount-- ;};if(this.hasListener(f)){var bg={firstRow:bb,lastRow:this.getRowCount()-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,bg);};};},getRowData:function(bi){var bj=this.getBlockSize();var bm=parseInt(bi/bj,10);var bk=this._rowBlockCache[bm];if(bk==null){return null;}else {var bl=bk.rowDataArr[bi-(bm*bj)];if(bk.lru!=this._lruCounter){bk.lru= ++this._lruCounter;};return bl;};},getValue:function(bo,bn){var bp=this.getRowData(bn);if(bp==null){return null;}else {var bq=this.getColumnId(bo);return bp[bq];};},setValue:function(bu,bs,bt){var bv=this.getRowData(bs);if(bv==null){return;}else {var br=this.getColumnId(bu);bv[br]=bt;if(this.hasListener(f)){var bw={firstRow:bs,lastRow:bs,firstColumn:bu,lastColumn:bu};this.fireDataEvent(f,bw);};};},setEditable:function(bx){this._editableColArr=[];for(var by=0;by<this.getColumnCount();by++ ){this._editableColArr[by]=bx;};this.fireEvent(c);},setColumnEditable:function(bz,bA){if(bA!=this.isColumnEditable(bz)){if(this._editableColArr==null){this._editableColArr=[];};this._editableColArr[bz]=bA;this.fireEvent(c);};},isColumnEditable:function(bB){return (this._editableColArr?(this._editableColArr[bB]==true):false);},setColumnSortable:function(bC,bD){if(bD!=this.isColumnSortable(bC)){if(this._sortableColArr==null){this._sortableColArr=[];};this._sortableColArr[bC]=bD;this.fireEvent(c);};},isColumnSortable:function(bE){return (this._sortableColArr?(this._sortableColArr[bE]!==false):true);},sortByColumn:function(bF,bG){if(this._sortColumnIndex!=bF||this._sortAscending!=bG){this._sortColumnIndex=bF;this._sortAscending=bG;this.clearCache();this.fireEvent(c);};},getSortColumnIndex:function(){return this._sortColumnIndex;},isSortAscending:function(){return this._sortAscending;},setSortColumnIndexWithoutSortingData:function(bH){this._sortColumnIndex=bH;},setSortAscendingWithoutSortingData:function(bI){this._sortAscending=bI;}},destruct:function(){this._sortableColArr=this._editableColArr=this._rowBlockCache=null;}});})();(function(){var a='_record',b='loadCount',c='qx.event.type.Data',d='clui.model.RemoteRecordTable',e='beforeRequest',f='timezone',g='afterRequest',h='timeSeries',i='qx.data.Array',j='Setting table model column names and ids:',k='count',l='loadRange',m='Array',n='group',o='Failed loading table record count',p='name',q='filter',r='Failed loading table record range',s='qx.event.type.Event',t='requestData',u='changeTimeSeries',w='id';qx.Class.define(d,{extend:qx.ui.table.model.Remote,events:{beforeRequest:s,afterRequest:c,requestData:c},properties:{blockSize:{refine:true,init:128},timeSeries:{check:m,init:[],event:u},columnset:{check:i}},construct:function(){qx.ui.table.model.Remote.call(this);this._record=new clui.io.PromisedRecord();},destruct:function(){this._disposeObjects(a);},members:{_record:null,_loadRowCount:function(){this.clearCache();this.fireEvent(e);var x={};if(this.fireDataEvent(t,{'data':x,'type':b})){this._record.count(x[n],x[f],x[q]).then(function(y){this._onRowCountLoaded(y[k]);this.setTimeSeries(y[h]);this.fireDataEvent(g,null);},this).caught(function(z){this.error(o,z);this.fireDataEvent(g,z);},this);};},_loadRowData:function(C,B){this.fireEvent(e);var A={};if(this.fireDataEvent(t,{'data':A,'type':l})){this._record.range(C,B,A[q]).then(function(D){this._onRowDataLoaded(D);this.fireDataEvent(g,null);},this).caught(function(E){this.error(r,E);this.fireDataEvent(g,E);},this);};},updateColumns:function(){var F=qx.util.Serializer.toNativeObject(this.getColumnset());var H=F.map(kucken.lang.Object.select.bind(null,p));var G=F.map(kucken.lang.Object.select.bind(null,w));this.debug(j,H,G);this.setColumns(H,G);F.forEach(function(v,I){this.setColumnSortable(I,false);},this);},getValue:function(K,J){var L=this.getRowData(J);if(L){return clui.util.DictQuery.execute(this.getColumnset().getItem(K).getPath(),L);}else {return null;};}}});})();(function(){var a='clui.util.DictQuery';qx.Class.define(a,{statics:{execute:function(b,c){var d=c;var e=null;b=b.concat();while(b.length){e=b.shift();if(e in d){d=d[e];}else {return null;};};return d;}}});})();(function(){var a='Must be overriden in descendent class',b='clui.view.list.Abstract',c='abstract';qx.Class.define(b,{extend:qx.ui.window.Window,type:c,construct:function(d,e){qx.ui.window.Window.call(this,d,e);this.set({'layout':new qx.ui.layout.VBox(),'showMinimize':false,'showClose':false,'contentPadding':0});this._createLayout();},members:{_toolbar:null,_dataWidget:null,_createLayout:function(){this._toolbar=this._createToolbar();this._dataWidget=this._createDataWidget();this.add(this._toolbar);this.add(this._dataWidget,{'flex':1});},_createToolbar:function(){return new qx.ui.toolbar.ToolBar();},_createDataWidget:function(){throw new Error(a);},getToolbar:function(){return this._toolbar;},getDataWidget:function(){return this._dataWidget;}}});})();(function(){var a="Boolean",b="changeShow",c="qx.ui.core.Widget",d="_applyOverflowHandling",f="both",g="_applySpacing",h="qx.ui.toolbar.ToolBar",j="qx.event.type.Data",k="Integer",m="showItem",n="Widget must be child of the toolbar.",o="visible",p="changeOpenMenu",q="resize",r="icon",s="_applyOverflowIndicator",t="toolbar",u="qx.ui.menu.Menu",v="Priority already in use!",w="label",x="_applyShow",y="excluded",z="show",A="hideItem";qx.Class.define(h,{extend:qx.ui.core.Widget,include:qx.ui.core.MChildrenHandling,construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.HBox());this.__pn=[];this.__po=[];},properties:{appearance:{refine:true,init:t},openMenu:{check:u,event:p,nullable:true},show:{init:f,check:[f,w,r],inheritable:true,apply:x,event:b},spacing:{nullable:true,check:k,themeable:true,apply:g},overflowIndicator:{check:c,nullable:true,apply:s},overflowHandling:{init:false,check:a,apply:d}},events:{"hideItem":j,"showItem":j},members:{__pn:null,__po:null,_computeSizeHint:function(){var D=qx.ui.core.Widget.prototype._computeSizeHint.call(this);if(true&&this.getOverflowHandling()){var B=0;var C=this.getOverflowIndicator();if(C){B=C.getSizeHint().width+this.getSpacing();};D.minWidth=B;};return D;},_onResize:function(e){this._recalculateOverflow(e.getData().width);},_recalculateOverflow:function(F,G){if(!this.getOverflowHandling()){return;};G=G||this.getSizeHint().width;var E=this.getOverflowIndicator();var L=0;if(E){L=E.getSizeHint().width;};if(F==undefined&&this.getBounds()!=null){F=this.getBounds().width;};if(F==undefined){return;};if(F<G){do {var K=this._getNextToHide();if(!K){return;};var P=K.getMarginLeft()+K.getMarginRight();P=Math.max(P,this.getSpacing());var J=K.getSizeHint().width+P;this.__pq(K);G-=J;if(E&&E.getVisibility()!=o){E.setVisibility(o);G+=L;var H=E.getMarginLeft()+E.getMarginRight();G+=Math.max(H,this.getSpacing());};}while(G>F);}else if(this.__pn.length>0){do {var Q=this.__pn[0];if(Q){var P=Q.getMarginLeft()+Q.getMarginRight();P=Math.max(P,this.getSpacing());if(Q.getContentElement().getDomElement()==null){Q.syncAppearance();Q.invalidateLayoutCache();};var I=Q.getSizeHint().width;var O=false;if(this.__pn.length==1&&L>0){var N=P-this.getSpacing();var M=G-L+I+N;O=F>M;};if(F>G+I+P||O){this.__pp(Q);G+=I;if(E&&this.__pn.length==0){E.setVisibility(y);};}else {return;};};}while(F>=G&&this.__pn.length>0);};},__pp:function(R){R.setVisibility(o);this.__pn.shift();this.fireDataEvent(m,R);},__pq:function(S){if(!S){return;};this.__pn.unshift(S);S.setVisibility(y);this.fireDataEvent(A,S);},_getNextToHide:function(){for(var i=this.__po.length-1;i>=0;i-- ){var T=this.__po[i];if(T&&T.getVisibility&&T.getVisibility()==o){return T;};};var U=this._getChildren();for(var i=U.length-1;i>=0;i-- ){var V=U[i];if(V==this.getOverflowIndicator()){continue;};if(V.getVisibility&&V.getVisibility()==o){return V;};};},setRemovePriority:function(X,W,Y){if(!Y&&this.__po[W]!=undefined){throw new Error(v);};this.__po[W]=X;},_applyOverflowHandling:function(bc,ba){this.invalidateLayoutCache();var parent=this.getLayoutParent();if(parent){parent.invalidateLayoutCache();};var bb=this.getBounds();if(bb&&bb.width){this._recalculateOverflow(bb.width);};if(bc){this.addListener(q,this._onResize,this);}else {this.removeListener(q,this._onResize,this);var bd=this.getOverflowIndicator();if(bd){bd.setVisibility(y);};for(var i=0;i<this.__pn.length;i++ ){this.__pn[i].setVisibility(o);};this.__pn=[];};},_applyOverflowIndicator:function(bf,be){if(be){this._remove(be);};if(bf){if(this._indexOf(bf)==-1){throw new Error(n);};bf.setVisibility(y);};},__pr:false,_setAllowMenuOpenHover:function(bg){this.__pr=bg;},_isAllowMenuOpenHover:function(){return this.__pr;},_applySpacing:function(bj,bh){var bi=this._getLayout();bj==null?bi.resetSpacing():bi.setSpacing(bj);},_applyShow:function(bl){var bk=this._getChildren();for(var i=0;i<bk.length;i++ ){if(bk[i].setShow){bk[i].setShow(bl);};};},_add:function(bo,bm){qx.ui.core.Widget.prototype._add.call(this,bo,bm);if(bo.setShow&&!qx.util.PropertyUtil.getUserValue(bo,z)){bo.setShow(this.getShow());};var bn=this.getSizeHint().width+bo.getSizeHint().width+2*this.getSpacing();this._recalculateOverflow(null,bn);},_addAt:function(bs,bp,bq){qx.ui.core.Widget.prototype._addAt.call(this,bs,bp,bq);if(bs.setShow&&!qx.util.PropertyUtil.getUserValue(bs,z)){bs.setShow(this.getShow());};var br=this.getSizeHint().width+bs.getSizeHint().width+2*this.getSpacing();this._recalculateOverflow(null,br);},_addBefore:function(bw,bt,bu){qx.ui.core.Widget.prototype._addBefore.call(this,bw,bt,bu);if(bw.setShow&&!qx.util.PropertyUtil.getUserValue(bw,z)){bw.setShow(this.getShow());};var bv=this.getSizeHint().width+bw.getSizeHint().width+2*this.getSpacing();this._recalculateOverflow(null,bv);},_addAfter:function(bA,bx,by){qx.ui.core.Widget.prototype._addAfter.call(this,bA,bx,by);if(bA.setShow&&!qx.util.PropertyUtil.getUserValue(bA,z)){bA.setShow(this.getShow());};var bz=this.getSizeHint().width+bA.getSizeHint().width+2*this.getSpacing();this._recalculateOverflow(null,bz);},_remove:function(bC){qx.ui.core.Widget.prototype._remove.call(this,bC);var bB=this.getSizeHint().width-bC.getSizeHint().width-2*this.getSpacing();this._recalculateOverflow(null,bB);},_removeAt:function(bD){var bF=this._getChildren()[bD];qx.ui.core.Widget.prototype._removeAt.call(this,bD);var bE=this.getSizeHint().width-bF.getSizeHint().width-2*this.getSpacing();this._recalculateOverflow(null,bE);},_removeAll:function(){qx.ui.core.Widget.prototype._removeAll.call(this);this._recalculateOverflow(null,0);},addSpacer:function(){var bG=new qx.ui.core.Spacer;this._add(bG,{flex:1});return bG;},addSeparator:function(){this.add(new qx.ui.toolbar.Separator);},getMenuButtons:function(){var bI=this.getChildren();var bH=[];var bJ;for(var i=0,l=bI.length;i<l;i++ ){bJ=bI[i];if(bJ instanceof qx.ui.menubar.Button){bH.push(bJ);}else if(bJ instanceof qx.ui.toolbar.Part){bH.push.apply(bH,bJ.getMenuButtons());};};return bH;}},destruct:function(){if(this.hasListener(q)){this.removeListener(q,this._onResize,this);};}});})();(function(){var a="toolbar-separator",b="qx.ui.toolbar.Separator";qx.Class.define(b,{extend:qx.ui.core.Widget,properties:{appearance:{refine:true,init:a},anonymous:{refine:true,init:true},width:{refine:true,init:0},height:{refine:true,init:0}}});})();(function(){var a="qx.ui.menu.Menu",b="submenu",c="hovered",d="Enter",f="pressed",g="abandoned",h="contextmenu",i="changeVisibility",j="changeMenu",k="qx.ui.form.MenuButton",l="menubutton",m="visible",n="left",o="_applyMenu";qx.Class.define(k,{extend:qx.ui.form.Button,construct:function(q,r,p){qx.ui.form.Button.call(this,q,r);if(p!=null){this.setMenu(p);};},properties:{menu:{check:a,nullable:true,apply:o,event:j},appearance:{refine:true,init:l}},members:{_applyVisibility:function(u,t){qx.ui.form.Button.prototype._applyVisibility.call(this,u,t);var s=this.getMenu();if(u!=m&&s){s.hide();};},_applyMenu:function(w,v){if(v){v.removeListener(i,this._onMenuChange,this);v.resetOpener();};if(w){w.addListener(i,this._onMenuChange,this);w.setOpener(this);w.removeState(b);w.removeState(h);};},open:function(x){var y=this.getMenu();if(y){qx.ui.menu.Manager.getInstance().hideAll();y.setOpener(this);y.open();if(x){var z=y.getSelectables()[0];if(z){y.setSelectedButton(z);};};};},_onMenuChange:function(e){var A=this.getMenu();if(A.isVisible()){this.addState(f);}else {this.removeState(f);};},_onPointerDown:function(e){qx.ui.form.Button.prototype._onPointerDown.call(this,e);if(e.getButton()!=n){return;};var B=this.getMenu();if(B){if(!B.isVisible()){this.open();}else {B.exclude();};e.stopPropagation();};},_onPointerUp:function(e){qx.ui.form.Button.prototype._onPointerUp.call(this,e);e.stopPropagation();},_onPointerOver:function(e){this.addState(c);},_onPointerOut:function(e){this.removeState(c);},_onKeyDown:function(e){switch(e.getKeyIdentifier()){case d:this.removeState(g);this.addState(f);var C=this.getMenu();if(C){if(!C.isVisible()){this.open();}else {C.exclude();};};e.stopPropagation();};},_onKeyUp:function(e){}}});})();(function(){var a="__pw",b="blur",c="keypress",d="Enter",f="Up",g="contextmenu",h="interval",j="__ls",k="roll",l="__px",m="Escape",n="pointerdown",o="qx.ui.menu.Manager",p="keydown",q="Left",r="event.touch",s="Down",t="Right",u="keyup",v="singleton",w="Space";qx.Class.define(o,{type:v,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__ls=[];var x=document.body;var y=qx.event.Registration;y.addListener(window.document.documentElement,n,this._onPointerDown,this,true);y.addListener(x,k,this._onRoll,this,true);y.addListener(x,p,this._onKeyUpDown,this,true);y.addListener(x,u,this._onKeyUpDown,this,true);y.addListener(x,c,this._onKeyPress,this,true);if(!qx.core.Environment.get(r)){qx.bom.Element.addListener(window,b,this.hideAll,this);};this.__pw=new qx.event.Timer();this.__pw.addListener(h,this._onOpenInterval,this);this.__px=new qx.event.Timer();this.__px.addListener(h,this._onCloseInterval,this);},members:{__py:null,__pz:null,__pw:null,__px:null,__ls:null,_getChild:function(z,B,A,E){var D=z.getChildren();var length=D.length;var C;for(var i=B;i<length&&i>=0;i+=A){C=D[i];if(C.isEnabled()&&!C.isAnonymous()&&C.isVisible()){return C;};};if(E){i=i==length?0:length-1;for(;i!=B;i+=A){C=D[i];if(C.isEnabled()&&!C.isAnonymous()&&C.isVisible()){return C;};};};return null;},_isInMenu:function(F){while(F){if(F instanceof qx.ui.menu.Menu){return true;};F=F.getLayoutParent();};return false;},_isMenuOpener:function(H){var G=this.__ls;for(var i=0;i<G.length;i++ ){if(G[i].getOpener()===H){return true;};};return false;},_getMenuButton:function(I){while(I){if(I instanceof qx.ui.menu.AbstractButton){return I;};I=I.getLayoutParent();};return null;},add:function(J){{};var K=this.__ls;K.push(J);J.setZIndex(1e6+K.length);},remove:function(L){{};var M=this.__ls;if(M){qx.lang.Array.remove(M,L);};},hideAll:function(){var N=this.__ls;if(N){for(var i=N.length-1;i>=0;i-- ){N[i].exclude();};};},getActiveMenu:function(){var O=this.__ls;return O.length>0?O[O.length-1]:null;},scheduleOpen:function(P){this.cancelClose(P);if(P.isVisible()){if(this.__py){this.cancelOpen(this.__py);};}else if(this.__py!=P){this.__py=P;this.__pw.restartWith(P.getOpenInterval());};},scheduleClose:function(Q){this.cancelOpen(Q);if(!Q.isVisible()){if(this.__pz){this.cancelClose(this.__pz);};}else if(this.__pz!=Q){this.__pz=Q;this.__px.restartWith(Q.getCloseInterval());};},cancelOpen:function(R){if(this.__py==R){this.__pw.stop();this.__py=null;};},cancelClose:function(S){if(this.__pz==S){this.__px.stop();this.__pz=null;};},_onOpenInterval:function(e){this.__pw.stop();this.__py.open();this.__py=null;},_onCloseInterval:function(e){this.__px.stop();this.__pz.exclude();this.__pz=null;},preventContextMenuOnce:function(){qx.event.Registration.addListener(document.body,g,this.__pA,this,true);},__pA:function(e){var T=e.getTarget();T=qx.ui.core.Widget.getWidgetByElement(T,true);if(this._isInMenu(T)){e.stopPropagation();e.preventDefault();};qx.event.Registration.removeListener(document.body,g,this.__pA,this,true);},_onPointerDown:function(e){var U=e.getTarget();U=qx.ui.core.Widget.getWidgetByElement(U,true);if(U==null){this.hideAll();return;};if(U.getMenu&&U.getMenu()&&U.getMenu().isVisible()){return;};if(this.__ls.length>0&&!this._isInMenu(U)){this.hideAll();};},__pB:{"Enter":1,"Space":1},__pC:{"Escape":1,"Up":1,"Down":1,"Left":1,"Right":1},_onKeyUpDown:function(e){var V=this.getActiveMenu();if(!V){return;};var W=e.getKeyIdentifier();if(this.__pC[W]||(this.__pB[W]&&V.getSelectedButton())){e.stopPropagation();};},_onKeyPress:function(e){var ba=this.getActiveMenu();if(!ba){return;};var X=e.getKeyIdentifier();var bc=this.__pC[X];var Y=this.__pB[X];if(bc){switch(X){case f:this._onKeyPressUp(ba);break;case s:this._onKeyPressDown(ba);break;case q:this._onKeyPressLeft(ba);break;case t:this._onKeyPressRight(ba);break;case m:this.hideAll();break;};e.stopPropagation();e.preventDefault();}else if(Y){var bb=ba.getSelectedButton();if(bb){switch(X){case d:this._onKeyPressEnter(ba,bb,e);break;case w:this._onKeyPressSpace(ba,bb,e);break;};e.stopPropagation();e.preventDefault();};};},_onKeyPressUp:function(bh){var bd=bh.getSelectedButton();var be=bh.getChildren();var bf=bd?bh.indexOf(bd)-1:be.length-1;var bg=this._getChild(bh,bf,-1,true);if(bg){bh.setSelectedButton(bg);}else {bh.resetSelectedButton();};},_onKeyPressDown:function(bi){var bj=bi.getSelectedButton();var bl=bj?bi.indexOf(bj)+1:0;var bk=this._getChild(bi,bl,1,true);if(bk){bi.setSelectedButton(bk);}else {bi.resetSelectedButton();};},_onKeyPressLeft:function(bo){var bq=bo.getOpener();if(!bq){return;};if(bq instanceof qx.ui.menu.AbstractButton){var bn=bq.getLayoutParent();bn.resetOpenedButton();bn.setSelectedButton(bq);}else if(bq instanceof qx.ui.menubar.Button){var br=bq.getMenuBar().getMenuButtons();var bm=br.indexOf(bq);if(bm===-1){return;};var bs=null;var length=br.length;for(var i=1;i<=length;i++ ){var bp=br[(bm-i+length)%length];if(bp.isEnabled()&&bp.isVisible()){bs=bp;break;};};if(bs&&bs!=bq){bs.open(true);};};},_onKeyPressRight:function(bw){var bu=bw.getSelectedButton();if(bu){var bt=bu.getMenu();if(bt){bw.setOpenedButton(bu);var bB=this._getChild(bt,0,1);if(bB){bt.setSelectedButton(bB);};return;};}else if(!bw.getOpenedButton()){var bB=this._getChild(bw,0,1);if(bB){bw.setSelectedButton(bB);if(bB.getMenu()){bw.setOpenedButton(bB);};return;};};var by=bw.getOpener();if(by instanceof qx.ui.menu.Button&&bu){while(by){by=by.getLayoutParent();if(by instanceof qx.ui.menu.Menu){by=by.getOpener();if(by instanceof qx.ui.menubar.Button){break;};}else {break;};};if(!by){return;};};if(by instanceof qx.ui.menubar.Button){var bz=by.getMenuBar().getMenuButtons();var bv=bz.indexOf(by);if(bv===-1){return;};var bA=null;var length=bz.length;for(var i=1;i<=length;i++ ){var bx=bz[(bv+i)%length];if(bx.isEnabled()&&bx.isVisible()){bA=bx;break;};};if(bA&&bA!=by){bA.open(true);};};},_onKeyPressEnter:function(bC,bD,e){if(bD.hasListener(c)){var bE=e.clone();bE.setBubbles(false);bE.setTarget(bD);bD.dispatchEvent(bE);};this.hideAll();},_onKeyPressSpace:function(bF,bG,e){if(bG.hasListener(c)){var bH=e.clone();bH.setBubbles(false);bH.setTarget(bG);bG.dispatchEvent(bH);};},_onRoll:function(e){var bI=e.getTarget();bI=qx.ui.core.Widget.getWidgetByElement(bI,true);if(this.__ls.length>0&&!this._isInMenu(bI)&&!this._isMenuOpener(bI)&&!e.getMomentum()){this.hideAll();};}},destruct:function(){var bK=qx.event.Registration;var bJ=document.body;bK.removeListener(window.document.documentElement,n,this._onPointerDown,this,true);bK.removeListener(bJ,p,this._onKeyUpDown,this,true);bK.removeListener(bJ,u,this._onKeyUpDown,this,true);bK.removeListener(bJ,c,this._onKeyPress,this,true);this._disposeObjects(a,l);this._disposeArray(j);}});})();(function(){var a="Boolean",b="pointerover",c="qx.ui.core.Widget",d="excluded",f="selected",g="Integer",h="slidebar",j="menu",k="visible",l="_applySelectedButton",m="_applySpacingY",n="resize",o="_blocker",p="_applyCloseInterval",q="_applyBlockerColor",r="The menu instance needs a configured 'opener' widget!",s="_applyIconColumnWidth",t="qx.ui.menu.Menu",u="_applyOpenedButton",v="Color",w="Number",x="_applyArrowColumnWidth",y="Unknown target: ",z="_applySpacingX",A="_applyBlockerOpacity",B="Could not open menu instance because 'opener' widget is not visible",C="_applyOpenInterval",D="pointerout";qx.Class.define(t,{extend:qx.ui.core.Widget,include:[qx.ui.core.MPlacement,qx.ui.core.MRemoteChildrenHandling],construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.menu.Layout);var E=this.getApplicationRoot();E.add(this);this.addListener(b,this._onPointerOver);this.addListener(D,this._onPointerOut);this.addListener(n,this._onResize,this);E.addListener(n,this._onResize,this);this._blocker=new qx.ui.core.Blocker(E);this.initVisibility();this.initKeepFocus();this.initKeepActive();},properties:{appearance:{refine:true,init:j},allowGrowX:{refine:true,init:false},allowGrowY:{refine:true,init:false},visibility:{refine:true,init:d},keepFocus:{refine:true,init:true},keepActive:{refine:true,init:true},spacingX:{check:g,apply:z,init:0,themeable:true},spacingY:{check:g,apply:m,init:0,themeable:true},iconColumnWidth:{check:g,init:0,themeable:true,apply:s},arrowColumnWidth:{check:g,init:0,themeable:true,apply:x},blockerColor:{check:v,init:null,nullable:true,apply:q,themeable:true},blockerOpacity:{check:w,init:1,apply:A,themeable:true},selectedButton:{check:c,nullable:true,apply:l},openedButton:{check:c,nullable:true,apply:u},opener:{check:c,nullable:true},openInterval:{check:g,themeable:true,init:250,apply:C},closeInterval:{check:g,themeable:true,init:250,apply:p},blockBackground:{check:a,themeable:true,init:false}},members:{__pE:null,__pF:null,_blocker:null,open:function(){if(this.getOpener()!=null){var F=this.placeToWidget(this.getOpener(),true);if(F){this.__pH();this.show();this._placementTarget=this.getOpener();}else {this.warn(B);};}else {this.warn(r);};},openAtPointer:function(e){this.placeToPointer(e);this.__pH();this.show();this._placementTarget={left:e.getDocumentLeft(),top:e.getDocumentTop()};},openAtPoint:function(G){this.placeToPoint(G);this.__pH();this.show();this._placementTarget=G;},addSeparator:function(){this.add(new qx.ui.menu.Separator);},getColumnSizes:function(){return this._getMenuLayout().getColumnSizes();},getSelectables:function(){var H=[];var I=this.getChildren();for(var i=0;i<I.length;i++ ){if(I[i].isEnabled()){H.push(I[i]);};};return H;},_applyIconColumnWidth:function(K,J){this._getMenuLayout().setIconColumnWidth(K);},_applyArrowColumnWidth:function(M,L){this._getMenuLayout().setArrowColumnWidth(M);},_applySpacingX:function(O,N){this._getMenuLayout().setColumnSpacing(O);},_applySpacingY:function(Q,P){this._getMenuLayout().setSpacing(Q);},_applyVisibility:function(T,S){qx.ui.core.Widget.prototype._applyVisibility.call(this,T,S);var R=qx.ui.menu.Manager.getInstance();if(T===k){R.add(this);var U=this.getParentMenu();if(U){U.setOpenedButton(this.getOpener());};}else if(S===k){R.remove(this);var U=this.getParentMenu();if(U&&U.getOpenedButton()==this.getOpener()){U.resetOpenedButton();};this.resetOpenedButton();this.resetSelectedButton();};this.__pG();},__pG:function(){if(this.isVisible()){if(this.getBlockBackground()){var V=this.getZIndex();this._blocker.blockContent(V-1);};}else {if(this._blocker.isBlocked()){this._blocker.unblock();};};},getParentMenu:function(){var W=this.getOpener();if(!W||!(W instanceof qx.ui.menu.AbstractButton)){return null;};if(W&&W.getContextMenu()===this){return null;};while(W&&!(W instanceof qx.ui.menu.Menu)){W=W.getLayoutParent();};return W;},_applySelectedButton:function(Y,X){if(X){X.removeState(f);};if(Y){Y.addState(f);};},_applyOpenedButton:function(bb,ba){if(ba&&ba.getMenu()){ba.getMenu().exclude();};if(bb){bb.getMenu().open();};},_applyBlockerColor:function(bd,bc){this._blocker.setColor(bd);},_applyBlockerOpacity:function(bf,be){this._blocker.setOpacity(bf);},getChildrenContainer:function(){return this.getChildControl(h,true)||this;},_createChildControlImpl:function(bi,bh){var bg;switch(bi){case h:var bg=new qx.ui.menu.MenuSlideBar();var bk=this._getLayout();this._setLayout(new qx.ui.layout.Grow());var bj=bg.getLayout();bg.setLayout(bk);bj.dispose();var bl=qx.lang.Array.clone(this.getChildren());for(var i=0;i<bl.length;i++ ){bg.add(bl[i]);};this.removeListener(n,this._onResize,this);bg.getChildrenContainer().addListener(n,this._onResize,this);this._add(bg);break;};return bg||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,bi);},_getMenuLayout:function(){if(this.hasChildControl(h)){return this.getChildControl(h).getChildrenContainer().getLayout();}else {return this._getLayout();};},_getMenuBounds:function(){if(this.hasChildControl(h)){return this.getChildControl(h).getChildrenContainer().getBounds();}else {return this.getBounds();};},_computePlacementSize:function(){return this._getMenuBounds();},__pH:function(){var bn=this._getMenuBounds();if(!bn){this.addListenerOnce(n,this.__pH,this);return;};var bm=this.getLayoutParent().getBounds().height;var top=this.getLayoutProperties().top;var bo=this.getLayoutProperties().left;if(top<0){this._assertSlideBar(function(){this.setHeight(bn.height+top);this.moveTo(bo,0);});}else if(top+bn.height>bm){this._assertSlideBar(function(){this.setHeight(bm-top);});}else {this.setHeight(null);};},_assertSlideBar:function(bp){if(this.hasChildControl(h)){return bp.call(this);};this.__pF=bp;qx.ui.core.queue.Widget.add(this);},syncWidget:function(bq){this.getChildControl(h);if(this.__pF){this.__pF.call(this);delete this.__pF;};},_onResize:function(){if(this.isVisible()){var br=this._placementTarget;if(!br){return;}else if(br instanceof qx.ui.core.Widget){this.placeToWidget(br,true);}else if(br.top!==undefined){this.placeToPoint(br);}else {throw new Error(y+br);};this.__pH();};},_onPointerOver:function(e){var bt=qx.ui.menu.Manager.getInstance();bt.cancelClose(this);var bu=e.getTarget();if(bu.isEnabled()&&bu instanceof qx.ui.menu.AbstractButton){this.setSelectedButton(bu);var bs=bu.getMenu&&bu.getMenu();if(bs){bs.setOpener(bu);bt.scheduleOpen(bs);this.__pE=bs;}else {var bv=this.getOpenedButton();if(bv){bt.scheduleClose(bv.getMenu());};if(this.__pE){bt.cancelOpen(this.__pE);this.__pE=null;};};}else if(!this.getOpenedButton()){this.resetSelectedButton();};},_onPointerOut:function(e){var bw=qx.ui.menu.Manager.getInstance();if(!qx.ui.core.Widget.contains(this,e.getRelatedTarget())){var bx=this.getOpenedButton();bx?this.setSelectedButton(bx):this.resetSelectedButton();if(bx){bw.cancelClose(bx.getMenu());};if(this.__pE){bw.cancelOpen(this.__pE);};};}},destruct:function(){if(!qx.core.ObjectRegistry.inShutDown){qx.ui.menu.Manager.getInstance().remove(this);};this.getApplicationRoot().removeListener(n,this._onResize,this);this._placementTarget=null;this._disposeObjects(o);}});})();(function(){var a="qx.ui.menu.Layout",b="Integer",c="_applyLayoutChange";qx.Class.define(a,{extend:qx.ui.layout.VBox,properties:{columnSpacing:{check:b,init:0,apply:c},spanColumn:{check:b,init:1,nullable:true,apply:c},iconColumnWidth:{check:b,init:0,themeable:true,apply:c},arrowColumnWidth:{check:b,init:0,themeable:true,apply:c}},members:{__pI:null,_computeSizeHint:function(){var q=this._getLayoutChildren();var o,g,k;var e=this.getSpanColumn();var j=this.__pI=[0,0,0,0];var n=this.getColumnSpacing();var m=0;var f=0;for(var i=0,l=q.length;i<l;i++ ){o=q[i];if(o.isAnonymous()){continue;};g=o.getChildrenSizes();for(var h=0;h<g.length;h++ ){if(e!=null&&h==e&&g[e+1]==0){m=Math.max(m,g[h]);}else {j[h]=Math.max(j[h],g[h]);};};var d=q[i].getInsets();f=Math.max(f,d.left+d.right);};if(e!=null&&j[e]+n+j[e+1]<m){j[e]=m-j[e+1]-n;};if(m==0){k=n*2;}else {k=n*3;};if(j[0]==0){j[0]=this.getIconColumnWidth();};if(j[3]==0){j[3]=this.getArrowColumnWidth();};var p=qx.ui.layout.VBox.prototype._computeSizeHint.call(this).height;return {minHeight:p,height:p,width:qx.lang.Array.sum(j)+f+k};},getColumnSizes:function(){return this.__pI||null;}},destruct:function(){this.__pI=null;}});})();(function(){var a="menu-separator",b="qx.ui.menu.Separator";qx.Class.define(b,{extend:qx.ui.core.Widget,properties:{appearance:{refine:true,init:a},anonymous:{refine:true,init:true}}});})();(function(){var a="Boolean",b="changeIcon",c="changeLabel",d="shortcut",f="_applyMenu",g="submenu",h="changeLocale",i="arrow",j="_applyShowCommandLabel",k="String",l="qx.ui.menu.AbstractButton",m="",n="icon",o="abstract",p="qx.ui.menu.Menu",q="keypress",r="_applyIcon",s="changeShowCommandLabel",t="label",u="changeMenu",v="tap",w="_applyLabel",x="changeCommand";qx.Class.define(l,{extend:qx.ui.core.Widget,include:[qx.ui.core.MExecutable],implement:[qx.ui.form.IExecutable],type:o,construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.menu.ButtonLayout);this.addListener(v,this._onTap);this.addListener(q,this._onKeyPress);this.addListener(x,this._onChangeCommand,this);},properties:{blockToolTip:{refine:true,init:true},label:{check:k,apply:w,nullable:true,event:c},menu:{check:p,apply:f,nullable:true,dereference:true,event:u},icon:{check:k,apply:r,themeable:true,nullable:true,event:b},showCommandLabel:{check:a,apply:j,themeable:true,init:true,event:s}},members:{_createChildControlImpl:function(A,z){var y;switch(A){case n:y=new qx.ui.basic.Image;y.setAnonymous(true);this._add(y,{column:0});break;case t:y=new qx.ui.basic.Label;y.setAnonymous(true);this._add(y,{column:1});break;case d:y=new qx.ui.basic.Label;y.setAnonymous(true);if(!this.getShowCommandLabel()){y.exclude();};this._add(y,{column:2});break;case i:y=new qx.ui.basic.Image;y.setAnonymous(true);this._add(y,{column:3});break;};return y||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,A);},_forwardStates:{selected:1},getChildrenSizes:function(){var B=0,C=0,D=0,H=0;if(this._isChildControlVisible(n)){var I=this.getChildControl(n);B=I.getMarginLeft()+I.getSizeHint().width+I.getMarginRight();};if(this._isChildControlVisible(t)){var F=this.getChildControl(t);C=F.getMarginLeft()+F.getSizeHint().width+F.getMarginRight();};if(this._isChildControlVisible(d)){var E=this.getChildControl(d);D=E.getMarginLeft()+E.getSizeHint().width+E.getMarginRight();};if(this._isChildControlVisible(i)){var G=this.getChildControl(i);H=G.getMarginLeft()+G.getSizeHint().width+G.getMarginRight();};return [B,C,D,H];},_onTap:function(e){if(e.isLeftPressed()){this.execute();qx.ui.menu.Manager.getInstance().hideAll();}else {if(!this.getContextMenu()){qx.ui.menu.Manager.getInstance().preventContextMenuOnce();};};},_onKeyPress:function(e){this.execute();},_onChangeCommand:function(e){var J=e.getData();if(J==null){return;};{var L=e.getOldData();if(!L){qx.locale.Manager.getInstance().addListener(h,this._onChangeLocale,this);};if(!J){qx.locale.Manager.getInstance().removeListener(h,this._onChangeLocale,this);};};var K=J!=null?J.toString():m;this.getChildControl(d).setValue(K);},_onChangeLocale:function(e){var M=this.getCommand();if(M!=null){this.getChildControl(d).setValue(M.toString());};},_applyIcon:function(O,N){if(O){this._showChildControl(n).setSource(O);}else {this._excludeChildControl(n);};},_applyLabel:function(Q,P){if(Q){this._showChildControl(t).setValue(Q);}else {this._excludeChildControl(t);};},_applyMenu:function(S,R){if(R){R.resetOpener();R.removeState(g);};if(S){this._showChildControl(i);S.setOpener(this);S.addState(g);}else {this._excludeChildControl(i);};},_applyShowCommandLabel:function(U,T){if(U){this._showChildControl(d);}else {this._excludeChildControl(d);};}},destruct:function(){this.removeListener(x,this._onChangeCommand,this);if(this.getMenu()){if(!qx.core.ObjectRegistry.inShutDown){this.getMenu().destroy();};};{qx.locale.Manager.getInstance().removeListener(h,this._onChangeLocale,this);};}});})();(function(){var a="middle",b="qx.ui.menu.ButtonLayout",c="left";qx.Class.define(b,{extend:qx.ui.layout.Abstract,members:{verifyLayoutProperty:null,renderLayout:function(g,k,d){var s=this._getLayoutChildren();var e;var o;var j=[];for(var i=0,l=s.length;i<l;i++ ){e=s[i];o=e.getLayoutProperties().column;j[o]=e;};var r=this.__pJ(s[0]);var q=r.getColumnSizes();var m=r.getSpacingX();var t=qx.lang.Array.sum(q)+m*(q.length-1);if(t<g){q[1]+=g-t;};var u=d.left,top=d.top;var n=qx.ui.layout.Util;for(var i=0,l=q.length;i<l;i++ ){e=j[i];if(e){var h=e.getSizeHint();var f=top+n.computeVerticalAlignOffset(e.getAlignY()||a,h.height,k,0,0);var p=n.computeHorizontalAlignOffset(e.getAlignX()||c,h.width,q[i],e.getMarginLeft(),e.getMarginRight());e.renderLayout(u+p,f,h.width,h.height);};if(q[i]>0){u+=q[i]+m;};};},__pJ:function(v){while(!(v instanceof qx.ui.menu.Menu)){v=v.getLayoutParent();};return v;},_computeSizeHint:function(){var y=this._getLayoutChildren();var x=0;var z=0;for(var i=0,l=y.length;i<l;i++ ){var w=y[i].getSizeHint();z+=w.width;x=Math.max(x,w.height);};return {width:z,height:x};}}});})();(function(){var a="button-backward",b="vertical",c="button-forward",d="menu-slidebar",e="qx.ui.menu.MenuSlideBar",f="execute";qx.Class.define(e,{extend:qx.ui.container.SlideBar,construct:function(){qx.ui.container.SlideBar.call(this,b);},properties:{appearance:{refine:true,init:d}},members:{_createChildControlImpl:function(i,h){var g;switch(i){case c:g=new qx.ui.form.HoverButton();g.addListener(f,this._onExecuteForward,this);this._addAt(g,2);break;case a:g=new qx.ui.form.HoverButton();g.addListener(f,this._onExecuteBackward,this);this._addAt(g,0);break;};return g||qx.ui.container.SlideBar.prototype._createChildControlImpl.call(this,i);}}});})();(function(){var a="hovered",b="hover-button",c="pointerover",d="interval",f="__de",g="qx.ui.form.HoverButton",h="Integer",i="pointerout";qx.Class.define(g,{extend:qx.ui.basic.Atom,include:[qx.ui.core.MExecutable],implement:[qx.ui.form.IExecutable],construct:function(j,k){qx.ui.basic.Atom.call(this,j,k);this.addListener(c,this._onPointerOver,this);this.addListener(i,this._onPointerOut,this);this.__de=new qx.event.AcceleratingTimer();this.__de.addListener(d,this._onInterval,this);},properties:{appearance:{refine:true,init:b},interval:{check:h,init:80},firstInterval:{check:h,init:200},minTimer:{check:h,init:20},timerDecrease:{check:h,init:2}},members:{__de:null,_onPointerOver:function(e){if(!this.isEnabled()||e.getTarget()!==this){return;};this.__de.set({interval:this.getInterval(),firstInterval:this.getFirstInterval(),minimum:this.getMinTimer(),decrease:this.getTimerDecrease()}).start();this.addState(a);},_onPointerOut:function(e){this.__de.stop();this.removeState(a);if(!this.isEnabled()||e.getTarget()!==this){return;};},_onInterval:function(){if(this.isEnabled()){this.execute();}else {this.__de.stop();};}},destruct:function(){this._disposeObjects(f);}});})();(function(){var a="hovered",b="inherit",c="pressed",d="mouse",f="qx.ui.menubar.Button",g="keydown",h="menubar-button",i="keyup";qx.Class.define(f,{extend:qx.ui.form.MenuButton,construct:function(k,l,j){qx.ui.form.MenuButton.call(this,k,l,j);this.removeListener(g,this._onKeyDown);this.removeListener(i,this._onKeyUp);},properties:{appearance:{refine:true,init:h},show:{refine:true,init:b},focusable:{refine:true,init:false}},members:{getMenuBar:function(){var parent=this;while(parent){if(parent instanceof qx.ui.toolbar.ToolBar){return parent;};parent=parent.getLayoutParent();};return null;},open:function(m){qx.ui.form.MenuButton.prototype.open.call(this,m);var menubar=this.getMenuBar();if(menubar){menubar._setAllowMenuOpenHover(true);};},_onMenuChange:function(e){var n=this.getMenu();var menubar=this.getMenuBar();if(n.isVisible()){this.addState(c);if(menubar){menubar.setOpenMenu(n);};}else {this.removeState(c);if(menubar&&menubar.getOpenMenu()==n){menubar.resetOpenMenu();menubar._setAllowMenuOpenHover(false);};};},_onPointerUp:function(e){qx.ui.form.MenuButton.prototype._onPointerUp.call(this,e);var o=this.getMenu();if(o&&o.isVisible()&&!this.hasState(c)){this.addState(c);};},_onPointerOver:function(e){this.addState(a);if(this.getMenu()&&e.getPointerType()==d){var menubar=this.getMenuBar();if(menubar&&menubar._isAllowMenuOpenHover()){qx.ui.menu.Manager.getInstance().hideAll();menubar._setAllowMenuOpenHover(true);if(this.isEnabled()){this.open();};};};}}});})();(function(){var a="qx.ui.menu.Button",b="menu-button";qx.Class.define(a,{extend:qx.ui.menu.AbstractButton,construct:function(g,d,f,c){qx.ui.menu.AbstractButton.call(this);if(g!=null){this.setLabel(g);};if(d!=null){this.setIcon(d);};if(f!=null){this.setCommand(f);};if(c!=null){this.setMenu(c);};},properties:{appearance:{refine:true,init:b}},members:{_onTap:function(e){if(e.isLeftPressed()&&this.getMenu()){this.execute();this.getMenu().open();return;};qx.ui.menu.AbstractButton.prototype._onTap.call(this,e);}}});})();(function(){var a="Integer",b="middle",c="qx.ui.toolbar.Part",d="icon",e="label",f="handle",g="left",h="container",j="syncAppearance",k="visible",m="changeShow",n="_applySpacing",o="both",p="toolbar/part",q="right",r="changeChildren";qx.Class.define(c,{extend:qx.ui.core.Widget,include:[qx.ui.core.MRemoteChildrenHandling],construct:function(){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.HBox);this._createChildControl(f);},properties:{appearance:{refine:true,init:p},show:{init:o,check:[o,e,d],inheritable:true,event:m},spacing:{nullable:true,check:a,themeable:true,apply:n}},members:{_createChildControlImpl:function(u,t){var s;switch(u){case f:s=new qx.ui.basic.Image();s.setAlignY(b);this._add(s);break;case h:s=new qx.ui.toolbar.PartContainer();s.addListener(j,this.__pP,this);this._add(s);s.addListener(r,function(){this.__pP();},this);break;};return s||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,u);},getChildrenContainer:function(){return this.getChildControl(h);},_applySpacing:function(x,v){var w=this.getChildControl(h).getLayout();x==null?w.resetSpacing():w.setSpacing(x);},__pP:function(){var y=this.getChildrenContainer().getChildren();y=y.filter(function(z){return z.getVisibility()==k;});for(var i=0;i<y.length;i++ ){if(i==0&&i!=y.length-1){y[i].addState(g);y[i].removeState(q);y[i].removeState(b);}else if(i==y.length-1&&i!=0){y[i].addState(q);y[i].removeState(g);y[i].removeState(b);}else if(i==0&&i==y.length-1){y[i].removeState(g);y[i].removeState(b);y[i].removeState(q);}else {y[i].addState(b);y[i].removeState(q);y[i].removeState(g);};};},addSeparator:function(){this.add(new qx.ui.toolbar.Separator);},getMenuButtons:function(){var B=this.getChildren();var A=[];var C;for(var i=0,l=B.length;i<l;i++ ){C=B[i];if(C instanceof qx.ui.menubar.Button){A.push(C);};};return A;}}});})();(function(){var a='clui.view.list.AbstractTable',b='changeColumnset',c='{0}:{1}',d='value',e='tableModel',f='qx.data.Array',g='visible',h='_applyColumnset',j='HH:mm:ss.SSS',k='changeBubble',l='columnset',m='HHmmssSSS',n='date',o='appear',p='Old columnset: {0}',q='_columnRendererMap',r='New columnset: {0}',s='column-button',t=' ',u=', ',v='old',w='medium',x='abstract';qx.Class.define(a,{extend:clui.view.list.Abstract,type:x,properties:{columnset:{check:f,event:b,apply:h}},construct:function(y,z){clui.view.list.Abstract.call(this,y,z);this._columnRendererMap=this._createColumnRendererMap();},destruct:function(){this._disposeMap(q);},members:{_columnRendererMap:null,_createColumnRendererMap:function(){var C={};var A=[qx.locale.Date.getDateFormat(w),qx.locale.Date.getDateTimeFormat(m,j)].join(t);var B=new qx.ui.table.cellrenderer.Date();B.setDateFormat(new qx.util.format.DateFormat(A));C[n]=B;return C;},_createDataWidget:function(){var E=new clui.view.widget.table.ExtendedColumnTable();E.set({'statusBarVisible':false,'showCellFocusIndicator':false});var D=new clui.view.list.ColumnTree();E.getChildControl(s).setMenu(D);E.bind(e,D,e);this.bind(l,D,l);this.addListenerOnce(o,function(){this.getLayoutParent().add(D);},this);return E;},_onColumnsetChangeBubble:function(event){var G=new clui.util.PropertyChain(event);if(G.isChangeOf(g)){var F=G.getPropertyOwner(g);this._dataWidget.getTableColumnModel().setColumnVisible(this.getColumnset().indexOf(F),event.getData()[d]);}else if(qx.lang.Type.isArray(event.getData()[v])&&event.getData()[v].length){}else {this._updateColumns();};},_applyColumnset:function(I,H){if(H){H.removeListener(k,this._onColumnsetChangeBubble,this);};I.addListener(k,this._onColumnsetChangeBubble,this);this._updateColumns();},__xW:function(J){return c.format(J.getId(),J.getVisible());},_updateColumns:function(){if(!this._dataWidget){return;};this._dataWidget.setSuppressMetaDataChangePropagation(true);try{this.debug(p.format(this.getColumnset().map(this.__xW).join(u)));var M=this._dataWidget.getTableColumnModel();var K=this.getColumnset().copy();kucken.lang.Array.range(M.getOverallColumnCount()).forEach(function(i){this.getColumnset().setItem(i,K.getItem(M.getOverallColumnAtX(i)));},this);K.dispose();this.debug(r.format(this.getColumnset().map(this.__xW).join(u)));this._dataWidget.getTableModel().updateColumns();}finally{this._dataWidget.setSuppressMetaDataChangePropagation(false);};M.setBehavior(new qx.ui.table.columnmodel.resizebehavior.Default());M.getBehavior()._setNumColumns(this.getColumnset().getLength());M.init(this.getColumnset().getLength(),this._dataWidget);var L=M.getBehavior();this.getColumnset().forEach(function(N,O){M.setColumnVisible(O,N.getVisible());L.setWidth(O,N.getWidth());if(N.getRenderer){M.setDataCellRenderer(O,N.getRenderer());}else if(N.getType() in this._columnRendererMap){M.setDataCellRenderer(O,this._columnRendererMap[N.getType()]);};},this);},setTableModel:function(P){this.bind(l,P,l);this._dataWidget.setTableModel(P);this._updateColumns();},getTable:function(){return this.getDataWidget();}}});})();(function(){var a="qx.ui.table.ICellRenderer";qx.Interface.define(a,{members:{createDataCellHtml:function(b,c){return true;}}});})();(function(){var a="qooxdoo-table-cell",b="content",c='</div>',d="nowrap",e="default",f="changeTheme",g="}",h="width:",i=".qooxdoo-table-cell-right { text-align:right } ",j="css.boxsizing",k="css.boxmodel",l="0px 6px",m='<div class="',n="0px",o="height:",p="1px solid ",q=".qooxdoo-table-cell-bold { font-weight:bold } ",r="String",s="} ",t="qx.dyntheme",u='>',v="",w='" ',x="ellipsis",y="content-box",z="px;",A='left:',B="qx.ui.table.cellrenderer.Abstract",C='" style="',D="abstract",E="none",F=".qooxdoo-table-cell {",G="hidden",H="table-column-line",I='px;',J=".qooxdoo-table-cell-italic { font-style:italic} ",K="absolute";qx.Class.define(B,{type:D,implement:qx.ui.table.ICellRenderer,extend:qx.core.Object,construct:function(){qx.core.Object.call(this);var L=qx.ui.table.cellrenderer.Abstract;if(!L.__wg){L.__wg=this.self(arguments);this._createStyleSheet();if(qx.core.Environment.get(t)){qx.theme.manager.Meta.getInstance().addListener(f,this._onChangeTheme,this);};};},properties:{defaultCellStyle:{init:null,check:r,nullable:true}},members:{_onChangeTheme:qx.core.Environment.select(t,{"true":function(){qx.bom.Stylesheet.removeAllRules(qx.ui.table.cellrenderer.Abstract.__wg.stylesheet);this._createStyleSheet();},"false":null}),_insetX:6+6+1,_insetY:0,_createStyleSheet:function(){var M=qx.theme.manager.Color.getInstance();var N=F+qx.bom.element.Style.compile({position:K,top:n,overflow:G,whiteSpace:d,borderRight:p+M.resolve(H),padding:l,cursor:e,textOverflow:x,userSelect:E})+s+i+J+q;if(qx.core.Environment.get(j)){N+=F+qx.bom.element.BoxSizing.compile(y)+g;};qx.ui.table.cellrenderer.Abstract.__wg.stylesheet=qx.bom.Stylesheet.createElement(N);},_getCellClass:function(O){return a;},_getCellStyle:function(P){return P.style||v;},_getCellAttributes:function(Q){return v;},_getContentHtml:function(R){return R.value||v;},_getCellSizeStyle:function(S,W,U,V){var T=v;if(qx.core.Environment.get(k)==b){S-=U;W-=V;};T+=h+Math.max(S,0)+z;T+=o+Math.max(W,0)+z;return T;},createDataCellHtml:function(X,Y){Y.push(m,this._getCellClass(X),C,A,X.styleLeft,I,this._getCellSizeStyle(X.styleWidth,X.styleHeight,this._insetX,this._insetY),this._getCellStyle(X),w,this._getCellAttributes(X),u+this._getContentHtml(X),c);}},destruct:function(){if(qx.core.Environment.get(t)){qx.theme.manager.Meta.getInstance().removeListener(f,this._onChangeTheme,this);};}});})();(function(){var a="Boolean",b="",c="qx.ui.table.cellrenderer.Default",d="number",e=" qooxdoo-table-cell-bold",f=" qooxdoo-table-cell-right",g=" qooxdoo-table-cell-italic",h="string";qx.Class.define(c,{extend:qx.ui.table.cellrenderer.Abstract,statics:{STYLEFLAG_ALIGN_RIGHT:1,STYLEFLAG_BOLD:2,STYLEFLAG_ITALIC:4,_numberFormat:null},properties:{useAutoAlign:{check:a,init:true}},members:{_getStyleFlags:function(i){if(this.getUseAutoAlign()){if(typeof i.value==d){return qx.ui.table.cellrenderer.Default.STYLEFLAG_ALIGN_RIGHT;};};return 0;},_getCellClass:function(j){var k=qx.ui.table.cellrenderer.Abstract.prototype._getCellClass.call(this,j);if(!k){return b;};var l=this._getStyleFlags(j);if(l&qx.ui.table.cellrenderer.Default.STYLEFLAG_ALIGN_RIGHT){k+=f;};if(l&qx.ui.table.cellrenderer.Default.STYLEFLAG_BOLD){k+=e;};if(l&qx.ui.table.cellrenderer.Default.STYLEFLAG_ITALIC){k+=g;};return k;},_getContentHtml:function(m){return qx.bom.String.escape(this._formatValue(m));},_formatValue:function(n){var p=n.value;var o;if(p==null){return b;};if(typeof p==h){return p;}else if(typeof p==d){if(!qx.ui.table.cellrenderer.Default._numberFormat){qx.ui.table.cellrenderer.Default._numberFormat=new qx.util.format.NumberFormat();qx.ui.table.cellrenderer.Default._numberFormat.setMaximumFractionDigits(2);};o=qx.ui.table.cellrenderer.Default._numberFormat.format(p);}else if(p instanceof Date){o=qx.util.format.DateFormat.getDateInstance().format(p);}else {o=p.toString();};return o;}}});})();(function(){var a="regex cannot be null!",b="font-weight",c="==",d="Condition not recognized or value1/value2 is null!",e="Condition not recognized or value is null!",f="",g=">",h="text-align",j="between",k="<",l=";",m='g',n="regex",o=":",p="qx.ui.table.cellrenderer.Conditional",q="!between",r=">=",s="color",t="font-style",u="!=",v="<=";qx.Class.define(p,{extend:qx.ui.table.cellrenderer.Default,construct:function(y,w,x,z){qx.ui.table.cellrenderer.Default.call(this);this.numericAllowed=[c,u,g,k,r,v];this.betweenAllowed=[j,q];this.conditions=[];this.__wh=y||f;this.__wi=w||f;this.__wj=x||f;this.__wk=z||f;},members:{__wh:null,__wi:null,__wj:null,__wk:null,__wl:function(B,A){if(B[1]!=null){A[h]=B[1];};if(B[2]!=null){A[s]=B[2];};if(B[3]!=null){A[t]=B[3];};if(B[4]!=null){A[b]=B[4];};},addNumericCondition:function(J,I,G,F,C,E,D){var H=null;if(qx.lang.Array.contains(this.numericAllowed,J)){if(I!=null){H=[J,G,F,C,E,I,D];};};if(H!=null){this.conditions.push(H);}else {throw new Error(e);};},addBetweenCondition:function(R,Q,S,O,N,K,M,L){if(qx.lang.Array.contains(this.betweenAllowed,R)){if(Q!=null&&S!=null){var P=[R,O,N,K,M,Q,S,L];};};if(P!=null){this.conditions.push(P);}else {throw new Error(d);};},addRegex:function(T,Y,X,U,W,V){if(T!=null){var ba=[n,Y,X,U,W,T,V];};if(ba!=null){this.conditions.push(ba);}else {throw new Error(a);};},_getCellStyle:function(bi){var bf=bi.table.getTableModel();var i;var be;var bb;var bd={"text-align":this.__wh,"color":this.__wi,"font-style":this.__wj,"font-weight":this.__wk};for(i in this.conditions){be=false;if(qx.lang.Array.contains(this.numericAllowed,this.conditions[i][0])){if(this.conditions[i][6]==null){bb=bi.value;}else {bb=bf.getValueById(this.conditions[i][6],bi.row);};switch(this.conditions[i][0]){case c:if(bb==this.conditions[i][5]){be=true;};break;case u:if(bb!=this.conditions[i][5]){be=true;};break;case g:if(bb>this.conditions[i][5]){be=true;};break;case k:if(bb<this.conditions[i][5]){be=true;};break;case r:if(bb>=this.conditions[i][5]){be=true;};break;case v:if(bb<=this.conditions[i][5]){be=true;};break;};}else if(qx.lang.Array.contains(this.betweenAllowed,this.conditions[i][0])){if(this.conditions[i][7]==null){bb=bi.value;}else {bb=bf.getValueById(this.conditions[i][7],bi.row);};switch(this.conditions[i][0]){case j:if(bb>=this.conditions[i][5]&&bb<=this.conditions[i][6]){be=true;};break;case q:if(bb<this.conditions[i][5]||bb>this.conditions[i][6]){be=true;};break;};}else if(this.conditions[i][0]==n){if(this.conditions[i][6]==null){bb=bi.value;}else {bb=bf.getValueById(this.conditions[i][6],bi.row);};var bc=new RegExp(this.conditions[i][5],m);be=bc.test(bb);};if(be==true){this.__wl(this.conditions[i],bd);};};var bg=[];for(var bh in bd){if(bd[bh]){bg.push(bh,o,bd[bh],l);};};return bg.join(f);}},destruct:function(){this.numericAllowed=this.betweenAllowed=this.conditions=null;}});})();(function(){var a="qx.util.format.DateFormat",b="qooxdoo-table-cell",c="qx.ui.table.cellrenderer.Date",d="";qx.Class.define(c,{extend:qx.ui.table.cellrenderer.Conditional,properties:{dateFormat:{check:a,init:null,nullable:true}},members:{_getContentHtml:function(e){var f=this.getDateFormat();if(f){if(e.value){return qx.bom.String.escape(f.format(e.value));}else {return d;};}else {return e.value||d;};},_getCellClass:function(g){return b;}}});})();(function(){var a="_applyStatusBarVisible",b="columnVisibilityMenuCreateStart",c="function",d="blur",f="qx.ui.table.Table",g="Boolean",h="_applyFocusCellOnPointerMove",k="columnVisibilityMenuCreateEnd",m="changeVisible",n="verticalScrollBarChanged",o="_applyMetaColumnCounts",p="PageUp",q="focus",r="changeDataRowRenderer",s="dataChanged",t="changeHeaderCellHeight",u="Escape",v="A",w="changeSelectionModel",y="__de",z="Left",A="Down",B="Integer",C="_applyHeaderCellHeight",D="qx.event.type.Data",E="__wv",F="statusbar",G="Function",H="menu",I="qx.ui.table.ITableModel",J="column-button",K="_applySelectionModel",L="changeLocale",M="__wn",N="menu-button",O="_applyResetSelectionOnHeaderTap",P="_applyAdditionalStatusBarText",Q="table",R="_applyColumnVisibilityButtonVisible",S="changeTableModel",T="qx.event.type.Event",U="tableWidthChanged",V="changeSelection",W="_applyHeaderCellsVisible",X="Object",Y="_applyShowCellFocusIndicator",bP="resize",bQ="__wm",bR="changeScrollY",bL="_applyTableModel",bM="End",bN="_applyKeepFirstVisibleRowComplete",bO="widthChanged",bV="one of one row",bW="Home",bX="_applyRowHeight",cq="F2",bS="appear",bT="visibilityChanged",bU="%1 rows",bI="qx.ui.table.selection.Model",co='"',bK="one row",cb="PageDown",cc="%1 of %2 rows",bJ="__wt",bY="keypress",cm="changeRowHeight",ca="Up",cd="Enter",ce="Number",cf="metaDataChanged",cj="header",ck="_applyContextMenuFromDataCellsOnly",cn="qx.ui.table.IRowRenderer",cp="__wu",cg="Right",ch="orderChanged",ci="qx.ui.table.pane.CellEvent",cl="Space";qx.Class.define(f,{extend:qx.ui.core.Widget,include:qx.ui.core.MDragDropScrolling,construct:function(cr,ct){qx.ui.core.Widget.call(this);if(!ct){ct={};};if(ct.initiallyHiddenColumns){this.setInitiallyHiddenColumns(ct.initiallyHiddenColumns);};if(ct.selectionManager){this.setNewSelectionManager(ct.selectionManager);};if(ct.selectionModel){this.setNewSelectionModel(ct.selectionModel);};if(ct.tableColumnModel){this.setNewTableColumnModel(ct.tableColumnModel);};if(ct.tablePane){this.setNewTablePane(ct.tablePane);};if(ct.tablePaneHeader){this.setNewTablePaneHeader(ct.tablePaneHeader);};if(ct.tablePaneScroller){this.setNewTablePaneScroller(ct.tablePaneScroller);};if(ct.tablePaneModel){this.setNewTablePaneModel(ct.tablePaneModel);};if(ct.columnMenu){this.setNewColumnMenu(ct.columnMenu);};this._setLayout(new qx.ui.layout.VBox());this.__wm=new qx.ui.container.Composite(new qx.ui.layout.HBox());this._add(this.__wm,{flex:1});this.setDataRowRenderer(new qx.ui.table.rowrenderer.Default(this));this.__wn=this.getNewSelectionManager()(this);this.setSelectionModel(this.getNewSelectionModel()(this));this.setTableModel(cr||this.getEmptyTableModel());this.setMetaColumnCounts([-1]);this.setTabIndex(1);this.addListener(bY,this._onKeyPress);this.addListener(q,this._onFocusChanged);this.addListener(d,this._onFocusChanged);var cs=new qx.ui.core.Widget().set({height:0});this._add(cs);cs.addListener(bP,this._onResize,this);this.__wo=null;this.__wp=null;{qx.locale.Manager.getInstance().addListener(L,this._onChangeLocale,this);};this.initStatusBarVisible();cr=this.getTableModel();if(cr.init&&typeof (cr.init)==c){cr.init(this);};},events:{"columnVisibilityMenuCreateStart":D,"columnVisibilityMenuCreateEnd":D,"tableWidthChanged":T,"verticalScrollBarChanged":D,"cellTap":ci,"cellDbltap":ci,"cellContextmenu":ci,"dataEdited":D},statics:{__wq:{cellTap:1,cellDbltap:1,cellContextmenu:1}},properties:{appearance:{refine:true,init:Q},focusable:{refine:true,init:true},minWidth:{refine:true,init:50},initiallyHiddenColumns:{init:null},selectable:{refine:true,init:false},selectionModel:{check:bI,apply:K,event:w},tableModel:{check:I,apply:bL,event:S},rowHeight:{check:ce,init:20,apply:bX,event:cm,themeable:true},forceLineHeight:{check:g,init:true},headerCellsVisible:{check:g,init:true,apply:W,themeable:true},headerCellHeight:{check:B,init:16,apply:C,event:t,nullable:true,themeable:true},statusBarVisible:{check:g,init:true,apply:a},additionalStatusBarText:{nullable:true,init:null,apply:P},columnVisibilityButtonVisible:{check:g,init:true,apply:R,themeable:true},metaColumnCounts:{check:X,apply:o},focusCellOnPointerMove:{check:g,init:false,apply:h},rowFocusChangeModifiesSelection:{check:g,init:true},showCellFocusIndicator:{check:g,init:true,apply:Y},contextMenuFromDataCellsOnly:{check:g,init:true,apply:ck},keepFirstVisibleRowComplete:{check:g,init:true,apply:bN},alwaysUpdateCells:{check:g,init:false},resetSelectionOnHeaderTap:{check:g,init:true,apply:O},dataRowRenderer:{check:cn,init:null,nullable:true,event:r},modalCellEditorPreOpenFunction:{check:G,init:null,nullable:true},newColumnMenu:{check:G,init:function(){return new qx.ui.table.columnmenu.Button();}},newSelectionManager:{check:G,init:function(cu){return new qx.ui.table.selection.Manager(cu);}},newSelectionModel:{check:G,init:function(cv){return new qx.ui.table.selection.Model(cv);}},newTableColumnModel:{check:G,init:function(cw){return new qx.ui.table.columnmodel.Basic(cw);}},newTablePane:{check:G,init:function(cx){return new qx.ui.table.pane.Pane(cx);}},newTablePaneHeader:{check:G,init:function(cy){return new qx.ui.table.pane.Header(cy);}},newTablePaneScroller:{check:G,init:function(cz){return new qx.ui.table.pane.Scroller(cz);}},newTablePaneModel:{check:G,init:function(cA){return new qx.ui.table.pane.Model(cA);}}},members:{__wo:null,__wp:null,__wm:null,__wn:null,__wr:null,__ws:null,__wf:null,__wt:null,__wu:null,__wv:null,__ww:null,__de:null,_createChildControlImpl:function(cE,cD){var cB;switch(cE){case F:cB=new qx.ui.basic.Label();cB.set({allowGrowX:true});this._add(cB);break;case J:cB=this.getNewColumnMenu()();cB.set({focusable:false});var cC=cB.factory(H,{table:this});cC.addListener(bS,this._initColumnMenu,this);break;};return cB||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,cE);},_applySelectionModel:function(cG,cF){this.__wn.setSelectionModel(cG);if(cF!=null){cF.removeListener(V,this._onSelectionChanged,this);};cG.addListener(V,this._onSelectionChanged,this);},_applyRowHeight:function(cJ,cI){var cH=this._getPaneScrollerArr();for(var i=0;i<cH.length;i++ ){cH[i].updateVerScrollBarMaximum();};},_applyHeaderCellsVisible:function(cM,cL){var cK=this._getPaneScrollerArr();for(var i=0;i<cK.length;i++ ){if(cM){cK[i]._showChildControl(cj);}else {cK[i]._excludeChildControl(cj);};};if(this.getColumnVisibilityButtonVisible()){this._applyColumnVisibilityButtonVisible(cM);};},_applyHeaderCellHeight:function(cP,cO){var cN=this._getPaneScrollerArr();for(var i=0;i<cN.length;i++ ){cN[i].getHeader().setHeight(cP);};},getEmptyTableModel:function(){if(!this.__wv){this.__wv=new qx.ui.table.model.Simple();this.__wv.setColumns([]);this.__wv.setData([]);};return this.__wv;},_applyTableModel:function(cR,cQ){this.getTableColumnModel().init(cR.getColumnCount(),this);if(cQ!=null){cQ.removeListener(cf,this._onTableModelMetaDataChanged,this);cQ.removeListener(s,this._onTableModelDataChanged,this);};cR.addListener(cf,this._onTableModelMetaDataChanged,this);cR.addListener(s,this._onTableModelDataChanged,this);this._updateStatusBar();this._updateTableData(0,cR.getRowCount(),0,cR.getColumnCount());this._onTableModelMetaDataChanged();if(cQ&&cR.init&&typeof (cR.init)==c){cR.init(this);};},getTableColumnModel:function(){if(!this.__wu){var cV=this.__wu=this.getNewTableColumnModel()(this);cV.addListener(bT,this._onColVisibilityChanged,this);cV.addListener(bO,this._onColWidthChanged,this);cV.addListener(ch,this._onColOrderChanged,this);var cT=this.getTableModel();cV.init(cT.getColumnCount(),this);var cS=this._getPaneScrollerArr();for(var i=0;i<cS.length;i++ ){var cW=cS[i];var cU=cW.getTablePaneModel();cU.setTableColumnModel(cV);};};return this.__wu;},_applyStatusBarVisible:function(cY,cX){if(cY){this._showChildControl(F);}else {this._excludeChildControl(F);};if(cY){this._updateStatusBar();};},_applyAdditionalStatusBarText:function(db,da){this.__wr=db;this._updateStatusBar();},_applyColumnVisibilityButtonVisible:function(dd,dc){if(dd){this._showChildControl(J);}else {this._excludeChildControl(J);};},_applyMetaColumnCounts:function(dm,dh){var dl=dm;var de=this._getPaneScrollerArr();var dj={};if(dm>dh){var dp=qx.event.Registration.getManager(de[0]);for(var dg in qx.ui.table.Table.__wq){dj[dg]={};dj[dg].capture=dp.getListeners(de[0],dg,true);dj[dg].bubble=dp.getListeners(de[0],dg,false);};};this._cleanUpMetaColumns(dl.length);var dk=0;for(var i=0;i<de.length;i++ ){var dr=de[i];var dn=dr.getTablePaneModel();dn.setFirstColumnX(dk);dn.setMaxColumnCount(dl[i]);dk+=dl[i];};if(dl.length>de.length){var dq=this.getTableColumnModel();for(var i=de.length;i<dl.length;i++ ){var dn=this.getNewTablePaneModel()(dq);dn.setFirstColumnX(dk);dn.setMaxColumnCount(dl[i]);dk+=dl[i];var dr=this.getNewTablePaneScroller()(this);dr.setTablePaneModel(dn);dr.addListener(bR,this._onScrollY,this);for(dg in qx.ui.table.Table.__wq){if(!dj[dg]){break;};if(dj[dg].capture&&dj[dg].capture.length>0){var df=dj[dg].capture;for(var j=0;j<df.length;j++ ){var di=df[j].context;if(!di){di=this;}else if(di==de[0]){di=dr;};dr.addListener(dg,df[j].handler,di,true);};};if(dj[dg].bubble&&dj[dg].bubble.length>0){var dt=dj[dg].bubble;for(var j=0;j<dt.length;j++ ){var di=dt[j].context;if(!di){di=this;}else if(di==de[0]){di=dr;};dr.addListener(dg,dt[j].handler,di,false);};};};var ds=(i==dl.length-1)?1:0;this.__wm.add(dr,{flex:ds});de=this._getPaneScrollerArr();};};for(var i=0;i<de.length;i++ ){var dr=de[i];var du=(i==(de.length-1));dr.getHeader().setHeight(this.getHeaderCellHeight());dr.setTopRightWidget(du?this.getChildControl(J):null);};if(!this.isColumnVisibilityButtonVisible()){this._excludeChildControl(J);};this._updateScrollerWidths();this._updateScrollBarVisibility();},_applyFocusCellOnPointerMove:function(dx,dw){var dv=this._getPaneScrollerArr();for(var i=0;i<dv.length;i++ ){dv[i].setFocusCellOnPointerMove(dx);};},_applyShowCellFocusIndicator:function(dA,dz){var dy=this._getPaneScrollerArr();for(var i=0;i<dy.length;i++ ){dy[i].setShowCellFocusIndicator(dA);};},_applyContextMenuFromDataCellsOnly:function(dD,dC){var dB=this._getPaneScrollerArr();for(var i=0;i<dB.length;i++ ){dB[i].setContextMenuFromDataCellsOnly(dD);};},_applyKeepFirstVisibleRowComplete:function(dG,dF){var dE=this._getPaneScrollerArr();for(var i=0;i<dE.length;i++ ){dE[i].onKeepFirstVisibleRowCompleteChanged();};},_applyResetSelectionOnHeaderTap:function(dJ,dI){var dH=this._getPaneScrollerArr();for(var i=0;i<dH.length;i++ ){dH[i].setResetSelectionOnHeaderTap(dJ);};},getSelectionManager:function(){return this.__wn;},_getPaneScrollerArr:function(){return this.__wm.getChildren();},getPaneScroller:function(dK){return this._getPaneScrollerArr()[dK];},_cleanUpMetaColumns:function(dM){var dL=this._getPaneScrollerArr();if(dL!=null){for(var i=dL.length-1;i>=dM;i-- ){dL[i].destroy();};};},_onChangeLocale:function(dN){this.updateContent();this._updateStatusBar();},_onChangeTheme:function(){qx.ui.core.Widget.prototype._onChangeTheme.call(this);this.getDataRowRenderer().initThemeValues();this.updateContent();this._updateStatusBar();},_onSelectionChanged:function(dP){var dO=this._getPaneScrollerArr();for(var i=0;i<dO.length;i++ ){dO[i].onSelectionChanged();};this._updateStatusBar();},_onTableModelMetaDataChanged:function(dR){var dQ=this._getPaneScrollerArr();for(var i=0;i<dQ.length;i++ ){dQ[i].onTableModelMetaDataChanged();};this._updateStatusBar();},_onTableModelDataChanged:function(dS){var dT=dS.getData();this._updateTableData(dT.firstRow,dT.lastRow,dT.firstColumn,dT.lastColumn,dT.removeStart,dT.removeCount);},_onContextMenuOpen:function(e){},_updateTableData:function(dY,ec,dW,dV,dX,eb){var dU=this._getPaneScrollerArr();if(eb){this.getSelectionModel().removeSelectionInterval(dX,dX+eb);if(this.__wp>=dX&&this.__wp<(dX+eb)){this.setFocusedCell();};};for(var i=0;i<dU.length;i++ ){dU[i].onTableModelDataChanged(dY,ec,dW,dV);};var ea=this.getTableModel().getRowCount();if(ea!=this.__ws){this.__ws=ea;this._updateScrollBarVisibility();this._updateStatusBar();};},_onScrollY:function(ee){if(!this.__wf){this.__wf=true;var ed=this._getPaneScrollerArr();for(var i=0;i<ed.length;i++ ){ed[i].setScrollY(ee.getData());};this.__wf=false;};},_onKeyPress:function(en){if(!this.getEnabled()){return;};var el=this.__wp;var ei=true;var em=en.getKeyIdentifier();if(this.isEditing()){if(en.getModifiers()==0){switch(em){case cd:this.stopEditing();var el=this.__wp;this.moveFocusedCell(0,1);if(this.__wp!=el){ei=this.startEditing();};break;case u:this.cancelEditing();this.focus();break;default:ei=false;break;};};}else {if(en.isCtrlPressed()){ei=true;switch(em){case v:var ej=this.getTableModel().getRowCount();if(ej>0){this.getSelectionModel().setSelectionInterval(0,ej-1);};break;default:ei=false;break;};}else {switch(em){case cl:this.__wn.handleSelectKeyDown(this.__wp,en);break;case cq:case cd:this.startEditing();ei=true;break;case bW:this.setFocusedCell(this.__wo,0,true);break;case bM:var ej=this.getTableModel().getRowCount();this.setFocusedCell(this.__wo,ej-1,true);break;case z:this.moveFocusedCell(-1,0);break;case cg:this.moveFocusedCell(1,0);break;case ca:this.moveFocusedCell(0,-1);break;case A:this.moveFocusedCell(0,1);break;case p:case cb:var eh=this.getPaneScroller(0);var ek=eh.getTablePane();var eg=this.getRowHeight();var ef=(em==p)?-1:1;ej=ek.getVisibleRowCount()-1;eh.setScrollY(eh.getScrollY()+ef*ej*eg);this.moveFocusedCell(0,ef*ej);break;default:ei=false;};};};if(el!=this.__wp&&this.getRowFocusChangeModifiesSelection()){this.__wn.handleMoveKeyDown(this.__wp,en);};if(ei){en.preventDefault();en.stopPropagation();};},_onFocusChanged:function(ep){var eo=this._getPaneScrollerArr();for(var i=0;i<eo.length;i++ ){eo[i].onFocusChanged();};},_onColVisibilityChanged:function(er){var eq=this._getPaneScrollerArr();for(var i=0;i<eq.length;i++ ){eq[i].onColVisibilityChanged();};var es=er.getData();if(this.__wt!=null&&es.col!=null&&es.visible!=null){this.__wt[es.col].setVisible(es.visible);};this._updateScrollerWidths();this._updateScrollBarVisibility();},_onColWidthChanged:function(eu){var et=this._getPaneScrollerArr();for(var i=0;i<et.length;i++ ){var ev=eu.getData();et[i].setColumnWidth(ev.col,ev.newWidth);};this._updateScrollerWidths();this._updateScrollBarVisibility();},_onColOrderChanged:function(ex){var ew=this._getPaneScrollerArr();for(var i=0;i<ew.length;i++ ){ew[i].onColOrderChanged();};this._updateScrollerWidths();this._updateScrollBarVisibility();},getTablePaneScrollerAtPageX:function(ez){var ey=this._getMetaColumnAtPageX(ez);return (ey!=-1)?this.getPaneScroller(ey):null;},setFocusedCell:function(eC,eD,eB){if(!this.isEditing()&&(eC!=this.__wo||eD!=this.__wp)){if(eC===null){eC=0;};this.__wo=eC;this.__wp=eD;var eA=this._getPaneScrollerArr();for(var i=0;i<eA.length;i++ ){eA[i].setFocusedCell(eC,eD);};if(eC!=null&&eB){this.scrollCellVisible(eC,eD);};};},resetSelection:function(){this.getSelectionModel().resetSelection();},resetCellFocus:function(){this.setFocusedCell(null,null,false);},getFocusedColumn:function(){return this.__wo;},getFocusedRow:function(){return this.__wp;},highlightFocusedRow:function(eE){this.getDataRowRenderer().setHighlightFocusRow(eE);},clearFocusedRowHighlight:function(eG){if(eG){var eH=eG.getRelatedTarget();if(eH instanceof qx.ui.table.pane.Pane||eH instanceof qx.ui.table.pane.FocusIndicator){return;};};this.resetCellFocus();var eF=this._getPaneScrollerArr();for(var i=0;i<eF.length;i++ ){eF[i].onFocusChanged();};},moveFocusedCell:function(eI,eJ){var eN=this.__wo;var eO=this.__wp;if(eN==null||eO==null){return;};if(eI!=0){var eM=this.getTableColumnModel();var x=eM.getVisibleX(eN);var eL=eM.getVisibleColumnCount();x=qx.lang.Number.limit(x+eI,0,eL-1);eN=eM.getVisibleColumnAtX(x);};if(eJ!=0){var eK=this.getTableModel();eO=qx.lang.Number.limit(eO+eJ,0,eK.getRowCount()-1);};this.setFocusedCell(eN,eO,true);},scrollCellVisible:function(eS,eT){var eQ=this.getContentElement().getDomElement();if(!eQ){this.addListenerOnce(bS,function(){this.scrollCellVisible(eS,eT);},this);};var eR=this.getTableColumnModel();var x=eR.getVisibleX(eS);var eP=this._getMetaColumnAtColumnX(x);if(eP!=-1){this.getPaneScroller(eP).scrollCellVisible(eS,eT);};},isEditing:function(){if(this.__wo!=null){var x=this.getTableColumnModel().getVisibleX(this.__wo);var eU=this._getMetaColumnAtColumnX(x);return this.getPaneScroller(eU).isEditing();};return false;},startEditing:function(){if(this.__wo!=null){var x=this.getTableColumnModel().getVisibleX(this.__wo);var eW=this._getMetaColumnAtColumnX(x);var eV=this.getPaneScroller(eW).startEditing();return eV;};return false;},stopEditing:function(){if(this.__wo!=null){var x=this.getTableColumnModel().getVisibleX(this.__wo);var eX=this._getMetaColumnAtColumnX(x);this.getPaneScroller(eX).stopEditing();};},cancelEditing:function(){if(this.__wo!=null){var x=this.getTableColumnModel().getVisibleX(this.__wo);var eY=this._getMetaColumnAtColumnX(x);this.getPaneScroller(eY).cancelEditing();};},updateContent:function(){var fa=this._getPaneScrollerArr();for(var i=0;i<fa.length;i++ ){fa[i].getTablePane().updateContent(true);};},blockHeaderElements:function(){var fb=this._getPaneScrollerArr();for(var i=0;i<fb.length;i++ ){fb[i].getHeader().getBlocker().blockContent(20);};this.getChildControl(J).getBlocker().blockContent(20);},unblockHeaderElements:function(){var fc=this._getPaneScrollerArr();for(var i=0;i<fc.length;i++ ){fc[i].getHeader().getBlocker().unblock();};this.getChildControl(J).getBlocker().unblock();},_getMetaColumnAtPageX:function(ff){var fd=this._getPaneScrollerArr();for(var i=0;i<fd.length;i++ ){var fe=fd[i].getContentLocation();if(ff>=fe.left&&ff<=fe.right){return i;};};return -1;},_getMetaColumnAtColumnX:function(fh){var fi=this.getMetaColumnCounts();var fj=0;for(var i=0;i<fi.length;i++ ){var fg=fi[i];fj+=fg;if(fg==-1||fh<fj){return i;};};return -1;},_updateStatusBar:function(){var fk=this.getTableModel();if(this.getStatusBarVisible()){var fl=this.getSelectionModel().getSelectedCount();var fm=fk.getRowCount();var fn;if(fm>=0){if(fl==0){fn=this.trn(bK,bU,fm,fm);}else {fn=this.trn(bV,cc,fm,fl,fm);};};if(this.__wr){if(fn){fn+=this.__wr;}else {fn=this.__wr;};};if(fn){this.getChildControl(F).setValue(fn);};};},_updateScrollerWidths:function(){var fo=this._getPaneScrollerArr();for(var i=0;i<fo.length;i++ ){var fq=(i==(fo.length-1));var fr=fo[i].getTablePaneModel().getTotalWidth();fo[i].setPaneWidth(fr);var fp=fq?1:0;fo[i].setLayoutProperties({flex:fp});};},_updateScrollBarVisibility:function(){if(!this.getBounds()){return;};var fv=qx.ui.table.pane.Scroller.HORIZONTAL_SCROLLBAR;var fx=qx.ui.table.pane.Scroller.VERTICAL_SCROLLBAR;var fs=this._getPaneScrollerArr();var fu=false;var fw=false;for(var i=0;i<fs.length;i++ ){var fy=(i==(fs.length-1));var ft=fs[i].getNeededScrollBars(fu,!fy);if(ft&fv){fu=true;};if(fy&&(ft&fx)){fw=true;};};for(var i=0;i<fs.length;i++ ){var fy=(i==(fs.length-1));fs[i].setHorizontalScrollBarVisible(fu);if(fy){if(this.__ww==null){this.__ww=fs[i].getVerticalScrollBarVisible();this.__de=qx.event.Timer.once(function(){this.__ww=null;this.__de=null;},this,0);};};fs[i].setVerticalScrollBarVisible(fy&&fw);if(fy&&fw!=this.__ww){this.fireDataEvent(n,fw);};};},_initColumnMenu:function(){var fB=this.getTableModel();var fC=this.getTableColumnModel();var fD=this.getChildControl(J);fD.empty();var fA=fD.getMenu();var fE={table:this,menu:fA,columnButton:fD};this.fireDataEvent(b,fE);this.__wt={};for(var fF=0,l=fB.getColumnCount();fF<l;fF++ ){var fz=fD.factory(N,{text:fB.getColumnName(fF),column:fF,bVisible:fC.isColumnVisible(fF)});qx.core.Assert.assertInterface(fz,qx.ui.table.IColumnMenuItem);fz.addListener(m,this._createColumnVisibilityCheckBoxHandler(fF),this);this.__wt[fF]=fz;};fE={table:this,menu:fA,columnButton:fD};this.fireDataEvent(k,fE);},_createColumnVisibilityCheckBoxHandler:function(fG){return function(fH){var fI=this.getTableColumnModel();fI.setColumnVisible(fG,fH.getData());};},setColumnWidth:function(fK,fJ){this.getTableColumnModel().setColumnWidth(fK,fJ);},_onResize:function(){this.fireEvent(U);this._updateScrollerWidths();this._updateScrollBarVisibility();},addListener:function(fO,fN,self,fL){if(this.self(arguments).__wq[fO]){var fP=[fO];for(var i=0,fM=this._getPaneScrollerArr();i<fM.length;i++ ){fP.push(fM[i].addListener.apply(fM[i],arguments));};return fP.join(co);}else {return qx.ui.core.Widget.prototype.addListener.call(this,fO,fN,self,fL);};},removeListener:function(fT,fS,self,fQ){if(this.self(arguments).__wq[fT]){for(var i=0,fR=this._getPaneScrollerArr();i<fR.length;i++ ){fR[i].removeListener.apply(fR[i],arguments);};}else {qx.ui.core.Widget.prototype.removeListener.call(this,fT,fS,self,fQ);};},removeListenerById:function(fY){var fV=fY.split(co);var fX=fV.shift();if(this.self(arguments).__wq[fX]){var fW=true;for(var i=0,fU=this._getPaneScrollerArr();i<fU.length;i++ ){fW=fU[i].removeListenerById.call(fU[i],fV[i])&&fW;};return fW;}else {return qx.ui.core.Widget.prototype.removeListenerById.call(this,fY);};},destroy:function(){this.getChildControl(J).getMenu().destroy();qx.ui.core.Widget.prototype.destroy.call(this);}},destruct:function(){{qx.locale.Manager.getInstance().removeListener(L,this._onChangeLocale,this);};var gb=this.getSelectionModel();if(gb){gb.dispose();};var ga=this.getDataRowRenderer();if(ga){ga.dispose();};this._cleanUpMetaColumns(0);this.getTableColumnModel().dispose();this._disposeObjects(M,bQ,E,E,cp,y);this._disposeMap(bJ);}});})();(function(){var a="qx.ui.table.IRowRenderer";qx.Interface.define(a,{members:{updateDataRowElement:function(c,b){},getRowHeightStyle:function(d){},createRowStyle:function(e){},getRowClass:function(f){}}});})();(function(){var a="table-row-background-even",b="Boolean",c="content",d="default",e="height:",f="changeTheme",g="'",h="table-row",i="table-row-background-focused",j="css.boxmodel",k=';color:',l="table-row-background-odd",m="1px solid ",n="table-row-line",o="qx.dyntheme",p="table-row-background-selected",q="background-color:",r="",s=';border-bottom: 1px solid ',t="table-row-selected",u="table-row-background-focused-selected",v="px;",w="qx.ui.table.rowrenderer.Default",x=";";qx.Class.define(w,{extend:qx.core.Object,implement:qx.ui.table.IRowRenderer,construct:function(){qx.core.Object.call(this);this.initThemeValues();if(qx.core.Environment.get(o)){qx.theme.manager.Meta.getInstance().addListener(f,this.initThemeValues,this);};},properties:{highlightFocusRow:{check:b,init:true}},members:{_colors:null,__wx:null,__wy:null,initThemeValues:function(){this.__wy=r;this.__wx={};this._colors={};this._renderFont(qx.theme.manager.Font.getInstance().resolve(d));var y=qx.theme.manager.Color.getInstance();this._colors.bgcolFocusedSelected=y.resolve(u);this._colors.bgcolFocused=y.resolve(i);this._colors.bgcolSelected=y.resolve(p);this._colors.bgcolEven=y.resolve(a);this._colors.bgcolOdd=y.resolve(l);this._colors.colSelected=y.resolve(t);this._colors.colNormal=y.resolve(h);this._colors.horLine=y.resolve(n);},_insetY:1,_renderFont:function(z){if(z){this.__wx=z.getStyles();this.__wy=qx.bom.element.Style.compile(this.__wx);this.__wy=this.__wy.replace(/"/g,g);}else {this.__wy=r;this.__wx=qx.bom.Font.getDefaultStyles();};},updateDataRowElement:function(D,A){var B=this.__wx;var C=A.style;qx.bom.element.Style.setStyles(A,B);if(D.focusedRow&&this.getHighlightFocusRow()){C.backgroundColor=D.selected?this._colors.bgcolFocusedSelected:this._colors.bgcolFocused;}else {if(D.selected){C.backgroundColor=this._colors.bgcolSelected;}else {C.backgroundColor=(D.row%2==0)?this._colors.bgcolEven:this._colors.bgcolOdd;};};C.color=D.selected?this._colors.colSelected:this._colors.colNormal;C.borderBottom=m+this._colors.horLine;},getRowHeightStyle:function(E){if(qx.core.Environment.get(j)==c){E-=this._insetY;};return e+E+v;},createRowStyle:function(G){var F=[];F.push(x);F.push(this.__wy);F.push(q);if(G.focusedRow&&this.getHighlightFocusRow()){F.push(G.selected?this._colors.bgcolFocusedSelected:this._colors.bgcolFocused);}else {if(G.selected){F.push(this._colors.bgcolSelected);}else {F.push((G.row%2==0)?this._colors.bgcolEven:this._colors.bgcolOdd);};};F.push(k);F.push(G.selected?this._colors.colSelected:this._colors.colNormal);F.push(s,this._colors.horLine);return F.join(r);},getRowClass:function(H){return r;},getRowAttributes:function(I){return r;}},destruct:function(){this._colors=this.__wx=this.__wy=null;if(qx.core.Environment.get(o)){qx.theme.manager.Meta.getInstance().removeListener(f,this.initThemeValues,this);};}});})();(function(){var a="qx.ui.table.IColumnMenuButton";qx.Interface.define(a,{properties:{menu:{}},members:{factory:function(b,c){return true;},empty:function(){return true;}}});})();(function(){var a="Unrecognized factory request: ",b="menu-button",c="table-column-reset-button",d="separator",e="user-button",f="qx.ui.table.columnmenu.Button",g="menu";qx.Class.define(f,{extend:qx.ui.form.MenuButton,implement:qx.ui.table.IColumnMenuButton,construct:function(){qx.ui.form.MenuButton.call(this);this.__lP=new qx.ui.core.Blocker(this);},members:{__wt:null,__lP:null,factory:function(h,k){switch(h){case g:var m=new qx.ui.menu.Menu();this.setMenu(m);return m;case b:var n=new qx.ui.table.columnmenu.MenuItem(k.text);n.setVisible(k.bVisible);this.getMenu().add(n);return n;case e:var j=new qx.ui.menu.Button(k.text);j.set({appearance:c});return j;case d:return new qx.ui.menu.Separator();default:throw new Error(a+h);};},getBlocker:function(){return this.__lP;},empty:function(){var o=this.getMenu();var p=o.getChildren();for(var i=0,l=p.length;i<l;i++ ){p[0].destroy();};}},destruct:function(){this.__lP.dispose();}});})();(function(){var a="qx.ui.table.IColumnMenuItem",b="qx.event.type.Data";qx.Interface.define(a,{properties:{visible:{}},events:{changeVisible:b}});})();(function(){var a="menu-checkbox",b="Boolean",c="label",d="_applyValue",f="value",g="changeValue",h="toolTipText",i="enabled",j="qx.ui.menu.CheckBox",k="checked",l="menu",m="execute";qx.Class.define(j,{extend:qx.ui.menu.AbstractButton,implement:[qx.ui.form.IBooleanForm],construct:function(o,n){qx.ui.menu.AbstractButton.call(this);if(o!=null){if(o.translate){this.setLabel(o.translate());}else {this.setLabel(o);};};if(n!=null){this.setMenu(n);};this.addListener(m,this._onExecute,this);},properties:{appearance:{refine:true,init:a},value:{check:b,init:false,apply:d,event:g,nullable:true}},members:{_bindableProperties:[i,c,h,f,l],_applyValue:function(q,p){q?this.addState(k):this.removeState(k);},_onExecute:function(e){this.toggleValue();}}});})();(function(){var a="changeVisible",b="qx.ui.table.columnmenu.MenuItem",c="_applyVisible",d="Boolean",f="changeValue";qx.Class.define(b,{extend:qx.ui.menu.CheckBox,implement:qx.ui.table.IColumnMenuItem,properties:{visible:{check:d,init:true,apply:c,event:a}},construct:function(g){qx.ui.menu.CheckBox.call(this,g);this.addListener(f,function(e){this.bInListener=true;this.setVisible(e.getData());this.bInListener=false;});},members:{_applyVisible:function(i,h){if(!this.bInListener){this.setValue(i);};}}});})();(function(){var a="qx.ui.table.selection.Model",b="qx.ui.table.selection.Manager";qx.Class.define(b,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);},properties:{selectionModel:{check:a}},members:{__wz:null,handleTap:function(c,d){if(d.isLeftPressed()){var e=this.getSelectionModel();if(!e.isSelectedIndex(c)){this._handleSelectEvent(c,d);this.__wz=true;}else {this.__wz=false;};}else if(d.isRightPressed()&&d.getModifiers()==0){var e=this.getSelectionModel();if(!e.isSelectedIndex(c)){e.setSelectionInterval(c,c);};};if(d.isLeftPressed()&&!this.__wz){this._handleSelectEvent(c,d);};},handleSelectKeyDown:function(f,g){this._handleSelectEvent(f,g);},handleMoveKeyDown:function(h,i){var k=this.getSelectionModel();switch(i.getModifiers()){case 0:k.setSelectionInterval(h,h);break;case qx.event.type.Dom.SHIFT_MASK:var j=k.getAnchorSelectionIndex();if(j==-1){k.setSelectionInterval(h,h);}else {k.setSelectionInterval(j,h);};break;};},_handleSelectEvent:function(l,n){var p=this.getSelectionModel();var m=p.getLeadSelectionIndex();var o=p.getAnchorSelectionIndex();if(n.isShiftPressed()){if(l!=m||p.isSelectionEmpty()){if(o==-1){o=l;};if(n.isCtrlOrCommandPressed()){p.addSelectionInterval(o,l);}else {p.setSelectionInterval(o,l);};};}else if(n.isCtrlOrCommandPressed()){if(p.isSelectedIndex(l)){p.removeSelectionInterval(l,l);}else {p.addSelectionInterval(l,l);};}else {p.setSelectionInterval(l,l);};}}});})();(function(){var a="..",b="changeSelection",c="Try to turn off batch mode althoug it was not turned on.",d="_applySelectionMode",f="]",g="qx.event.type.Event",h="Ranges:",k="qx.ui.table.selection.Model",l=" [";qx.Class.define(k,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__wA=[];this.__wB=-1;this.__wC=-1;this.hasBatchModeRefCount=0;this.__wD=false;},events:{"changeSelection":g},statics:{NO_SELECTION:1,SINGLE_SELECTION:2,SINGLE_INTERVAL_SELECTION:3,MULTIPLE_INTERVAL_SELECTION:4,MULTIPLE_INTERVAL_SELECTION_TOGGLE:5},properties:{selectionMode:{init:2,check:[1,2,3,4,5],apply:d}},members:{__wD:null,__wB:null,__wC:null,__wA:null,_applySelectionMode:function(m){this.resetSelection();},setBatchMode:function(n){if(n){this.hasBatchModeRefCount+=1;}else {if(this.hasBatchModeRefCount==0){throw new Error(c);};this.hasBatchModeRefCount-=1;if(this.__wD){this.__wD=false;this._fireChangeSelection();};};return this.hasBatchMode();},hasBatchMode:function(){return this.hasBatchModeRefCount>0;},getAnchorSelectionIndex:function(){return this.__wB;},_setAnchorSelectionIndex:function(o){this.__wB=o;},getLeadSelectionIndex:function(){return this.__wC;},_setLeadSelectionIndex:function(p){this.__wC=p;},_getSelectedRangeArr:function(){return this.__wA;},resetSelection:function(){if(!this.isSelectionEmpty()){this._resetSelection();this._fireChangeSelection();};},isSelectionEmpty:function(){return this.__wA.length==0;},getSelectedCount:function(){var r=0;for(var i=0;i<this.__wA.length;i++ ){var q=this.__wA[i];r+=q.maxIndex-q.minIndex+1;};return r;},isSelectedIndex:function(s){for(var i=0;i<this.__wA.length;i++ ){var t=this.__wA[i];if(s>=t.minIndex&&s<=t.maxIndex){return true;};};return false;},getSelectedRanges:function(){var u=[];for(var i=0;i<this.__wA.length;i++ ){u.push({minIndex:this.__wA[i].minIndex,maxIndex:this.__wA[i].maxIndex});};return u;},iterateSelection:function(w,v){for(var i=0;i<this.__wA.length;i++ ){for(var j=this.__wA[i].minIndex;j<=this.__wA[i].maxIndex;j++ ){w.call(v,j);};};},setSelectionInterval:function(z,y){var x=this.self(arguments);switch(this.getSelectionMode()){case x.NO_SELECTION:return;case x.SINGLE_SELECTION:if(this.isSelectedIndex(y)){return;};z=y;break;case x.MULTIPLE_INTERVAL_SELECTION_TOGGLE:this.setBatchMode(true);try{for(var i=z;i<=y;i++ ){if(!this.isSelectedIndex(i)){this._addSelectionInterval(i,i);}else {this.removeSelectionInterval(i,i);};};}catch(e){throw e;}finally{this.setBatchMode(false);};this._fireChangeSelection();return;};this._resetSelection();this._addSelectionInterval(z,y);this._fireChangeSelection();},addSelectionInterval:function(B,A){var C=qx.ui.table.selection.Model;switch(this.getSelectionMode()){case C.NO_SELECTION:return;case C.MULTIPLE_INTERVAL_SELECTION:case C.MULTIPLE_INTERVAL_SELECTION_TOGGLE:this._addSelectionInterval(B,A);this._fireChangeSelection();break;default:this.setSelectionInterval(B,A);break;};},removeSelectionInterval:function(G,E){this.__wB=G;this.__wC=E;var D=Math.min(G,E);var H=Math.max(G,E);for(var i=0;i<this.__wA.length;i++ ){var J=this.__wA[i];if(J.minIndex>H){break;}else if(J.maxIndex>=D){var K=(J.minIndex>=D)&&(J.minIndex<=H);var F=(J.maxIndex>=D)&&(J.maxIndex<=H);if(K&&F){this.__wA.splice(i,1);i-- ;}else if(K){J.minIndex=H+1;}else if(F){J.maxIndex=D-1;}else {var I={minIndex:H+1,maxIndex:J.maxIndex};this.__wA.splice(i+1,0,I);J.maxIndex=D-1;break;};};};this._fireChangeSelection();},_resetSelection:function(){this.__wA=[];this.__wB=-1;this.__wC=-1;},_addSelectionInterval:function(O,M){this.__wB=O;this.__wC=M;var L=Math.min(O,M);var P=Math.max(O,M);var N=0;for(;N<this.__wA.length;N++ ){var Q=this.__wA[N];if(Q.minIndex>L){break;};};this.__wA.splice(N,0,{minIndex:L,maxIndex:P});var R=this.__wA[0];for(var i=1;i<this.__wA.length;i++ ){var Q=this.__wA[i];if(R.maxIndex+1>=Q.minIndex){R.maxIndex=Math.max(R.maxIndex,Q.maxIndex);this.__wA.splice(i,1);i-- ;}else {R=Q;};};},_dumpRanges:function(){var S=h;for(var i=0;i<this.__wA.length;i++ ){var T=this.__wA[i];S+=l+T.minIndex+a+T.maxIndex+f;};this.debug(S);},_fireChangeSelection:function(){if(this.hasBatchMode()){this.__wD=true;}else {this.fireEvent(b);};}},destruct:function(){this.__wA=null;}});})();(function(){var a="qx.ui.table.ICellEditorFactory";qx.Interface.define(a,{members:{createCellEditor:function(b){return true;},getCellEditorValue:function(c){return true;}}});})();(function(){var a="Function",b="abstract",c="",d="number",e="appear",f="Abstract method call!",g="qx.ui.table.celleditor.AbstractField";qx.Class.define(g,{extend:qx.core.Object,implement:qx.ui.table.ICellEditorFactory,type:b,properties:{validationFunction:{check:a,nullable:true,init:null}},members:{_createEditor:function(){throw new Error(f);},createCellEditor:function(h){var i=this._createEditor();i.originalValue=h.value;if(h.value===null||h.value===undefined){h.value=c;};i.setValue(c+h.value);i.addListener(e,function(){i.selectAllText();});return i;},getCellEditorValue:function(j){var k=j.getValue();var l=this.getValidationFunction();if(l){k=l(k,j.originalValue);};if(typeof j.originalValue==d){k=parseFloat(k);};return k;}}});})();(function(){var a='',b="number",c="qx.ui.table.celleditor.TextField",d="table-editor-textfield";qx.Class.define(c,{extend:qx.ui.table.celleditor.AbstractField,members:{getCellEditorValue:function(e){var f=e.getValue();var g=this.getValidationFunction();if(g){f=g(f,e.originalValue);};if(typeof e.originalValue==b){if(f!=null&&f!=a){f=parseFloat(f);};};return f;},_createEditor:function(){var h=new qx.ui.form.TextField();h.setAppearance(d);return h;}}});})();(function(){var a="qx.ui.table.IHeaderRenderer";qx.Interface.define(a,{members:{createHeaderCell:function(b){return true;},updateHeaderCell:function(c,d){return true;}}});})();(function(){var a="qx.ui.table.headerrenderer.Default",b="sortedAscending",c="sorted",d="String";qx.Class.define(a,{extend:qx.core.Object,implement:qx.ui.table.IHeaderRenderer,statics:{STATE_SORTED:c,STATE_SORTED_ASCENDING:b},properties:{toolTip:{check:d,init:null,nullable:true}},members:{createHeaderCell:function(e){var f=new qx.ui.table.headerrenderer.HeaderCell();this.updateHeaderCell(e,f);return f;},updateHeaderCell:function(j,i){var h=qx.ui.table.headerrenderer.Default;if(j.name&&j.name.translate){i.setLabel(j.name.translate());}else {i.setLabel(j.name);};var g=i.getToolTip();if(this.getToolTip()!=null){if(g==null){g=new qx.ui.tooltip.ToolTip(this.getToolTip());i.setToolTip(g);qx.util.DisposeUtil.disposeTriggeredBy(g,i);}else {g.setLabel(this.getToolTip());};};j.sorted?i.addState(h.STATE_SORTED):i.removeState(h.STATE_SORTED);j.sortedAscending?i.addState(h.STATE_SORTED_ASCENDING):i.removeState(h.STATE_SORTED_ASCENDING);}}});})();(function(){var a="_applySortIcon",b="_applyIcon",c="icon",d="label",e="table-header-cell",f="qx.ui.table.headerrenderer.HeaderCell",g="_applyLabel",h="String",i="sort-icon";qx.Class.define(f,{extend:qx.ui.container.Composite,construct:function(){qx.ui.container.Composite.call(this);var j=new qx.ui.layout.Grid();j.setRowFlex(0,1);j.setColumnFlex(1,1);j.setColumnFlex(2,1);this.setLayout(j);},properties:{appearance:{refine:true,init:e},label:{check:h,init:null,nullable:true,apply:g},sortIcon:{check:h,init:null,nullable:true,apply:a,themeable:true},icon:{check:h,init:null,nullable:true,apply:b}},members:{_applyLabel:function(l,k){if(l){this._showChildControl(d).setValue(l);}else {this._excludeChildControl(d);};},_applySortIcon:function(n,m){if(n){this._showChildControl(i).setSource(n);}else {this._excludeChildControl(i);};},_applyIcon:function(p,o){if(p){this._showChildControl(c).setSource(p);}else {this._excludeChildControl(c);};},_createChildControlImpl:function(s,r){var q;switch(s){case d:q=new qx.ui.basic.Label(this.getLabel()).set({anonymous:true,allowShrinkX:true});this._add(q,{row:0,column:1});break;case i:q=new qx.ui.basic.Image(this.getSortIcon());q.setAnonymous(true);this._add(q,{row:0,column:2});break;case c:q=new qx.ui.basic.Image(this.getIcon()).set({anonymous:true,allowShrinkX:true});this._add(q,{row:0,column:0});break;};return q||qx.ui.container.Composite.prototype._createChildControlImpl.call(this,s);}}});})();(function(){var a="visibilityChanged",b="__wJ",c="orderChanged",d="widthChanged",e="qx.ui.table.columnmodel.Basic",f=". The column is not added to this TablePaneModel.",g="Showing column failed: ",h=", got ",j="setColumnsOrder: Invalid number of column positions given, expected ",k="headerCellRendererChanged",l="__wK",m="qx.event.type.Data",n="__wI",o="visibilityChangedPre";qx.Class.define(e,{extend:qx.core.Object,construct:function(){qx.core.Object.call(this);this.__wE=[];this.__wF=[];},events:{"widthChanged":m,"visibilityChangedPre":m,"visibilityChanged":m,"orderChanged":m,"headerCellRendererChanged":m},statics:{DEFAULT_WIDTH:100,DEFAULT_HEADER_RENDERER:qx.ui.table.headerrenderer.Default,DEFAULT_DATA_RENDERER:qx.ui.table.cellrenderer.Default,DEFAULT_EDITOR_FACTORY:qx.ui.table.celleditor.TextField},members:{__wf:null,__wG:null,__wF:null,__wE:null,__wH:null,__wI:null,__wJ:null,__wK:null,init:function(s,v){{};this.__wH=[];var r=qx.ui.table.columnmodel.Basic.DEFAULT_WIDTH;var t=this.__wI||(this.__wI=new qx.ui.table.columnmodel.Basic.DEFAULT_HEADER_RENDERER());var q=this.__wJ||(this.__wJ=new qx.ui.table.columnmodel.Basic.DEFAULT_DATA_RENDERER());var p=this.__wK||(this.__wK=new qx.ui.table.columnmodel.Basic.DEFAULT_EDITOR_FACTORY());this.__wE=[];this.__wF=[];var u;if(v){u=v.getInitiallyHiddenColumns();};u=u||[];for(var z=0;z<s;z++ ){this.__wH[z]={width:r,headerRenderer:t,dataRenderer:q,editorFactory:p};this.__wE[z]=z;this.__wF[z]=z;};this.__wG=null;this.__wf=true;for(var w=0;w<u.length;w++ ){this.setColumnVisible(u[w],false);};this.__wf=false;for(z=0;z<s;z++ ){var y={col:z,visible:this.isColumnVisible(z)};this.fireDataEvent(o,y);this.fireDataEvent(a,y);};},getVisibleColumns:function(){return this.__wF!=null?this.__wF:[];},setColumnWidth:function(E,A,D){{};var C=this.__wH[E].width;if(C!=A){this.__wH[E].width=A;var B={col:E,newWidth:A,oldWidth:C,isPointerAction:D||false};this.fireDataEvent(d,B);};},getColumnWidth:function(F){{};return this.__wH[F].width;},setHeaderCellRenderer:function(H,I){{};var G=this.__wH[H].headerRenderer;if(G!==this.__wI){G.dispose();};this.__wH[H].headerRenderer=I;this.fireDataEvent(k,{col:H});},getHeaderCellRenderer:function(J){{};return this.__wH[J].headerRenderer;},setDataCellRenderer:function(L,M){{};var K=this.__wH[L].dataRenderer;this.__wH[L].dataRenderer=M;if(K!==this.__wJ){return K;};return null;},getDataCellRenderer:function(N){{};return this.__wH[N].dataRenderer;},setCellEditorFactory:function(P,O){{};var Q=this.__wH[P].editorFactory;if(Q!==this.__wK){Q.dispose();};this.__wH[P].editorFactory=O;},getCellEditorFactory:function(R){{};return this.__wH[R].editorFactory;},_getColToXPosMap:function(){if(this.__wG==null){this.__wG={};for(var U=0;U<this.__wE.length;U++ ){var T=this.__wE[U];this.__wG[T]={overX:U};};for(var S=0;S<this.__wF.length;S++ ){var T=this.__wF[S];this.__wG[T].visX=S;};};return this.__wG;},getVisibleColumnCount:function(){return this.__wF!=null?this.__wF.length:0;},getVisibleColumnAtX:function(V){{};return this.__wF[V];},getVisibleX:function(W){{};return this._getColToXPosMap()[W].visX;},getOverallColumnCount:function(){return this.__wE.length;},getOverallColumnAtX:function(X){{};return this.__wE[X];},getOverallX:function(Y){{};return this._getColToXPosMap()[Y].overX;},isColumnVisible:function(ba){{};return (this._getColToXPosMap()[ba].visX!=null);},setColumnVisible:function(bj,bd){{};if(bd!=this.isColumnVisible(bj)){if(bd){var bh=this._getColToXPosMap();var bf=bh[bj].overX;if(bf==null){throw new Error(g+bj+f);};var be;for(var x=bf+1;x<this.__wE.length;x++ ){var bg=this.__wE[x];var bb=bh[bg].visX;if(bb!=null){be=bb;break;};};if(be==null){be=this.__wF.length;};this.__wF.splice(be,0,bj);}else {var bc=this.getVisibleX(bj);this.__wF.splice(bc,1);};this.__wG=null;if(!this.__wf){var bi={col:bj,visible:bd};this.fireDataEvent(o,bi);this.fireDataEvent(a,bi);};};},moveColumn:function(bk,bn){{};this.__wf=true;var bo=this.__wE[bk];var bl=this.isColumnVisible(bo);if(bl){this.setColumnVisible(bo,false);};this.__wE.splice(bk,1);this.__wE.splice(bn,0,bo);this.__wG=null;if(bl){this.setColumnVisible(bo,true);};this.__wf=false;var bm={col:bo,fromOverXPos:bk,toOverXPos:bn};this.fireDataEvent(c,bm);},setColumnsOrder:function(br){{};if(br.length==this.__wE.length){this.__wf=true;var bq=new Array(br.length);for(var bp=0;bp<this.__wE.length;bp++ ){var bs=this.isColumnVisible(bp);bq[bp]=bs;if(bs){this.setColumnVisible(bp,false);};};this.__wE=qx.lang.Array.clone(br);this.__wG=null;for(var bp=0;bp<this.__wE.length;bp++ ){if(bq[bp]){this.setColumnVisible(bp,true);};};this.__wf=false;this.fireDataEvent(c);}else {throw new Error(j+this.__wE.length+h+br.length);};}},destruct:function(){for(var i=0;i<this.__wH.length;i++ ){this.__wH[i].headerRenderer.dispose();this.__wH[i].dataRenderer.dispose();this.__wH[i].editorFactory.dispose();};this.__wE=this.__wF=this.__wH=this.__wG=null;this._disposeObjects(n,b,l);}});})();(function(){var a='<div>',b="</div>",c="overflow: hidden;",d="qx.event.type.Data",e='</div>',f="paneReloadsData",g="div",h='style="',j="_applyMaxCacheLines",k="track",l="qx.ui.table.pane.Pane",m="width: 100%;",n="qx.event.type.Event",o="_applyVisibleRowCount",p='>',q="",r='" ',s="line-height: ",t="paneUpdated",u="appear",v='class="',w="width:100%;",z="px;",A='<div ',B="'>",C="Number",D="_applyFirstVisibleRow",E="<div style='",F=";position:relative;";qx.Class.define(l,{extend:qx.ui.core.Widget,construct:function(G){qx.ui.core.Widget.call(this);this.__wL=G;this.__wM=0;this.__ws=0;this.__wN=[];},events:{"paneReloadsData":d,"paneUpdated":n},properties:{firstVisibleRow:{check:C,init:0,apply:D},visibleRowCount:{check:C,init:0,apply:o},maxCacheLines:{check:C,init:1000,apply:j},allowShrinkX:{refine:true,init:false}},members:{__ws:null,__wM:null,__wL:null,__wO:null,__wp:null,__wo:null,__wN:null,__wP:0,_applyFirstVisibleRow:function(I,H){this.updateContent(false,I-H);},_applyVisibleRowCount:function(K,J){this.updateContent(true);},_getContentHint:function(){return {width:this.getPaneScroller().getTablePaneModel().getTotalWidth(),height:400};},getPaneScroller:function(){return this.__wL;},getTable:function(){return this.__wL.getTable();},setFocusedCell:function(N,M,L){if(N!=this.__wo||M!=this.__wp){var O=this.__wp;this.__wo=N;this.__wp=M;if(M!=O&&!L){if(O!==null){this.updateContent(false,null,O,true);};if(M!==null){this.updateContent(false,null,M,true);};};};},onSelectionChanged:function(){this.updateContent(false,null,null,true);},onFocusChanged:function(){this.updateContent(false,null,null,true);},setColumnWidth:function(Q,P){this.updateContent(true);},onColOrderChanged:function(){this.updateContent(true);},onPaneModelChanged:function(){this.updateContent(true);},onTableModelDataChanged:function(U,W,S,R){this.__wQ();var T=this.getFirstVisibleRow();var V=this.getVisibleRowCount();if(W==-1||W>=T&&U<T+V){this.updateContent();};},onTableModelMetaDataChanged:function(){this.updateContent(true);},_applyMaxCacheLines:function(Y,X){if(this.__wP>=Y&&Y!==-1){this.__wQ();};},__wQ:function(){this.__wN=[];this.__wP=0;},__wR:function(bc,ba,bb){if(!ba&&!bb&&this.__wN[bc]){return this.__wN[bc];}else {return null;};},__wS:function(bh,bg,be,bf){var bd=this.getMaxCacheLines();if(!be&&!bf&&!this.__wN[bh]&&bd>0){this._applyMaxCacheLines(bd);this.__wN[bh]=bg;this.__wP+=1;};},updateContent:function(bi,bl,bk,bj){if(bi){this.__wQ();};if(bl&&Math.abs(bl)<=Math.min(10,this.getVisibleRowCount())){this._scrollContent(bl);}else if(bj&&!this.getTable().getAlwaysUpdateCells()){this._updateRowStyles(bk);}else {this._updateAllRows();};},_updateRowStyles:function(br){var bq=this.getContentElement().getDomElement();if(!bq||!bq.firstChild){this._updateAllRows();return;};var bu=this.getTable();var bn=bu.getSelectionModel();var bs=bu.getTableModel();var bv=bu.getDataRowRenderer();var bp=bq.firstChild.childNodes;var bo={table:bu};var bw=this.getFirstVisibleRow();var y=0;var bm=bp.length;if(br!=null){var bt=br-bw;if(bt>=0&&bt<bm){bw=br;y=bt;bm=bt+1;}else {return;};};for(;y<bm;y++ ,bw++ ){bo.row=bw;bo.selected=bn.isSelectedIndex(bw);bo.focusedRow=(this.__wp==bw);bo.rowData=bs.getRowData(bw);bv.updateDataRowElement(bo,bp[y]);};},_getRowsHtml:function(bI,bR){var bC=this.getTable();var bF=bC.getSelectionModel();var bA=bC.getTableModel();var bB=bC.getTableColumnModel();var bW=this.getPaneScroller().getTablePaneModel();var bL=bC.getDataRowRenderer();bA.prefetchRows(bI,bI+bR-1);var bT=bC.getRowHeight();var bV=bW.getColumnCount();var cb=0;var bz=[];for(var x=0;x<bV;x++ ){var ca=bW.getColumnAtX(x);var bE=bB.getColumnWidth(ca);bz.push({col:ca,xPos:x,editable:bA.isColumnEditable(ca),focusedCol:this.__wo==ca,styleLeft:cb,styleWidth:bE});cb+=bE;};var bY=[];var bx=false;for(var bD=bI;bD<bI+bR;bD++ ){var bG=bF.isSelectedIndex(bD);var bK=(this.__wp==bD);var bM=this.__wR(bD,bG,bK);if(bM){bY.push(bM);continue;};var bN=[];var bS={table:bC};bS.styleHeight=bT;bS.row=bD;bS.selected=bG;bS.focusedRow=bK;bS.rowData=bA.getRowData(bD);if(!bS.rowData){bx=true;};bN.push(A);var bO=bL.getRowAttributes(bS);if(bO){bN.push(bO);};var by=bL.getRowClass(bS);if(by){bN.push(v,by,r);};var bP=bL.createRowStyle(bS);bP+=F+bL.getRowHeightStyle(bT)+w;if(bP){bN.push(h,bP,r);};bN.push(p);var bX=false;for(x=0;x<bV&&!bX;x++ ){var bH=bz[x];for(var bU in bH){bS[bU]=bH[bU];};var ca=bS.col;bS.value=bA.getValue(ca,bD);var bJ=bB.getDataCellRenderer(ca);bS.style=bJ.getDefaultCellStyle();bX=bJ.createDataCellHtml(bS,bN)||false;};bN.push(e);var bQ=bN.join(q);this.__wS(bD,bQ,bG,bK);bY.push(bQ);};this.fireDataEvent(f,bx);return bY.join(q);},_scrollContent:function(cn){var cc=this.getContentElement().getDomElement();if(!(cc&&cc.firstChild)){this._updateAllRows();return;};var cl=cc.firstChild;var cd=cl.childNodes;var cf=this.getVisibleRowCount();var ci=this.getFirstVisibleRow();var cg=this.getTable().getTableModel();var cm=0;cm=cg.getRowCount();if(ci+cf>cm){this._updateAllRows();return;};var co=cn<0?cf+cn:0;var ce=cn<0?0:cf-cn;for(var i=Math.abs(cn)-1;i>=0;i-- ){var ch=cd[co];try{cl.removeChild(ch);}catch(cp){break;};};if(!this.__wO){this.__wO=document.createElement(g);};var ck=a;ck+=this._getRowsHtml(ci+ce,Math.abs(cn));ck+=e;this.__wO.innerHTML=ck;var cj=this.__wO.firstChild.childNodes;if(cn>0){for(var i=cj.length-1;i>=0;i-- ){var ch=cj[0];cl.appendChild(ch);};}else {for(var i=cj.length-1;i>=0;i-- ){var ch=cj[cj.length-1];cl.insertBefore(ch,cl.firstChild);};};if(this.__wp!==null){this._updateRowStyles(this.__wp-cn);this._updateRowStyles(this.__wp);};this.fireEvent(t);},_updateAllRows:function(){var ct=this.getContentElement().getDomElement();if(!ct){this.addListenerOnce(u,this._updateAllRows,this);return;};var cz=this.getTable();var cw=cz.getTableModel();var cy=this.getPaneScroller().getTablePaneModel();var cx=cy.getColumnCount();var cq=cz.getRowHeight();var cu=this.getFirstVisibleRow();var cr=this.getVisibleRowCount();var cA=cw.getRowCount();if(cu+cr>cA){cr=Math.max(0,cA-cu);};var cs=cy.getTotalWidth();var cv;if(cr>0){cv=[E,m,(cz.getForceLineHeight()?s+cq+z:q),c,B,this._getRowsHtml(cu,cr),b];}else {cv=[];};var cB=cv.join(q);ct.innerHTML=cB;this.setWidth(cs);this.__wM=cx;this.__ws=cr;this.fireEvent(t);}},destruct:function(){this.__wO=this.__wL=this.__wN=null;this.removeListener(k,this._onTrack,this);}});})();(function(){var a="first",b="hovered",c="__wL",d="last",e="qx.ui.table.pane.Header";qx.Class.define(e,{extend:qx.ui.core.Widget,construct:function(f){qx.ui.core.Widget.call(this);this._setLayout(new qx.ui.layout.HBox());this.__lP=new qx.ui.core.Blocker(this);this.__wL=f;},members:{__wL:null,__wT:null,__wU:null,__lP:null,getPaneScroller:function(){return this.__wL;},getTable:function(){return this.__wL.getTable();},getBlocker:function(){return this.__lP;},onColOrderChanged:function(){this._updateContent(true);},onPaneModelChanged:function(){this._updateContent(true);},onTableModelMetaDataChanged:function(){this._updateContent();},setColumnWidth:function(h,g,i){var j=this.getHeaderWidgetAtColumn(h);if(j!=null){j.setWidth(g);};},setPointerOverColumn:function(l){if(l!=this.__wU){if(this.__wU!=null){var k=this.getHeaderWidgetAtColumn(this.__wU);if(k!=null){k.removeState(b);};};if(l!=null){this.getHeaderWidgetAtColumn(l).addState(b);};this.__wU=l;};},getHeaderWidgetAtColumn:function(n){var m=this.getPaneScroller().getTablePaneModel().getX(n);return this._getChildren()[m];},showColumnMoveFeedback:function(y,x){var r=this.getContentLocation();if(this.__wT==null){var w=this.getTable();var o=this.getPaneScroller().getTablePaneModel().getX(y);var q=this._getChildren()[o];var s=w.getTableModel();var u=w.getTableColumnModel();var v={xPos:o,col:y,name:s.getColumnName(y),table:w};var t=u.getHeaderCellRenderer(y);var p=t.createHeaderCell(v);var z=q.getBounds();p.setWidth(z.width);p.setHeight(z.height);p.setZIndex(1000000);p.setOpacity(0.8);p.setLayoutProperties({top:r.top});this.getApplicationRoot().add(p);this.__wT=p;};this.__wT.setLayoutProperties({left:r.left+x});this.__wT.show();},hideColumnMoveFeedback:function(){if(this.__wT!=null){this.__wT.destroy();this.__wT=null;};},isShowingColumnMoveFeedback:function(){return this.__wT!=null;},_updateContent:function(B){var L=this.getTable();var E=L.getTableModel();var H=L.getTableColumnModel();var A=this.getPaneScroller().getTablePaneModel();var D=this._getChildren();var F=A.getColumnCount();var I=E.getSortColumnIndex();if(B){this._cleanUpCells();};var J={};J.sortedAscending=E.isSortAscending();for(var x=0;x<F;x++ ){var M=A.getColumnAtX(x);if(M===undefined){continue;};var K=H.getColumnWidth(M);var G=H.getHeaderCellRenderer(M);J.xPos=x;J.col=M;J.name=E.getColumnName(M);J.editable=E.isColumnEditable(M);J.sorted=(M==I);J.table=L;var C=D[x];if(C==null){C=G.createHeaderCell(J);C.set({width:K});this._add(C);}else {G.updateHeaderCell(J,C);};if(x===0){C.addState(a);C.removeState(d);}else if(x===F-1){C.removeState(a);C.addState(d);}else {C.removeState(a);C.removeState(d);};};},_cleanUpCells:function(){var O=this._getChildren();for(var x=O.length-1;x>=0;x-- ){var N=O[x];N.destroy();};}},destruct:function(){this.__lP.dispose();this._disposeObjects(c);}});})();(function(){var a="__xa",b="changeScrollX",c="Boolean",d="__xc",g="scroll",h="focus-indicator",i="_paneClipper",j="changeHorizontalScrollBarVisible",k="cellDbltap",l="excluded",m="__de",n="bottom",o="_applyScrollTimeout",p="_applyTablePaneModel",q="Integer",r="cellTap",s="roll",t="qx.event.type.Data",u="dblclick",v="dataEdited",w="__wW",y="mouse",z="changeVerticalScrollBarVisible",A="interval",B="__wY",C="qx.ui.table.pane.Scroller",D="scrollbar-y",E="table-scroller-focus-indicator",F="_headerClipper",G="visible",H="__wX",I="resize-line",J="_applyShowCellFocusIndicator",K="header",L="dbltap",M="resize",N="pointerup",O="vertical",P="changeScrollY",Q="__xb",R="device.type",S="os.scrollBarOverlayed",T="pointerdown",U="modelChanged",V="changeTablePaneModel",W="beforeSort",X="scrollbar-x",Y="__xd",bz="cellContextmenu",bA="horizontal",bB="table-scroller",bv="appear",bw="losecapture",bx="contextmenu",by="col-resize",bF="disappear",bG="_applyVerticalScrollBarVisible",bH="_applyHorizontalScrollBarVisible",bL="editing",bC="pane",bD="desktop",bE="close",bt="tap",bK="pointermove",bu="qx.ui.table.pane.Model",bI="qx.ui.table.pane.CellEvent",bJ="pointerout";qx.Class.define(C,{extend:qx.ui.core.Widget,include:[qx.ui.core.scroll.MScrollBarFactory],construct:function(bM){qx.ui.core.Widget.call(this);this.__wV=bM;var bN=new qx.ui.layout.Grid();bN.setColumnFlex(0,1);bN.setRowFlex(1,1);this._setLayout(bN);this.__wW=this._showChildControl(K);this.__wX=this._showChildControl(bC);this.__wY=new qx.ui.container.Composite(new qx.ui.layout.HBox()).set({minWidth:0});this._add(this.__wY,{row:0,column:0,colSpan:2});this._headerClipper=this._createHeaderClipper();this._headerClipper.add(this.__wW);this._headerClipper.addListener(bw,this._onChangeCaptureHeader,this);this._headerClipper.addListener(bK,this._onPointermoveHeader,this);this._headerClipper.addListener(T,this._onPointerdownHeader,this);this._headerClipper.addListener(N,this._onPointerupHeader,this);this._headerClipper.addListener(bt,this._onTapHeader,this);this.__wY.add(this._headerClipper,{flex:1});this._paneClipper=this._createPaneClipper();this._paneClipper.add(this.__wX);this._paneClipper.addListener(s,this._onRoll,this);this._paneClipper.addListener(bK,this._onPointermovePane,this);this._paneClipper.addListener(T,this._onPointerdownPane,this);this._paneClipper.addListener(bt,this._onTapPane,this);this._paneClipper.addListener(bx,this._onTapPane,this);this._paneClipper.addListener(bx,this._onContextMenu,this);if(qx.core.Environment.get(R)===bD){this._paneClipper.addListener(u,this._onDbltapPane,this);}else {this._paneClipper.addListener(L,this._onDbltapPane,this);};this._paneClipper.addListener(M,this._onResizePane,this);if(qx.core.Environment.get(S)){this.__xa=new qx.ui.container.Composite();this.__xa.setLayout(new qx.ui.layout.Canvas());this.__xa.add(this._paneClipper,{edge:0});this._add(this.__xa,{row:1,column:0});}else {this._add(this._paneClipper,{row:1,column:0});};this.__xb=this._showChildControl(X);this.__xc=this._showChildControl(D);this.__xd=this.getChildControl(h);this.initShowCellFocusIndicator();this.getChildControl(I).hide();this.addListener(bJ,this._onPointerout,this);this.addListener(bv,this._onAppear,this);this.addListener(bF,this._onDisappear,this);this.__de=new qx.event.Timer();this.__de.addListener(A,this._oninterval,this);this.initScrollTimeout();},statics:{MIN_COLUMN_WIDTH:10,RESIZE_REGION_RADIUS:5,TAP_TOLERANCE:5,HORIZONTAL_SCROLLBAR:1,VERTICAL_SCROLLBAR:2},events:{"changeScrollY":t,"changeScrollX":t,"cellTap":bI,"cellDbltap":bI,"cellContextmenu":bI,"beforeSort":t},properties:{horizontalScrollBarVisible:{check:c,init:false,apply:bH,event:j},verticalScrollBarVisible:{check:c,init:false,apply:bG,event:z},tablePaneModel:{check:bu,apply:p,event:V},liveResize:{check:c,init:false},focusCellOnPointerMove:{check:c,init:false},selectBeforeFocus:{check:c,init:false},showCellFocusIndicator:{check:c,init:true,apply:J},contextMenuFromDataCellsOnly:{check:c,init:true},resetSelectionOnHeaderTap:{check:c,init:true},scrollTimeout:{check:q,init:100,apply:o},appearance:{refine:true,init:bB}},members:{__ws:null,__wV:null,__xe:null,__xf:null,__xg:null,_moveColumn:null,__xh:null,_lastMoveTargetX:null,_lastMoveTargetScroller:null,__xi:null,__xj:null,__xk:null,__xl:null,__xm:null,__xn:false,__xo:null,__xp:null,__xq:null,__wo:null,__wp:null,_cellEditor:null,__xr:null,__xs:null,__xb:null,__xc:null,__wW:null,_headerClipper:null,__wX:null,_paneClipper:null,__xa:null,__xd:null,__wY:null,__de:null,__xt:null,getPaneInsetRight:function(){var bQ=this.getTopRightWidget();var bR=bQ&&bQ.isVisible()&&bQ.getBounds()?bQ.getBounds().width+bQ.getMarginLeft()+bQ.getMarginRight():0;var bP=this.__xc;var bO=this.getVerticalScrollBarVisible()?this.getVerticalScrollBarWidth()+bP.getMarginLeft()+bP.getMarginRight():0;return Math.max(bR,bO);},setPaneWidth:function(bS){if(this.isVerticalScrollBarVisible()){bS+=this.getPaneInsetRight();};this.setWidth(bS);},_createChildControlImpl:function(bV,bU){var bT;switch(bV){case K:bT=(this.getTable().getNewTablePaneHeader())(this);break;case bC:bT=(this.getTable().getNewTablePane())(this);break;case h:bT=new qx.ui.table.pane.FocusIndicator(this);bT.setUserBounds(0,0,0,0);bT.setZIndex(1000);bT.addListener(N,this._onPointerupFocusIndicator,this);this._paneClipper.add(bT);bT.show();bT.setDecorator(null);break;case I:bT=new qx.ui.core.Widget();bT.setUserBounds(0,0,0,0);bT.setZIndex(1000);this._paneClipper.add(bT);break;case X:bT=this._createScrollBar(bA).set({alignY:n});bT.addListener(g,this._onScrollX,this);if(this.__xa!=null){bT.setMinHeight(qx.ui.core.scroll.AbstractScrollArea.DEFAULT_SCROLLBAR_WIDTH);this.__xa.add(bT,{bottom:0,right:0,left:0});}else {this._add(bT,{row:2,column:0});};break;case D:bT=this._createScrollBar(O);bT.addListener(g,this._onScrollY,this);if(this.__xa!=null){this.__xa.add(bT,{right:0,bottom:0,top:0});}else {this._add(bT,{row:1,column:1});};break;};return bT||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,bV);},_applyHorizontalScrollBarVisible:function(bX,bW){this.__xb.setVisibility(bX?G:l);},_applyVerticalScrollBarVisible:function(ca,bY){this.__xc.setVisibility(ca?G:l);},_applyTablePaneModel:function(cc,cb){if(cb!=null){cb.removeListener(U,this._onPaneModelChanged,this);};cc.addListener(U,this._onPaneModelChanged,this);},_applyShowCellFocusIndicator:function(ce,cd){if(ce){this.__xd.setDecorator(E);this._updateFocusIndicator();}else {if(this.__xd){this.__xd.setDecorator(null);};};},getScrollY:function(){return this.__xc.getPosition();},setScrollY:function(scrollY,cf){this.__xc.scrollTo(scrollY);if(cf){this._updateContent();};},getScrollX:function(){return this.__xb.getPosition();},setScrollX:function(scrollX){this.__xb.scrollTo(scrollX);},getTable:function(){return this.__wV;},_createPaneClipper:function(){return new qx.ui.table.pane.Clipper();},_createHeaderClipper:function(){return new qx.ui.table.pane.Clipper();},onColVisibilityChanged:function(){this.updateHorScrollBarMaximum();this._updateFocusIndicator();},setColumnWidth:function(ci,ch){this.__wW.setColumnWidth(ci,ch);this.__wX.setColumnWidth(ci,ch);var cg=this.getTablePaneModel();var x=cg.getX(ci);if(x!=-1){this.updateHorScrollBarMaximum();this._updateFocusIndicator();};},onColOrderChanged:function(){this.__wW.onColOrderChanged();this.__wX.onColOrderChanged();this.updateHorScrollBarMaximum();},onTableModelDataChanged:function(cm,ck,cn,cl){this.__wX.onTableModelDataChanged(cm,ck,cn,cl);var cj=this.getTable().getTableModel().getRowCount();if(cj!=this.__ws){this.updateVerScrollBarMaximum();if(this.getFocusedRow()>=cj){if(cj==0){this.setFocusedCell(null,null);}else {this.setFocusedCell(this.getFocusedColumn(),cj-1);};};this.__ws=cj;};},onSelectionChanged:function(){this.__wX.onSelectionChanged();},onFocusChanged:function(){this.__wX.onFocusChanged();},onTableModelMetaDataChanged:function(){this.__wW.onTableModelMetaDataChanged();this.__wX.onTableModelMetaDataChanged();},_onPaneModelChanged:function(){this.__wW.onPaneModelChanged();this.__wX.onPaneModelChanged();},_onResizePane:function(){this.updateHorScrollBarMaximum();this.updateVerScrollBarMaximum();this._updateContent();this.__wW._updateContent();this.__wV._updateScrollBarVisibility();},updateHorScrollBarMaximum:function(){var cs=this._paneClipper.getInnerSize();if(!cs){return;};var cp=this.getTablePaneModel().getTotalWidth();var cq=this.__xb;if(cs.width<cp){var co=Math.max(0,cp-cs.width);cq.setMaximum(co);cq.setKnobFactor(cs.width/cp);var cr=cq.getPosition();cq.setPosition(Math.min(cr,co));}else {cq.setMaximum(0);cq.setKnobFactor(1);cq.setPosition(0);};},updateVerScrollBarMaximum:function(){var cA=this._paneClipper.getInnerSize();if(!cA){return;};var cy=this.getTable().getTableModel();var cu=cy.getRowCount();if(this.getTable().getKeepFirstVisibleRowComplete()){cu+=1;};var ct=this.getTable().getRowHeight();var cw=cu*ct;var cz=this.__xc;if(cA.height<cw){var cv=Math.max(0,cw-cA.height);cz.setMaximum(cv);cz.setKnobFactor(cA.height/cw);var cx=cz.getPosition();cz.setPosition(Math.min(cx,cv));}else {cz.setMaximum(0);cz.setKnobFactor(1);cz.setPosition(0);};},onKeepFirstVisibleRowCompleteChanged:function(){this.updateVerScrollBarMaximum();this._updateContent();},_onAppear:function(){this._startInterval(this.getScrollTimeout());},_onDisappear:function(){this._stopInterval();},_onScrollX:function(e){var cB=e.getData();this.fireDataEvent(b,cB,e.getOldData());this._headerClipper.scrollToX(cB);this._paneClipper.scrollToX(cB);},_onScrollY:function(e){this.fireDataEvent(P,e.getData(),e.getOldData());this._postponedUpdateContent();},_onRoll:function(e){var cD=this.getTable();if(e.getPointerType()==y||!cD.getEnabled()){return;};var cE=e.getDelta();if(cE.y>0&&cE.y<1){cE.y=1;}else if(cE.y<0&&cE.y>-1){cE.y=-1;};this.__xc.scrollBy(parseInt(cE.y,10));var cC=cE.y!=0&&!this.__xu(this.__xc,cE.y);if(cE.x>0&&cE.x<1){cE.x=1;}else if(cE.x<0&&cE.x>-1){cE.x=-1;};this.__xb.scrollBy(parseInt(cE.x,10));if(this.__xp&&this.getFocusCellOnPointerMove()){this._focusCellAtPagePos(this.__xp,this.__xq);};cC=cC||(cE.x!=0&&!this.__xu(this.__xb,cE.x));if(cC){e.stop();}else {e.stopMomentum();};},__xu:function(cG,cH){var cF=cG.getPosition();return (cH<0&&cF<=0)||(cH>0&&cF>=cG.getMaximum());},__xv:function(cN){var cL=this.getTable();var cO=this.__wW.getHeaderWidgetAtColumn(this.__xj);var cI=cO.getSizeHint().minWidth;var cK=Math.max(cI,this.__xl+cN-this.__xk);if(this.getLiveResize()){var cJ=cL.getTableColumnModel();cJ.setColumnWidth(this.__xj,cK,true);}else {this.__wW.setColumnWidth(this.__xj,cK,true);var cM=this.getTablePaneModel();this._showResizeLine(cM.getColumnLeft(this.__xj)+cK);};this.__xk+=cK-this.__xl;this.__xl=cK;},__xw:function(cR){var cQ=qx.ui.table.pane.Scroller.TAP_TOLERANCE;if(this.__wW.isShowingColumnMoveFeedback()||cR>this.__xi+cQ||cR<this.__xi-cQ){this.__xh+=cR-this.__xi;this.__wW.showColumnMoveFeedback(this._moveColumn,this.__xh);var cP=this.__wV.getTablePaneScrollerAtPageX(cR);if(this._lastMoveTargetScroller&&this._lastMoveTargetScroller!=cP){this._lastMoveTargetScroller.hideColumnMoveFeedback();};if(cP!=null){this._lastMoveTargetX=cP.showColumnMoveFeedback(cR);}else {this._lastMoveTargetX=null;};this._lastMoveTargetScroller=cP;this.__xi=cR;};},_onPointermoveHeader:function(e){var cY=this.getTable();if(!cY.getEnabled()){return;};var da=false;var cS=null;var cW=e.getDocumentLeft();var cX=e.getDocumentTop();this.__xp=cW;this.__xq=cX;if(this.__xj!=null){this.__xv(cW);da=true;e.stopPropagation();}else if(this._moveColumn!=null){this.__xw(cW);e.stopPropagation();}else {var cT=this._getResizeColumnForPageX(cW);if(cT!=-1){da=true;}else {var cV=cY.getTableModel();var db=this._getColumnForPageX(cW);if(db!=null&&cV.isColumnSortable(db)){cS=db;};};};var cU=da?by:null;this.getApplicationRoot().setGlobalCursor(cU);this.setCursor(cU);this.__wW.setPointerOverColumn(cS);},_onPointermovePane:function(e){var dc=this.getTable();if(!dc.getEnabled()){return;};var de=e.getDocumentLeft();var df=e.getDocumentTop();this.__xp=de;this.__xq=df;var dd=this._getRowForPagePos(de,df);if(dd!=null&&this._getColumnForPageX(de)!=null){if(this.getFocusCellOnPointerMove()){this._focusCellAtPagePos(de,df);};};this.__wW.setPointerOverColumn(null);},_onPointerdownHeader:function(e){if(!this.getTable().getEnabled()){return;};var dh=e.getDocumentLeft();var di=this._getResizeColumnForPageX(dh);if(di!=-1){this._startResizeHeader(di,dh);e.stop();}else {var dg=this._getColumnForPageX(dh);if(dg!=null){this._startMoveHeader(dg,dh);e.stop();};};},_startResizeHeader:function(dl,dj){var dk=this.getTable().getTableColumnModel();this.__xj=dl;this.__xk=dj;this.__xl=dk.getColumnWidth(this.__xj);this._headerClipper.capture();},_startMoveHeader:function(dm,dn){this._moveColumn=dm;this.__xi=dn;this.__xh=this.getTablePaneModel().getColumnLeft(dm);this._headerClipper.capture();},_onPointerdownPane:function(e){var dr=this.getTable();if(!dr.getEnabled()){return;};if(dr.isEditing()){dr.stopEditing();};var dp=e.getDocumentLeft();var dq=e.getDocumentTop();var dt=this._getRowForPagePos(dp,dq);var ds=this._getColumnForPageX(dp);if(dt!==null){this.__xm={row:dt,col:ds};this.__xn=false;};},_onPointerupFocusIndicator:function(e){if(this.__xm&&!this.__xn&&!this.isEditing()&&this.__xd.getRow()==this.__xm.row&&this.__xd.getColumn()==this.__xm.col){this.fireEvent(r,qx.ui.table.pane.CellEvent,[this,e,this.__xm.row,this.__xm.col],true);this.__xn=true;}else if(!this.isEditing()){this._onPointerdownPane(e);};},_onChangeCaptureHeader:function(e){if(this.__xj!=null){this._stopResizeHeader();};if(this._moveColumn!=null){this._stopMoveHeader();};},_stopResizeHeader:function(){var du=this.getTable().getTableColumnModel();if(!this.getLiveResize()){this._hideResizeLine();du.setColumnWidth(this.__xj,this.__xl,true);};this.__xj=null;this._headerClipper.releaseCapture();this.getApplicationRoot().setGlobalCursor(null);this.setCursor(null);if(this.isEditing()){var dv=this._cellEditor.getBounds().height;this._cellEditor.setUserBounds(0,0,this.__xl,dv);};},_stopMoveHeader:function(){var dA=this.getTable().getTableColumnModel();var dB=this.getTablePaneModel();this.__wW.hideColumnMoveFeedback();if(this._lastMoveTargetScroller){this._lastMoveTargetScroller.hideColumnMoveFeedback();};if(this._lastMoveTargetX!=null){var dD=dB.getFirstColumnX()+dB.getX(this._moveColumn);var dz=this._lastMoveTargetX;if(dz!=dD&&dz!=dD+1){var dC=dA.getVisibleColumnAtX(dD);var dy=dA.getVisibleColumnAtX(dz);var dx=dA.getOverallX(dC);var dw=(dy!=null)?dA.getOverallX(dy):dA.getOverallColumnCount();if(dw>dx){dw-- ;};dA.moveColumn(dx,dw);this._updateFocusIndicator();};};this._moveColumn=null;this._lastMoveTargetX=null;this._headerClipper.releaseCapture();},_onPointerupHeader:function(e){var dE=this.getTable();if(!dE.getEnabled()){return;};if(this.__xj!=null){this._stopResizeHeader();this.__xo=true;e.stop();}else if(this._moveColumn!=null){this._stopMoveHeader();e.stop();};},_onTapHeader:function(e){if(this.__xo){this.__xo=false;return;};var dJ=this.getTable();if(!dJ.getEnabled()){return;};var dH=dJ.getTableModel();var dI=e.getDocumentLeft();var dG=this._getResizeColumnForPageX(dI);if(dG==-1){var dM=this._getColumnForPageX(dI);if(dM!=null&&dH.isColumnSortable(dM)){var dF=dH.getSortColumnIndex();var dK=(dM!=dF)?true:!dH.isSortAscending();var dL={column:dM,ascending:dK,tapEvent:e};if(this.fireDataEvent(W,dL,null,true)){if(dJ.isEditing()){dJ.stopEditing();};dH.sortByColumn(dM,dK);if(this.getResetSelectionOnHeaderTap()){dJ.getSelectionModel().resetSelection();};};};};e.stop();},_onTapPane:function(e){var dQ=this.getTable();if(!dQ.getEnabled()){return;};var dO=e.getDocumentLeft();var dP=e.getDocumentTop();var dS=this._getRowForPagePos(dO,dP);var dR=this._getColumnForPageX(dO);if(dS!=null&&dR!=null){var dN=this.getSelectBeforeFocus();if(dN){dQ.getSelectionManager().handleTap(dS,e);};if(!this.getFocusCellOnPointerMove()){this._focusCellAtPagePos(dO,dP);};if(!dN){dQ.getSelectionManager().handleTap(dS,e);};if(this.__xd.isHidden()||(this.__xm&&!this.__xn&&!this.isEditing()&&dS==this.__xm.row&&dR==this.__xm.col)){this.fireEvent(r,qx.ui.table.pane.CellEvent,[this,e,dS,dR],true);this.__xn=true;};};},_onContextMenu:function(e){var dU=e.getDocumentLeft();var dV=e.getDocumentTop();var dX=this._getRowForPagePos(dU,dV);var dW=this._getColumnForPageX(dU);if(dX===null&&this.getContextMenuFromDataCellsOnly()){return;};if(!this.getShowCellFocusIndicator()||dX===null||(this.__xm&&dX==this.__xm.row&&dW==this.__xm.col)){this.fireEvent(bz,qx.ui.table.pane.CellEvent,[this,e,dX,dW],true);var dT=this.getTable().getContextMenu();if(dT){if(dT.getChildren().length>0){dT.openAtPointer(e);}else {dT.exclude();};e.preventDefault();};};},_onContextMenuOpen:function(e){},_onDbltapPane:function(e){var eb=e.getDocumentLeft();var ec=e.getDocumentTop();var ea=this._getColumnForPageX(eb);if(ea!==null){this._focusCellAtPagePos(eb,ec);this.startEditing();var dY=this._getRowForPagePos(eb,ec);if(dY!=-1&&dY!=null){this.fireEvent(k,qx.ui.table.pane.CellEvent,[this,e,dY],true);};};},_onPointerout:function(e){var ed=this.getTable();if(!ed.getEnabled()){return;};if(this.__xj==null){this.setCursor(null);this.getApplicationRoot().setGlobalCursor(null);};this.__wW.setPointerOverColumn(null);if(this.getFocusCellOnPointerMove()){this.__wV.setFocusedCell();};},_showResizeLine:function(x){var ef=this._showChildControl(I);var ee=ef.getWidth();var eg=this._paneClipper.getBounds();ef.setUserBounds(x-Math.round(ee/2),0,ee,eg.height);},_hideResizeLine:function(){this._excludeChildControl(I);},showColumnMoveFeedback:function(ep){var eq=this.getTablePaneModel();var ej=this.getTable().getTableColumnModel();var ek=this.__wX.getContentLocation().left;var eo=eq.getColumnCount();var el=0;var et=0;var ei=ek;for(var eh=0;eh<eo;eh++ ){var es=eq.getColumnAtX(eh);var er=ej.getColumnWidth(es);if(ep<ei+er/2){break;};ei+=er;el=eh+1;et=ei-ek;};var en=this._paneClipper.getContentLocation().left;var em=this._paneClipper.getBounds().width;var scrollX=en-ek;et=qx.lang.Number.limit(et,scrollX+2,scrollX+em-1);this._showResizeLine(et);return eq.getFirstColumnX()+el;},hideColumnMoveFeedback:function(){this._hideResizeLine();},_focusCellAtPagePos:function(ew,eu){var ex=this._getRowForPagePos(ew,eu);if(ex!=-1&&ex!=null){var ev=this._getColumnForPageX(ew);this.__wV.setFocusedCell(ev,ex);};},setFocusedCell:function(ey,ez){if(!this.isEditing()){this.__wX.setFocusedCell(ey,ez,this.__xf);this.__wo=ey;this.__wp=ez;this._updateFocusIndicator();};},getFocusedColumn:function(){return this.__wo;},getFocusedRow:function(){return this.__wp;},scrollCellVisible:function(eM,eN){var eK=this.getTablePaneModel();var eA=eK.getX(eM);if(eA!=-1){var eH=this._paneClipper.getInnerSize();if(!eH){return;};var eD=this.getTable().getTableColumnModel();var eE=eK.getColumnLeft(eM);var eL=eD.getColumnWidth(eM);var eC=this.getTable().getRowHeight();var eB=eN*eC;var scrollX=this.getScrollX();var scrollY=this.getScrollY();var eJ=Math.min(eE,eE+eL-eH.width);var eG=eE;this.setScrollX(Math.max(eJ,Math.min(eG,scrollX)));var eI=eB+eC-eH.height;if(this.getTable().getKeepFirstVisibleRowComplete()){eI+=eC;};var eF=eB;this.setScrollY(Math.max(eI,Math.min(eF,scrollY)),true);};},isEditing:function(){return this._cellEditor!=null;},startEditing:function(){var eS=this.getTable();var eQ=eS.getTableModel();var eU=this.__wo;if(!this.isEditing()&&(eU!=null)&&eQ.isColumnEditable(eU)){var eT=this.__wp;var eO=this.getTablePaneModel().getX(eU);var eP=eQ.getValue(eU,eT);this.scrollCellVisible(eO,eT);this.__xr=eS.getTableColumnModel().getCellEditorFactory(eU);var eR={col:eU,row:eT,xPos:eO,value:eP,table:eS};this._cellEditor=this.__xr.createCellEditor(eR);if(this._cellEditor===null){return false;}else if(this._cellEditor instanceof qx.ui.window.Window){this._cellEditor.setModal(true);this._cellEditor.setShowClose(false);this._cellEditor.addListener(bE,this._onCellEditorModalWindowClose,this);var f=eS.getModalCellEditorPreOpenFunction();if(f!=null){f(this._cellEditor,eR);};this._cellEditor.open();}else {var eV=this.__xd.getInnerSize();this._cellEditor.setUserBounds(0,0,eV.width,eV.height);this.__xt=this.__xd.addListener(T,function(e){this.__xm={row:this.__wp,col:this.__wo};e.stopPropagation();},this);this.__xd.add(this._cellEditor);this.__xd.addState(bL);this.__xd.setKeepActive(false);this.__xd.setDecorator(E);this._cellEditor.focus();this._cellEditor.activate();};return true;};return false;},stopEditing:function(){if(!this.getShowCellFocusIndicator()){this.__xd.setDecorator(null);};this.flushEditor();this.cancelEditing();},flushEditor:function(){if(this.isEditing()){var eW=this.__xr.getCellEditorValue(this._cellEditor);var eX=this.getTable().getTableModel().getValue(this.__wo,this.__wp);this.getTable().getTableModel().setValue(this.__wo,this.__wp,eW);this.__wV.focus();this.__wV.fireDataEvent(v,{row:this.__wp,col:this.__wo,oldValue:eX,value:eW});};},cancelEditing:function(){if(this.isEditing()){if(!(this._cellEditor instanceof qx.ui.window.Window)){this.__xd.removeState(bL);this.__xd.setKeepActive(true);if(this.__xt!==null){this.__xd.removeListenerById(this.__xt);this.__xt=null;};};this._cellEditor.destroy();this._cellEditor=null;this.__xr=null;};},_onCellEditorModalWindowClose:function(e){this.stopEditing();},_getColumnForPageX:function(eY){var fc=this.getTable().getTableColumnModel();var fd=this.getTablePaneModel();var fb=fd.getColumnCount();var fa=this.__wX.getContentLocation().left;for(var x=0;x<fb;x++ ){var ff=fd.getColumnAtX(x);var fe=fc.getColumnWidth(ff);fa+=fe;if(eY<fa){return ff;};};return null;},_getResizeColumnForPageX:function(fh){var fk=this.getTable().getTableColumnModel();var fl=this.getTablePaneModel();var fj=fl.getColumnCount();var fi=this.__wW.getContentLocation().left;var fg=qx.ui.table.pane.Scroller.RESIZE_REGION_RADIUS;for(var x=0;x<fj;x++ ){var fn=fl.getColumnAtX(x);var fm=fk.getColumnWidth(fn);fi+=fm;if(fh>=(fi-fg)&&fh<=(fi+fg)){return fn;};};return -1;},_getRowForPagePos:function(fu,fv){var fo=this.__wX.getContentLocation();if(fu<fo.left||fu>fo.right){return null;};if(fv>=fo.top&&fv<=fo.bottom){var fp=this.getTable().getRowHeight();var scrollY=this.__xc.getPosition();if(this.getTable().getKeepFirstVisibleRowComplete()){scrollY=Math.floor(scrollY/fp)*fp;};var fs=scrollY+fv-fo.top;var fw=Math.floor(fs/fp);var fq=this.getTable().getTableModel();var ft=fq.getRowCount();return (fw<ft)?fw:null;};var fr=this.__wW.getContentLocation();if(fv>=fr.top&&fv<=fr.bottom&&fu<=fr.right){return -1;};return null;},setTopRightWidget:function(fx){var fy=this.__xs;if(fy!=null){this.__wY.remove(fy);};if(fx!=null){this.__wY.add(fx);};this.__xs=fx;},getTopRightWidget:function(){return this.__xs;},getHeader:function(){return this.__wW;},getTablePane:function(){return this.__wX;},getVerticalScrollBarWidth:function(){var fz=this.__xc;return fz.isVisible()?(fz.getSizeHint().width||0):0;},getNeededScrollBars:function(fD,fE){var fP=this.__xc;var fO=fP.getSizeHint().width+fP.getMarginLeft()+fP.getMarginRight();var fJ=this.__xb;var fM=fJ.getSizeHint().height+fJ.getMarginTop()+fJ.getMarginBottom();var fG=this._paneClipper.getInnerSize();var fA=fG?fG.width:0;if(this.getVerticalScrollBarVisible()){fA+=fO;};var fK=fG?fG.height:0;if(this.getHorizontalScrollBarVisible()){fK+=fM;};var fH=this.getTable().getTableModel();var fI=fH.getRowCount();var fB=this.getTablePaneModel().getTotalWidth();var fL=this.getTable().getRowHeight()*fI;var fC=false;var fQ=false;if(fB>fA){fC=true;if(fL>fK-fM){fQ=true;};}else if(fL>fK){fQ=true;if(!fE&&(fB>fA-fO)){fC=true;};};var fF=qx.ui.table.pane.Scroller.HORIZONTAL_SCROLLBAR;var fN=qx.ui.table.pane.Scroller.VERTICAL_SCROLLBAR;return ((fD||fC)?fF:0)|((fE||!fQ)?0:fN);},getPaneClipper:function(){return this._paneClipper;},getScrollAreaContainer:function(){return this.getPaneClipper();},_applyScrollTimeout:function(fS,fR){this._startInterval(fS);},_startInterval:function(fT){this.__de.setInterval(fT);this.__de.start();},_stopInterval:function(){this.__de.stop();},_postponedUpdateContent:function(){this._updateContent();},_oninterval:qx.event.GlobalError.observeMethod(function(){if(this.__xf&&!this.__wX._layoutPending){this.__xf=false;this._updateContent();};}),_updateContent:function(){var gc=this._paneClipper.getInnerSize();if(!gc){return;};var ga=gc.height;var scrollX=this.__xb.getPosition();var scrollY=this.__xc.getPosition();var fV=this.getTable().getRowHeight();var fX=Math.floor(scrollY/fV);var gb=this.__wX.getFirstVisibleRow();this.__wX.setFirstVisibleRow(fX);var fW=Math.ceil(ga/fV);var fU=0;var fY=this.getTable().getKeepFirstVisibleRowComplete();if(!fY){fW++ ;fU=scrollY%fV;};this.__wX.setVisibleRowCount(fW);if(fX!=gb){this._updateFocusIndicator();};this._paneClipper.scrollToX(scrollX);if(!fY){this._paneClipper.scrollToY(fU);};},_updateFocusIndicator:function(){var gd=this.getTable();if(!gd.getEnabled()){return;};this.__xd.moveToCell(this.__wo,this.__wp);}},destruct:function(){this._stopInterval();var ge=this.getTablePaneModel();if(ge){ge.dispose();};this.__xm=this.__xs=this.__wV=null;this._disposeObjects(Q,d,F,i,Y,w,H,B,m,a);}});})();(function(){var a="Escape",b="keypress",c="Enter",d="excluded",f="Integer",g="qx.ui.table.pane.FocusIndicator";qx.Class.define(g,{extend:qx.ui.container.Composite,construct:function(h){qx.ui.container.Composite.call(this);this.__xx=h;this.setKeepActive(true);this.addListener(b,this._onKeyPress,this);},properties:{visibility:{refine:true,init:d},row:{check:f,nullable:true},column:{check:f,nullable:true}},members:{__xx:null,_onKeyPress:function(e){var i=e.getKeyIdentifier();if(i!==a&&i!==c){e.stopPropagation();};},moveToCell:function(p,q){if(!this.__xx.getShowCellFocusIndicator()&&!this.__xx.getTable().getTableModel().isColumnEditable(p)){this.exclude();return;}else {this.show();};if(p==null){this.hide();this.setRow(null);this.setColumn(null);}else {var j=this.__xx.getTablePaneModel().getX(p);if(j==-1){this.hide();this.setRow(null);this.setColumn(null);}else {var o=this.__xx.getTable();var m=o.getTableColumnModel();var n=this.__xx.getTablePaneModel();var l=this.__xx.getTablePane().getFirstVisibleRow();var k=o.getRowHeight();this.setUserBounds(n.getColumnLeft(p)-2,(q-l)*k-2,m.getColumnWidth(p)+3,k+3);this.show();this.setRow(q);this.setColumn(p);};};}},destruct:function(){this.__xx=null;}});})();(function(){var a="qx.ui.table.pane.Clipper";qx.Class.define(a,{extend:qx.ui.container.Composite,construct:function(){qx.ui.container.Composite.call(this,new qx.ui.layout.Grow());this.setMinWidth(0);},members:{scrollToX:function(b){this.getContentElement().scrollToX(b,false);},scrollToY:function(c){this.getContentElement().scrollToY(c,true);}}});})();(function(){var a="Integer",b="qx.ui.table.pane.CellEvent";qx.Class.define(b,{extend:qx.event.type.Pointer,properties:{row:{check:a,nullable:true},column:{check:a,nullable:true}},members:{init:function(e,c,f,d){c.clone(this);this.setBubbles(false);if(f!=null){this.setRow(f);}else {this.setRow(e._getRowForPagePos(this.getDocumentLeft(),this.getDocumentTop()));};if(d!=null){this.setColumn(d);}else {this.setColumn(e._getColumnForPageX(this.getDocumentLeft()));};},clone:function(g){var h=qx.event.type.Pointer.prototype.clone.call(this,g);h.set({row:this.getRow(),column:this.getColumn()});return h;}}});})();(function(){var a="qx.lang.Number";qx.Class.define(a,{statics:{isInRange:function(c,d,b){return c>=d&&c<=b;},isBetweenRange:function(f,g,e){return f>g&&f<e;},limit:function(i,j,h){if(h!=null&&i>h){return h;}else if(j!=null&&i<j){return j;}else {return i;};}}});})();(function(){var a="Number",b="qx.event.type.Event",c="modelChanged",d="_applyFirstColumnX",e="headerCellRendererChanged",f="Integer",g="qx.ui.table.pane.Model",h="_applyMaxColumnCount",i="visibilityChangedPre";qx.Class.define(g,{extend:qx.core.Object,construct:function(j){qx.core.Object.call(this);this.setTableColumnModel(j);},events:{"modelChanged":b},statics:{EVENT_TYPE_MODEL_CHANGED:c},properties:{firstColumnX:{check:f,init:0,apply:d},maxColumnCount:{check:a,init:-1,apply:h}},members:{__xy:null,__xz:null,_applyFirstColumnX:function(l,k){this.__xy=null;this.fireEvent(qx.ui.table.pane.Model.EVENT_TYPE_MODEL_CHANGED);},_applyMaxColumnCount:function(n,m){this.__xy=null;this.fireEvent(qx.ui.table.pane.Model.EVENT_TYPE_MODEL_CHANGED);},setTableColumnModel:function(o){if(this.__xz){this.__xz.removeListener(i,this._onColVisibilityChanged,this);this.__xz.removeListener(e,this._onHeaderCellRendererChanged,this);};this.__xz=o;this.__xz.addListener(i,this._onColVisibilityChanged,this);this.__xz.addListener(e,this._onHeaderCellRendererChanged,this);this.__xy=null;},_onColVisibilityChanged:function(p){this.__xy=null;this.fireEvent(qx.ui.table.pane.Model.EVENT_TYPE_MODEL_CHANGED);},_onHeaderCellRendererChanged:function(q){this.fireEvent(qx.ui.table.pane.Model.EVENT_TYPE_MODEL_CHANGED);},getColumnCount:function(){if(this.__xy==null){var r=this.getFirstColumnX();var t=this.getMaxColumnCount();var s=this.__xz.getVisibleColumnCount();if(t==-1||(r+t)>s){this.__xy=s-r;}else {this.__xy=t;};};return this.__xy;},getColumnAtX:function(v){var u=this.getFirstColumnX();return this.__xz.getVisibleColumnAtX(u+v);},getX:function(z){var w=this.getFirstColumnX();var y=this.getMaxColumnCount();var x=this.__xz.getVisibleX(z)-w;if(x>=0&&(y==-1||x<y)){return x;}else {return -1;};},getColumnLeft:function(D){var B=0;var C=this.getColumnCount();for(var x=0;x<C;x++ ){var A=this.getColumnAtX(x);if(A==D){return B;};B+=this.__xz.getColumnWidth(A);};return -1;},getTotalWidth:function(){var E=0;var F=this.getColumnCount();for(var x=0;x<F;x++ ){var G=this.getColumnAtX(x);E+=this.__xz.getColumnWidth(G);};return E;}},destruct:function(){if(this.__xz){this.__xz.removeListener(i,this._onColVisibilityChanged,this);this.__xz.removeListener(e,this._onHeaderCellRendererChanged,this);};this.__xz=null;}});})();(function(){var a="qx.ui.table.model.Simple",b="Boolean",c="this.__rowArr out of bounds: ",d="metaDataChanged",e=")",f="dataChanged",g=" (0..",h="sorted";qx.Class.define(a,{extend:qx.ui.table.model.Abstract,construct:function(){qx.ui.table.model.Abstract.call(this);this.__xA=[];this.__xB=-1;this.__xC=[];this.__xD=null;},properties:{caseSensitiveSorting:{check:b,init:true}},statics:{_defaultSortComparatorAscending:function(l,m){var k=l[arguments.callee.columnIndex];var n=m[arguments.callee.columnIndex];if(qx.lang.Type.isNumber(k)&&qx.lang.Type.isNumber(n)){var o=isNaN(k)?isNaN(n)?0:1:isNaN(n)?-1:null;if(o!=null){return o;};};return (k>n)?1:((k==n)?0:-1);},_defaultSortComparatorInsensitiveAscending:function(q,r){var p=(q[arguments.callee.columnIndex].toLowerCase?q[arguments.callee.columnIndex].toLowerCase():q[arguments.callee.columnIndex]);var s=(r[arguments.callee.columnIndex].toLowerCase?r[arguments.callee.columnIndex].toLowerCase():r[arguments.callee.columnIndex]);if(qx.lang.Type.isNumber(p)&&qx.lang.Type.isNumber(s)){var t=isNaN(p)?isNaN(s)?0:1:isNaN(s)?-1:null;if(t!=null){return t;};};return (p>s)?1:((p==s)?0:-1);},_defaultSortComparatorDescending:function(v,w){var u=v[arguments.callee.columnIndex];var x=w[arguments.callee.columnIndex];if(qx.lang.Type.isNumber(u)&&qx.lang.Type.isNumber(x)){var y=isNaN(u)?isNaN(x)?0:1:isNaN(x)?-1:null;if(y!=null){return y;};};return (u<x)?1:((u==x)?0:-1);},_defaultSortComparatorInsensitiveDescending:function(A,B){var z=(A[arguments.callee.columnIndex].toLowerCase?A[arguments.callee.columnIndex].toLowerCase():A[arguments.callee.columnIndex]);var C=(B[arguments.callee.columnIndex].toLowerCase?B[arguments.callee.columnIndex].toLowerCase():B[arguments.callee.columnIndex]);if(qx.lang.Type.isNumber(z)&&qx.lang.Type.isNumber(C)){var D=isNaN(z)?isNaN(C)?0:1:isNaN(C)?-1:null;if(D!=null){return D;};};return (z<C)?1:((z==C)?0:-1);}},members:{__xA:null,__xD:null,__xE:null,__xC:null,__xB:null,__xF:null,getRowData:function(E){var F=this.__xA[E];if(F==null||F.originalData==null){return F;}else {return F.originalData;};},getRowDataAsMap:function(G){var I=this.__xA[G];if(I!=null){var H={};for(var J=0;J<this.getColumnCount();J++ ){H[this.getColumnId(J)]=I[J];};if(I.originalData!=null){for(var K in I.originalData){if(H[K]==undefined){H[K]=I.originalData[K];};};};return H;};return (I&&I.originalData)?I.originalData:null;},getDataAsMapArray:function(){var M=this.getRowCount();var L=[];for(var i=0;i<M;i++ ){L.push(this.getRowDataAsMap(i));};return L;},setEditable:function(N){this.__xD=[];for(var O=0;O<this.getColumnCount();O++ ){this.__xD[O]=N;};this.fireEvent(d);},setColumnEditable:function(P,Q){if(Q!=this.isColumnEditable(P)){if(this.__xD==null){this.__xD=[];};this.__xD[P]=Q;this.fireEvent(d);};},isColumnEditable:function(R){return this.__xD?(this.__xD[R]==true):false;},setColumnSortable:function(S,T){if(T!=this.isColumnSortable(S)){if(this.__xE==null){this.__xE=[];};this.__xE[S]=T;this.fireEvent(d);};},isColumnSortable:function(U){return (this.__xE?(this.__xE[U]!==false):true);},sortByColumn:function(V,ba){var Y;var X=this.__xC[V];if(X){Y=(ba?X.ascending:X.descending);}else {if(this.getCaseSensitiveSorting()){Y=(ba?qx.ui.table.model.Simple._defaultSortComparatorAscending:qx.ui.table.model.Simple._defaultSortComparatorDescending);}else {Y=(ba?qx.ui.table.model.Simple._defaultSortComparatorInsensitiveAscending:qx.ui.table.model.Simple._defaultSortComparatorInsensitiveDescending);};};Y.columnIndex=V;this.__xA.sort(Y);this.__xB=V;this.__xF=ba;var W={columnIndex:V,ascending:ba};this.fireDataEvent(h,W);this.fireEvent(d);},setSortMethods:function(bb,bc){var bd;if(qx.lang.Type.isFunction(bc)){bd={ascending:bc,descending:function(be,bf){return bc(bf,be);}};}else {bd=bc;};this.__xC[bb]=bd;},getSortMethods:function(bg){return this.__xC[bg];},clearSorting:function(){if(this.__xB!=-1){this.__xB=-1;this.__xF=true;this.fireEvent(d);};},getSortColumnIndex:function(){return this.__xB;},_setSortColumnIndex:function(bh){this.__xB=bh;},isSortAscending:function(){return this.__xF;},_setSortAscending:function(bi){this.__xF=bi;},getRowCount:function(){return this.__xA.length;},getValue:function(bk,bj){if(bj<0||bj>=this.__xA.length){throw new Error(c+bj+g+this.__xA.length+e);};return this.__xA[bj][bk];},setValue:function(bm,bl,bo){if(this.__xA[bl][bm]!=bo){this.__xA[bl][bm]=bo;if(this.hasListener(f)){var bn={firstRow:bl,lastRow:bl,firstColumn:bm,lastColumn:bm};this.fireDataEvent(f,bn);};if(bm==this.__xB){this.clearSorting();};};},setData:function(bq,bp){this.__xA=bq;if(this.hasListener(f)){var br={firstRow:0,lastRow:bq.length-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,br);};if(bp!==false){this.clearSorting();};},getData:function(){return this.__xA;},setDataAsMapArray:function(bt,bs,bu){this.setData(this._mapArray2RowArr(bt,bs),bu);},addRows:function(bx,bw,bv){if(bw==null){bw=this.__xA.length;};bx.splice(0,0,bw,0);Array.prototype.splice.apply(this.__xA,bx);var by={firstRow:bw,lastRow:this.__xA.length-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,by);if(bv!==false){this.clearSorting();};},addRowsAsMapArray:function(bA,bB,bz,bC){this.addRows(this._mapArray2RowArr(bA,bz),bB,bC);},setRows:function(bF,bE,bD){if(bE==null){bE=0;};bF.splice(0,0,bE,bF.length);Array.prototype.splice.apply(this.__xA,bF);var bG={firstRow:bE,lastRow:this.__xA.length-1,firstColumn:0,lastColumn:this.getColumnCount()-1};this.fireDataEvent(f,bG);if(bD!==false){this.clearSorting();};},setRowsAsMapArray:function(bI,bJ,bH,bK){this.setRows(this._mapArray2RowArr(bI,bH),bJ,bK);},removeRows:function(bM,bN,bL){this.__xA.splice(bM,bN);var bO={firstRow:bM,lastRow:this.__xA.length-1,firstColumn:0,lastColumn:this.getColumnCount()-1,removeStart:bM,removeCount:bN};this.fireDataEvent(f,bO);if(bL!==false){this.clearSorting();};},_mapArray2RowArr:function(bQ,bU){var bT=bQ.length;var bP=this.getColumnCount();var bS=new Array(bT);var bR;for(var i=0;i<bT; ++i){bR=[];if(bU){bR.originalData=bQ[i];};for(var j=0;j<bP; ++j){bR[j]=bQ[i][this.getColumnId(j)];};bS[i]=bR;};return bS;}},destruct:function(){this.__xA=this.__xD=this.__xC=this.__xE=null;}});})();(function(){var a='Boolean',b='execute',c='clui.view.widget.table.ExtendedColumnTable',d='column-button';qx.Class.define(c,{extend:qx.ui.table.Table,properties:{newTableColumnModel:{refine:true,init:function(e){return new qx.ui.table.columnmodel.Resize(e);}},suppressMetaDataChangePropagation:{check:a,init:false}},members:{_createChildControlImpl:function(h,g){var f=null;if(h==d){f=new clui.view.widget.table.TableColumnButton();f.setFocusable(false);f.addListener(b,function(){if(f.getMenu()){f.getMenu().open();};},this);};return f||qx.ui.table.Table.prototype._createChildControlImpl.call(this,h,g);},_onTableModelMetaDataChanged:function(event){if(!this.getSuppressMetaDataChangePropagation()){qx.ui.table.Table.prototype._onTableModelMetaDataChanged.call(this,event);};}}});})();(function(){var a="columnVisibilityMenuCreateEnd",b="tableWidthChanged",c="verticalScrollBarChanged",d="qx.ui.table.columnmodel.resizebehavior.Abstract",e="qx.ui.table.columnmodel.Resize",f="_applyBehavior",g="separator",h="appear",i="visibilityChanged",j="Reset column widths",k="changeBehavior",l="user-button",m="widthChanged",n="execute";qx.Class.define(e,{extend:qx.ui.table.columnmodel.Basic,include:qx.locale.MTranslation,construct:function(){qx.ui.table.columnmodel.Basic.call(this);this.__xG=false;this.__xH=false;},properties:{behavior:{check:d,init:null,nullable:true,apply:f,event:k}},members:{__xH:null,__xG:null,__wV:null,_applyBehavior:function(q,p){if(p!=null){p.dispose();p=null;};q._setNumColumns(this.getOverallColumnCount());q.setTableColumnModel(this);},init:function(s,r){qx.ui.table.columnmodel.Basic.prototype.init.call(this,s,r);if(this.__wV==null){this.__wV=r;r.addListener(h,this._onappear,this);r.addListener(b,this._onTableWidthChanged,this);r.addListener(c,this._onverticalscrollbarchanged,this);r.addListener(a,this._addResetColumnWidthButton,this);this.addListener(m,this._oncolumnwidthchanged,this);this.addListener(i,this._onvisibilitychanged,this);};if(this.getBehavior()==null){this.setBehavior(new qx.ui.table.columnmodel.resizebehavior.Default());};this.getBehavior()._setNumColumns(s);},getTable:function(){return this.__wV;},_addResetColumnWidthButton:function(event){var v=event.getData();var u=v.columnButton;var t=v.menu;var o;o=u.factory(g);t.add(o);o=u.factory(l,{text:this.tr(j)});t.add(o);o.addListener(n,this._onappear,this);},_onappear:function(event){if(this.__xG){return;};this.__xG=true;{};this.getBehavior().onAppear(event,event.getType()!==h);this.__wV._updateScrollerWidths();this.__wV._updateScrollBarVisibility();this.__xG=false;this.__xH=true;},_onTableWidthChanged:function(event){if(this.__xG||!this.__xH){return;};this.__xG=true;{};this.getBehavior().onTableWidthChanged(event);this.__xG=false;},_onverticalscrollbarchanged:function(event){if(this.__xG||!this.__xH){return;};this.__xG=true;{};this.getBehavior().onVerticalScrollBarChanged(event);qx.event.Timer.once(function(){if(this.__wV&&!this.__wV.isDisposed()){this.__wV._updateScrollerWidths();this.__wV._updateScrollBarVisibility();};},this,0);this.__xG=false;},_oncolumnwidthchanged:function(event){if(this.__xG||!this.__xH){return;};this.__xG=true;{};this.getBehavior().onColumnWidthChanged(event);this.__xG=false;},_onvisibilitychanged:function(event){if(this.__xG||!this.__xH){return;};this.__xG=true;{};this.getBehavior().onVisibilityChanged(event);this.__xG=false;}},destruct:function(){this.__wV=null;}});})();(function(){var a="string",b="number",c="auto",d="*",e="qx.ui.core.ColumnData";qx.Class.define(e,{extend:qx.ui.core.LayoutItem,construct:function(){qx.ui.core.LayoutItem.call(this);this.setColumnWidth(c);},members:{__xI:null,renderLayout:function(g,top,f,h){this.__xI=f;},getComputedWidth:function(){return this.__xI;},getFlex:function(){return this.getLayoutProperties().flex||0;},setColumnWidth:function(l,i){var i=i||0;var j=null;if(typeof l==b){this.setWidth(l);}else if(typeof l==a){if(l==c){i=1;}else {var k=l.match(/^[0-9]+(?:\.[0-9]+)?([%\*])$/);if(k){if(k[1]==d){i=parseFloat(l);}else {j=l;};};};};this.setLayoutProperties({flex:i,width:j});}},environment:{"qx.tableResizeDebug":false}});})();(function(){var a="onAppear is abstract",b="onVisibilityChanged is abstract",c="onVerticalScrollBarChanged is abstract",d="abstract",e="qx.ui.table.columnmodel.resizebehavior.Abstract",f="_setNumColumns is abstract",g="onTableWidthChanged is abstract",h="onColumnWidthChanged is abstract";qx.Class.define(e,{type:d,extend:qx.core.Object,members:{_setNumColumns:function(i){throw new Error(f);},onAppear:function(event,j){throw new Error(a);},onTableWidthChanged:function(event){throw new Error(g);},onVerticalScrollBarChanged:function(event){throw new Error(c);},onColumnWidthChanged:function(event){throw new Error(h);},onVisibilityChanged:function(event){throw new Error(b);},_getAvailableWidth:function(){var l=this.getTableColumnModel();var o=l.getTable();var k=o._getPaneScrollerArr();if(!k[0]||!k[0].getLayoutParent().getBounds()){return null;};var n=k[0].getLayoutParent().getBounds().width;var m=k[k.length-1];n-=m.getPaneInsetRight();return n;}}});})();(function(){var a="Column number out of range",b="Function",c="__xL",d="Boolean",e="minWidth",f="width",g="qx.ui.table.columnmodel.Resize",h="qx.ui.table.columnmodel.resizebehavior.Default",j="Unknown property: ",k="maxWidth",m="__xK";qx.Class.define(h,{extend:qx.ui.table.columnmodel.resizebehavior.Abstract,construct:function(){qx.ui.table.columnmodel.resizebehavior.Abstract.call(this);this.__xJ=[];this.__xK=new qx.ui.layout.HBox();this.__xK.connectToWidget(this);this.__xL=new qx.util.DeferredCall(this._computeColumnsFlexWidth,this);},properties:{newResizeBehaviorColumnData:{check:b,init:function(n){return new qx.ui.core.ColumnData();}},initializeWidthsOnEveryAppear:{check:d,init:false},tableColumnModel:{check:g}},members:{__xK:null,__xM:null,__xJ:null,__xL:null,__xN:false,setWidth:function(p,o,q){if(p>=this.__xJ.length){throw new Error(a);};this.__xJ[p].setColumnWidth(o,q);this.__xL.schedule();},setMinWidth:function(s,r){if(s>=this.__xJ.length){throw new Error(a);};this.__xJ[s].setMinWidth(r);this.__xL.schedule();},setMaxWidth:function(u,t){if(u>=this.__xJ.length){throw new Error(a);};this.__xJ[u].setMaxWidth(t);this.__xL.schedule();},set:function(w,v){for(var x in v){switch(x){case f:this.setWidth(w,v[x]);break;case e:this.setMinWidth(w,v[x]);break;case k:this.setMaxWidth(w,v[x]);break;default:throw new Error(j+x);};};},onAppear:function(event,y){if(y===true||!this.__xN||this.getInitializeWidthsOnEveryAppear()){this._computeColumnsFlexWidth();this.__xN=true;};},onTableWidthChanged:function(event){this._computeColumnsFlexWidth();},onVerticalScrollBarChanged:function(event){this._computeColumnsFlexWidth();},onColumnWidthChanged:function(event){this._extendNextColumn(event);},onVisibilityChanged:function(event){var z=event.getData();if(z.visible){this._computeColumnsFlexWidth();return;};this._extendLastColumn(event);},_setNumColumns:function(B){var A=this.__xJ;if(B<=A.length){A.splice(B,A.length);return;};for(var i=A.length;i<B;i++ ){A[i]=this.getNewResizeBehaviorColumnData()();A[i].columnNumber=i;};},getLayoutChildren:function(){return this.__xM;},_computeColumnsFlexWidth:function(){this.__xL.cancel();var C=this._getAvailableWidth();if(C===null){return;};var G=this.getTableColumnModel();var E=G.getVisibleColumns();var F=E.length;var D=this.__xJ;var i,l;if(F===0){return;};var I=[];for(i=0;i<F;i++ ){I.push(D[E[i]]);};this.__xM=I;this.__xO();this.__xK.renderLayout(C,100,{top:0,right:0,bottom:0,left:0});for(i=0,l=I.length;i<l;i++ ){var H=I[i].getComputedWidth();G.setColumnWidth(E[i],H);};},__xO:function(){this.__xK.invalidateChildrenCache();var J=this.__xM;for(var i=0,l=J.length;i<l;i++ ){J[i].invalidateLayoutCache();};},_extendNextColumn:function(event){var L=this.getTableColumnModel();var R=event.getData();var M=L.getVisibleColumns();var O=this._getAvailableWidth();var K=M.length;if(R.newWidth>R.oldWidth){return;};var i;var N;var Q=0;for(i=0;i<K;i++ ){Q+=L.getColumnWidth(M[i]);};if(Q<O){for(i=0;i<M.length;i++ ){if(M[i]==R.col){N=M[i+1];break;};};if(N){var P=(O-(Q-L.getColumnWidth(N)));L.setColumnWidth(N,P);};};},_extendLastColumn:function(event){var T=this.getTableColumnModel();var ba=event.getData();if(ba.visible){return;};var U=T.getVisibleColumns();if(U.length==0){return;};var V=this._getAvailableWidth(T);var S=U.length;var i;var X;var Y=0;for(i=0;i<S;i++ ){Y+=T.getColumnWidth(U[i]);};if(Y<V){X=U[U.length-1];var W=(V-(Y-T.getColumnWidth(X)));T.setColumnWidth(X,W);};},_getResizeColumnData:function(){return this.__xJ;}},destruct:function(){this.__xJ=this.__xM=null;this._disposeObjects(m,c);}});})();(function(){var a='clui.view.widget.table.TableColumnButton',b='qx.ui.core.Widget',c='_blocker';qx.Class.define(a,{extend:qx.ui.form.Button,implement:qx.ui.table.IColumnMenuButton,properties:{menu:{check:b}},construct:function(){qx.ui.form.Button.call(this);this._blocker=new qx.ui.core.Blocker(this);},destruct:function(){this._disposeObjects(c);},members:{_blocker:null,getBlocker:function(){return this._blocker;},factory:function(d,e){},empty:function(){}}});})();(function(){var a='Column selection',b='%1 existing columns',c='%1 row in table cache',d=' · ',e='appear',f='qx.ui.table.ITableModel',g='qx.data.Array',h='children',i='rowDataArr',j='Adding new column "{0}"',k='%1 rows in table cache',l='rowBlockCache',m='name',n='checked',o='clui.view.list.ColumnTree',p='value',q='visible',r='type',s='Setting visiblity of "{0}" to {1}',t='changeBubble';qx.Class.define(o,{extend:clui.view.list.Abstract,construct:function(){clui.view.list.Abstract.call(this);this.set({'showMaximize':false,'showMinimize':false,'showClose':true,'width':400,'height':300});this.addListener(e,this._updateTreeModel,this);this.addListener(e,this._updateCaption,this);this.addListener(e,this.center,this);},properties:{tableModel:{check:f},columnset:{check:g}},members:{_createDataWidget:function(){var u=new qx.ui.tree.VirtualTree(null,m,h);u.set({'focusable':false,'hideRoot':true,'showTopLevelOpenCloseIcons':true});u.setDelegate({createItem:function(){return new clui.view.widget.table.ColumnTreeItem();},bindItem:function(x,w,y){x.bindDefaultProperties(w,y);x.bindProperty(q,n,null,w,y);x.bindPropertyReverse(q,n,null,w,y);x.bindProperty(r,r,null,w,y);}});return u;},_updateTreeModel:function(){var z=clui.util.ColumnTreeBuilder.getColumnTree(this.getColumnset(),this.getTableModel());var A=qx.data.marshal.Json.createModel(z,true);A.addListener(t,this._onTreeModelChangeBubble,this);this._dataWidget.setModel(A);},_updateCaption:function(){var C=qx.lang.Array.sum(kucken.lang.Object.values(this.getTableModel().getCacheContent()[l]).map(function(D){return D[i].length;}));var B=[this.tr(a),this.tr(b,this.getColumnset().getLength()),this.trn(c,k,C,C)].join(d);this.setCaption(B);},_onTreeModelChangeBubble:function(event){var G=new clui.util.PropertyChain(event);if(!G.isChangeOf(q)){return;};var E=G.getPropertyOwner(q);var H=this.getColumnset().filter(function(v){return v.getId()==E.getId();});if(H.getLength()){this.debug(s.format(E.getId(),event.getData()[p]));H.getItem(0).setVisible(event.getData()[p]);}else {this.debug(j.format(E.getId()));var F=qx.data.marshal.Json.createModel(qx.util.Serializer.toNativeObject(E),true);F.setName(F.getId());this.getColumnset().push(F);};},getTree:function(){return this.getDataWidget();}}});})();(function(){var a="qx.ui.tree.core.IVirtualTree";qx.Interface.define(a,{members:{isShowTopLevelOpenCloseIcons:function(){},getLookupTable:function(){},isNode:function(b){this.assertArgumentsCount(arguments,1,1);this.assertInterface(b,qx.core.Object);},isNodeOpen:function(c){this.assertArgumentsCount(arguments,1,1);this.assertInterface(c,qx.core.Object);},getLevel:function(d){this.assertArgumentsCount(arguments,1,1);this.assertInteger(d);},hasChildren:function(e){this.assertArgumentsCount(arguments,1,1);this.assertInterface(e,qx.core.Object);},openNode:function(f){this.assertArgumentsCount(arguments,1,1);this.assertInterface(f,qx.core.Object);},openNodeWithoutScrolling:function(g){this.assertArgumentsCount(arguments,1,1);this.assertInterface(g,qx.core.Object);},closeNode:function(h){this.assertArgumentsCount(arguments,1,1);this.assertInterface(h,qx.core.Object);},closeNodeWithoutScrolling:function(i){this.assertArgumentsCount(arguments,1,1);this.assertInterface(i,qx.core.Object);},getSelection:function(){}}});})();(function(){var a="scrollY",b="The method 'getItemRight' is not implemented!",c="update",d="scrollX",f="The method 'getItemLeft' is not implemented!",g="The method 'getItemBottom' is not implemented!",h="The method 'getItemTop' is not implemented!",i="pane",j="os.scrollBarOverlayed",k="qx.ui.virtual.core.Scroller";qx.Class.define(k,{extend:qx.ui.core.scroll.AbstractScrollArea,construct:function(o,l,n,m){qx.ui.core.scroll.AbstractScrollArea.call(this);this.__qW=new qx.ui.virtual.core.Pane(o,l,n,m);this.__qW.addListener(c,this._computeScrollbars,this);this.__qW.addListener(d,this._onScrollPaneX,this);this.__qW.addListener(a,this._onScrollPaneY,this);if(qx.core.Environment.get(j)){this._add(this.__qW,{edge:0});}else {this._add(this.__qW,{row:0,column:0});};},properties:{width:{refine:true,init:null},height:{refine:true,init:null}},members:{__qW:null,getPane:function(){return this.__qW;},_createChildControlImpl:function(q,p){if(q==i){return this.__qW;}else {return qx.ui.core.scroll.AbstractScrollArea.prototype._createChildControlImpl.call(this,q);};},getItemTop:function(r){throw new Error(h);},getItemBottom:function(s){throw new Error(g);},getItemLeft:function(t){throw new Error(f);},getItemRight:function(u){throw new Error(b);},_onScrollBarX:function(e){this.__qW.setScrollX(e.getData());},_onScrollBarY:function(e){this.__qW.setScrollY(e.getData());}},destruct:function(){this.__qW.dispose();this.__qW=null;}});})();(function(){var a="qx.ui.virtual.core.Pane",b="resize",c="qx.ui.virtual.core.CellEvent",d="update",f="scrollX",g="scrollY",h="change",j="contextmenu",k="__rf",l="appear",m="__rg",n="cellDbltap",o="pointerdown",p="__qX",q="tap",r="qx.event.type.Event",s="qx.event.type.Data",t="cellTap",u="cellContextmenu",v="__qY",w="dbltap";qx.Class.define(a,{extend:qx.ui.core.Widget,construct:function(A,x,z,y){qx.ui.core.Widget.call(this);this.__qX=new qx.ui.virtual.core.Axis(z,A);this.__qY=new qx.ui.virtual.core.Axis(y,x);this.__ra=0;this.__rb=0;this.__rc=0;this.__rd=0;this.__re={};this.__jj={};this.__rf=new qx.ui.container.Composite();this.__rf.setUserBounds(0,0,0,0);this._add(this.__rf);this.__rg=[];this.__qX.addListener(h,this.fullUpdate,this);this.__qY.addListener(h,this.fullUpdate,this);this.addListener(b,this._onResize,this);this.addListenerOnce(l,this._onAppear,this);this.addListener(o,this._onPointerDown,this);this.addListener(q,this._onTap,this);this.addListener(w,this._onDbltap,this);this.addListener(j,this._onContextmenu,this);},events:{cellTap:c,cellContextmenu:c,cellDbltap:c,update:r,scrollX:s,scrollY:s},properties:{width:{refine:true,init:400},height:{refine:true,init:300}},members:{__qX:null,__qY:null,__ra:null,__rb:null,__rc:null,__rd:null,__re:null,__jj:null,__rf:null,__rg:null,__rh:null,__pI:null,__ri:null,__rj:null,getRowConfig:function(){return this.__qX;},getColumnConfig:function(){return this.__qY;},getChildren:function(){return [this.__rf];},addLayer:function(B){{};this.__rg.push(B);B.setUserBounds(0,0,0,0);this.__rf.add(B);},getLayers:function(){return this.__rg;},getVisibleLayers:function(){var C=[];for(var i=0;i<this.__rg.length;i++ ){var D=this.__rg[i];if(D.isVisible()){C.push(D);};};return C;},getScrollMaxX:function(){var E=this.getInnerSize();if(E){return Math.max(0,this.__qY.getTotalSize()-E.width);};return 0;},getScrollMaxY:function(){var F=this.getInnerSize();if(F){return Math.max(0,this.__qX.getTotalSize()-F.height);};return 0;},setScrollY:function(I){var G=this.getScrollMaxY();if(I<0){I=0;}else if(I>G){I=G;};if(this.__ra!==I){var H=this.__ra;this.__ra=I;this._deferredUpdateScrollPosition();this.fireDataEvent(g,I,H);};},getScrollY:function(){return this.__ra;},setScrollX:function(L){var J=this.getScrollMaxX();if(L<0){L=0;}else if(L>J){L=J;};if(L!==this.__rb){var K=this.__rb;this.__rb=L;this._deferredUpdateScrollPosition();this.fireDataEvent(f,L,K);};},getScrollX:function(){return this.__rb;},getScrollSize:function(){return {width:this.__qY.getTotalSize(),height:this.__qX.getTotalSize()};},scrollRowIntoView:function(O){var P=this.getBounds();if(!P){this.addListenerOnce(l,function(){qx.event.Timer.once(function(){this.scrollRowIntoView(O);},this,0);},this);return;};var Q=this.__qX.getItemPosition(O);var N=Q+this.__qX.getItemSize(O);var M=this.getScrollY();if(Q<M){this.setScrollY(Q);}else if(N>M+P.height){this.setScrollY(N-P.height);};},scrollColumnIntoView:function(R){var U=this.getBounds();if(!U){this.addListenerOnce(l,function(){qx.event.Timer.once(function(){this.scrollColumnIntoView(R);},this,0);},this);return;};var T=this.__qY.getItemPosition(R);var S=T+this.__qY.getItemSize(R);var V=this.getScrollX();if(T<V){this.setScrollX(T);}else if(S>V+U.width){this.setScrollX(S-U.width);};},scrollCellIntoView:function(W,Y){var X=this.getBounds();if(!X){this.addListenerOnce(l,function(){qx.event.Timer.once(function(){this.scrollCellIntoView(W,Y);},this,0);},this);return;};this.scrollColumnIntoView(W);this.scrollRowIntoView(Y);},getCellAtPosition:function(ba,bb){var be,bd;var bc=this.getContentLocation();if(!bc||bb<bc.top||bb>=bc.bottom||ba<bc.left||ba>=bc.right){return null;};be=this.__qX.getItemAtPosition(this.getScrollY()+bb-bc.top);bd=this.__qY.getItemAtPosition(this.getScrollX()+ba-bc.left);if(!be||!bd){return null;};return {row:be.index,column:bd.index};},prefetchX:function(bi,bl,bj,bh){var bf=this.getVisibleLayers();if(bf.length==0){return;};var bk=this.getBounds();if(!bk){return;};var bm=this.__rb+bk.width;var bn=this.__rd-bm;if(this.__rb-this.__re.left<Math.min(this.__rb,bi)||this.__re.right-bm<Math.min(bn,bj)){var bo=Math.min(this.__rb,bl);var bg=Math.min(bn,bh);this._setLayerWindow(bf,this.__rb-bo,this.__ra,bk.width+bo+bg,bk.height,false);};},prefetchY:function(by,bu,bq,bt){var bp=this.getVisibleLayers();if(bp.length==0){return;};var bv=this.getBounds();if(!bv){return;};var br=this.__ra+bv.height;var bs=this.__rc-br;if(this.__ra-this.__re.top<Math.min(this.__ra,by)||this.__re.bottom-br<Math.min(bs,bq)){var bx=Math.min(this.__ra,bu);var bw=Math.min(bs,bt);this._setLayerWindow(bp,this.__rb,this.__ra-bx,bv.width,bv.height+bx+bw,false);};},_onResize:function(){if(this.getContentElement().getDomElement()){this.__rh=true;this._updateScrollPosition();this.__rh=null;this.fireEvent(d);};},_onAppear:function(){this.fullUpdate();},_onPointerDown:function(e){this.__rj=this.getCellAtPosition(e.getDocumentLeft(),e.getDocumentTop());},_onTap:function(e){this.__rk(e,t);},_onContextmenu:function(e){this.__rk(e,u);},_onDbltap:function(e){this.__rk(e,n);},__rk:function(e,bB){var bA=this.getCellAtPosition(e.getDocumentLeft(),e.getDocumentTop());if(!bA){return;};var bz=this.__rj;if(bz==null||bz.row!==bA.row||bz.column!==bA.column){return;};this.fireNonBubblingEvent(bB,qx.ui.virtual.core.CellEvent,[this,e,bA.row,bA.column]);},syncWidget:function(bC){if(this.__jj._fullUpdate){this._fullUpdate();}else if(this.__jj._updateScrollPosition){this._updateScrollPosition();};this.__jj={};},_setLayerWindow:function(bD,bS,top,bO,bK,bU){var bJ=this.__qX.getItemAtPosition(top);if(bJ){var bM=bJ.index;var bQ=this.__qX.getItemSizes(bM,bK+bJ.offset);var bL=qx.lang.Array.sum(bQ);var bT=top-bJ.offset;var bP=top-bJ.offset+bL;}else {var bM=0;var bQ=[];var bL=0;var bT=0;var bP=0;};var bE=this.__qY.getItemAtPosition(bS);if(bE){var bI=bE.index;var bG=this.__qY.getItemSizes(bI,bO+bE.offset);var bN=qx.lang.Array.sum(bG);var bR=bS-bE.offset;var bH=bS-bE.offset+bN;}else {var bI=0;var bG=[];var bN=0;var bR=0;var bH=0;};this.__re={top:bT,bottom:bP,left:bR,right:bH};this.__rf.setUserBounds((this.getPaddingLeft()||0)+(this.__re.left-this.__rb),(this.getPaddingTop()||0)+(this.__re.top-this.__ra),bN,bL);this.__pI=bG;this.__ri=bQ;for(var i=0;i<this.__rg.length;i++ ){var bF=this.__rg[i];bF.setUserBounds(0,0,bN,bL);if(bU){bF.fullUpdate(bM,bI,bQ,bG);}else {bF.updateLayerWindow(bM,bI,bQ,bG);};};},__rl:function(){if(this.__rh){return;};var bV=this.getScrollSize();if(this.__rc!==bV.height||this.__rd!==bV.width){this.__rc=bV.height;this.__rd=bV.width;this.fireEvent(d);};},fullUpdate:function(){this.__jj._fullUpdate=1;qx.ui.core.queue.Widget.add(this);},isUpdatePending:function(){return !!this.__jj._fullUpdate;},_fullUpdate:function(){var bW=this.getVisibleLayers();if(bW.length==0){this.__rl();return;};var bX=this.getBounds();if(!bX){return;};this._setLayerWindow(bW,this.__rb,this.__ra,bX.width,bX.height,true);this.__rl();},_deferredUpdateScrollPosition:function(){this.__jj._updateScrollPosition=1;qx.ui.core.queue.Widget.add(this);},_updateScrollPosition:function(){var bY=this.getVisibleLayers();if(bY.length==0){this.__rl();return;};var cb=this.getBounds();if(!cb){return;};var ca={top:this.__ra,bottom:this.__ra+cb.height,left:this.__rb,right:this.__rb+cb.width};if(this.__re.top<=ca.top&&this.__re.bottom>=ca.bottom&&this.__re.left<=ca.left&&this.__re.right>=ca.right){this.__rf.setUserBounds((this.getPaddingLeft()||0)+(this.__re.left-ca.left),(this.getPaddingTop()||0)+(this.__re.top-ca.top),this.__re.right-this.__re.left,this.__re.bottom-this.__re.top);}else {this._setLayerWindow(bY,this.__rb,this.__ra,cb.width,cb.height,false);};this.__rl();}},destruct:function(){this._disposeArray(m);this._disposeObjects(p,v,k);this.__re=this.__jj=this.__pI=this.__ri=null;}});})();(function(){var c="change",d="qx.event.type.Event",e="qx.ui.virtual.core.Axis";qx.Class.define(e,{extend:qx.core.Object,construct:function(f,g){qx.core.Object.call(this);this.itemCount=g;this.defaultItemSize=f;this.customSizes={};},events:{"change":d},members:{__rm:null,getDefaultItemSize:function(){return this.defaultItemSize;},setDefaultItemSize:function(h){if(this.defaultItemSize!==h){this.defaultItemSize=h;this.__rm=null;this.fireNonBubblingEvent(c);};},getItemCount:function(){return this.itemCount;},setItemCount:function(j){if(this.itemCount!==j){this.itemCount=j;this.__rm=null;this.fireNonBubblingEvent(c);};},setItemSize:function(k,l){{};if(this.customSizes[k]==l){return;};if(l===null){delete this.customSizes[k];}else {this.customSizes[k]=l;};this.__rm=null;this.fireNonBubblingEvent(c);},getItemSize:function(m){return this.customSizes[m]||this.defaultItemSize;},resetItemSizes:function(){this.customSizes={};this.__rm=null;this.fireNonBubblingEvent(c);},__rn:function(){if(this.__rm){return this.__rm;};var q=this.defaultItemSize;var o=this.itemCount;var w=[];for(var t in this.customSizes){var n=parseInt(t,10);if(n<o){w.push(n);};};if(w.length==0){var s=[{startIndex:0,endIndex:o-1,firstItemSize:q,rangeStart:0,rangeEnd:o*q-1}];this.__rm=s;return s;};w.sort(function(a,b){return a>b?1:-1;});var s=[];var p=0;for(var i=0;i<w.length;i++ ){var n=w[i];if(n>=o){break;};var v=this.customSizes[n];var r=n*q+p;p+=v-q;s[i]={startIndex:n,firstItemSize:v,rangeStart:r};if(i>0){s[i-1].rangeEnd=r-1;s[i-1].endIndex=n-1;};};if(s[0].rangeStart>0){s.unshift({startIndex:0,endIndex:s[0].startIndex-1,firstItemSize:q,rangeStart:0,rangeEnd:s[0].rangeStart-1});};var x=s[s.length-1];var u=(o-x.startIndex-1)*q;x.rangeEnd=x.rangeStart+x.firstItemSize+u-1;x.endIndex=o-1;this.__rm=s;return s;},__ro:function(D){var z=this.__rm||this.__rn();var A=0;var y=z.length-1;while(true){var C=A+((y-A)>>1);var B=z[C];if(B.rangeEnd<D){A=C+1;}else if(B.rangeStart>D){y=C-1;}else {return B;};};},getItemAtPosition:function(I){if(I<0||I>=this.getTotalSize()){return null;};var H=this.__ro(I);var J=H.rangeStart;var E=H.startIndex;var G=H.firstItemSize;if(J+G>I){return {index:E,offset:I-J};}else {var F=this.defaultItemSize;return {index:E+1+Math.floor((I-J-G)/F),offset:(I-J-G)%F};};},__rp:function(K){var M=this.__rm||this.__rn();var N=0;var L=M.length-1;while(true){var P=N+((L-N)>>1);var O=M[P];if(O.endIndex<K){N=P+1;}else if(O.startIndex>K){L=P-1;}else {return O;};};},getItemPosition:function(Q){if(Q<0||Q>=this.itemCount){return null;};var R=this.__rp(Q);if(R.startIndex==Q){return R.rangeStart;}else {return R.rangeStart+R.firstItemSize+(Q-R.startIndex-1)*this.defaultItemSize;};},getTotalSize:function(){var S=this.__rm||this.__rn();return S[S.length-1].rangeEnd+1;},getItemSizes:function(Y,T){var X=this.customSizes;var W=this.defaultItemSize;var V=0;var U=[];var i=0;while(V<T){var ba=X[Y]!=null?X[Y]:W;Y++ ;V+=ba;U[i++ ]=ba;if(Y>=this.itemCount){break;};};return U;}},destruct:function(){this.customSizes=this.__rm=null;}});})();(function(){var a="qx.ui.virtual.core.CellEvent",b="Integer";qx.Class.define(a,{extend:qx.event.type.Pointer,properties:{row:{check:b,nullable:true},column:{check:b,nullable:true}},members:{init:function(e,c,f,d){c.clone(this);this.setBubbles(false);this.setRow(f);this.setColumn(d);}}});})();(function(){var a="one",b="Boolean",c="qx.ui.virtual.selection.MModel",d="qx.data.Array",f="multi",g="selected",h="_applySelection",j="change",k="_applyDragSelection",l="single",m="_applyQuickSelection",n="changeSelection",o="_applySelectionMode",p="additive",q="qx.event.type.Data";qx.Mixin.define(c,{construct:function(){this._initSelectionManager();this.__rq=new qx.data.Array();this.initSelection(this.__rq);},properties:{selection:{check:d,event:n,apply:h,nullable:false,deferredInit:true},selectionMode:{check:[l,f,p,a],init:l,apply:o},dragSelection:{check:b,init:false,apply:k},quickSelection:{check:b,init:false,apply:m}},events:{"changeSelection":q},members:{_manager:null,__rr:false,__rs:false,__rq:null,_initSelectionManager:function(){var self=this;var r={isItemSelectable:function(s){return self._provider.isSelectable(s);},styleSelectable:function(t,u,v){if(u!=g){return;};if(v){self._provider.styleSelectabled(t);}else {self._provider.styleUnselectabled(t);};}};this._manager=new qx.ui.virtual.selection.Row(this.getPane(),r);this._manager.attachPointerEvents(this.getPane());this._manager.attachKeyEvents(this);this._manager.addListener(n,this._onManagerChangeSelection,this);},setAutoScrollIntoView:function(w){this._manager._autoScrollIntoView=w;},getAutoScrollIntoView:function(){return this._manager._autoScrollIntoView;},_updateSelection:function(){if(this._manager==null){return;};this._onChangeSelection();},_applySelection:function(y,x){y.addListener(j,this._onChangeSelection,this);if(x!=null){x.removeListener(j,this._onChangeSelection,this);};this._onChangeSelection();},_applySelectionMode:function(A,z){this._manager.setMode(A);},_applyDragSelection:function(C,B){this._manager.setDrag(C);},_applyQuickSelection:function(E,D){this._manager.setQuick(E);},_onChangeSelection:function(e){if(this.__rs==true){return;};this.__rr=true;var G=this.getSelection();var I=[];for(var i=0;i<G.getLength();i++ ){var H=G.getItem(i);var J=this._getSelectables();var F=-1;if(J!=null){F=J.indexOf(H);};var K=this._reverseLookup(F);if(K>=0){I.push(K);};};if(this._beforeApplySelection!=null&&qx.lang.Type.isFunction(this._beforeApplySelection)){this._beforeApplySelection(I);};try{if(!qx.lang.Array.equals(I,this._manager.getSelection())){this._manager.replaceSelection(I);};}catch(L){this._manager.selectItem(I[I.length-1]);};this.__rt();if(this._afterApplySelection!=null&&qx.lang.Type.isFunction(this._afterApplySelection)){this._afterApplySelection();};this.__rr=false;},_onManagerChangeSelection:function(e){if(this.__rr==true){return;};this.__rs=true;this.__rt();this.__rs=false;},__rt:function(){if(this.__rv()){return;};var M=this._manager.getSelection();var N=[];for(var i=0;i<M.length;i++ ){var O=this._getDataFromRow(M[i]);if(O!=null){N.push(O);};};this.__ru(N);},__ru:function(R){var Q=this.getSelection();if(R.length>0){var P=[0,Q.getLength()];P=P.concat(R);var S=Q.splice.apply(Q,P);S.dispose();}else {Q.removeAll();};},__rv:function(){var U=this.getSelection();var W=this._manager.getSelection();if(U.getLength()!==W.length){return false;};for(var i=0;i<U.getLength();i++ ){var V=U.getItem(i);var X=this._getSelectables();var T=-1;if(X!=null){T=X.indexOf(V);};var Y=this._reverseLookup(T);if(Y!==W[i]){return false;};};return true;},_applyDefaultSelection:function(){if(this._manager!=null){this._manager._applyDefaultSelection();};}},destruct:function(){this._manager.dispose();this._manager=null;if(this.__rq){this.__rq.dispose();};}});})();(function(){var a="qx.ui.virtual.selection.Abstract",b="keypress",c="losecapture",d="pointerover",e="pointerdown",f="removeItem",g="tap",h="pointermove",i="addItem";qx.Class.define(a,{extend:qx.ui.core.selection.Abstract,construct:function(k,j){qx.ui.core.selection.Abstract.call(this);{};this._pane=k;this._delegate=j||{};},members:{_autoScrollIntoView:true,_isSelectable:function(l){return this._delegate.isItemSelectable?this._delegate.isItemSelectable(l):true;},_styleSelectable:function(m,n,o){if(this._delegate.styleSelectable){this._delegate.styleSelectable(m,n,o);};},attachPointerEvents:function(){var p=this._pane.getContentElement();p.addListener(e,this.handlePointerDown,this);p.addListener(g,this.handleTap,this);p.addListener(d,this.handlePointerOver,this);p.addListener(h,this.handlePointerMove,this);p.addListener(c,this.handleLoseCapture,this);},detatchPointerEvents:function(){var q=this._pane.getContentElement();q.removeListener(e,this.handlePointerDown,this);q.removeListener(g,this.handleTap,this);q.removeListener(d,this.handlePointerOver,this);q.removeListener(h,this.handlePointerMove,this);q.removeListener(c,this.handleLoseCapture,this);},attachKeyEvents:function(r){r.addListener(b,this.handleKeyPress,this);},detachKeyEvents:function(s){s.removeListener(b,this.handleKeyPress,this);},attachListEvents:function(t){t.addListener(i,this.handleAddItem,this);t.addListener(f,this.handleRemoveItem,this);},detachListEvents:function(u){u.removeListener(i,this.handleAddItem,this);u.removeListener(f,this.handleRemoveItem,this);},_capture:function(){this._pane.capture();},_releaseCapture:function(){this._pane.releaseCapture();},_getScroll:function(){return {left:this._pane.getScrollX(),top:this._pane.getScrollY()};},_scrollBy:function(v,w){this._pane.setScrollX(this._pane.getScrollX()+v);this._pane.setScrollY(this._pane.getScrollY()+w);},_getLocation:function(){var x=this._pane.getContentElement().getDomElement();return x?qx.bom.element.Location.get(x):null;},_getDimension:function(){return this._pane.getInnerSize();}},destruct:function(){this._pane=this._delegate=null;}});})();(function(){var a="qx.ui.virtual.selection.Row",b="above",c="under";qx.Class.define(a,{extend:qx.ui.virtual.selection.Abstract,members:{_getItemCount:function(){return this._pane.getRowConfig().getItemCount();},_getSelectableFromPointerEvent:function(event){var d=this._pane.getCellAtPosition(event.getDocumentLeft(),event.getDocumentTop());if(!d){return null;};return this._isSelectable(d.row)?d.row:null;},getSelectables:function(f){var e=[];for(var i=0,l=this._getItemCount();i<l;i++ ){if(this._isSelectable(i)){e.push(i);};};return e;},_getSelectableRange:function(j,k){var m=[];var g=Math.min(j,k);var h=Math.max(j,k);for(var i=g;i<=h;i++ ){if(this._isSelectable(i)){m.push(i);};};return m;},_getFirstSelectable:function(){var n=this._getItemCount();for(var i=0;i<n;i++ ){if(this._isSelectable(i)){return i;};};return null;},_getLastSelectable:function(){var o=this._getItemCount();for(var i=o-1;i>=0;i-- ){if(this._isSelectable(i)){return i;};};return null;},_getRelatedSelectable:function(q,s){if(s==b){var r=q-1;var p=0;var t=-1;}else if(s==c){var r=q+1;var p=this._getItemCount()-1;var t=1;}else {return null;};for(var i=r;i!==p+t;i+=t){if(this._isSelectable(i)){return i;};};return null;},_getPage:function(v,u){if(u){return this._getFirstSelectable();}else {return this._getLastSelectable();};},_selectableToHashCode:function(w){return w;},_scrollItemIntoView:function(x){if(this._autoScrollIntoView){this._pane.scrollRowIntoView(x);};},_getSelectableLocationX:function(y){return {left:0,right:this._pane.getColumnConfig().getTotalSize()-1};},_getSelectableLocationY:function(z){var C=this._pane.getRowConfig();var B=C.getItemPosition(z);var A=B+C.getItemSize(z)-1;return {top:B,bottom:A};}}});})();(function(){var a="changeModel",b="resize",c="_applyLabelOptions",d="_applyLabelPath",f='Could not build tree, because \'childProperty\' and/or \'labelPath\' is \'null\'!',g="one",h="_applyOpenMode",j="qx.core.Object",k="Space",l="Left",m="filter",n="Integer",o="_applyModel",p="_applyShowTopLevelOpenCloseIcons",q="Boolean",r="open",s="changeOpenMode",t="cellTap",u="changeDelegate",v="virtual-tree",w="_applyChildProperty",x="qx.event.type.Data",y="_applyIconPath",z="dbltap",A="_applyDelegate",B="cellDbltap",C="_applyHideRoot",D="close",E="_applyRowHeight",F="changeBubble",G="sorter",H="Right",I="Enter",J="qx.ui.tree.VirtualTree",K="keypress",L="none",M="updated",N="_applyShowLeafs",O="String",P="_applyIconOptions",Q="tap",R=".";qx.Class.define(J,{extend:qx.ui.virtual.core.Scroller,implement:[qx.ui.tree.core.IVirtualTree,qx.data.controller.ISelection],include:[qx.ui.virtual.selection.MModel,qx.ui.core.MContentPadding],construct:function(S,U,T){qx.ui.virtual.core.Scroller.call(this,0,1,20,100);this._init();if(U!=null){this.setLabelPath(U);};if(T!=null){this.setChildProperty(T);};if(S!=null){this.initModel(S);};this.initItemHeight();this.initOpenMode();this.addListener(K,this._onKeyPress,this);},events:{open:x,close:x},properties:{appearance:{refine:true,init:v},focusable:{refine:true,init:true},width:{refine:true,init:100},height:{refine:true,init:200},itemHeight:{check:n,init:25,apply:E,themeable:true},openMode:{check:[Q,z,L],init:z,apply:h,event:s,themeable:true},hideRoot:{check:q,init:false,apply:C},showTopLevelOpenCloseIcons:{check:q,init:false,apply:p},showLeafs:{check:q,init:true,apply:N},childProperty:{check:O,apply:w,nullable:true},labelPath:{check:O,apply:d,nullable:true},iconPath:{check:O,apply:y,nullable:true},labelOptions:{apply:c,nullable:true},iconOptions:{apply:P,nullable:true},model:{check:j,apply:o,event:a,nullable:true,deferredInit:true},delegate:{event:u,apply:A,init:null,nullable:true}},members:{_provider:null,_layer:null,__rU:null,__rV:null,__rW:null,__ha:null,_itemWidth:0,__rX:null,syncWidget:function(W){var Y=this._layer.getFirstRow();var X=this._layer.getRowSizes().length;for(var bb=Y;bb<Y+X;bb++ ){var V=this._layer.getRenderedCellWidget(bb,0);if(V!=null){this._itemWidth=Math.max(this._itemWidth,V.getSizeHint().width);};};var ba=this.getPane().getInnerSize().width;this.getPane().getColumnConfig().setItemSize(0,Math.max(this._itemWidth,ba));},openNode:function(bc){this.__sb(bc);this.buildLookupTable();},openNodeWithoutScrolling:function(bd){var be=this.getAutoScrollIntoView();this.setAutoScrollIntoView(false);this.openNode(bd);this.setAutoScrollIntoView(be);},refresh:function(){this.buildLookupTable();},openNodeAndParents:function(bf){this.__sc(this.getModel(),bf);this.buildLookupTable();},closeNode:function(bg){if(qx.lang.Array.contains(this.__rV,bg)){qx.lang.Array.remove(this.__rV,bg);this.fireDataEvent(D,bg);this.buildLookupTable();};},closeNodeWithoutScrolling:function(bh){var bi=this.getAutoScrollIntoView();this.setAutoScrollIntoView(false);this.closeNode(bh);this.setAutoScrollIntoView(bi);},isNodeOpen:function(bj){return qx.lang.Array.contains(this.__rV,bj);},_init:function(){this.__rU=new qx.data.Array();this.__rV=[];this.__rW=[];this._initLayer();},_initLayer:function(){this._provider=new qx.ui.tree.provider.WidgetProvider(this);this._layer=this._provider.createLayer();this._layer.addListener(M,this._onUpdated,this);this.getPane().addLayer(this._layer);this.getPane().addListenerOnce(b,function(e){this.getPane().getColumnConfig().setItemSize(0,e.getData().width);},this);},getLookupTable:function(){return this.__rU;},_reverseLookup:function(bk){return bk;},_getDataFromRow:function(bl){return this.__rU.getItem(bl);},_getSelectables:function(){return this.__rU;},getOpenNodes:function(){return this.__rV;},isNode:function(bm){return qx.ui.tree.core.Util.isNode(bm,this.getChildProperty());},getLevel:function(bn){return this.__rW[bn];},hasChildren:function(bo){return qx.ui.tree.core.Util.hasChildren(bo,this.getChildProperty(),!this.isShowLeafs());},_getContentPaddingTarget:function(){return this.getPane();},_applyRowHeight:function(bq,bp){this.getPane().getRowConfig().setDefaultItemSize(bq);},_applyOpenMode:function(bs,br){var bt=this.getPane();if(bs===z){bt.addListener(B,this._onOpen,this);}else if(bs===Q){bt.addListener(t,this._onOpen,this);};if(br===z){bt.removeListener(B,this._onOpen,this);}else if(br===Q){bt.removeListener(t,this._onOpen,this);};},_applyHideRoot:function(bv,bu){this.buildLookupTable();},_applyShowTopLevelOpenCloseIcons:function(bx,bw){this.getLookupTable().removeAll();this.buildLookupTable();},_applyShowLeafs:function(bz,by){this.getLookupTable().removeAll();this.buildLookupTable();},_applyChildProperty:function(bB,bA){this._provider.setChildProperty(bB);},_applyLabelPath:function(bD,bC){this._provider.setLabelPath(bD);},_applyIconPath:function(bF,bE){this._provider.setIconPath(bF);},_applyLabelOptions:function(bH,bG){this._provider.setLabelOptions(bH);},_applyIconOptions:function(bJ,bI){this._provider.setIconOptions(bJ);},_applyModel:function(bL,bK){this.__rV=[];if(bL!=null){{};bL.addListener(F,this._onChangeBubble,this);this.__sb(bL);};if(bK!=null){bK.removeListener(F,this._onChangeBubble,this);};this.__rY();},_applyDelegate:function(bN,bM){this._provider.setDelegate(bN);this.buildLookupTable();},_onChangeBubble:function(event){var bS=event.getData();var bP=bS.name;var bO=bP.lastIndexOf(R);if(bO!=-1){bP=bP.substr(bO+1,bP.length);};if(qx.lang.String.startsWith(bP,this.getChildProperty())){var bQ=bS.item;if(qx.Class.isSubClassOf(bQ.constructor,qx.data.Array)){if(bO===-1){bQ=this.getModel();}else {var bR=bS.name.substr(0,bO);bQ=qx.data.SingleValueBinding.resolvePropertyChain(this.getModel(),bR);};};if(this.__rU.indexOf(bQ)!=-1){this.__rY();};};},_onUpdated:function(event){if(this.__ha==null){this.__ha=new qx.util.DeferredCall(function(){qx.ui.core.queue.Widget.add(this);},this);};this.__ha.schedule();},_onOpen:function(event){var bU=event.getRow();var bT=this.__rU.getItem(bU);if(this.isNode(bT)){if(this.isNodeOpen(bT)){this.closeNode(bT);}else {this.openNode(bT);};};},_onKeyPress:function(e){var bV=this.getSelection();if(bV.getLength()>0){var bX=bV.getItem(0);var bW=this.isNode(bX);switch(e.getKeyIdentifier()){case l:if(bW&&this.isNodeOpen(bX)){this.closeNode(bX);}else {var parent=this.getParent(bX);if(parent!=null){bV.splice(0,1,parent);};};break;case H:if(bW&&!this.isNodeOpen(bX)){this.openNode(bX);}else {if(bW){var bY=bX.get(this.getChildProperty());if(bY!=null&&bY.getLength()>0){bV.splice(0,1,bY.getItem(0));};};};break;case I:case k:if(!bW){return;};if(this.isNodeOpen(bX)){this.closeNode(bX);}else {this.openNode(bX);};break;};};},_beforeApplySelection:function(cb){if(cb.length===0&&this.getSelectionMode()===g){var ca=this.__sf();var cc=this.getLookupTable().indexOf(ca);if(cc>=0){cb.push(cc);};};},_afterApplySelection:function(){var cd=this.getSelection();if(cd.getLength()>0&&this.getSelectionMode()===g){this.__se(cd.getItem(0));}else {this.__rX=[];};},__rY:function(){this.buildLookupTable();this._applyDefaultSelection();},buildLookupTable:function(){if(this.getModel()!=null&&(this.getChildProperty()==null||this.getLabelPath()==null)){throw new Error(f);};this._itemWidth=0;var ch=[];this.__rW=[];var cf=-1;var cg=this.getModel();if(cg!=null){if(!this.isHideRoot()){cf++ ;ch.push(cg);this.__rW.push(cf);};if(this.isNodeOpen(cg)){var ce=this.__sa(cg,cf);ch=ch.concat(ce);};};if(!qx.lang.Array.equals(this.__rU.toArray(),ch)){this._provider.removeBindings();this.__rU.removeAll();this.__rU.append(ch);this.__sd();this._updateSelection();};},__sa:function(ci,cn){var cm=[];cn++ ;if(!this.isNode(ci)){return cm;};var cq=ci.get(this.getChildProperty());if(cq==null){return cm;};cq=cq.copy();var co=this.getDelegate();var cl=qx.util.Delegate.getMethod(co,m);var ck=qx.util.Delegate.getMethod(co,G);if(ck!=null){cq.sort(ck);};for(var i=0;i<cq.getLength();i++ ){var cp=cq.getItem(i);if(cl&&!cl(cp)){continue;};if(this.isNode(cp)){this.__rW.push(cn);cm.push(cp);if(this.isNodeOpen(cp)){var cj=this.__sa(cp,cn);cm=cm.concat(cj);};}else {if(this.isShowLeafs()){this.__rW.push(cn);cm.push(cp);};};};cq.dispose();return cm;},__sb:function(cr){if(!qx.lang.Array.contains(this.__rV,cr)){this.__rV.push(cr);this.fireDataEvent(r,cr);};},__sc:function(cs,ct){if(cs===ct){this.__sb(ct);return true;};if(!this.isNode(cs)){return false;};var cw=cs.get(this.getChildProperty());if(cw==null){return false;};for(var i=0;i<cw.getLength();i++ ){var cv=cw.getItem(i);var cu=this.__sc(cv,ct);if(cu===true){this.__sb(cv);return true;};};return false;},__sd:function(){this.getPane().getRowConfig().setItemCount(this.__rU.getLength());this.getPane().fullUpdate();},getParent:function(cy){var cz=this.__rU.indexOf(cy);if(cz<0){return null;};var cA=this.__rW[cz];while(cz>0){cz-- ;var cx=this.__rW[cz];if(cx<cA){return this.__rU.getItem(cz);};};return null;},__se:function(cB){this.__rX=[];var parent=this.getParent(cB);while(parent!=null){this.__rX.unshift(parent);parent=this.getParent(parent);};},__sf:function(){if(this.__rX==null){return this.getModel();};var cC=this.getLookupTable();var parent=this.__rX.pop();while(parent!=null){if(cC.contains(parent)){return parent;};parent=this.__rX.pop();};return this.getModel();}},destruct:function(){var cE=this.getPane();if(cE!=null){if(cE.hasListener(B)){cE.removeListener(B,this._onOpen,this);};if(cE.hasListener(t)){cE.removeListener(t,this._onOpen,this);};};if(!qx.core.ObjectRegistry.inShutDown&&this.__ha!=null){this.__ha.cancel();this.__ha.dispose();};var cD=this.getModel();if(cD!=null){cD.removeListener(F,this._onChangeBubble,this);};this._layer.removeListener(M,this._onUpdated,this);this._layer.destroy();this._provider.dispose();this.__rU.dispose();this._layer=this._provider=this.__rU=this.__rV=this.__ha=null;}});})();(function(){var a="qx.ui.virtual.core.IWidgetCellProvider";qx.Interface.define(a,{members:{getCellWidget:function(c,b){},poolCellWidget:function(d){}}});})();(function(){var a="qx.ui.tree.provider.IVirtualTreeProvider";qx.Interface.define(a,{members:{createLayer:function(){},createRenderer:function(){},setChildProperty:function(b){this.assertArgumentsCount(arguments,1,1);this.assertString(b);},setLabelPath:function(c){this.assertArgumentsCount(arguments,1,1);this.assertString(c);},styleSelectabled:function(d){this.assertArgumentsCount(arguments,1,1);this.assertInteger(d);},styleUnselectabled:function(e){this.assertArgumentsCount(arguments,1,1);this.assertInteger(e);},isSelectable:function(f){this.assertArgumentsCount(arguments,1,1);this.assertInteger(f);}}});})();(function(){var a="BindingIds",b="model",c="",d="changeDelegate",f="virtual-tree-file",g="label",h="appearance",i="icon",j="bindItem",k=".length",l="]",m="virtual-tree-folder",n="[",o=".",p="String",q="qx.ui.tree.core.MWidgetController";qx.Mixin.define(q,{construct:function(){this.__sg=[];},properties:{labelPath:{check:p,nullable:true},iconPath:{check:p,nullable:true},labelOptions:{nullable:true},iconOptions:{nullable:true},childProperty:{check:p,nullable:true},delegate:{event:d,init:null,nullable:true}},members:{__sg:null,bindDefaultProperties:function(u,s){this.bindProperty(c,b,null,u,s);this.bindProperty(this.getLabelPath(),g,this.getLabelOptions(),u,s);var r=this.__sh(s);var t=this._tree.getLookupTable();t=qx.data.SingleValueBinding.resolvePropertyChain(t,r);if(qx.util.OOUtil.hasProperty(t.constructor,this.getChildProperty())){this.bindProperty(this.getChildProperty()+k,h,{converter:function(){return m;}},u,s);}else {u.setAppearance(f);};if(this.getIconPath()!=null){this.bindProperty(this.getIconPath(),i,this.getIconOptions(),u,s);};},bindProperty:function(y,B,z,x,v){var A=this.__sh(v,y);var w=this._tree.getLookupTable();var C=w.bind(A,x,B,z);this.__si(x,C);},bindPropertyReverse:function(J,F,H,I,D){var G=this.__sh(D,J);var E=this._tree.getLookupTable();var K=I.bind(F,E,G,H);this.__si(I,K);},removeBindings:function(){while(this.__sg.length>0){var L=this.__sg.pop();this._removeBindingsFrom(L);};},_bindItem:function(N,O){var M=qx.util.Delegate.getMethod(this.getDelegate(),j);if(M!=null){M(this,N,O);}else {this.bindDefaultProperties(N,O);};},_removeBindingsFrom:function(P){var Q=this.__sj(P);while(Q.length>0){var R=Q.pop();try{this._tree.getLookupTable().removeBinding(R);}catch(e){P.removeBinding(R);};};if(qx.lang.Array.contains(this.__sg,P)){qx.lang.Array.remove(this.__sg,P);};},__sh:function(T,U){var S=n+T+l;if(U!=null&&U!=c){S+=o+U;};return S;},__si:function(W,X){var V=this.__sj(W);if(!qx.lang.Array.contains(V,X)){V.push(X);};if(!qx.lang.Array.contains(this.__sg,W)){this.__sg.push(W);};},__sj:function(Y){var ba=Y.getUserData(a);if(ba==null){ba=[];Y.setUserData(a,ba);};return ba;}},destruct:function(){this.__sg=null;}});})();(function(){var a="qx.util.Delegate";qx.Class.define(a,{statics:{getMethod:function(b,c){if(qx.util.Delegate.containsMethod(b,c)){return qx.lang.Function.bind(b[c],b);};return null;},containsMethod:function(e,f){var d=qx.lang.Type;if(d.isObject(e)){return d.isFunction(e[f]);};return false;}}});})();(function(){var a="changeOpen",b="cell.childProperty",c="changeDelegate",d="cell.level",e="createItem",f="auto",g="cell.showLeafs",h="configureItem",i="created",j="onPool",k="cell.row",l="qx.ui.tree.provider.WidgetProvider",m="never";qx.Class.define(l,{extend:qx.core.Object,implement:[qx.ui.virtual.core.IWidgetCellProvider,qx.ui.tree.provider.IVirtualTreeProvider],include:[qx.ui.tree.core.MWidgetController],construct:function(n){qx.core.Object.call(this);this._tree=n;this.addListener(c,this._onChangeDelegate,this);this._onChangeDelegate();},members:{_tree:null,_renderer:null,getCellWidget:function(t,r){var s=this._tree.getLookupTable().getItem(t);var p=false;if(this._tree.isNode(s)){p=this._tree.hasChildren(s);};var o=this._renderer.getCellWidget();o.setOpen(p&&this._tree.isNodeOpen(s));o.addListener(a,this.__sk,this);o.setUserData(b,this.getChildProperty());o.setUserData(g,this._tree.isShowLeafs());if(this._tree.getSelection().contains(s)){this._styleSelectabled(o);}else {this._styleUnselectabled(o);};var q=this._tree.getLevel(t);if(!this._tree.isShowTopLevelOpenCloseIcons()){q-=1;};o.setUserData(d,q);if(!this._tree.isShowTopLevelOpenCloseIcons()&&q==-1){o.setOpenSymbolMode(m);}else {o.setOpenSymbolMode(f);};this._bindItem(o,t);qx.ui.core.queue.Widget.add(o);return o;},poolCellWidget:function(u){u.removeListener(a,this.__sk,this);this._removeBindingsFrom(u);this._renderer.pool(u);this._onPool(u);},createLayer:function(){return new qx.ui.virtual.layer.WidgetCell(this);},createRenderer:function(){var v=qx.util.Delegate.getMethod(this.getDelegate(),e);if(v==null){v=function(){return new qx.ui.tree.VirtualTreeItem();};};var w=new qx.ui.virtual.cell.WidgetCell();w.setDelegate({createWidget:v});return w;},styleSelectabled:function(y){var x=this._tree._layer.getRenderedCellWidget(y,0);this._styleSelectabled(x);},styleUnselectabled:function(A){var z=this._tree._layer.getRenderedCellWidget(A,0);this._styleUnselectabled(z);},isSelectable:function(C){var B=this._tree._layer.getRenderedCellWidget(C,0);if(B!=null){return B.isEnabled();}else {return true;};},_styleSelectabled:function(D){if(D==null){return;};this._renderer.updateStates(D,{selected:1});},_styleUnselectabled:function(E){if(E==null){return;};this._renderer.updateStates(E,{});},_onPool:function(F){var G=qx.util.Delegate.getMethod(this.getDelegate(),j);if(G!=null){G(F);};},_onItemCreated:function(event){var H=qx.util.Delegate.getMethod(this.getDelegate(),h);if(H!=null){var I=event.getData();H(I);};},_onChangeDelegate:function(event){if(this._renderer!=null){this._renderer.dispose();this.removeBindings();};this._renderer=this.createRenderer();this._renderer.addListener(i,this._onItemCreated,this);},__sk:function(event){var K=event.getTarget();var L=K.getUserData(k);var J=this._tree.getLookupTable().getItem(L);if(event.getData()){this._tree.openNodeWithoutScrolling(J);}else {this._tree.closeNodeWithoutScrolling(J);};}},destruct:function(){this.removeBindings();this._renderer.dispose();this._tree=this._renderer=null;}});})();(function(){var a="qx.ui.virtual.core.ILayer";qx.Interface.define(a,{members:{fullUpdate:function(d,e,c,b){this.assertArgumentsCount(arguments,6,6);this.assertPositiveInteger(d);this.assertPositiveInteger(e);this.assertArray(c);this.assertArray(b);},updateLayerWindow:function(h,i,g,f){this.assertArgumentsCount(arguments,6,6);this.assertPositiveInteger(h);this.assertPositiveInteger(i);this.assertArray(g);this.assertArray(f);},updateLayerData:function(){}}});})();(function(){var a="qx.ui.virtual.layer.Abstract",b="abstract",c="Abstract method '_fullUpdate' called!";qx.Class.define(a,{extend:qx.ui.core.Widget,type:b,implement:[qx.ui.virtual.core.ILayer],construct:function(){qx.ui.core.Widget.call(this);this.__jj={};},properties:{anonymous:{refine:true,init:true}},members:{__jj:null,__I:null,__sl:null,__sm:null,__ri:null,__pI:null,getFirstRow:function(){return this.__sl;},getFirstColumn:function(){return this.__sm;},getRowSizes:function(){return this.__ri||[];},getColumnSizes:function(){return this.__pI||[];},syncWidget:function(e){if(!this.getContentElement().getDomElement()){return;};if(this.__jj.fullUpdate||this.__jj.updateLayerWindow&&this.__jj.updateLayerData){this._fullUpdate.apply(this,this.__I);}else if(this.__jj.updateLayerWindow){this._updateLayerWindow.apply(this,this.__I);}else if(this.__jj.updateLayerData&&this.__ri){this._updateLayerData();};if(this.__jj.fullUpdate||this.__jj.updateLayerWindow){var d=this.__I;this.__sl=d[0];this.__sm=d[1];this.__ri=d[2];this.__pI=d[3];};this.__jj={};},_updateLayerData:function(){this._fullUpdate(this.__sl,this.__sm,this.__ri,this.__pI);},_fullUpdate:function(g,i,h,f){throw new Error(c);},_updateLayerWindow:function(k,m,l,j){this._fullUpdate(k,m,l,j);},updateLayerData:function(){this.__jj.updateLayerData=true;qx.ui.core.queue.Widget.add(this);},fullUpdate:function(p,q,o,n){this.__I=arguments;this.__jj.fullUpdate=true;qx.ui.core.queue.Widget.add(this);},updateLayerWindow:function(t,u,s,r){this.__I=arguments;this.__jj.updateLayerWindow=true;qx.ui.core.queue.Widget.add(this);}},destruct:function(){this.__jj=this.__I=this.__ri=this.__pI=null;}});})();(function(){var a="cell.column",b="updated",c="qx.event.type.Event",d="qx.ui.virtual.layer.WidgetCell",e="cell.row",f="cell.empty";qx.Class.define(d,{extend:qx.ui.virtual.layer.Abstract,include:[qx.ui.core.MChildrenHandling],construct:function(g){qx.ui.virtual.layer.Abstract.call(this);this.setZIndex(12);{};this._cellProvider=g;this.__sn=[];},properties:{anonymous:{refine:true,init:false}},events:{updated:c},members:{__sn:null,getRenderedCellWidget:function(p,m){if(this._getChildren().length===0){return null;};var h=this.getColumnSizes().length;var o=this.getRowSizes().length;var n=this.getFirstRow();var l=this.getFirstColumn();if(p<n||p>=n+o||m<l||m>=l+h){return null;};var k=(m-l)+(p-n)*h;var j=this._getChildren()[k];if(!j||j.getUserData(f)){return null;}else {return j;};},_getSpacer:function(){var q=this.__sn.pop();if(!q){q=new qx.ui.core.Spacer();q.setUserData(f,1);};return q;},_activateNotEmptyChild:function(r){var s=qx.ui.core.FocusHandler.getInstance().getActiveWidget();if(s==r||qx.ui.core.Widget.contains(r,s)){var t=this._getChildren();for(var i=t.length-1;i>=0;i-- ){if(!t[i].getUserData(f)){t[i].activate();break;};};};},_fullUpdate:function(A,u,z,w){var B=this._cellProvider;var G=this._getChildren().concat();for(var i=0;i<G.length;i++ ){var E=G[i];if(E.getUserData(f)){this.__sn.push(E);}else {this._activateNotEmptyChild(E);B.poolCellWidget(E);};};var top=0;var F=0;var D=[];for(var y=0;y<z.length;y++ ){for(var x=0;x<w.length;x++ ){var H=A+y;var v=u+x;var C=B.getCellWidget(H,v)||this._getSpacer();D.push(C);C.setUserBounds(F,top,w[x],z[y]);C.setUserData(e,H);C.setUserData(a,v);this._add(C);F+=w[x];};top+=z[y];F=0;};G.forEach(function(I){if(D.indexOf(I)===-1){this._remove(I);};}.bind(this));this.fireEvent(b);},_updateLayerWindow:function(W,J,M,bb){{};var N=W+M.length-1;var X=J+bb.length-1;var L={firstRow:Math.max(W,this.getFirstRow()),lastRow:Math.min(N,this._lastRow),firstColumn:Math.max(J,this.getFirstColumn()),lastColumn:Math.min(X,this._lastColumn)};this._lastColumn=X;this._lastRow=N;if(L.firstRow>L.lastRow||L.firstColumn>L.lastColumn){return this._fullUpdate(W,J,M,bb);};var O=this._getChildren();var Q=this.getColumnSizes().length;var T=[];var ba={};for(var P=W;P<=N;P++ ){T[P]=[];for(var Y=J;Y<=X;Y++ ){if(P>=L.firstRow&&P<=L.lastRow&&Y>=L.firstColumn&&Y<=L.lastColumn){var x=Y-this.getFirstColumn();var y=P-this.getFirstRow();var R=y*Q+x;T[P][Y]=O[R];ba[R]=true;};};};var K=this._cellProvider;var O=this._getChildren().concat();for(var i=0;i<O.length;i++ ){if(!ba[i]){var V=O[i];if(V.getUserData(f)){this.__sn.push(V);}else {this._activateNotEmptyChild(V);K.poolCellWidget(V);};};};var top=0;var bc=0;var U=[];for(var y=0;y<M.length;y++ ){for(var x=0;x<bb.length;x++ ){var P=W+y;var Y=J+x;var S=T[P][Y]||K.getCellWidget(P,Y)||this._getSpacer();U.push(S);S.setUserBounds(bc,top,bb[x],M[y]);S.setUserData(e,P);S.setUserData(a,Y);this._add(S);bc+=bb[x];};top+=M[y];bc=0;};O.forEach(function(bd){if(U.indexOf(bd)===-1){this._remove(bd);};}.bind(this));this.fireEvent(b);}},destruct:function(){var be=this._getChildren();for(var i=0;i<be.length;i++ ){be[i].dispose();};this._cellProvider=this.__sn=null;}});})();(function(){var a="qx.ui.virtual.cell.IWidgetCell";qx.Interface.define(a,{members:{getCellWidget:function(c,b){},pool:function(d){},updateStates:function(f,e){},updateData:function(g,h){}}});})();(function(){var a="created",b="qx.ui.virtual.cell.AbstractWidget",c="cell.states",d="abstract method call",e="qx.event.type.Data";qx.Class.define(b,{extend:qx.core.Object,implement:[qx.ui.virtual.cell.IWidgetCell],construct:function(){qx.core.Object.call(this);this.__cO=[];},events:{"created":e},members:{__cO:null,_createWidget:function(){throw new Error(d);},updateData:function(f,g){throw new Error(d);},updateStates:function(j,h){var k=j.getUserData(c);if(k){var i=h||{};for(var l in k){if(!i[l]){j.removeState(l);};};}else {k={};};if(h){for(var l in h){if(!k.state){j.addState(l);};};};j.setUserData(c,h);},getCellWidget:function(o,m){var n=this.__so();this.updateStates(n,m);this.updateData(n,o);return n;},pool:function(p){this.__cO.push(p);},_cleanupPool:function(){var q=this.__cO.pop();while(q){q.destroy();q=this.__cO.pop();};},__so:function(){var r=this.__cO.shift();if(r==null){r=this._createWidget();this.fireDataEvent(a,r);};return r;}},destruct:function(){this._cleanupPool();this.__cO=null;}});})();(function(){var a="_applyDelegate",b="qx.ui.virtual.cell.WidgetCell",c="Can't update data! The key '",d="' is not a Property!";qx.Class.define(b,{extend:qx.ui.virtual.cell.AbstractWidget,properties:{delegate:{apply:a,init:null,nullable:true}},members:{_applyDelegate:function(f,e){this._cleanupPool();},_createWidget:function(){var g=this.getDelegate();if(g!=null&&g.createWidget!=null){return g.createWidget();}else {return new qx.ui.core.Widget();};},updateData:function(h,i){for(var j in i){if(qx.Class.hasProperty(h.constructor,j)){qx.util.PropertyUtil.setUserValue(h,j,i[j]);}else {throw new Error(c+j+d);};};}}});})();(function(){var a="_applyIconOpened",b="changeOpen",c="Boolean",d="changeIcon",f="changeIconOpened",g="changeLabel",h="__sr",i="Integer",j="auto",k="Abstract method call.",l="_applyIndent",m="open",n="changeOpenSymbolMode",o="_applyOpenSymbolMode",p="middle",q="String",r="resize",s="",t="icon",u="opened",v="iconOpened",w="abstract",x="never",y="_applyIcon",z="always",A="_applyOpen",B="changeIndent",C="qx.ui.tree.core.AbstractItem",D="label",E="_applyLabel";qx.Class.define(C,{extend:qx.ui.core.Widget,type:w,include:[qx.ui.form.MModelProperty],implement:[qx.ui.form.IModel],construct:function(F){qx.ui.core.Widget.call(this);if(F!=null){this.setLabel(F);};this._setLayout(new qx.ui.layout.HBox());this._addWidgets();this.initOpen();},properties:{open:{check:c,init:false,event:b,apply:A},openSymbolMode:{check:[z,x,j],init:j,event:n,apply:o},indent:{check:i,init:19,apply:l,event:B,themeable:true},icon:{check:q,apply:y,event:d,nullable:true,themeable:true},iconOpened:{check:q,apply:a,event:f,nullable:true,themeable:true},label:{check:q,apply:E,event:g,init:s}},members:{__sp:null,__sq:null,__sr:null,_addWidgets:function(){throw new Error(k);},_createChildControlImpl:function(I,H){var G;switch(I){case D:G=new qx.ui.basic.Label().set({alignY:p,anonymous:true,value:this.getLabel()});break;case t:G=new qx.ui.basic.Image().set({alignY:p,anonymous:true,source:this.getIcon()});break;case m:G=new qx.ui.tree.core.FolderOpenButton().set({alignY:p});G.addListener(b,this._onChangeOpen,this);G.addListener(r,this._updateIndent,this);break;};return G||qx.ui.core.Widget.prototype._createChildControlImpl.call(this,I);},addWidget:function(J,K){this._add(J,K);},addSpacer:function(){if(!this.__sr){this.__sr=new qx.ui.core.Spacer();}else {this._remove(this.__sr);};this._add(this.__sr);},addOpenButton:function(){this._add(this.getChildControl(m));},_onChangeOpen:function(e){if(this.isOpenable()){this.setOpen(e.getData());};},addIcon:function(){var L=this.getChildControl(t);if(this.__sq){this._remove(L);};this._add(L);this.__sq=true;},addLabel:function(M){var N=this.getChildControl(D);if(this.__sp){this._remove(N);};if(M){this.setLabel(M);}else {N.setValue(this.getLabel());};this._add(N);this.__sp=true;},_applyIcon:function(P,O){if(!this.__st()){this.__su(P);}else if(!this.isOpen()){this.__su(P);};},_applyIconOpened:function(R,Q){if(this.isOpen()){if(this.__ss()&&this.__st()){this.__su(R);}else if(!this.__ss()&&this.__st()){this.__su(R);};};},_applyLabel:function(T,S){var U=this.getChildControl(D,true);if(U){U.setValue(T);};},_applyOpen:function(W,V){var open=this.getChildControl(m,true);if(open){open.setOpen(W);};var X;if(W){X=this.__st()?this.getIconOpened():null;}else {X=this.getIcon();};if(X){this.__su(X);};W?this.addState(u):this.removeState(u);},__ss:function(){return qx.util.PropertyUtil.getUserValue(this,t);},__st:function(){return qx.util.PropertyUtil.getUserValue(this,v);},__su:function(Y){var ba=this.getChildControl(t,true);if(ba){ba.setSource(Y);};},isOpenable:function(){var bb=this.getOpenSymbolMode();return (bb===z||bb===j&&this.hasChildren());},_shouldShowOpenSymbol:function(){throw new Error(k);},_applyOpenSymbolMode:function(bd,bc){this._updateIndent();},_updateIndent:function(){var bf=0;var open=this.getChildControl(m,true);if(open){if(this._shouldShowOpenSymbol()){open.show();var be=open.getBounds();if(be){bf=be.width;}else {return;};}else {open.exclude();};};if(this.__sr){this.__sr.setWidth((this.getLevel()+1)*this.getIndent()-bf);};},_applyIndent:function(bh,bg){this._updateIndent();},getLevel:function(){throw new Error(k);},syncWidget:function(bi){this._updateIndent();},hasChildren:function(){throw new Error(k);}},destruct:function(){this._disposeObjects(h);}});})();(function(){var a="pointerup",b="qx.ui.tree.core.FolderOpenButton",c="Boolean",d="opened",f="_applyOpen",g="pointerdown",h="tap",i="changeOpen";qx.Class.define(b,{extend:qx.ui.basic.Image,include:qx.ui.core.MExecutable,construct:function(){qx.ui.basic.Image.call(this);this.initOpen();this.addListener(h,this._onTap);this.addListener(g,this._stopPropagation,this);this.addListener(a,this._stopPropagation,this);},properties:{open:{check:c,init:false,event:i,apply:f}},members:{_applyOpen:function(k,j){k?this.addState(d):this.removeState(d);this.execute();},_stopPropagation:function(e){e.stopPropagation();},_onTap:function(e){this.toggleOpen();e.stopPropagation();}}});})();(function(){var a="open",b="cell.childProperty",c="cell.level",d="qx.ui.tree.VirtualTreeItem",f="change",g="virtual-tree-folder",h="cell.showLeafs",i="changeLength";qx.Class.define(d,{extend:qx.ui.tree.core.AbstractItem,properties:{appearance:{refine:true,init:g}},members:{_forwardStates:{selected:true},_addWidgets:function(){this.addSpacer();this.addOpenButton();this.addIcon();this.addLabel();},_shouldShowOpenSymbol:function(){var open=this.getChildControl(a,true);if(open==null){return false;};return this.isOpenable();},getLevel:function(){return this.getUserData(c);},hasChildren:function(){var j=this.getModel();var l=this.getUserData(b);var k=this.getUserData(h);return qx.ui.tree.core.Util.hasChildren(j,l,!k);},_applyModel:function(p,m){var q=this.getUserData(b);var o=this.getUserData(h);if(p!=null&&qx.ui.tree.core.Util.isNode(p,q)){var n=f+qx.lang.String.firstUp(q);if(qx.Class.hasProperty(p.constructor,q)){p.addListener(n,this._onChangeChildProperty,this);};if(qx.ui.tree.core.Util.hasChildren(p,q,!o)){p.get(q).addListener(i,this._onChangeLength,this);this._updateIndent();};};if(m!=null&&qx.ui.tree.core.Util.isNode(m,q)){var n=f+qx.lang.String.firstUp(q);m.removeListener(n,this._onChangeChildProperty,this);var r=m.get(q);if(r){r.removeListener(i,this._onChangeLength,this);};};},_onChangeLength:function(){this._updateIndent();},_onChangeChildProperty:function(e){var t=e.getData();var s=e.getOldData();if(t){this._updateIndent();t.addListener(i,this._onChangeLength,this);};if(s){s.removeListener(i,this._onChangeLength,this);};}}});})();(function(){var a="qx.ui.tree.core.Util";qx.Class.define(a,{statics:{isNode:function(b,c){if(b==null||c==null){return false;};return qx.Class.hasProperty(b.constructor,c);},hasChildren:function(d,f,h){if(d==null||f==null||!this.isNode(d,f)){return false;};var g=d.get(f);if(g==null){return false;};if(!h){return g.length>0;}else {for(var i=0;i<g.getLength();i++ ){var e=g.getItem(i);if(this.isNode(e,f)){return true;};};};return false;}}});})();(function(){var a='changeChecked',b='String',c='excluded',d='11px italic',e='cell.childProperty',f='Boolean',g='icon',h='changeBranch',i='dbltap',j='checked',k='clui.view.widget.table.ColumnTreeItem',l='value',m='visible',n='type',o='changeType',p='_applyBranch';qx.Class.define(k,{extend:qx.ui.tree.VirtualTreeItem,properties:{checked:{check:f,nullable:true,event:a},type:{check:b,nullable:true,event:o},branch:{check:f,nullable:true,event:h,apply:p}},construct:function(q){qx.ui.tree.VirtualTreeItem.call(this,q);this.addListener(i,this._onDblTap,this);},members:{_createChildControlImpl:function(t,s){var r=null;if(t==j){r=new qx.ui.form.CheckBox();r.setFocusable(false);r.setMarginLeft(2);r.setMarginRight(4);this.bind(j,r,l);r.bind(l,this,j);}else if(t==n){r=new qx.ui.basic.Label();r.setFont(qx.bom.Font.fromString(d));r.setWidth(50);this.bind(n,r,l);};return r||qx.ui.tree.VirtualTreeItem.prototype._createChildControlImpl.call(this,t);},_onDblTap:function(event){if(!this.isBranch()){this.getChildControl(j).toggleValue();};},_addWidgets:function(){this.addSpacer();this.addOpenButton();this.addIcon();this.addWidget(this.getChildControl(j));this.addLabel();this.addWidget(new qx.ui.core.Spacer(),{'flex':1});this.addWidget(this.getChildControl(n));},_applyModel:function(v,u){qx.ui.tree.VirtualTreeItem.prototype._applyModel.call(this,v,u);this.setBranch(qx.Class.hasProperty(v.constructor,this.getUserData(e)));},_applyBranch:function(x,w){this.getChildControl(g).setVisibility(x?m:c);this.getChildControl(j).setVisibility(x?c:m);}}});})();(function(){var a="hovered",b="Boolean",c="pressed",d="_applyTriState",f="pointerover",g="changeValue",h="Space",i="keydown",j="abandoned",k="undetermined",l="_applyGroup",m="button",n="execute",o="Enter",p="qx.ui.form.RadioGroup",q="_applyValue",r="qx.ui.form.ToggleButton",s="pointerup",t="pointerdown",u="keyup",v="checked",w="pointerout";qx.Class.define(r,{extend:qx.ui.basic.Atom,include:[qx.ui.core.MExecutable],implement:[qx.ui.form.IBooleanForm,qx.ui.form.IExecutable,qx.ui.form.IRadioItem],construct:function(x,y){qx.ui.basic.Atom.call(this,x,y);this.addListener(f,this._onPointerOver);this.addListener(w,this._onPointerOut);this.addListener(t,this._onPointerDown);this.addListener(s,this._onPointerUp);this.addListener(i,this._onKeyDown);this.addListener(u,this._onKeyUp);this.addListener(n,this._onExecute,this);},properties:{appearance:{refine:true,init:m},focusable:{refine:true,init:true},value:{check:b,nullable:true,event:g,apply:q,init:false},group:{check:p,nullable:true,apply:l},triState:{check:b,apply:d,nullable:true,init:null}},members:{_applyGroup:function(A,z){if(z){z.remove(this);};if(A){A.add(this);};},_applyValue:function(C,B){C?this.addState(v):this.removeState(v);if(this.isTriState()){if(C===null){this.addState(k);}else if(B===null){this.removeState(k);};};},_applyTriState:function(E,D){this._applyValue(this.getValue());},_onExecute:function(e){this.toggleValue();},_onPointerOver:function(e){if(e.getTarget()!==this){return;};this.addState(a);if(this.hasState(j)){this.removeState(j);this.addState(c);};},_onPointerOut:function(e){if(e.getTarget()!==this){return;};this.removeState(a);if(this.hasState(c)){if(!this.getValue()){this.removeState(c);};this.addState(j);};},_onPointerDown:function(e){if(!e.isLeftPressed()){return;};this.capture();this.removeState(j);this.addState(c);e.stopPropagation();},_onPointerUp:function(e){this.releaseCapture();if(this.hasState(j)){this.removeState(j);}else if(this.hasState(c)){this.execute();};this.removeState(c);e.stopPropagation();},_onKeyDown:function(e){switch(e.getKeyIdentifier()){case o:case h:this.removeState(j);this.addState(c);e.stopPropagation();};},_onKeyUp:function(e){if(!this.hasState(c)){return;};switch(e.getKeyIdentifier()){case o:case h:this.removeState(j);this.execute();this.removeState(c);e.stopPropagation();};}}});})();(function(){var a="label",b="checkbox",c="qx.ui.form.CheckBox",d="value",e="toolTipText",f="enabled",g="menu";qx.Class.define(c,{extend:qx.ui.form.ToggleButton,include:[qx.ui.form.MForm,qx.ui.form.MModelProperty],implement:[qx.ui.form.IForm,qx.ui.form.IModel],construct:function(h){{};qx.ui.form.ToggleButton.call(this,h);this.setValue(false);},properties:{appearance:{refine:true,init:b},allowGrowX:{refine:true,init:false}},members:{_forwardStates:{invalid:true,focused:true,undetermined:true,checked:true,hovered:true},_bindableProperties:[f,a,e,d,g]}});})();(function(){var c='root',d='isString',e='isDate',f='isArray',g='isNumber',h='clui.util.ColumnTreeBuilder',j='1*',k='isBoolean',l='object',n='.',o='Skipping leaf source key "{0}" already found in target',p='children',q='type',r='other';qx.Class.define(h,{statics:{_getType:function(v){var s=r;[d,g,k,e,f].some(function(m){if(qx.lang.Type[m](v)){s=m.slice(2).toLowerCase();return true;};});return s;},_mergeIntoInterim:function(u,w,t){kucken.lang.Object.items(w).forEach(function(x){var y=t.concat([x[0]]);if(qx.lang.Type.isObject(x[1])){if(!(x[0] in u)){u[x[0]]={'type':l,'children':{}};};this._mergeIntoInterim(u[x[0]][p],x[1],y);}else if(!(x[0] in u)){u[x[0]]={'name':x[0],'width':j,'path':y,'id':y.join(n),'visible':false,'type':this._getType(x[1])};};},this);return u;},_getInterimColumnTree:function(z){var A={};z.iterateCachedRows(function(i,B){this._mergeIntoInterim(A,B,[]);},this);return A;},_convertTree:function(C){return kucken.lang.Object.items(C).sort(function(a,b){if(a[1][q]==l&&b[1][q]!=l){return 1;}else if(b[1][q]==l&&a[1][q]!=l){return -1;};return a[0].localeCompare(b[0]);}).map(function(D){var E=kucken.lang.Object.merge({'name':D[0],'visible':null},D[1]);if(D[1][q]==l){E[p]=this._convertTree(D[1][p]);};return E;},this);},_expandKeyPathToTree:function(F,G){var H={'children':{}};F.reduce(function(J,K,I){return J[p][K]=F.length-1==I?kucken.lang.Object.merge(G):{'type':l,'children':{}};},H);return H[p];},_mergeTree:function(M,L){kucken.lang.Object.items(L).forEach(function(N){if(N[0] in M){if(p in N[1]&&p in M[N[0]]){this._mergeTree(M[N[0]][p],N[1][p]);}else {qx.log.Logger.debug(o.format(N[0]));};}else {M[N[0]]=N[1];};},this);return M;},getColumnTree:function(P,O){var Q=P.reduce(function(S,R){return this._mergeTree(S,this._expandKeyPathToTree(R.getPath(),qx.util.Serializer.toNativeObject(R)));}.bind(this),{});this._mergeTree(Q,this._getInterimColumnTree(O));return {'name':c,'visible':null,'type':l,'children':this._convertTree(Q)};}}});})();(function(){var a='clui.util.PropertyChain',b='_targetObject',c='.',d='name';qx.Class.define(a,{extend:qx.core.Object,construct:function(event){qx.core.Object.call(this);this._propertyChain=event.getData()[d];this._targetObject=event.getTarget();},destruct:function(){this._disposeObjects(b);},members:{_propertyChain:null,_targetObject:null,isChangeOf:function(e){return qx.lang.String.endsWith(this._propertyChain,c+e);},getPropertyOwner:function(f){var g=this._propertyChain.slice(0,-1*(f.length+1));return qx.data.SingleValueBinding.resolvePropertyChain(this._targetObject,g);}}});})();(function(){var a='solid',b='icon/22/actions/system-run.png',c='message',d='qx.event.type.Data',e='Failed to apply search field qeury',f='Group by day',g='changeZoomRange',h='timeSeries',i='validQuery',j='icon',k='Clone',l='Failed to set "after" date',m='zoomEnabled',n='Array',o='appear',p='group',q='day',r='icon/22/actions/go-last.png',s='1*',t='execute',u='Open',v='timestamp',w='Date selection',x='clui.model.form.TableQuery',y='changeValid',z='no-repeat',A='changeValue',B='changeSelection',C='invalid',D='Boolean',E='after',F='value',G='valid',H='open',I='excluded',J='changeBubble',K='date',L='_timeline',M='changeValidQuery',N='Level',O='qx.event.type.Event',P='Failed to apply dialog query',Q='Timeline',R='medium',S='icon/22/actions/view-restore.png',T='icon/22/apps/office-chart.png',U='_dateChooser',V='visible',W='cellDbltap',X='icon/22/actions/view-refresh.png',Y='After',bO='refresh',bP='border-light',bQ='Range',bK='Visible',bL='icon/22/actions/view-sort-ascending.png',bM='name',bN='_queryController',bV='icon/22/actions/system-search.png',bW='icon/22/apps/utilities-text-editor.png',bX='string',bY='changeTimeSeries',bR='white',bS='changeGroup',bT='Editor',bU='icon/22/apps/office-calendar.png',cd='hour',cq='icon/22/actions/go-first.png',cr='before',ce='clone',ca='Reload',cb='icon/22/actions/mail-mark-read.png',ct='Invalid query',cc='completed',cf='modelSelection[0]',cg='Record query',ch='Before',cl='query',cu='level',cm='Zoom',ci='Group by hour',cj='number',cs='clui.view.list.RecordTable',ck='label',cn='series',co='Failed to set "before" date',cp='ts';qx.Class.define(cs,{extend:clui.view.list.AbstractTable,events:{refresh:O,open:d,clone:O},properties:{tableQueryModel:{check:x,nullable:true},validQuery:{check:D,init:true,event:M},timeSeries:{check:n,init:[],event:bY},group:{check:[q,cd],init:q,event:bS}},construct:function(cw,cx,cv){this.setTableQueryModel(cv);this.setColumnset(this._getDefaultColumnset());this.setWidth(800);this._timeline=new clui.view.Timeline();this._timeline.setCompact(true);this._timeline.addListener(g,this._onChangeZoomRange,this);this.bind(h,this._timeline,cn);this.bind(p,this._timeline,p);clui.view.list.AbstractTable.call(this,cw,cx);this.addListenerOnce(o,this._createQueryController,this);this.addListenerOnce(o,this._createDateChooser,this);},destruct:function(){this._disposeObjects(U,bN,L);},members:{_dateChooser:null,_queryController:null,_timeline:null,_zoomOriginalRange:null,_getDefaultColumnset:function(){var cy=new qx.ui.table.cellrenderer.Replace();cy.setReplaceMap(clui.model.form.Record.levelMap);return qx.data.marshal.Json.createModel([{'name':this.tr(v),'width':165,'path':[cp],'id':cp,'type':K,'visible':true},{'name':this.tr(cu),'width':80,'path':[cu],'id':cu,'renderer':cy,'type':cj,'visible':true},{'name':this.tr(bM),'width':s,'id':bM,'path':[bM],'type':bX,'visible':true},{'name':this.tr(c),'width':s,'id':c,'path':[c],'type':bX,'visible':true}],true);},_onQueryCompleted:function(event){try{this.getTableQueryModel().updateFrom(event.getData()[cl]);this.setValidQuery(true);}catch(cz){this.error(P,cz);this.setValidQuery(false);};},_onChangeZoomRange:function(event){var cB=this.getTableQueryModel().getFormModel();var cC=event.getData();if(cC){var cA=(this._zoomOriginalRange||[]).map(function(cD){return cD.toDate();});if(qx.lang.Json.stringify(cC)!=qx.lang.Json.stringify(cA)){cB.set({'after':new kucken.date.RelativeDate(cC[0]),'before':new kucken.date.RelativeDate(cC[1])});};}else if(this._zoomOriginalRange){cB.set({'after':this._zoomOriginalRange[0],'before':this._zoomOriginalRange[1]});this._zoomOriginalRange=null;};},_onChangeZoomEnalbed:function(event){if(event.getData()){var cE=this.getTableQueryModel().getFormModel();this._zoomOriginalRange=[cE.getAfter(),cE.getBefore()];};},_createQueryController:function(){this._queryController=new kucken.ui.form.mvc.Controller(this.getLayoutParent(),clui.view.form.Query,clui.model.form.Query);this._queryController.addListener(cc,this._onQueryCompleted,this);},_createDateChooser:function(){this._dateChooser=new clui.view.widget.DateChooserWindow(this.tr(w));this.getLayoutParent().add(this._dateChooser);},_onLevelChange:function(event){var cF=this.getTableQueryModel().getFormModel();cF.setLevel(event.getTarget().getUserData(cu));},_onLevelMenuAppear:function(event){var cG=this.getTableQueryModel().getFormModel().getLevel();event.getTarget().getChildren().forEach(function(cH){cH.setValue(cH.getUserData(cu)==cG);});},_createLevelMenu:function(){var cI=new qx.ui.menu.Menu();cI.addListener(o,this._onLevelMenuAppear,this);var cJ=new qx.ui.form.RadioGroup();kucken.lang.Object.items(clui.model.form.Record.levelMap).forEach(function(cK){var cL=new qx.ui.menu.RadioButton(cK[1]);cL.setUserData(cu,cK[0]);cL.addListener(t,this._onLevelChange,this);cI.add(cL);cJ.add(cL);},this);return cI;},_createDateMenu:function(){var cN=new qx.ui.menu.Menu();var cP=new qx.util.format.DateFormat(qx.locale.Date.getDateFormat(R));var cQ=this.getTableQueryModel().getFormModel();var cO=new qx.ui.menu.Button(null,cq);cO.addListener(t,function(){this._dateChooser.getDate(cQ.getAfter().toDate()).then(clui.util.DateRange.toDayBegin).then(function(cR){cQ.setAfter(new kucken.date.RelativeDate(cR));}).caught(function(cS){this.error(l,cS);},this);},this);cQ.bind(E,cO,ck,{'converter':function(cT){if(cT){return cP.format(cT.toDate());};return this.tr(Y);}.bind(this)});cN.add(cO);var cM=new qx.ui.menu.Button(null,r);cM.addListener(t,function(){this._dateChooser.getDate(cQ.getBefore().toDate()).then(clui.util.DateRange.toDayEnd).then(function(cU){cQ.setBefore(new kucken.date.RelativeDate(cU));}).caught(function(cV){this.error(co,cV);},this);},this);cQ.bind(cr,cM,ck,{'converter':function(cW){if(cW){return cP.format(cW.toDate());};return this.tr(ch);}.bind(this)});cN.add(cM);return cN;},_createTimelineMenu:function(){var da=new qx.ui.menu.Menu();var dc=new qx.ui.menu.CheckBox(this.tr(bK));dc.setValue(true);dc.addListener(A,function(event){this._timeline.setVisibility(event.getData()?V:I);},this);da.add(dc);var db=new qx.ui.menu.CheckBox(this.tr(cm));db.setValue(false);db.addListener(A,this._onChangeZoomEnalbed,this);db.bind(F,this._timeline,m);da.add(db);var cX=new qx.ui.form.RadioGroup();cX.bind(cf,this,p);var dd=new qx.ui.menu.RadioButton(this.tr(f));dd.setModel(q);dd.setValue(true);cX.add(dd);var cY=new qx.ui.menu.RadioButton(this.tr(ci));cY.setModel(cd);cX.add(cY);da.add(cY);da.add(dd);return da;},_createFilterMenu:function(){var df=new qx.ui.menu.Menu();var dk=bL;var de=new qx.ui.menu.Button(this.tr(N),dk,null,this._createLevelMenu());df.add(de);dk=bU;var dh=new qx.ui.menu.Button(this.tr(bQ),dk,null,this._createDateMenu());df.add(dh);dk=T;var di=new qx.ui.menu.Button(this.tr(Q),dk,null,this._createTimelineMenu());df.add(di);dk=bW;var dj=new qx.ui.menu.Button(this.tr(bT),dk);dj.addListener(t,function(){this._queryController.open({'query':this.getTableQueryModel().toString(),'parent':this});},this);df.add(dj);dk=S;var dg=new qx.ui.menu.Button(this.tr(k),dk);dg.addListener(t,this.fireEvent.bind(this,ce,undefined,undefined));df.add(dg);return df;},_createSearchField:function(){var dl={'style':a,'width':1,'color':bP,'backgroundColor':bR,'backgroundImage':bV,'backgroundRepeat':z,'backgroundPosition':[3,2]};var dq=new qx.ui.decoration.Decorator();dq.set(dl);var dn=new qx.ui.decoration.Decorator();dn.set(kucken.lang.Object.merge({},dl,{'color':C}));var dm=new qx.ui.form.TextField();dm.set({'height':30,'decorator':dq,'padding':[3,2,3,26],'margin':[7,0,0,4],'placeholder':this.tr(cg),'invalidMessage':this.tr(ct),'value':this.getTableQueryModel().toString()});dm.addListener(y,function(event){if(event.getData()){dm.setDecorator(dq);}else {dm.setDecorator(dn);};});this.bind(i,dm,G);dm.addListener(A,function(event){try{this.getTableQueryModel().updateFrom(event.getData());this.setValidQuery(true);}catch(dr){this.error(e,dr);this.setValidQuery(false);};},this);var dp=this.getTableQueryModel();dp.getFormModel().addListener(J,qx.util.Function.debounce(function(event){dm.setValue(dp.toString());},10));return dm;},_createDataWidget:function(){var ds=clui.view.list.AbstractTable.prototype._createDataWidget.call(this);ds.addListener(W,function(event){this.fireDataEvent(H,event.getRow());},this);ds.getSelectionModel().addListener(B,function(event){var dt=event.getTarget().getLeadSelectionIndex();var du=ds.getTableModel().getRowData(dt);this._timeline.setHighlightDate(du?du[cp]:null);},this);return ds;},_createToolbar:function(){var toolbar=clui.view.list.AbstractTable.prototype._createToolbar.call(this);var dv=new qx.ui.toolbar.Button(this.tr(ca),X);dv.setMarginLeft(10);dv.setShow(j);dv.addListener(t,this.fireEvent.bind(this,bO,undefined,undefined));toolbar.add(dv);var open=new qx.ui.toolbar.Button(this.tr(u),bW);open.setIcon(cb);open.setShow(j);open.addListener(t,function(){this.fireDataEvent(H,this.getTable().getSelectionModel().getLeadSelectionIndex());},this);toolbar.add(open);toolbar.add(this._createSearchField(),{'flex':1});var dw=new qx.ui.toolbar.MenuButton(null,b);dw.set({'marginRight':10,'menu':this._createFilterMenu()});toolbar.add(dw);return toolbar;},_createLayout:function(){clui.view.list.AbstractTable.prototype._createLayout.call(this);this.addAt(this._timeline,1);}}});})();(function(){var a="Function",b="undefined",c="qx.ui.table.cellrenderer.Replace",d="Object";qx.Class.define(c,{extend:qx.ui.table.cellrenderer.Default,properties:{replaceMap:{check:d,nullable:true,init:null},replaceFunction:{check:a,nullable:true,init:null}},members:{_getContentHtml:function(g){var h=g.value;var e=this.getReplaceMap();var f=this.getReplaceFunction();var i;if(e){i=e[h];if(typeof i!=b){g.value=i;return qx.bom.String.escape(this._formatValue(g));};};if(f){g.value=f(h);};return qx.bom.String.escape(this._formatValue(g));},addReversedReplaceMap:function(){var j=this.getReplaceMap();for(var k in j){var l=j[k];j[l]=k;};return true;}}});})();(function(){var a='Reset',b='clui.view.form.Query',c='changeQueryHistory',d='Query editor',e='valid',f='monospace',g='Courier',h='',i='query',j='Close',k='Courier New',l='preload',m='icon/16/actions/document-properties.png',n='icon/16/actions/system-search.png',o='execute',p='icon/16/actions/document-open-recent.png',q='Apply',r='Invalid query',s='Enter',t='keypress';qx.Class.define(b,{extend:kucken.ui.form.mvc.View,construct:function(u){kucken.ui.form.mvc.View.call(this,u);this.setWidth(350);this.setHeight(200);this.setCaption(this.tr(d));this.setIcon(m);},members:{_createForm:function(){kucken.ui.form.mvc.View.prototype._createForm.call(this);var v=new qx.ui.form.TextArea();v.set({'height':150,'font':new qx.bom.Font(11,[k,g,f]),'invalidMessage':this.tr(r),'liveUpdate':true});v.addListener(t,function(event){if(event.getKeyIdentifier()==s&&event.isCtrlPressed()){this._onOk();};},this);this.add(v,{'flex':1});this.getModel().addListener(l,function(){this.getModel().removeRelatedBindings(v);this.getModel().bind(e,v,e);},this);this._form.add(v,null,null,i);},_onHistoryButtonExecute:function(event){var w=event.getTarget().getUserData(i);this.getModel().getFormModel().setQuery(w);},_updateHistoryMenu:function(y,x){y.setEnabled(Boolean(x.length));y.getMenu().removeAll();x.forEach(function(z){var A=new qx.ui.menu.Button(z);A.setUserData(i,z);A.addListener(o,this._onHistoryButtonExecute,this);y.getMenu().add(A);},this);},_createHistoryButton:function(){var B=new qx.ui.menu.Menu();var C=new qx.ui.form.MenuButton(null,p,B);this.getModel().addListener(c,function(event){this._updateHistoryMenu(C,event.getData());},this);this._updateHistoryMenu(C,this.getModel().getQueryHistory());return C;},_onOk:function(){if(this._form.validate()){this.getModel().save();};},_renderForm:function(){var E=new qx.ui.container.Composite();E.setMargin([8,8,0,8]);E.setLayout(new qx.ui.layout.HBox(5));E.add(this._createHistoryButton());var D=new qx.ui.form.Button(this.tr(a));D.addListener(o,function(){this.getModel().getFormModel().setQuery(h);},this);E.add(D);E.add(new qx.ui.core.Spacer(),{'flex':1});E.add(this._okButton);this._okButton.setLabel(this.tr(q));this._okButton.setMinWidth(80);this._okButton.setIcon(n);E.add(this._cancelButton);this._cancelButton.setLabel(this.tr(j));this.add(E);}}});})();(function(){var a='parent',b='changeValid',c='Array',d='valid',e='preload',f='_applyQueryHistory',g='validQuery',h='loaded',i='',j='Boolean',k='query',l='saved',m='changeQueryHistory',n='clui.model.form.Query';qx.Class.define(n,{extend:kucken.ui.form.mvc.Model,properties:{queryHistory:{check:c,apply:f,event:m},valid:{check:j,init:true,event:b}},construct:function(){kucken.ui.form.mvc.Model.call(this);this._queryStorage=qx.bom.Storage.getLocal();this.setQueryHistory(this._queryStorage.getItem(this.classname)||[]);},members:{_queryStorage:null,_createFormModel:function(){this._item[a].bind(g,this,d);var o={'query':this._item[k]||i};this.fireEvent(e);this.setFormModel(qx.data.marshal.Json.createModel(o));this.fireDataEvent(h,o);},_applyQueryHistory:function(q,p){this._queryStorage.setItem(this.classname,q);},pushQueryHistory:function(r){if(!r){return;};var s=this.getQueryHistory();s.unshift(r);this.setQueryHistory(qx.lang.Array.unique(s).slice(0,20));},save:function(){var t=qx.util.Serializer.toNativeObject(this.getFormModel());this.pushQueryHistory(t[k]);this.fireDataEvent(l,t);}}});})();(function(){var a="html.storage.local",b="html.storage.userdata",c="qx.bom.Storage";qx.Bootstrap.define(c,{statics:{__xP:null,getLocal:function(){if(qx.core.Environment.get(a)){return qx.bom.storage.Web.getLocal();}else if(qx.core.Environment.get(b)){return qx.bom.storage.UserData.getLocal();};return qx.bom.storage.Memory.getLocal();},getSession:function(){if(qx.core.Environment.get(a)){return qx.bom.storage.Web.getSession();}else if(qx.core.Environment.get(b)){return qx.bom.storage.UserData.getSession();};return qx.bom.storage.Memory.getSession();}}});})();(function(){var a="local",b="session",c="Storage",d="qx.bom.storage.Web",f="Storage full.";qx.Bootstrap.define(d,{statics:{__xQ:null,__xR:null,getLocal:function(){if(this.__xQ){return this.__xQ;};return this.__xQ=new qx.bom.storage.Web(a);},getSession:function(){if(this.__xR){return this.__xR;};return this.__xR=new qx.bom.storage.Web(b);}},construct:function(g){this.__pW=g;},members:{__pW:null,getStorage:function(){return window[this.__pW+c];},getLength:function(){return this.getStorage(this.__pW).length;},setItem:function(h,j){j=qx.lang.Json.stringify(j);try{this.getStorage(this.__pW).setItem(h,j);}catch(e){throw new Error(f);};},getItem:function(l){var k=this.getStorage(this.__pW).getItem(l);if(qx.lang.Type.isString(k)){k=qx.lang.Json.parse(k);}else if(k&&k.value&&qx.lang.Type.isString(k.value)){k=qx.lang.Json.parse(k.value);};return k;},removeItem:function(m){this.getStorage(this.__pW).removeItem(m);},clear:function(){var n=this.getStorage(this.__pW);if(!n.clear){for(var i=n.length-1;i>=0;i-- ){n.removeItem(n.key(i));};}else {n.clear();};},getKey:function(o){return this.getStorage(this.__pW).key(o);},forEach:function(p,r){var length=this.getLength();for(var i=0;i<length;i++ ){var q=this.getKey(i);p.call(r,q,this.getItem(q));};}}});})();(function(){var a="session",b="head",c="none",d="qx",e="qx.bom.storage.UserData",f="div",g="local",h="qxtest",j="#default#userdata",k="display";qx.Bootstrap.define(e,{statics:{__xQ:null,__xR:null,__cl:0,getLocal:function(){if(this.__xQ){return this.__xQ;};return this.__xQ=new qx.bom.storage.UserData(g);},getSession:function(){if(this.__xR){return this.__xR;};return this.__xR=new qx.bom.storage.UserData(a);}},construct:function(m){this.__xS=document.createElement(f);this.__xS.style[k]=c;document.getElementsByTagName(b)[0].appendChild(this.__xS);this.__xS.addBehavior(j);this.__xT=m;this.__xS.load(this.__xT);this.__fv={};this.__xU={};var l=this.__xS.getAttribute(d+qx.bom.storage.UserData.__cl);while(l!=undefined){l=qx.lang.Json.parse(l);this.__fv[l.key]=l.value;this.__xU[l.key]=d+qx.bom.storage.UserData.__cl;qx.bom.storage.UserData.__cl++ ;l=this.__xS.getAttribute(d+qx.bom.storage.UserData.__cl);};},members:{__xS:null,__xT:h,__fv:null,__xU:null,getStorage:function(){return this.__fv;},getLength:function(){return Object.keys(this.__fv).length;},setItem:function(n,p){if(this.__xU[n]){var o=this.__xU[n];}else {var o=d+qx.bom.storage.UserData.__cl;qx.bom.storage.UserData.__cl++ ;};var q=qx.lang.Json.stringify({key:n,value:p});this.__xS.setAttribute(o,q);this.__xS.save(this.__xT);this.__fv[n]=p;this.__xU[n]=o;},getItem:function(r){return this.__fv[r]||null;},removeItem:function(v){var u=this.__xU[v];if(u==undefined){return;};this.__xS.removeAttribute(u);qx.bom.storage.UserData.__cl-- ;delete this.__fv[v];delete this.__xU[v];var t=d+qx.bom.storage.UserData.__cl;if(this.__xS.getAttribute(t)){var w=this.__xS.getAttribute(d+qx.bom.storage.UserData.__cl);this.__xS.removeAttribute(t);this.__xS.setAttribute(u,w);var s=qx.lang.Json.parse(w).key;this.__xU[s]=u;};this.__xS.save(this.__xT);},clear:function(){for(var x in this.__xU){this.__xS.removeAttribute(this.__xU[x]);};this.__xS.save(this.__xT);this.__fv={};this.__xU={};},getKey:function(y){return Object.keys(this.__fv)[y];},forEach:function(z,B){var length=this.getLength();for(var i=0;i<length;i++ ){var A=this.getKey(i);z.call(B,A,this.getItem(A));};}}});})();(function(){var a="qx.bom.storage.Memory";qx.Bootstrap.define(a,{statics:{__xQ:null,__xR:null,getLocal:function(){if(this.__xQ){return this.__xQ;};return this.__xQ=new qx.bom.storage.Memory();},getSession:function(){if(this.__xR){return this.__xR;};return this.__xR=new qx.bom.storage.Memory();}},construct:function(){this.__fv={};},members:{__fv:null,getStorage:function(){return this.__fv;},getLength:function(){return Object.keys(this.__fv).length;},setItem:function(b,c){c=qx.lang.Json.stringify(c);this.__fv[b]=c;},getItem:function(e){var d=this.__fv[e];if(qx.lang.Type.isString(d)){d=qx.lang.Json.parse(d);};return d;},removeItem:function(f){delete this.__fv[f];},clear:function(){this.__fv={};},getKey:function(h){var g=Object.keys(this.__fv);return g[h];},forEach:function(j,l){var length=this.getLength();for(var i=0;i<length;i++ ){var k=this.getKey(i);j.call(l,k,this.getItem(k));};}}});})();(function(){var a='changeValue',b='appear',c='_applyPromise',d='Cancelled',e='_chooser',f='close',g='kucken.Promise',h='clui.view.widget.DateChooserWindow';qx.Class.define(h,{extend:qx.ui.window.Window,properties:{promise:{check:g,nullable:true,apply:c}},construct:function(i,j){qx.ui.window.Window.call(this,i,j);this.set({'layout':new qx.ui.layout.VBox(),'showMinimize':false,'showMaximize':false,'modal':true,'contentPadding':0});this.addListener(b,this.center,this);this._chooser=new qx.ui.control.DateChooser();this._chooser.setDecorator(new qx.ui.decoration.Decorator());this.add(this._chooser);},destruct:function(){this._disposeObjects(e);},members:{_chooser:null,_applyPromise:function(l,k){if(l){this.addListener(f,this._onClose,this);this._chooser.addListener(a,this._onChangeValue,this);}else {this.removeListener(f,this._onClose,this);this._chooser.removeListener(a,this._onChangeValue,this);};},_onClose:function(){var m=this.getPromise();if(m){m.reject(new Error(d));this.resetPromise();};},_onChangeValue:function(event){var n=this.getPromise();if(n){n.resolve(event.getData());this.resetPromise();this.close();};},getDate:function(o){this._chooser.setValue(o);this.open();return this.setPromise(new kucken.Promise());}}});})();(function(){var a="qx.ui.form.RadioGroup",b="Boolean",c="menu-radiobutton",d="label",f="_applyValue",g="qx.ui.menu.RadioButton",h="value",i="changeValue",j="toolTipText",k="enabled",l="_applyGroup",m="checked",n="menu",o="execute";qx.Class.define(g,{extend:qx.ui.menu.AbstractButton,include:[qx.ui.form.MModelProperty],implement:[qx.ui.form.IRadioItem,qx.ui.form.IBooleanForm,qx.ui.form.IModel],construct:function(q,p){qx.ui.menu.AbstractButton.call(this);if(q!=null){this.setLabel(q);};if(p!=null){this.setMenu(p);};this.addListener(o,this._onExecute,this);},properties:{appearance:{refine:true,init:c},value:{check:b,nullable:true,event:i,apply:f,init:false},group:{check:a,nullable:true,apply:l}},members:{_bindableProperties:[k,d,j,h,n],_applyValue:function(s,r){s?this.addState(m):this.removeState(m);},_applyGroup:function(u,t){if(t){t.remove(this);};if(u){u.add(this);};},_onExecute:function(e){var v=this.getGroup();if(v&&v.getAllowEmptySelection()){this.toggleValue();}else {this.setValue(true);};}}});})();(function(){var a='clui.util.DateRange';qx.Class.define(a,{statics:{toDayBegin:function(b){var c=new Date(b);c.setHours(0,0,0,0);return c;},toDayEnd:function(d){var e=new Date(d);e.setHours(23,59,59,999);return e;}}});})();(function(){var a="Boolean",b="arrow",c="visible",d="_applyShowArrow",e="toolbar-menubutton",f="qx.ui.toolbar.MenuButton";qx.Class.define(f,{extend:qx.ui.menubar.Button,properties:{appearance:{refine:true,init:e},showArrow:{check:a,init:false,themeable:true,apply:d}},members:{_applyVisibility:function(i,h){qx.ui.menubar.Button.prototype._applyVisibility.call(this,i,h);var g=this.getMenu();if(i!=c&&g){g.hide();};var parent=this.getLayoutParent();if(parent&&parent instanceof qx.ui.toolbar.PartContainer){qx.ui.core.queue.Appearance.add(parent);};},_createChildControlImpl:function(l,k){var j;switch(l){case b:j=new qx.ui.basic.Image();j.setAnonymous(true);this._addAt(j,10);break;};return j||qx.ui.menubar.Button.prototype._createChildControlImpl.call(this,l);},_applyShowArrow:function(n,m){if(n){this._showChildControl(b);}else {this._excludeChildControl(b);};}}});})();(function(){var a="table-row-background-even",b="button-box-pressed-top-right",c="arrow-left",d="datechooser-weekday",e="arrow-up",f="menu-slidebar-button",g="background-disabled",h="background",j="scrollbar/button",k="icon/16/actions/dialog-ok.png",l="border-invalid",m="combobox/button",n="button-box-top-right",o="slidebar",p="#BABABA",q="button-box-hovered-bottom-right",r="move-frame",s="nodrop",t="window-caption",u="table-header-cell",v="button-box-hovered-top-right",w="row-layer",x="treevirtual-plus-only",y="-right",z="button-frame",A="radiobutton",B="move",C="treevirtual-plus-end",D="background-selected-dark",E="vertical",F="list",G="arrow-down-small",H="arrow-down",I="arrow-",J="-pressed",K="tooltip-error",L="button-box",M="window-restore",N="bold",O="resize-frame",P="text-disabled",Q="scroll-knob",R="tree-minus",S="statusbar",T="white",U="tabview-close",V="down",W="text",X="checkbox",Y="atom/label",eJ="button-box-pressed-bottom-right",eF="button-box-pressed-hovered-bottom-right",eK="background-disabled-checked",eG="groupbox",eH="icon/16/actions/dialog-cancel.png",eE="qx.theme.simple.Appearance",eI="menu-slidebar",eP="-left",eQ="treevirtual-minus-cross",eW="arrow-right",eR="background-pane",eL="table-",eM="scroll-knob-pressed",eN="icon",eO="arrow-rewind",eV="icon/16/apps/office-calendar.png",fz="headline",eX="treevirtual-plus-start",eY="treevirtual-minus-end",eS="middle",eT="-middle",gA="tree",eU="checkbox-undetermined",fa="button-box-bottom-right",fb="datechooser-week",fc="menu-button",fh="descending",fi="splitpane",fj="slidebar/button-forward",fd="toolbar-separator",fe="arrow-up-small",ff="progressive-table-header",fg="invalid",fn="icon/16/places/folder.png",fo="combobox",fp="tree-folder",fq="horizontal",fk="icon/16/mimetypes/text-plain.png",fl="border-light-shadow",gB="tree-plus",fm="text-placeholder",fu="scrollbar",fv="dragover",gG="treevirtual-plus-cross",fw="scrollarea",fr="treevirtual-line",fs="text-selected",gE="cell",ft="menu-checkbox",fx="best-fit",fy="button-border",fK="treevirtual-cross",fJ="default",fI="tabview-page-button-right",fO="button-hover",fN="tabview-page-button-top",fM="tabview-page-button-bottom",fL="inset",fD="tabview-page-button-left",fC="button",fB="menubar-button-pressed",fA="progressbar",fH="tree-file",fG="tooltip-text",fF="keep-align",fE="center",fV="datechooser/button",fU="alias",fT="datechooser",fS="toolbar-button",ga="ascending",fY="button-box-hovered-right-borderless",fX="button-box-right-borderless",fW="lead-item",fR="checkbox-focused",fQ="selectbox",fP="window-minimize",gl="right",gk="button-box-pressed-hovered-top-right",gj="main",gp="image",go="knob-",gn="blank",gm="popup",ge="treevirtual-folder",gd="treevirtual-minus-only",gc="treevirtual-minus-start",gb="checkbox-checked",gi="virtual-list",gh="background-selected",gg="window",gf="-hovered",gv="window-active",gu="table-header-cell-first",gt="left",gs="button-box-pressed-right-borderless",gz="scroll-knob-hovered",gy="up",gx="atom",gw="main-dark",gr="select-column-order",gq="button-box-pressed-hovered-right-borderless",ed="-invalid",ec="scroll-knob-pressed-hovered",gH="white-box",ea="datechooser-week-header",eb="widget",dY="menubar-button-hovered",gF="table-header-column-button",dW="window-close",dX="datechooser-date-pane",dV="cursor-",gC="-focused",dT="menu-radiobutton",dU="window-maximize",dS="treevirtual-end",em="button-box-hovered",en="table",ek="arrow-forward",el="right-top",ei="pointer",ej="focused-inset",eh="slidebar/button-backward",dR="light-background",ef="copy",eg="table-row-background-selected",ee="radiobutton-focused",eA="",ey="textfield",ez="scrollbar/slider/knob",ew="button-box-pressed-hovered",ex="atom/icon",ev="spinner",eB="tooltip",et="-disabled",eu="label",es="table-header",gD="progressive-table-header-cell",eq="menu-separator",er="-invert",eo="link",ep="icon/16/places/folder-open.png",eC="icon/16/actions/view-refresh.png",eD="button-box-pressed";qx.Theme.define(eE,{appearances:{"widget":{},"label":{style:function(gI){return {textColor:gI.disabled?P:undefined};}},"image":{style:function(gJ){return {opacity:!gJ.replacement&&gJ.disabled?0.3:undefined};}},"atom":{},"atom/label":eu,"atom/icon":gp,"root":{style:function(gK){return {backgroundColor:h,textColor:W,font:fJ};}},"popup":{style:function(gL){return {decorator:gm,backgroundColor:eR};}},"tooltip":{include:gm,style:function(gM){return {backgroundColor:eB,textColor:fG,decorator:eB,padding:[1,3,2,3],offset:[10,5,5,5]};}},"tooltip/atom":gx,"tooltip-error":{include:eB,style:function(gN){return {textColor:fs,showTimeout:100,hideTimeout:10000,decorator:K,font:N,backgroundColor:undefined};}},"tooltip-error/atom":gx,"iframe":{style:function(gO){return {backgroundColor:T,decorator:gw};}},"move-frame":{style:function(gP){return {decorator:gw};}},"resize-frame":r,"dragdrop-cursor":{style:function(gQ){var gR=s;if(gQ.copy){gR=ef;}else if(gQ.move){gR=B;}else if(gQ.alias){gR=fU;};return {source:qx.theme.simple.Image.URLS[dV+gR],position:el,offset:[2,16,2,6]};}},"slidebar":{},"slidebar/scrollpane":{},"slidebar/content":{},"slidebar/button-forward":{alias:fC,include:fC,style:function(gS){return {icon:qx.theme.simple.Image.URLS[I+(gS.vertical?V:gl)]};}},"slidebar/button-backward":{alias:fC,include:fC,style:function(gT){return {icon:qx.theme.simple.Image.URLS[I+(gT.vertical?gy:gt)]};}},"table":eb,"table/statusbar":{style:function(gU){return {decorator:S,padding:[2,5]};}},"table/column-button":{alias:fC,style:function(gV){return {decorator:gF,padding:3,icon:qx.theme.simple.Image.URLS[gr]};}},"table-column-reset-button":{include:fc,alias:fc,style:function(){return {icon:eC};}},"table-scroller/scrollbar-x":fu,"table-scroller/scrollbar-y":fu,"table-scroller":eb,"table-scroller/header":{style:function(){return {decorator:es};}},"table-scroller/pane":{},"table-scroller/focus-indicator":{style:function(gW){return {decorator:gj};}},"table-scroller/resize-line":{style:function(gX){return {backgroundColor:fy,width:3};}},"table-header-cell":{alias:gx,style:function(gY){return {decorator:gY.first?gu:u,minWidth:13,font:N,paddingTop:3,paddingLeft:5,cursor:gY.disabled?undefined:ei,sortIcon:gY.sorted?(qx.theme.simple.Image.URLS[eL+(gY.sortedAscending?ga:fh)]):undefined};}},"table-header-cell/icon":{include:ex,style:function(ha){return {paddingRight:5};}},"table-header-cell/sort-icon":{style:function(hb){return {alignY:eS,alignX:gl,paddingRight:5};}},"table-editor-textfield":{include:ey,style:function(hc){return {decorator:undefined,padding:[2,2]};}},"table-editor-selectbox":{include:fQ,alias:fQ,style:function(hd){return {padding:[0,2]};}},"table-editor-combobox":{include:fo,alias:fo,style:function(he){return {decorator:undefined};}},"progressive-table-header":{style:function(hf){return {decorator:ff};}},"progressive-table-header-cell":{style:function(hg){return {decorator:gD,padding:[5,6,5,6]};}},"treevirtual":{include:ey,alias:en,style:function(hh,hi){return {padding:[hi.padding[0]+2,hi.padding[1]+1]};}},"treevirtual-folder":{style:function(hj){return {icon:(hj.opened?ep:fn),opacity:hj.drag?0.5:undefined};}},"treevirtual-file":{include:ge,alias:ge,style:function(hk){return {icon:fk,opacity:hk.drag?0.5:undefined};}},"treevirtual-line":{style:function(hl){return {icon:qx.theme.simple.Image.URLS[fr]};}},"treevirtual-contract":{style:function(hm){return {icon:qx.theme.simple.Image.URLS[R]};}},"treevirtual-expand":{style:function(hn){return {icon:qx.theme.simple.Image.URLS[gB]};}},"treevirtual-only-contract":{style:function(ho){return {icon:qx.theme.simple.Image.URLS[gd]};}},"treevirtual-only-expand":{style:function(hp){return {icon:qx.theme.simple.Image.URLS[x]};}},"treevirtual-start-contract":{style:function(hq){return {icon:qx.theme.simple.Image.URLS[gc]};}},"treevirtual-start-expand":{style:function(hr){return {icon:qx.theme.simple.Image.URLS[eX]};}},"treevirtual-end-contract":{style:function(hs){return {icon:qx.theme.simple.Image.URLS[eY]};}},"treevirtual-end-expand":{style:function(ht){return {icon:qx.theme.simple.Image.URLS[C]};}},"treevirtual-cross-contract":{style:function(hu){return {icon:qx.theme.simple.Image.URLS[eQ]};}},"treevirtual-cross-expand":{style:function(hv){return {icon:qx.theme.simple.Image.URLS[gG]};}},"treevirtual-end":{style:function(hw){return {icon:qx.theme.simple.Image.URLS[dS]};}},"treevirtual-cross":{style:function(hx){return {icon:qx.theme.simple.Image.URLS[fK]};}},"resizer":{style:function(hy){return {decorator:gw};}},"splitpane":{},"splitpane/splitter":{style:function(hz){return {backgroundColor:dR};}},"splitpane/splitter/knob":{style:function(hA){return {source:qx.theme.simple.Image.URLS[go+(hA.horizontal?fq:E)],padding:2};}},"splitpane/slider":{style:function(hB){return {backgroundColor:fl,opacity:0.3};}},"menu":{style:function(hC){var hD={backgroundColor:h,decorator:gj,spacingX:6,spacingY:1,iconColumnWidth:16,arrowColumnWidth:4,padding:1,placementModeY:hC.submenu||hC.contextmenu?fx:fF};if(hC.submenu){hD.position=el;hD.offset=[-2,-3];};if(hC.contextmenu){hD.offset=4;};return hD;}},"menu/slidebar":eI,"menu-slidebar":eb,"menu-slidebar-button":{style:function(hE){return {backgroundColor:hE.hovered?gh:undefined,padding:6,center:true};}},"menu-slidebar/button-backward":{include:f,style:function(hF){return {icon:qx.theme.simple.Image.URLS[e+(hF.hovered?er:eA)]};}},"menu-slidebar/button-forward":{include:f,style:function(hG){return {icon:qx.theme.simple.Image.URLS[H+(hG.hovered?er:eA)]};}},"menu-separator":{style:function(hH){return {height:0,decorator:eq,marginTop:4,marginBottom:4,marginLeft:2,marginRight:2};}},"menu-button":{alias:gx,style:function(hI){return {backgroundColor:hI.selected?gh:undefined,textColor:hI.selected?fs:undefined,padding:[2,6]};}},"menu-button/icon":{include:gp,style:function(hJ){return {alignY:eS};}},"menu-button/label":{include:eu,style:function(hK){return {alignY:eS,padding:1};}},"menu-button/shortcut":{include:eu,style:function(hL){return {alignY:eS,marginLeft:14,padding:1};}},"menu-button/arrow":{include:gp,style:function(hM){return {source:qx.theme.simple.Image.URLS[eW+(hM.selected?er:eA)],alignY:eS};}},"menu-checkbox":{alias:fc,include:fc,style:function(hN){return {icon:!hN.checked?undefined:qx.theme.simple.Image.URLS[ft+(hN.selected?er:eA)]};}},"menu-radiobutton":{alias:fc,include:fc,style:function(hO){return {icon:!hO.checked?undefined:qx.theme.simple.Image.URLS[dT+(hO.selected?er:eA)]};}},"menubar":{style:function(hP){return {backgroundColor:dR,padding:[4,2]};}},"menubar-button":{style:function(hQ){var hS;var hR=[2,6];if(!hQ.disabled){if(hQ.pressed){hS=fB;hR=[1,5,2,5];}else if(hQ.hovered){hS=dY;hR=[1,5];};};return {padding:hR,cursor:hQ.disabled?undefined:ei,textColor:eo,decorator:hS};}},"virtual-list":F,"virtual-list/row-layer":w,"row-layer":eb,"column-layer":eb,"group-item":{include:eu,alias:eu,style:function(hT){return {padding:4,backgroundColor:p,textColor:T,font:N};}},"virtual-selectbox":fQ,"virtual-selectbox/dropdown":gm,"virtual-selectbox/dropdown/list":{alias:gi},"virtual-combobox":fo,"virtual-combobox/dropdown":gm,"virtual-combobox/dropdown/list":{alias:gi},"virtual-tree":{include:gA,alias:gA,style:function(hU){return {itemHeight:21};}},"virtual-tree-folder":fp,"virtual-tree-file":fH,"cell":{style:function(hV){return {backgroundColor:hV.selected?eg:a,textColor:hV.selected?fs:W,padding:[3,6]};}},"cell-string":gE,"cell-number":{include:gE,style:function(hW){return {textAlign:gl};}},"cell-image":gE,"cell-boolean":gE,"cell-atom":gE,"cell-date":gE,"cell-html":gE,"scrollbar":{},"scrollbar/slider":{},"scrollbar/slider/knob":{style:function(hX){var hY=Q;if(!hX.disabled){if(hX.hovered&&!hX.pressed&&!hX.checked){hY=gz;}else if(hX.hovered&&(hX.pressed||hX.checked)){hY=ec;}else if(hX.pressed||hX.checked){hY=eM;};};return {height:14,width:14,cursor:hX.disabled?undefined:ei,decorator:hY,minHeight:hX.horizontal?undefined:20,minWidth:hX.horizontal?20:undefined};}},"scrollbar/button":{style:function(ia){var ib={};ib.padding=4;var ic=eA;if(ia.left){ic=gt;ib.marginRight=2;}else if(ia.right){ic+=gl;ib.marginLeft=2;}else if(ia.up){ic+=gy;ib.marginBottom=2;}else {ic+=V;ib.marginTop=2;};ib.icon=qx.theme.simple.Image.URLS[I+ic];ib.cursor=ei;ib.decorator=L;return ib;}},"scrollbar/button-begin":j,"scrollbar/button-end":j,"scrollarea/corner":{style:function(id){return {backgroundColor:h};}},"scrollarea":eb,"scrollarea/pane":eb,"scrollarea/scrollbar-x":fu,"scrollarea/scrollbar-y":fu,"textfield":{style:function(ie){var ih;if(ie.disabled){ih=P;}else if(ie.showingPlaceholder){ih=fm;}else {ih=undefined;};var ii;var ig;if(ie.disabled){ii=fL;ig=[2,3];}else if(ie.invalid){ii=l;ig=[1,2];}else if(ie.focused){ii=ej;ig=[1,2];}else {ig=[2,3];ii=fL;};return {decorator:ii,padding:ig,textColor:ih,backgroundColor:ie.disabled?g:T};}},"textarea":ey,"radiobutton/icon":{style:function(ij){var ik=A;if(ij.focused&&!ij.invalid){ik=ee;};ik+=ij.invalid&&!ij.disabled?ed:eA;var il;if(ij.disabled&&ij.checked){il=eK;}else if(ij.disabled){il=g;}else if(ij.checked){il=gh;};return {decorator:ik,width:12,height:12,backgroundColor:il};}},"radiobutton":{style:function(im){return {icon:qx.theme.simple.Image.URLS[gn]};}},"form-renderer-label":{include:eu,style:function(){return {paddingTop:3};}},"checkbox":{alias:gx,style:function(io){var ip;if(io.checked){ip=qx.theme.simple.Image.URLS[gb];}else if(io.undetermined){ip=qx.theme.simple.Image.URLS[eU];}else {ip=qx.theme.simple.Image.URLS[gn];};return {icon:ip,gap:6};}},"checkbox/icon":{style:function(iq){var is=X;if(iq.focused&&!iq.invalid){is=fR;};is+=iq.invalid&&!iq.disabled?ed:eA;var ir;if(iq.checked){ir=2;}else if(iq.undetermined){ir=[4,2];};return {decorator:is,width:12,height:12,padding:ir,backgroundColor:T};}},"spinner":{style:function(it){return {textColor:it.disabled?P:undefined};}},"spinner/textfield":ey,"spinner/upbutton":{alias:m,include:m,style:function(iu){var iv=n;if(iu.hovered&&!iu.pressed&&!iu.checked){iv=v;}else if(iu.hovered&&(iu.pressed||iu.checked)){iv=gk;}else if(iu.pressed||iu.checked){iv=b;};return {icon:qx.theme.simple.Image.URLS[fe],decorator:iv,width:17};}},"spinner/downbutton":{alias:m,include:m,style:function(iw){var ix=fa;if(iw.hovered&&!iw.pressed&&!iw.checked){ix=q;}else if(iw.hovered&&(iw.pressed||iw.checked)){ix=eF;}else if(iw.pressed||iw.checked){ix=eJ;};return {icon:qx.theme.simple.Image.URLS[G],decorator:ix,width:17};}},"selectbox":z,"selectbox/atom":gx,"selectbox/popup":gm,"selectbox/list":{alias:F,include:F,style:function(){return {decorator:undefined};}},"selectbox/arrow":{include:gp,style:function(iy){return {source:qx.theme.simple.Image.URLS[H],paddingRight:4,paddingLeft:5};}},"combobox":{},"combobox/button":{alias:z,include:z,style:function(iz){var iA=fX;if(iz.hovered&&!iz.pressed&&!iz.checked){iA=fY;}else if(iz.hovered&&(iz.pressed||iz.checked)){iA=gq;}else if(iz.pressed||iz.checked){iA=gs;};return {icon:qx.theme.simple.Image.URLS[H],decorator:iA,padding:[0,5],width:19};}},"combobox/popup":gm,"combobox/list":{alias:F},"combobox/textfield":ey,"datefield":ey,"datefield/button":{alias:m,include:m,style:function(iB){return {icon:eV,padding:[0,0,0,3],backgroundColor:undefined,decorator:undefined,width:19};}},"datefield/textfield":{alias:ey,include:ey,style:function(iC){return {decorator:undefined,padding:0};}},"datefield/list":{alias:fT,include:fT,style:function(iD){return {decorator:undefined};}},"list":{alias:fw,include:ey},"listitem":{alias:gx,style:function(iE){var iF=[3,5,3,5];if(iE.lead){iF=[2,4,2,4];};if(iE.dragover){iF[2]-=2;};var iG;if(iE.selected){iG=gh;if(iE.disabled){iG+=et;};};return {gap:4,padding:iF,backgroundColor:iG,textColor:iE.selected?fs:undefined,decorator:iE.lead?fW:iE.dragover?fv:undefined,opacity:iE.drag?0.5:undefined};}},"slider":{style:function(iH){var iJ;var iI;if(iH.disabled){iJ=fL;iI=[2,3];}else if(iH.invalid){iJ=l;iI=[1,2];}else if(iH.focused){iJ=ej;iI=[1,2];}else {iI=[2,3];iJ=fL;};return {decorator:iJ,padding:iI};}},"slider/knob":ez,"button-frame":{alias:gx,style:function(iK){var iL=L;if(!iK.disabled){if(iK.hovered&&!iK.pressed&&!iK.checked){iL=em;}else if(iK.hovered&&(iK.pressed||iK.checked)){iL=ew;}else if(iK.pressed||iK.checked){iL=eD;};};if(iK.invalid&&!iK.disabled){iL+=ed;}else if(iK.focused){iL+=gC;};return {decorator:iL,padding:[3,8],cursor:iK.disabled?undefined:ei,minWidth:5,minHeight:5};}},"button-frame/label":{alias:Y,style:function(iM){return {textColor:iM.disabled?P:undefined};}},"button":{alias:z,include:z,style:function(iN){return {center:true};}},"hover-button":{alias:fC,include:fC,style:function(iO){return {decorator:iO.hovered?fO:undefined};}},"menubutton":{include:fC,alias:fC,style:function(iP){return {icon:qx.theme.simple.Image.URLS[H],iconPosition:gl};}},"splitbutton":{},"splitbutton/button":{alias:gx,style:function(iQ){var iR=L;if(!iQ.disabled){if(iQ.pressed||iQ.checked){iR+=J;};if(iQ.hovered){iR+=gf;};};if(iQ.focused){iR+=gC;};iR+=eP;return {decorator:iR,padding:[3,8],cursor:iQ.disabled?undefined:ei};}},"splitbutton/arrow":{style:function(iS){var iT=L;if(!iS.disabled){if(iS.pressed||iS.checked){iT+=J;};if(iS.hovered){iT+=gf;};};if(iS.focused){iT+=gC;};iT+=y;return {icon:qx.theme.simple.Image.URLS[H],decorator:iT,cursor:iS.disabled?undefined:ei,padding:[3,4]};}},"groupbox":{},"groupbox/legend":{alias:gx,style:function(iU){return {textColor:iU.invalid?fg:undefined,padding:5,margin:4,font:N};}},"groupbox/frame":{style:function(iV){return {backgroundColor:h,padding:[6,9],margin:[18,2,2,2],decorator:gH};}},"check-groupbox":eG,"check-groupbox/legend":{alias:X,include:X,style:function(iW){return {textColor:iW.invalid?fg:undefined,padding:5,margin:4,font:N};}},"radio-groupbox":eG,"radio-groupbox/legend":{alias:A,include:A,style:function(iX){return {textColor:iX.invalid?fg:undefined,padding:5,margin:4,font:N};}},"tree-folder/open":{include:gp,style:function(iY){return {source:iY.opened?qx.theme.simple.Image.URLS[R]:qx.theme.simple.Image.URLS[gB]};}},"tree-folder":{style:function(ja){var jb;if(ja.selected){jb=gh;if(ja.disabled){jb+=et;};};return {padding:[2,8,2,5],icon:ja.opened?ep:fn,backgroundColor:jb,iconOpened:ep,opacity:ja.drag?0.5:undefined};}},"tree-folder/icon":{include:gp,style:function(jc){return {padding:[0,4,0,0]};}},"tree-folder/label":{style:function(jd){return {padding:[1,2],textColor:jd.selected&&!jd.disabled?fs:undefined};}},"tree-file":{include:fp,alias:fp,style:function(je){return {icon:fk,opacity:je.drag?0.5:undefined};}},"tree":{include:F,alias:F,style:function(jf){return {contentPadding:jf.invalid&&!jf.disabled?[3,0]:[4,1],padding:jf.focused?0:1};}},"window":{style:function(jg){return {contentPadding:[10,10,10,10],backgroundColor:h,decorator:jg.maximized?undefined:jg.active?gv:gg};}},"window-resize-frame":O,"window/pane":{},"window/captionbar":{style:function(jh){return {backgroundColor:jh.active?dR:g,padding:8,font:N,decorator:t};}},"window/icon":{style:function(ji){return {marginRight:4};}},"window/title":{style:function(jj){return {cursor:fJ,font:N,marginRight:20,alignY:eS};}},"window/minimize-button":{alias:fC,style:function(jk){return {icon:qx.theme.simple.Image.URLS[fP],padding:[1,2],cursor:jk.disabled?undefined:ei};}},"window/restore-button":{alias:fC,style:function(jl){return {icon:qx.theme.simple.Image.URLS[M],padding:[1,2],cursor:jl.disabled?undefined:ei};}},"window/maximize-button":{alias:fC,style:function(jm){return {icon:qx.theme.simple.Image.URLS[dU],padding:[1,2],cursor:jm.disabled?undefined:ei};}},"window/close-button":{alias:fC,style:function(jn){return {marginLeft:2,icon:qx.theme.simple.Image.URLS[dW],padding:[1,2],cursor:jn.disabled?undefined:ei};}},"window/statusbar":{style:function(jo){return {decorator:S,padding:[2,6]};}},"window/statusbar-text":eu,"datechooser":{style:function(jp){return {decorator:gj,minWidth:220};}},"datechooser/navigation-bar":{style:function(jq){return {backgroundColor:h,textColor:jq.disabled?P:jq.invalid?fg:undefined,padding:[2,10]};}},"datechooser/last-year-button-tooltip":eB,"datechooser/last-month-button-tooltip":eB,"datechooser/next-year-button-tooltip":eB,"datechooser/next-month-button-tooltip":eB,"datechooser/last-year-button":fV,"datechooser/last-month-button":fV,"datechooser/next-year-button":fV,"datechooser/next-month-button":fV,"datechooser/button/icon":{},"datechooser/button":{style:function(jr){var js={width:17,show:eN,cursor:jr.disabled?undefined:ei};if(jr.lastYear){js.icon=qx.theme.simple.Image.URLS[eO];}else if(jr.lastMonth){js.icon=qx.theme.simple.Image.URLS[c];}else if(jr.nextYear){js.icon=qx.theme.simple.Image.URLS[ek];}else if(jr.nextMonth){js.icon=qx.theme.simple.Image.URLS[eW];};return js;}},"datechooser/month-year-label":{style:function(jt){return {font:N,textAlign:fE};}},"datechooser/date-pane":{style:function(ju){return {decorator:dX,backgroundColor:h};}},"datechooser/weekday":{style:function(jv){return {decorator:d,font:N,textAlign:fE,textColor:jv.disabled?P:jv.weekend?D:h,backgroundColor:jv.weekend?h:D,paddingTop:2};}},"datechooser/day":{style:function(jw){return {textAlign:fE,decorator:jw.today?gj:undefined,textColor:jw.disabled?P:jw.selected?fs:jw.otherMonth?P:undefined,backgroundColor:jw.disabled?undefined:jw.selected?gh:undefined,padding:jw.today?[1,3]:[2,4]};}},"datechooser/week":{style:function(jx){return {textAlign:fE,textColor:D,padding:[2,4],decorator:jx.header?ea:fb};}},"progressbar":{style:function(jy){return {decorator:fA,padding:1,backgroundColor:T,width:200,height:20};}},"progressbar/progress":{style:function(jz){return {backgroundColor:jz.disabled?eK:gh};}},"toolbar":{style:function(jA){return {backgroundColor:dR,padding:0};}},"toolbar/part":{style:function(jB){return {margin:[0,15]};}},"toolbar/part/container":{},"toolbar/part/handle":{},"toolbar-separator":{style:function(jC){return {decorator:fd,margin:[7,0],width:4};}},"toolbar-button":{alias:gx,style:function(jD){var jF=L;if(jD.disabled){jF=L;}else if(jD.hovered&&!jD.pressed&&!jD.checked){jF=em;}else if(jD.hovered&&(jD.pressed||jD.checked)){jF=ew;}else if(jD.pressed||jD.checked){jF=eD;};if(jD.left){jF+=eP;}else if(jD.right){jF+=y;}else if(jD.middle){jF+=eT;};var jE=[7,10];if(jD.left||jD.middle||jD.right){jE=[7,0];};return {cursor:jD.disabled?undefined:ei,decorator:jF,margin:jE,padding:[3,5]};}},"toolbar-menubutton":{alias:fS,include:fS,style:function(jG){return {showArrow:true};}},"toolbar-menubutton/arrow":{alias:gp,include:gp,style:function(jH){return {source:qx.theme.simple.Image.URLS[H],cursor:jH.disabled?undefined:ei,padding:[0,5],marginLeft:2};}},"toolbar-splitbutton":{},"toolbar-splitbutton/button":{alias:fS,include:fS,style:function(jI){var jK=L;if(jI.disabled){jK=L;}else if(jI.hovered&&!jI.pressed&&!jI.checked){jK=em;}else if(jI.hovered&&(jI.pressed||jI.checked)){jK=ew;}else if(jI.pressed||jI.checked){jK=eD;};var jJ=[7,0,7,10];if(jI.left||jI.middle||jI.right){jJ=[7,0,7,0];};if(jI.left){jK+=eP;}else if(jI.right){jK+=eT;}else if(jI.middle){jK+=eT;}else {jK+=eP;};return {icon:qx.theme.simple.Image.URLS[H],decorator:jK,margin:jJ};}},"toolbar-splitbutton/arrow":{alias:fS,include:fS,style:function(jL){var jN=L;if(jL.disabled){jN=L;}else if(jL.hovered&&!jL.pressed&&!jL.checked){jN=em;}else if(jL.hovered&&(jL.pressed||jL.checked)){jN=ew;}else if(jL.pressed||jL.checked){jN=eD;};var jM=[7,10,7,0];if(jL.left||jL.middle||jL.right){jM=[7,0,7,0];};if(jL.left){jN+=eT;}else if(jL.right){jN+=y;}else if(jL.middle){jN+=eT;}else {jN+=y;};return {icon:qx.theme.simple.Image.URLS[H],decorator:jN,margin:jM};}},"tabview":{},"tabview/bar":{alias:o,style:function(jO){var jP=0,jS=0,jQ=0,jR=0;if(jO.barTop){jQ-=1;}else if(jO.barBottom){jP-=1;}else if(jO.barRight){jR-=1;}else {jS-=1;};return {marginBottom:jQ,marginTop:jP,marginLeft:jR,marginRight:jS};}},"tabview/bar/button-forward":{include:fj,alias:fj,style:function(jT){if(jT.barTop){return {marginTop:4,marginBottom:2,decorator:null};}else if(jT.barBottom){return {marginTop:2,marginBottom:4,decorator:null};}else if(jT.barLeft){return {marginLeft:4,marginRight:2,decorator:null};}else {return {marginLeft:2,marginRight:4,decorator:null};};}},"tabview/bar/button-backward":{include:eh,alias:eh,style:function(jU){if(jU.barTop){return {marginTop:4,marginBottom:2,decorator:null};}else if(jU.barBottom){return {marginTop:2,marginBottom:4,decorator:null};}else if(jU.barLeft){return {marginLeft:4,marginRight:2,decorator:null};}else {return {marginLeft:2,marginRight:4,decorator:null};};}},"tabview/pane":{style:function(jV){return {backgroundColor:h,decorator:gj,padding:10};}},"tabview-page":eb,"tabview-page/button":{style:function(jW){var jY;if(jW.barTop||jW.barBottom){var jX=[8,16,8,13];}else {var jX=[8,4,8,4];};if(jW.checked){if(jW.barTop){jY=fN;}else if(jW.barBottom){jY=fM;}else if(jW.barRight){jY=fI;}else if(jW.barLeft){jY=fD;};}else {for(var i=0;i<jX.length;i++ ){jX[i]+=1;};if(jW.barTop){jX[2]-=1;}else if(jW.barBottom){jX[0]-=1;}else if(jW.barRight){jX[3]-=1;}else if(jW.barLeft){jX[1]-=1;};};return {zIndex:jW.checked?10:5,decorator:jY,textColor:jW.disabled?P:jW.checked?null:eo,padding:jX,cursor:ei};}},"tabview-page/button/label":{alias:eu,style:function(ka){return {padding:[0,1,0,1]};}},"tabview-page/button/icon":gp,"tabview-page/button/close-button":{alias:gx,style:function(kb){return {cursor:kb.disabled?undefined:ei,icon:qx.theme.simple.Image.URLS[U]};}},"colorpopup":{alias:gm,include:gm,style:function(kc){return {padding:5};}},"colorpopup/field":{style:function(kd){return {margin:2,width:14,height:14,backgroundColor:h,decorator:gw};}},"colorpopup/selector-button":fC,"colorpopup/auto-button":fC,"colorpopup/preview-pane":eG,"colorpopup/current-preview":{style:function(ke){return {height:20,padding:4,marginLeft:4,decorator:gw,allowGrowX:true};}},"colorpopup/selected-preview":{style:function(kf){return {height:20,padding:4,marginRight:4,decorator:gw,allowGrowX:true};}},"colorpopup/colorselector-okbutton":{alias:fC,include:fC,style:function(kg){return {icon:k};}},"colorpopup/colorselector-cancelbutton":{alias:fC,include:fC,style:function(kh){return {icon:eH};}},"colorselector":eb,"colorselector/control-bar":eb,"colorselector/visual-pane":eG,"colorselector/control-pane":eb,"colorselector/preset-grid":eb,"colorselector/colorbucket":{style:function(ki){return {decorator:gw,width:16,height:16};}},"colorselector/preset-field-set":eG,"colorselector/input-field-set":{include:eG,alias:eG,style:function(){return {paddingTop:12};}},"colorselector/preview-field-set":{include:eG,alias:eG,style:function(){return {paddingTop:12};}},"colorselector/hex-field-composite":eb,"colorselector/hex-field":ey,"colorselector/rgb-spinner-composite":eb,"colorselector/rgb-spinner-red":ev,"colorselector/rgb-spinner-green":ev,"colorselector/rgb-spinner-blue":ev,"colorselector/hsb-spinner-composite":eb,"colorselector/hsb-spinner-hue":ev,"colorselector/hsb-spinner-saturation":ev,"colorselector/hsb-spinner-brightness":ev,"colorselector/preview-content-old":{style:function(kj){return {decorator:gw,width:50,height:25};}},"colorselector/preview-content-new":{style:function(kk){return {decorator:gw,backgroundColor:T,width:50,height:25};}},"colorselector/hue-saturation-field":{style:function(kl){return {decorator:gw,margin:5};}},"colorselector/brightness-field":{style:function(km){return {decorator:gw,margin:[5,7]};}},"colorselector/hue-saturation-pane":eb,"colorselector/hue-saturation-handle":eb,"colorselector/brightness-pane":eb,"colorselector/brightness-handle":eb,"app-header":{style:function(kn){return {font:fz,textColor:fs,backgroundColor:D,padding:[8,12]};}},"app-header-label":{style:function(ko){return {paddingTop:5};}},"app-splitpane":{alias:fi,style:function(kp){return {padding:[0,10,10,10],backgroundColor:dR};}}}});})();(function(){var a="decoration/table/select-column-order.png",b="decoration/treevirtual/end.gif",c="decoration/checkbox/checked.png",d="decoration/arrows/right.gif",e="decoration/window/maximize.gif",f="decoration/treevirtual/only_plus.gif",g="qx.theme.simple.Image",h="decoration/cursors/move.gif",i="decoration/menu/checkbox.gif",j="decoration/table/ascending.png",k="decoration/arrows/down-small.gif",l="decoration/checkbox/undetermined.png",m="decoration/splitpane/knob-vertical.png",n="decoration/arrows/forward.gif",o="decoration/arrows/up-small.gif",p="decoration/arrows/up-invert.gif",q="decoration/treevirtual/cross_plus.gif",r="decoration/window/minimize.gif",s="qx/static/blank.png",t="decoration/tree/minus.gif",u="decoration/arrows/down-invert.gif",v="decoration/arrows/right-invert.gif",w="decoration/cursors/alias.gif",x="decoration/splitpane/knob-horizontal.png",y="decoration/treevirtual/only_minus.gif",z="decoration/treevirtual/start_plus.gif",A="decoration/cursors/nodrop.gif",B="decoration/cursors/copy.gif",C="decoration/arrows/down.gif",D="decoration/treevirtual/end_plus.gif",E="decoration/treevirtual/start_minus.gif",F="decoration/treevirtual/cross.gif",G="decoration/menu/radiobutton.gif",H="decoration/treevirtual/line.gif",I="decoration/arrows/up.gif",J="decoration/tabview/close.gif",K="decoration/tree/plus.gif",L="decoration/arrows/rewind.gif",M="decoration/window/restore.gif",N="decoration/table/descending.png",O="decoration/menu/checkbox-invert.gif",P="decoration/treevirtual/cross_minus.gif",Q="decoration/treevirtual/end_minus.gif",R="decoration/arrows/left.gif",S="decoration/menu/radiobutton-invert.gif",T="decoration/window/close.gif";qx.Class.define(g,{extend:qx.core.Object,statics:{URLS:{"blank":s,"checkbox-checked":c,"checkbox-undetermined":l,"window-minimize":r,"window-maximize":e,"window-restore":M,"window-close":T,"cursor-copy":B,"cursor-move":h,"cursor-alias":w,"cursor-nodrop":A,"arrow-right":d,"arrow-left":R,"arrow-up":I,"arrow-down":C,"arrow-forward":n,"arrow-rewind":L,"arrow-down-small":k,"arrow-up-small":o,"arrow-up-invert":p,"arrow-down-invert":u,"arrow-right-invert":v,"knob-horizontal":x,"knob-vertical":m,"tree-minus":t,"tree-plus":K,"select-column-order":a,"table-ascending":j,"table-descending":N,"treevirtual-line":H,"treevirtual-minus-only":y,"treevirtual-plus-only":f,"treevirtual-minus-start":E,"treevirtual-plus-start":z,"treevirtual-minus-end":Q,"treevirtual-plus-end":D,"treevirtual-minus-cross":P,"treevirtual-plus-cross":q,"treevirtual-end":b,"treevirtual-cross":F,"menu-checkbox":i,"menu-checkbox-invert":O,"menu-radiobutton-invert":S,"menu-radiobutton":G,"tabview-close":J}}});})();(function(){var a='clui.theme.Appearance',b='pointer',c='checkbox';qx.Theme.define(a,{extend:qx.theme.simple.Appearance,appearances:{'tree-folder/checked':c,'table/column-button':{base:true,style:function(d){return {'cursor':b};}}}});})();(function(){var a="button-box-dark-pressed",b="checkbox",c="tabview-page-button-top",d="button-border",e="table-header",f="button-box-invalid",g="button-border-hovered",h="menubar-button-hovered",i="button-box-dark",j="#999999",k="button-box-hovered-focused",l="solid",m="qx/decoration/Simple",n="dotted",o="border-separator",p="shadow",q="window-border",r="tooltip-text",s="button-box-hovered",t="table-focus-indicator",u="button-box-pressed-invalid",v="dark-blue",w="scrollbar-dark",x="radiobutton",y="scroll-knob",z="qx.theme.simple.Decoration",A="button-box-focused",B="table-header-cell",C="button",D="scroll-knob-pressed",E="border-lead",F="button-box-pressed-hovered",G="border-main",H="#FFF",I="button-box-pressed-focused",J="invalid",K="button-box",L="background",M="scrollbar-bright",N="button-box-bright",O="window-border-inner",P="border-light-shadow",Q="white-box-border",R="background-selected",S="window",T="white",U="gray",V="border-light",W="button-box-bright-pressed",X="button-box-pressed-hovered-focused",Y="button-box-pressed";qx.Theme.define(z,{aliases:{decoration:m},decorations:{"border-blue":{style:{width:4,color:R}},"main":{style:{width:1,color:G}},"main-dark":{style:{width:1,color:d}},"popup":{style:{width:1,color:q,shadowLength:2,shadowBlurRadius:5,shadowColor:p}},"dragover":{style:{bottom:[2,l,v]}},"button-box":{style:{radius:3,width:1,color:d,gradientStart:[N,40],gradientEnd:[i,70],backgroundColor:N}},"button-box-pressed":{include:K,style:{gradientStart:[W,40],gradientEnd:[a,70],backgroundColor:W}},"button-box-pressed-hovered":{include:Y,style:{color:g}},"button-box-hovered":{include:K,style:{color:g}},"button-box-invalid":{include:K,style:{color:J}},"button-box-pressed-invalid":{include:Y,style:{color:J}},"button-box-hovered-invalid":{include:f},"button-box-pressed-hovered-invalid":{include:u},"button-box-focused":{include:K,style:{color:R}},"button-box-pressed-focused":{include:Y,style:{color:R}},"button-box-hovered-focused":{include:A},"button-box-pressed-hovered-focused":{include:I},"button-box-right":{include:K,style:{radius:[0,3,3,0]}},"button-box-pressed-right":{include:Y,style:{radius:[0,3,3,0]}},"button-box-pressed-hovered-right":{include:F,style:{radius:[0,3,3,0]}},"button-box-hovered-right":{include:s,style:{radius:[0,3,3,0]}},"button-box-focused-right":{include:A,style:{radius:[0,3,3,0]}},"button-box-hovered-focused-right":{include:k,style:{radius:[0,3,3,0]}},"button-box-pressed-focused-right":{include:I,style:{radius:[0,3,3,0]}},"button-box-pressed-hovered-focused-right":{include:X,style:{radius:[0,3,3,0]}},"button-box-right-borderless":{include:K,style:{radius:[0,3,3,0],width:[1,1,1,0]}},"button-box-pressed-right-borderless":{include:Y,style:{radius:[0,3,3,0],width:[1,1,1,0]}},"button-box-pressed-hovered-right-borderless":{include:F,style:{radius:[0,3,3,0],width:[1,1,1,0]}},"button-box-hovered-right-borderless":{include:s,style:{radius:[0,3,3,0],width:[1,1,1,0]}},"button-box-top-right":{include:K,style:{radius:[0,3,0,0],width:[1,1,1,0]}},"button-box-pressed-top-right":{include:Y,style:{radius:[0,3,0,0],width:[1,1,1,0]}},"button-box-pressed-hovered-top-right":{include:F,style:{radius:[0,3,0,0],width:[1,1,1,0]}},"button-box-hovered-top-right":{include:s,style:{radius:[0,3,0,0],width:[1,1,1,0]}},"button-box-bottom-right":{include:K,style:{radius:[0,0,3,0],width:[0,1,1,0]}},"button-box-pressed-bottom-right":{include:Y,style:{radius:[0,0,3,0],width:[0,1,1,0]}},"button-box-pressed-hovered-bottom-right":{include:F,style:{radius:[0,0,3,0],width:[0,1,1,0]}},"button-box-hovered-bottom-right":{include:s,style:{radius:[0,0,3,0],width:[0,1,1,0]}},"button-box-bottom-left":{include:K,style:{radius:[0,0,0,3],width:[0,0,1,1]}},"button-box-pressed-bottom-left":{include:Y,style:{radius:[0,0,0,3],width:[0,0,1,1]}},"button-box-pressed-hovered-bottom-left":{include:F,style:{radius:[0,0,0,3],width:[0,0,1,1]}},"button-box-hovered-bottom-left":{include:s,style:{radius:[0,0,0,3],width:[0,0,1,1]}},"button-box-top-left":{include:K,style:{radius:[3,0,0,0],width:[1,0,0,1]}},"button-box-pressed-top-left":{include:Y,style:{radius:[3,0,0,0],width:[1,0,0,1]}},"button-box-pressed-hovered-top-left":{include:F,style:{radius:[3,0,0,0],width:[1,0,0,1]}},"button-box-hovered-top-left":{include:s,style:{radius:[3,0,0,0],width:[1,0,0,1]}},"button-box-middle":{include:K,style:{radius:0,width:[1,0,1,1]}},"button-box-pressed-middle":{include:Y,style:{radius:0,width:[1,0,1,1]}},"button-box-pressed-hovered-middle":{include:F,style:{radius:0,width:[1,0,1,1]}},"button-box-hovered-middle":{include:s,style:{radius:0,width:[1,0,1,1]}},"button-box-left":{include:K,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-pressed-left":{include:Y,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-pressed-hovered-left":{include:F,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-hovered-left":{include:s,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-focused-left":{include:A,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-hovered-focused-left":{include:k,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-pressed-hovered-focused-left":{include:X,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"button-box-pressed-focused-left":{include:I,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"separator-horizontal":{style:{widthLeft:1,colorLeft:o}},"separator-vertical":{style:{widthTop:1,colorTop:o}},"scroll-knob":{style:{radius:3,width:1,color:d,backgroundColor:M}},"scroll-knob-pressed":{include:y,style:{backgroundColor:w}},"scroll-knob-hovered":{include:y,style:{color:g}},"scroll-knob-pressed-hovered":{include:D,style:{color:g}},"button-hover":{style:{backgroundColor:C,radius:3}},"window":{style:{width:1,color:q,innerWidth:4,innerColor:O,shadowLength:1,shadowBlurRadius:3,shadowColor:p,backgroundColor:L}},"window-active":{include:S,style:{shadowLength:2,shadowBlurRadius:5}},"window-caption":{style:{width:[0,0,2,0],color:O}},"white-box":{style:{width:1,color:Q,shadowBlurRadius:2,shadowColor:j,radius:7,backgroundColor:T,shadowLength:0}},"inset":{style:{width:1,color:[P,V,V,V]}},"focused-inset":{style:{width:2,color:R}},"border-invalid":{style:{width:2,color:J}},"lead-item":{style:{width:1,style:n,color:E}},"tooltip":{style:{width:1,color:r,shadowLength:1,shadowBlurRadius:2,shadowColor:p}},"tooltip-error":{style:{radius:5,backgroundColor:J}},"toolbar-separator":{style:{widthLeft:1,colorLeft:d}},"menu-separator":{style:{widthTop:1,colorTop:R}},"menubar-button-hovered":{style:{width:1,color:G,radius:3,backgroundColor:T}},"menubar-button-pressed":{include:h,style:{radius:[3,3,0,0],width:[1,1,0,1]}},"datechooser-date-pane":{style:{widthTop:1,colorTop:U,style:l}},"datechooser-weekday":{style:{widthBottom:1,colorBottom:U,style:l}},"datechooser-week":{style:{widthRight:1,colorRight:U,style:l}},"datechooser-week-header":{style:{widthBottom:1,colorBottom:U,widthRight:1,colorRight:U,style:l}},"tabview-page-button-top":{style:{width:[1,1,0,1],backgroundColor:L,color:G,radius:[3,3,0,0]}},"tabview-page-button-bottom":{include:c,style:{radius:[0,0,3,3],width:[0,1,1,1]}},"tabview-page-button-left":{include:c,style:{radius:[3,0,0,3],width:[1,0,1,1]}},"tabview-page-button-right":{include:c,style:{radius:[0,3,3,0],width:[1,1,1,0]}},"statusbar":{style:{widthTop:1,colorTop:R,styleTop:l}},"table-scroller-focus-indicator":{style:{width:2,color:t,style:l}},"table-header":{include:K,style:{radius:0,width:[1,0,1,0]}},"table-header-column-button":{include:e,style:{width:1,color:d}},"table-header-cell":{style:{widthRight:1,color:d}},"table-header-cell-first":{include:B,style:{widthLeft:1}},"progressive-table-header":{include:K,style:{radius:0,width:[1,0,1,1]}},"progressive-table-header-cell":{style:{widthRight:1,color:d}},"progressbar":{style:{backgroundColor:H,width:1,color:o}},"radiobutton":{style:{radius:10,width:1,color:d,innerColor:L,innerWidth:2}},"radiobutton-focused":{include:x,style:{color:R}},"radiobutton-invalid":{include:x,style:{color:J}},"checkbox":{style:{width:1,color:d}},"checkbox-focused":{include:b,style:{color:R}},"checkbox-invalid":{include:b,style:{color:J}}}});})();(function(){var a="Tango",b="qx/icon/Tango",c="qx.theme.icon.Tango";qx.Theme.define(c,{title:a,aliases:{"icon":b}});})();(function(){var a="sans-serif",b="monospace",c="Courier New",d="qx.theme.simple.Font",e="arial",f="DejaVu Sans Mono";qx.Theme.define(d,{fonts:{"default":{size:13,family:[e,a]},"bold":{size:13,family:[e,a],bold:true},"headline":{size:24,family:[a,e]},"small":{size:11,family:[e,a]},"monospace":{size:11,family:[f,c,b]}}});})();(function(){var a="#D9D9D9",b="#1866B5",c="#24B",d="#FF0000",e="#CCCCCC",f="#5685D6",g="rgba(0, 0, 0, 0.4)",h="#FFFFE1",i="#B7B7B7",j="#BBBBBB",k="black",l="#9DCBFE",m="#A7A6AA",n="#EBEBEB",o="#666666",p="#CBC8CD",q="#F9F9F9",r="#CDCDCD",s="#808080",t="#F7F7F7",u="#6694E3",v="#686868",w="white",x="#888888",y="#E0ECFF",z="#2E3A46",A="css.rgba",B="#F5F5F5",C="#EEE",D="#E3E3E3",E="#DDDDDD",F="#BBB",G="qx.theme.simple.Color",H="#F1F1F1",I="#939393",J="#BCBCBC",K="#134983",L="gray",M="#E8F0E3",N="#FAFBFE",O="#AAAAAA";qx.Theme.define(G,{colors:{"background":w,"dark-blue":f,"light-background":y,"background-selected":u,"background-selected-disabled":r,"background-selected-dark":f,"background-disabled":t,"background-disabled-checked":j,"background-pane":N,"tabview-unselected":b,"tabview-button-border":K,"tabview-label-active-disabled":a,"link":c,"scrollbar-bright":H,"scrollbar-dark":n,"button":M,"button-border":F,"button-border-hovered":I,"invalid":d,"button-box-bright":q,"button-box-dark":D,"button-box-bright-pressed":E,"button-box-dark-pressed":B,"border-lead":x,"window-border":z,"window-border-inner":l,"white-box-border":J,"shadow":qx.core.Environment.get(A)?g:o,"border-main":u,"border-light":i,"border-light-shadow":v,"border-separator":s,"text":k,"text-disabled":m,"text-selected":w,"text-placeholder":p,"tooltip":h,"tooltip-text":k,"table-header":[242,242,242],"table-focus-indicator":[179,217,255],"table-header-cell":[235,234,219],"table-row-background-focused-selected":[90,138,211],"table-row-background-focused":[221,238,255],"table-row-background-selected":[51,94,168],"table-row-background-even":w,"table-row-background-odd":w,"table-row-selected":[255,255,255],"table-row":[0,0,0],"table-row-line":C,"table-column-line":C,"progressive-table-header":O,"progressive-table-row-background-even":[250,248,243],"progressive-table-row-background-odd":[255,255,255],"progressive-progressbar-background":L,"progressive-progressbar-indicator-done":e,"progressive-progressbar-indicator-undone":w,"progressive-progressbar-percent-background":L,"progressive-progressbar-percent-text":w}});})();(function(){var a='clui.theme.Theme',b='Chronologer';qx.Theme.define(a,{title:b,meta:{color:qx.theme.simple.Color,decoration:qx.theme.simple.Decoration,font:qx.theme.simple.Font,icon:qx.theme.icon.Tango,appearance:clui.theme.Appearance}});})();

qx.$$loader.init();

